%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v20.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         12 - July - 2020                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE1354PEGASE  Power flow data for medium part of European system.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of part of the
%   European high voltage transmission network. The network contains 1,354
%   buses, 260 generators, and 1,991 branches and it operates at 380 and
%   220 kV. Please note that the data are fictitious and do not correspond
%   to real world data. They can thus be used to validate methods and tools
%   but should not be used for operation and planning of the European grid.
%
%   The data stems from the Pan European Grid Advanced Simulation and State
%   Estimation (PEGASE) project, part of the 7th Framework Program of the
%   European Union (http://www.fp7-pegase.com/). When publishing results
%   based on this data, please cite:
%
%     S. Fliscounakis, P. Panciatici, F. Capitanescu, and L. Wehenkel,
%     "Contingency ranking with respect to overloads in very large power
%     systems taking into account uncertainty, preventive and corrective
%     actions", Power Systems, IEEE Trans. on, (28)4:4909-4917, 2013.
%     http://dx.doi.org/10.1109/TPWRS.2013.2251015
%
%   Remarks:
%
%   1. Line flow limits are 100 MVA (at 1 p.u. voltage) lower than the
%   current flow limits found in PEGASE data.
%
%   2. PEGASE data contains asymmetric shunt conductance and susceptance in
%   the PI transmission line model of branches. Thus total line charging
%   susceptance of branches is set to 0 p.u. and the nodal representation
%   of shunt condutance and susceptance is used. As a result, power flow
%   equations are left unchanged compared with original PEGASE data.
%   However, line flow constraints in the optimal flow problem are
%   modified.
%
%   3. Identical linear costs are used for all generators to form a loss
%   minimizing OPF objective function.
%
%   4. Since some parts of the network are aggregated, some generators
%   (e.g. with negative PMIN) represent aggregations of multiple loads
%   and generators.
%
%   Cédric Josz, Stéphane Fliscounakis, Jean Maeght, Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Réseau de Transport d'Electricité (French Transmission System Operator)
%   Département Expertise Système, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 18th, 2015
%
%   Copyright (c) 2015 by Cédric Josz, Stéphane Fliscounakis, Jean Maeght,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case1354_pegase
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	3	 1	 151.0	 48.8	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4	 1	 171.41	 23.4	 0.0	 2.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10	 1	 134.0	 24.7	 0.0	 12.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	21	 1	 161.2	 39.3	 0.0	 30.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	22	 1	 0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	26	 1	 167.3	 54.8	 0.0	 110.54	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	29	 1	 152.9	 49.4	 0.0	 27.65	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	44	 1	 -0.0	 0.0	 0.0	 7.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	53	 1	 48.65	 16.1	 0.0	 7.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	58	 1	 0.0	 0.0	 0.0	 2.31	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	59	 1	 119.2	 20.7	 0.0	 3.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	90	 1	 363.25	 115.39	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	96	 1	 -8.4	 28.66	 0.0	 3.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	113	 1	 -0.0	 -0.0	 0.0	 6.532711	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	115	 1	 0.0	 -0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	118	 1	 704.53	 -35.33	 0.0	 13.102834	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	124	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	128	 1	 23.73	 12.7	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	145	 1	 38.34	 5.6	 0.0	 7.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	148	 1	 32.34	 12.0	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	163	 1	 147.76	 32.73	 0.0	 8.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	171	 1	 100.8	 13.2	 0.0	 5.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	174	 1	 370.5	 -17.0	 0.0	 9.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	184	 1	 -0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	188	 1	 36.84	 13.9	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	195	 1	 73.14	 21.55	 0.0	 8.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	196	 1	 0.0	 -0.0	 0.0	 12.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	198	 1	 39.74	 11.8	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	207	 1	 321.98	 84.4	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	216	 1	 155.6	 54.7	 0.0	 2.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	217	 1	 105.2	 0.1	 0.0	 7.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	218	 1	 69.83	 15.12	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	221	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	225	 1	 0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	280	 1	 119.6	 29.6	 0.0	 5.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	283	 1	 27.33	 11.9	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	292	 1	 13.82	 1.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	305	 1	 103.0	 12.0	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	306	 1	 -0.0	 0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	314	 1	 163.1	 46.3	 0.0	 10.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	333	 1	 524.5	 43.0	 0.0	 6.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	346	 1	 197.5	 48.3	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	350	 1	 110.4	 26.2	 0.0	 5.62	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	367	 1	 65.17	 -51.5	 0.0	 4.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	401	 1	 56.5	 36.29	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	408	 1	 129.1	 7.4	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	410	 1	 170.89	 50.38	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	413	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	416	 1	 70.68	 13.5	 0.0	 6.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	426	 1	 123.1	 6.5	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	432	 1	 -0.0	 -0.0	 0.0	 68.517663	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	444	 1	 0.0	 -0.0	 0.0	 2.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	449	 1	 0.0	 0.0	 0.0	 29.42	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	453	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	455	 1	 274.32	 5.66	 0.0	 13.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	490	 1	 20.52	 4.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	500	 1	 144.4	 35.5	 0.0	 7.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	502	 1	 -0.0	 0.0	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	506	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	513	 1	 57.46	 17.1	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	520	 1	 118.5	 20.4	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	549	 1	 0.0	 -0.0	 0.0	 5.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	554	 1	 0.0	 -0.0	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	556	 1	 16.52	 9.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	561	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	575	 1	 0.0	 -0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	583	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	594	 1	 67.57	 17.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	601	 1	 140.6	 42.6	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	604	 1	 33.24	 4.4	 0.0	 24.54	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	608	 1	 150.9	 10.4	 0.0	 4.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	609	 1	 -0.0	 -0.0	 0.0	 5.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	615	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	616	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	619	 1	 72.88	 14.4	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	639	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	641	 1	 45.32	 18.5	 0.0	 0.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	658	 1	 258.4	 66.7	 0.0	 5.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	661	 1	 -0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	666	 1	 -5.61	 -2.79	 0.0	 150.93	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	678	 1	 232.1	 89.8	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	682	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	687	 1	 -0.0	 0.0	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	707	 1	 83.99	 21.2	 0.0	 5.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	718	 1	 135.11	 41.0	 0.0	 5.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	720	 1	 -0.0	 -0.0	 0.0	 23.554121	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	726	 1	 400.3	 189.9	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	742	 1	 0.0	 -0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	747	 1	 69.58	 16.0	 0.0	 3.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	749	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	750	 1	 -0.0	 -0.0	 0.0	 18.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	766	 1	 -0.0	 0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	769	 1	 152.57	 40.0	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	772	 1	 343.9	 141.9	 0.0	 5.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	778	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	789	 1	 -0.0	 -0.0	 0.0	 6.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	795	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	800	 1	 50.56	 18.0	 0.0	 0.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	803	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	804	 1	 -0.0	 -0.0	 0.0	 7.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	805	 1	 124.5	 29.6	 0.0	 15.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	809	 1	 0.0	 -0.0	 0.0	 58.088687	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	819	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	839	 1	 -0.0	 -0.0	 0.0	 8.17514	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	870	 1	 110.0	 3.4	 0.0	 11.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	871	 1	 108.89	 -21.76	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	883	 1	 192.5	 78.3	 0.0	 6.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	891	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	892	 1	 -0.0	 -0.0	 0.0	 9.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	900	 1	 0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	903	 1	 82.69	 20.1	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	905	 1	 631.71	 -54.16	 0.0	 7.534129	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	907	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	908	 1	 125.9	 -0.5	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	920	 1	 34.44	 8.5	 0.0	 1.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	923	 1	 62.07	 14.7	 0.0	 4.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	933	 1	 -0.0	 0.0	 0.0	 22.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	935	 1	 -0.0	 0.0	 0.0	 9.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	953	 1	 108.7	 -12.15	 0.0	 37.11	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	954	 1	 66.27	 13.6	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	960	 1	 -0.0	 -0.0	 0.0	 108.728602	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	964	 1	 88.5	 16.5	 0.0	 146.44	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	972	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	980	 1	 14.71	 4.6	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1002	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1005	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1015	 1	 44.55	 0.0	 0.0	 4.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1026	 1	 201.4	 53.0	 0.0	 9.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1027	 1	 -5.91	 -2.33	 0.0	 30.393595	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1033	 1	 26.33	 5.3	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1035	 1	 382.5	 57.9	 0.0	 8.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1039	 1	 34.64	 -0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1040	 1	 31.94	 8.8	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1051	 1	 -0.0	 0.0	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1077	 1	 -0.0	 0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1078	 1	 -0.0	 -0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1081	 1	 277.86	 58.95	 0.0	 182.880644	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1083	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1090	 1	 56.06	 18.7	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1096	 1	 0.0	 -0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1100	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1101	 1	 -0.0	 -0.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1105	 1	 29.83	 7.3	 0.0	 6.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1111	 1	 0.0	 0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1129	 1	 190.47	 55.03	 0.0	 6.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1136	 1	 16.22	 2.0	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1137	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1146	 1	 32.84	 -0.0	 0.0	 1.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1151	 1	 -0.0	 -0.0	 0.0	 18.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1153	 1	 12.41	 3.9	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1156	 1	 65.67	 24.0	 0.0	 9.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1159	 1	 112.4	 13.0	 0.0	 3.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1172	 1	 -0.0	 -0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1179	 1	 86.6	 23.4	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1183	 1	 199.4	 -19.9	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1187	 1	 67.57	 21.2	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1188	 1	 30.93	 6.6	 0.0	 9.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1194	 1	 129.6	 13.3	 0.0	 13.98	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1198	 1	 0.0	 0.0	 0.0	 30.637696	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1201	 1	 114.1	 23.5	 0.0	 1.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1216	 1	 0.0	 0.0	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1233	 1	 0.0	 -0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1234	 1	 71.78	 17.9	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	1248	 1	 0.0	 0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1249	 1	 348.93	 26.47	 0.0	 9.36	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1251	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1262	 1	 -0.0	 0.0	 0.0	 10.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1265	 1	 173.0	 -21.3	 0.0	 5.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1275	 1	 52.46	 2.9	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1295	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1301	 1	 479.0	 99.2	 0.0	 10.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1305	 1	 -0.0	 -0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1311	 1	 37.94	 15.2	 0.0	 35.31	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1326	 1	 0.0	 0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1334	 1	 0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1341	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1343	 1	 -0.0	 -0.0	 0.0	 58.3	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1355	 1	 -3.29	 -1.32	 0.0	 190.704588	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1364	 1	 40.85	 14.5	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1380	 1	 145.2	 21.4	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1394	 1	 30.93	 7.6	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1397	 1	 0.0	 -0.0	 0.0	 2.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1398	 1	 196.7	 44.2	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1401	 1	 11.91	 2.9	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1414	 1	 144.7	 20.3	 0.0	 6.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1415	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1435	 1	 -0.0	 0.0	 0.0	 3.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1448	 1	 0.0	 0.0	 0.0	 9.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1459	 1	 -0.0	 -0.0	 0.0	 3.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1462	 1	 -0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1465	 1	 -11.03	 -5.11	 0.0	 29.706803	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1478	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1483	 1	 0.0	 0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1486	 1	 79.59	 18.8	 0.0	 6.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1494	 1	 -1.85	 -1.63	 0.0	 31.424588	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1502	 1	 -0.0	 0.0	 0.0	 37.116157	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1504	 1	 0.0	 -0.0	 0.0	 1.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1526	 1	 -10.86	 -5.93	 0.0	 12.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1538	 1	 36.34	 15.2	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1539	 1	 73.58	 3.24	 0.0	 52.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1541	 1	 125.4	 45.8	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1545	 1	 42.55	 8.2	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1547	 1	 -0.0	 -0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1551	 1	 -0.0	 -0.0	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1552	 1	 20.42	 8.1	 0.0	 35.15	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1554	 1	 0.0	 -0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1556	 1	 -0.0	 -0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1562	 1	 77.39	 24.1	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1566	 1	 156.9	 -4.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1568	 1	 69.08	 21.5	 0.0	 1.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1578	 1	 0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1584	 1	 0.0	 -0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1592	 1	 28.33	 44.8	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1595	 1	 71.77	 13.57	 0.0	 3.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1604	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1605	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1607	 1	 73.78	 -0.0	 0.0	 2.69	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1609	 1	 0.0	 0.0	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1625	 1	 73.18	 22.3	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1629	 1	 41.95	 8.5	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1643	 1	 95.71	 25.9	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1644	 1	 449.56	 245.72	 0.0	 94.55	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1662	 1	 3.67	 -1.86	 0.0	 3.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1672	 1	 -28.13	 -0.83	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1680	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1692	 1	 83.19	 25.8	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1704	 1	 62.16	 8.0	 0.0	 2.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1708	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1709	 1	 -15.38	 -4.94	 0.0	 33.241519	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1711	 1	 25.13	 -61.6	 0.0	 3.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1730	 1	 -17.18	 -4.35	 0.0	 44.419365	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1742	 1	 0.0	 0.0	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1746	 1	 -0.0	 0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1750	 1	 58.46	 6.6	 0.0	 10.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1754	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1758	 1	 0.0	 -0.0	 0.0	 121.29	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1763	 1	 -0.0	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1767	 1	 333.5	 -1.4	 0.0	 8.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1768	 1	 73.98	 22.5	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1775	 1	 -0.0	 0.0	 0.0	 1.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1794	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1798	 1	 -0.63	 -0.83	 0.0	 22.810288	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1803	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1813	 1	 88.92	 19.79	 0.0	 2.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1817	 1	 108.91	 33.7	 0.0	 56.24	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1833	 1	 0.0	 0.0	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1838	 1	 0.0	 -0.0	 0.0	 3.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1844	 1	 -28.14	 -0.76	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1857	 1	 0.0	 0.0	 0.0	 1.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1860	 1	 88.8	 -3.2	 0.0	 13.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1866	 1	 209.2	 23.5	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1868	 1	 11.71	 3.8	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1876	 1	 -0.0	 -0.0	 0.0	 6.273568	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1883	 1	 27.33	 5.0	 0.0	 6.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1895	 1	 20.82	 -0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1896	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1910	 1	 -0.0	 0.0	 0.0	 2.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1917	 1	 197.5	 -31.0	 0.0	 17.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1923	 1	 192.11	 45.5	 0.0	 68.04	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1940	 1	 0.0	 0.0	 0.0	 1.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1959	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1965	 1	 248.7	 8.1	 0.0	 12.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1973	 1	 210.1	 66.2	 0.0	 59.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1979	 1	 0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1980	 1	 177.3	 36.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1998	 1	 25.73	 7.3	 0.0	 2.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2012	 1	 41.45	 4.9	 0.0	 18.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2019	 1	 72.08	 21.3	 0.0	 7.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2020	 1	 0.0	 0.0	 0.0	 9.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2021	 1	 3.9	 1.0	 0.0	 3.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2035	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2042	 1	 14.02	 6.5	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2043	 1	 3.2	 1.7	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2044	 1	 0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2050	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2056	 1	 -0.0	 0.0	 0.0	 7.338808	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2057	 1	 120.2	 20.5	 0.0	 19.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2072	 1	 101.2	 2.1	 0.0	 38.43	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2078	 1	 77.19	 18.6	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2079	 1	 0.0	 -0.0	 0.0	 13.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2083	 1	 121.4	 20.2	 0.0	 16.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2088	 1	 -0.0	 0.0	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2089	 1	 199.86	 56.93	 0.0	 46.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2093	 1	 -5.64	 -2.84	 0.0	 34.582195	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2101	 1	 -0.0	 -0.0	 0.0	 38.32	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2128	 1	 79.09	 18.7	 0.0	 10.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2129	 1	 0.0	 0.0	 0.0	 56.686515	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2132	 1	 107.3	 14.2	 0.0	 20.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2142	 1	 0.0	 -0.0	 0.0	 7.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2155	 1	 63.67	 20.2	 0.0	 6.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2161	 1	 35.66	 -9.39	 0.0	 7.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2166	 1	 20.92	 7.7	 0.0	 1.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2174	 1	 0.0	 0.0	 0.0	 61.795782	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2177	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2183	 1	 0.0	 0.0	 0.0	 32.849821	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2189	 1	 -0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2208	 1	 74.98	 26.9	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2229	 1	 0.0	 -0.0	 0.0	 2.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2230	 1	 0.0	 -0.0	 0.0	 1.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2231	 1	 0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2242	 1	 -0.0	 -0.0	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2252	 1	 100.7	 -4.2	 0.0	 1.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2273	 1	 141.3	 32.4	 0.0	 7.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2276	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2286	 1	 208.88	 60.8	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2288	 1	 170.9	 39.0	 0.0	 11.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2303	 1	 0.0	 -0.0	 0.0	 7.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2304	 1	 88.7	 -0.1	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2308	 1	 32.04	 6.6	 0.0	 0.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2313	 1	 0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2319	 1	 39.64	 20.9	 0.0	 0.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2327	 1	 114.5	 25.2	 0.0	 17.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2328	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2337	 1	 103.4	 27.0	 0.0	 1.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2340	 1	 96.91	 13.9	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2341	 1	 -0.0	 0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2360	 1	 215.5	 31.3	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2361	 1	 16.9	 3.85	 0.0	 25.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2365	 1	 37.94	 15.4	 0.0	 117.386167	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2372	 1	 0.0	 -0.0	 0.0	 14.490904	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2377	 1	 101.7	 17.6	 0.0	 13.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2393	 1	 20.82	 0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2406	 1	 0.0	 0.0	 0.0	 1.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2421	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2424	 1	 44.55	 16.8	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2425	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2426	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2430	 1	 -0.0	 0.0	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2432	 1	 291.2	 35.4	 0.0	 21.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2438	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2446	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2457	 1	 30.73	 9.6	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2458	 1	 132.0	 26.0	 0.0	 27.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2467	 1	 0.0	 -0.0	 0.0	 11.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2468	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2475	 1	 0.0	 0.0	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2479	 1	 -2.65	 -1.17	 0.0	 65.673108	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2503	 1	 -0.0	 0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2510	 1	 115.87	 29.41	 0.0	 7.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2518	 1	 -5.29	 -1.91	 0.0	 42.622979	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2526	 1	 238.45	 46.86	 0.0	 125.534496	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2527	 1	 59.77	 16.7	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2535	 1	 51.56	 2.1	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2550	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2558	 1	 159.27	 38.31	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2563	 1	 52.86	 13.0	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2575	 1	 62.97	 17.4	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2591	 1	 253.77	 84.6	 0.0	 20.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2597	 1	 14.72	 5.4	 0.0	 0.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2598	 1	 25.63	 12.7	 0.0	 8.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2600	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2629	 1	 203.1	 65.2	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2641	 1	 0.0	 0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2644	 1	 0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2653	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2654	 1	 207.1	 50.4	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2656	 1	 -0.72	 0.0	 0.0	 69.582294	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2676	 1	 123.24	 23.65	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2689	 1	 0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2695	 1	 16.22	 8.9	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2702	 1	 151.7	 27.6	 0.0	 6.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2719	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2721	 1	 -0.0	 0.0	 0.0	 10.040547	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2732	 1	 85.59	 20.72	 0.0	 142.79	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2749	 1	 55.56	 26.5	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2751	 1	 34.54	 8.6	 0.0	 5.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2754	 1	 -0.0	 0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2770	 1	 85.39	 14.3	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2782	 1	 -28.13	 -0.81	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	2794	 1	 0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2795	 1	 -0.0	 -0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2799	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2801	 1	 0.0	 -0.0	 0.0	 12.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2806	 1	 -0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2815	 1	 25.33	 14.2	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2841	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2847	 1	 40.14	 8.8	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2848	 1	 453.23	 139.16	 0.0	 25.583218	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2850	 1	 -0.0	 -0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2854	 1	 -12.33	 -2.65	 0.0	 69.323028	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2863	 1	 37.73	 13.84	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2866	 1	 -0.0	 0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2872	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2877	 1	 29.93	 -0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2878	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2886	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2888	 1	 -0.0	 0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2889	 1	 -0.0	 0.0	 0.0	 3.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2898	 1	 56.76	 13.4	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2910	 1	 -0.0	 0.0	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2918	 1	 0.0	 0.0	 0.0	 53.25003	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2919	 1	 -0.0	 0.0	 0.0	 32.049116	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2924	 1	 19.92	 7.4	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2928	 1	 0.0	 -0.0	 0.0	 92.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2931	 1	 230.7	 19.3	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2938	 1	 0.0	 -0.0	 0.0	 137.29	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2940	 1	 103.0	 28.7	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2949	 1	 -0.0	 -0.0	 0.0	 11.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2961	 1	 159.9	 53.2	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2967	 1	 0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2968	 1	 112.51	 16.51	 0.0	 1.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2972	 1	 97.82	 20.59	 0.0	 6.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2980	 1	 -0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2981	 1	 -0.0	 0.0	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2985	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2995	 1	 0.0	 -0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3013	 1	 2.2	 1.1	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3018	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3019	 1	 0.0	 -0.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3021	 1	 74.38	 8.8	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3022	 1	 149.0	 19.8	 0.0	 23.89	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3028	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3036	 1	 116.93	 33.6	 0.0	 3.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3037	 1	 221.0	 146.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3044	 1	 29.33	 5.6	 0.0	 6.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3051	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3069	 1	 89.6	 22.7	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3070	 1	 0.0	 -0.0	 0.0	 4.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3071	 1	 0.0	 -0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3072	 1	 92.9	 27.7	 0.0	 5.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3075	 1	 30.33	 10.5	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3082	 1	 0.0	 0.0	 0.0	 75.076038	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3083	 1	 567.97	 130.73	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3085	 1	 64.67	 24.5	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3112	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3114	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3121	 1	 242.16	 73.64	 0.0	 12.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3126	 1	 104.78	 20.92	 0.0	 6.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3137	 1	 0.0	 -0.0	 0.0	 0.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3145	 1	 860.95	 -182.67	 0.0	 18.309116	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3166	 1	 184.91	 32.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3184	 1	 14.12	 7.7	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3187	 1	 107.0	 34.7	 0.0	 1.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3191	 1	 127.8	 15.2	 0.0	 9.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3200	 1	 86.2	 19.9	 0.0	 5.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3204	 1	 8.51	 3.2	 0.0	 0.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3205	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3221	 1	 76.38	 24.8	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3231	 1	 251.3	 42.6	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3239	 1	 -5.06	 -1.84	 0.0	 187.327025	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3240	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3241	 1	 132.0	 27.0	 0.0	 4.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3243	 1	 -0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3246	 1	 20.9	 -171.5	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3248	 1	 84.19	 17.3	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3255	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3276	 1	 -0.0	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3293	 1	 33.14	 11.6	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3306	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3325	 1	 -0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3327	 1	 -0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3331	 1	 -0.0	 -0.0	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3344	 1	 83.29	 24.1	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3346	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3353	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3364	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3377	 1	 77.49	 21.4	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3390	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3391	 1	 302.5	 65.1	 0.0	 8.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3400	 1	 0.0	 0.0	 0.0	 17.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3401	 1	 23.22	 6.3	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3412	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3430	 1	 125.1	 44.0	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3435	 1	 -0.0	 0.0	 0.0	 10.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3445	 1	 45.14	 -6.64	 0.0	 88.82001	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3450	 1	 78.99	 16.2	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3481	 1	 142.5	 23.6	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3483	 1	 157.78	 276.03	 0.0	 91.192543	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3485	 1	 -0.0	 0.0	 0.0	 6.501668	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3486	 1	 101.5	 -18.3	 0.0	 8.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3488	 1	 55.66	 4.5	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3492	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3496	 1	 99.3	 23.3	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3498	 1	 138.5	 19.3	 0.0	 5.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3499	 1	 180.4	 71.6	 0.0	 81.042938	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3502	 1	 98.2	 19.1	 0.0	 10.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3503	 1	 -0.0	 0.0	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3513	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3519	 1	 -0.0	 0.0	 0.0	 68.053762	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3520	 1	 -0.0	 0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3526	 1	 33.34	 13.2	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3535	 1	 -0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3541	 1	 0.0	 -0.0	 0.0	 3.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3543	 1	 -0.0	 -0.0	 0.0	 14.079026	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3545	 1	 20.12	 7.6	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3557	 1	 87.2	 31.8	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3558	 1	 -0.0	 0.0	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3565	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3577	 1	 -38.7	 -12.99	 0.0	 13.47383	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3579	 1	 277.72	 7.35	 0.0	 3.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3580	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3589	 1	 37.54	 18.3	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3594	 1	 31.43	 6.6	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3601	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3602	 1	 86.6	 14.9	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3608	 1	 0.0	 -0.0	 0.0	 58.146813	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3609	 1	 -28.13	 -0.82	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3610	 1	 185.8	 31.8	 0.0	 3.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3613	 1	 152.5	 14.4	 0.0	 24.61	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3643	 1	 24.23	 6.4	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3645	 1	 42.55	 17.6	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3649	 1	 -0.0	 -0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3654	 1	 20.72	 5.0	 0.0	 6.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3657	 1	 131.0	 1.3	 0.0	 120.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3670	 1	 28.03	 6.5	 0.0	 6.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3672	 1	 82.99	 25.9	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3674	 1	 155.05	 39.56	 0.0	 6.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3680	 1	 -0.0	 -0.0	 0.0	 12.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3697	 1	 -32.71	 -13.76	 0.0	 135.136611	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3701	 1	 -0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3707	 1	 77.49	 17.3	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3718	 1	 179.4	 58.3	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3737	 1	 42.48	 10.36	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3740	 1	 0.0	 -0.0	 0.0	 13.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3741	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3749	 1	 115.1	 16.4	 0.0	 7.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3758	 1	 83.49	 17.4	 0.0	 19.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3760	 1	 163.5	 44.9	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3768	 1	 19.82	 10.9	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3775	 1	 55.54	 15.06	 0.0	 6.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3786	 1	 -0.0	 -0.0	 0.0	 26.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3793	 1	 197.7	 67.65	 0.0	 13.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3794	 1	 165.3	 7.4	 0.0	 28.32	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3809	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3814	 1	 130.5	 24.7	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3817	 1	 0.0	 -0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3818	 1	 44.45	 10.9	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3830	 1	 -0.0	 0.0	 0.0	 97.326028	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3834	 1	 160.0	 69.2	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3855	 1	 -38.73	 -15.32	 0.0	 97.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3857	 1	 -0.0	 -0.0	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3865	 1	 -0.0	 -0.0	 0.0	 2.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3866	 1	 201.06	 19.46	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3869	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3876	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3880	 1	 -28.13	 -0.82	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3894	 1	 0.0	 0.0	 0.0	 4.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3903	 1	 0.0	 0.0	 0.0	 4.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3906	 1	 0.0	 0.0	 0.0	 98.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3912	 1	 0.0	 -0.0	 0.0	 19.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3918	 1	 -11.8	 -5.47	 0.0	 88.050735	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3919	 1	 -0.0	 0.0	 0.0	 39.95	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3925	 1	 89.3	 25.1	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3928	 1	 105.2	 24.2	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3929	 1	 48.95	 11.6	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3951	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3956	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3962	 1	 19.42	 11.8	 0.0	 2.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3969	 1	 -0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3971	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3975	 1	 148.0	 26.1	 0.0	 9.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3985	 1	 77.19	 26.5	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3994	 1	 36.34	 10.4	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3997	 1	 26.13	 9.7	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3999	 1	 110.8	 36.9	 0.0	 23.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4000	 1	 -0.0	 0.0	 0.0	 24.103274	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4005	 1	 171.18	 28.49	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4024	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4025	 1	 0.0	 0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4031	 1	 0.0	 -0.0	 0.0	 6.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4032	 1	 265.7	 113.5	 0.0	 1.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4039	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4049	 1	 -0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4054	 1	 0.0	 -0.0	 0.0	 2.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4060	 1	 -0.0	 0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4100	 1	 -0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4103	 1	 81.09	 12.5	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4110	 1	 13.01	 3.8	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4114	 1	 9.91	 5.4	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4118	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4125	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4127	 1	 39.14	 7.7	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4128	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4134	 1	 -0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4141	 1	 -0.62	 0.0	 0.0	 75.020288	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4143	 1	 11.11	 4.1	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4144	 1	 310.2	 4.5	 0.0	 8.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4157	 1	 0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4185	 1	 87.5	 21.3	 0.0	 7.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4186	 1	 -0.0	 0.0	 0.0	 5.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4189	 1	 200.65	 30.72	 0.0	 9.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4196	 1	 -3.2	 -1.05	 0.0	 48.471563	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4197	 1	 9.01	 4.9	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4205	 1	 5.81	 1.7	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4215	 1	 -0.0	 -0.0	 0.0	 17.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4231	 3	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4234	 1	 0.0	 0.0	 0.0	 8.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4235	 1	 -0.0	 -0.0	 0.0	 12.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4239	 1	 190.7	 52.0	 0.0	 20.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4245	 1	 24.93	 9.6	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4251	 1	 47.15	 15.7	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4267	 1	 70.78	 19.6	 0.0	 7.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4281	 1	 -0.0	 -0.0	 0.0	 11.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4300	 1	 81.49	 25.1	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4301	 1	 -0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4306	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4313	 1	 133.4	 29.4	 0.0	 10.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4314	 1	 26.13	 2.7	 0.0	 1.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4324	 1	 307.42	 -38.3	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4339	 1	 -0.0	 -0.0	 0.0	 42.345005	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4353	 1	 165.8	 44.0	 0.0	 6.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4355	 1	 65.07	 15.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4357	 1	 235.0	 58.9	 0.0	 14.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4368	 1	 90.6	 15.8	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4395	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4402	 1	 -0.0	 0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4410	 1	 45.05	 13.2	 0.0	 44.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4418	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4419	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4426	 1	 485.5	 -63.38	 0.0	 34.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4432	 1	 -0.0	 0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4435	 1	 -0.0	 -0.0	 0.0	 102.217726	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4454	 1	 -0.0	 -0.0	 0.0	 1.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4484	 1	 69.78	 25.0	 0.0	 14.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4491	 1	 0.0	 -0.0	 0.0	 1.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4494	 1	 -0.0	 0.0	 0.0	 55.514618	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4504	 1	 170.1	 -9.3	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4505	 1	 95.51	 17.1	 0.0	 8.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4506	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4511	 1	 81.89	 19.9	 0.0	 5.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4513	 1	 92.1	 29.5	 0.0	 3.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4520	 1	 -0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4525	 1	 -0.0	 0.0	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4529	 1	 48.48	 8.7	 0.0	 10.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4541	 1	 0.0	 -0.0	 0.0	 150.797812	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4544	 1	 -0.0	 -0.0	 0.0	 14.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4549	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4550	 1	 0.0	 -0.0	 0.0	 124.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4554	 1	 119.0	 21.9	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4562	 1	 130.5	 25.7	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4566	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4580	 1	 11.01	 3.9	 0.0	 7.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4594	 1	 -1.73	 -1.71	 0.0	 22.062314	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4598	 1	 -0.0	 0.0	 0.0	 52.958443	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4615	 1	 42.55	 17.6	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4623	 1	 0.0	 -0.0	 0.0	 80.388213	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4624	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4656	 1	 93.9	 -0.4	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4674	 1	 124.0	 29.2	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4679	 1	 102.7	 17.8	 0.0	 48.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4683	 1	 38.84	 8.5	 0.0	 7.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4685	 1	 46.15	 11.2	 0.0	 10.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4689	 1	 109.7	 15.0	 0.0	 30.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4701	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4710	 1	 195.4	 76.84	 0.0	 8.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4711	 1	 -0.0	 0.0	 0.0	 16.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4725	 1	 4.91	 1.6	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4728	 1	 3.1	 0.1	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4729	 1	 0.0	 0.0	 0.0	 2.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4734	 1	 0.0	 0.0	 0.0	 25.339116	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4738	 1	 101.89	 25.72	 0.0	 5.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4747	 1	 93.3	 27.8	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4748	 1	 -0.0	 -0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4765	 1	 33.04	 10.1	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4783	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4787	 1	 71.98	 27.1	 0.0	 7.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4826	 1	 103.6	 16.0	 0.0	 11.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4829	 1	 171.9	 39.1	 0.0	 4.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4831	 1	 130.4	 44.33	 0.0	 5.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4850	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4852	 1	 45.55	 -59.9	 0.0	 30.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4864	 1	 -28.21	 -6.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4867	 1	 65.77	 27.3	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4874	 1	 -0.58	 -53.03	 0.0	 6.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4885	 1	 166.4	 50.4	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4889	 1	 74.98	 19.8	 0.0	 6.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4907	 1	 125.16	 29.2	 0.0	 2.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4908	 1	 50.06	 9.9	 0.0	 11.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4914	 1	 14.91	 -8.73	 0.0	 34.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4918	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4925	 1	 -0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4936	 1	 312.2	 28.0	 0.0	 48.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4939	 1	 56.76	 31.1	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4942	 1	 109.9	 33.6	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4950	 1	 218.7	 -9.1	 0.0	 49.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4951	 1	 183.95	 -6.47	 0.0	 5.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4952	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4970	 1	 -0.0	 -0.0	 0.0	 171.931977	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4974	 1	 89.08	 26.9	 0.0	 4.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5002	 1	 -0.0	 0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5003	 1	 17.87	 -8.59	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5004	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5007	 1	 0.0	 0.0	 0.0	 40.291745	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5016	 1	 -0.0	 0.0	 0.0	 8.347383	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5019	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5049	 1	 136.6	 29.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5051	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5067	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5077	 1	 30.93	 5.8	 0.0	 4.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5083	 1	 80.39	 10.8	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5093	 1	 70.78	 28.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5099	 1	 0.0	 0.0	 0.0	 9.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5106	 1	 39.94	 13.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5120	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5131	 1	 -0.0	 0.0	 0.0	 7.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5137	 1	 16.92	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5144	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5146	 1	 229.9	 48.9	 0.0	 8.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5174	 1	 0.0	 -0.0	 0.0	 8.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5179	 1	 179.8	 5.67	 0.0	 12.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5182	 1	 0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5212	 1	 -0.0	 0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5213	 1	 246.8	 36.3	 0.0	 16.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5215	 1	 -0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5233	 1	 -0.0	 -0.0	 0.0	 14.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5241	 1	 0.0	 -0.0	 0.0	 70.905048	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5256	 1	 91.0	 36.0	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5257	 1	 -0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5270	 1	 -0.0	 -0.0	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5286	 1	 17.22	 5.1	 0.0	 0.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5288	 1	 -0.0	 -0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5297	 1	 55.26	 11.0	 0.0	 7.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5300	 1	 -0.0	 -0.0	 0.0	 1.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5308	 1	 0.0	 -0.0	 0.0	 42.19206	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5317	 1	 293.2	 87.4	 0.0	 26.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5334	 1	 17.52	 6.6	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5340	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5341	 1	 64.27	 17.5	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5350	 1	 0.0	 0.0	 0.0	 28.208233	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5351	 1	 0.0	 0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5354	 1	 70.18	 19.5	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5362	 1	 152.73	 -17.2	 0.0	 45.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5365	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5379	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	5383	 1	 0.0	 -0.0	 0.0	 24.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5388	 1	 159.5	 42.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5393	 1	 -0.0	 0.0	 0.0	 9.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5395	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5400	 1	 241.62	 52.78	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5410	 1	 69.78	 26.0	 0.0	 5.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5413	 1	 -0.0	 -0.0	 0.0	 5.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5417	 1	 32.74	 5.3	 0.0	 3.07	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5418	 1	 -0.0	 0.0	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5419	 1	 349.3	 144.3	 0.0	 0.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5420	 1	 56.96	 1.94	 0.0	 26.48	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5421	 1	 -0.0	 -0.0	 0.0	 0.92	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5441	 1	 138.01	 34.55	 0.0	 8.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5455	 1	 -0.0	 -0.0	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5458	 1	 0.0	 0.0	 0.0	 9.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5460	 1	 -15.89	 -6.42	 0.0	 38.657071	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5461	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5469	 1	 106.6	 -18.8	 0.0	 4.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5477	 1	 -0.0	 -0.0	 0.0	 18.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5488	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5490	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5502	 1	 -0.0	 -0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5519	 1	 0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5522	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5525	 1	 236.33	 59.35	 0.0	 18.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5529	 1	 0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5533	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5546	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5550	 1	 0.0	 -0.0	 0.0	 10.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5567	 1	 0.0	 0.0	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5571	 1	 -0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5573	 1	 0.0	 -0.0	 0.0	 2.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5574	 1	 99.7	 6.0	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5586	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5589	 1	 0.0	 0.0	 0.0	 173.904854	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5610	 1	 99.5	 9.2	 0.0	 27.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5616	 1	 225.2	 35.2	 0.0	 11.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5627	 1	 -0.0	 -0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5630	 1	 0.0	 0.0	 0.0	 11.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5641	 1	 -0.0	 -0.0	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5648	 1	 -0.0	 -0.0	 0.0	 115.528858	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5653	 1	 96.59	 7.28	 0.0	 2.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5664	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5666	 1	 124.8	 34.7	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5686	 1	 52.26	 19.6	 0.0	 2.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5688	 1	 14.12	 5.2	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5691	 1	 195.1	 -14.2	 0.0	 12.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5695	 1	 142.8	 20.3	 0.0	 6.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5699	 1	 -0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5712	 1	 183.07	 44.65	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5720	 1	 337.6	 -15.4	 0.0	 6.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5723	 1	 141.2	 45.4	 0.0	 7.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5735	 1	 161.3	 10.04	 0.0	 4.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5738	 1	 -0.0	 -0.0	 0.0	 8.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5743	 1	 -0.0	 0.0	 0.0	 4.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5753	 1	 -0.0	 -0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5764	 1	 99.4	 4.3	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5781	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5789	 1	 0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5799	 1	 -0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5803	 1	 0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5836	 1	 244.09	 48.92	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5837	 1	 -0.0	 -0.0	 0.0	 132.04744	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5853	 1	 122.5	 38.9	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5856	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5857	 1	 78.39	 21.2	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5891	 1	 14.02	 5.5	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5907	 1	 186.1	 14.8	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5918	 1	 73.83	 16.41	 0.0	 15.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5926	 1	 0.0	 -0.0	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5935	 1	 -0.0	 0.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5940	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5944	 1	 71.88	 21.7	 0.0	 9.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5957	 1	 208.06	 36.6	 0.0	 3.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5971	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	5983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5987	 1	 24.04	 1.68	 0.0	 4.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5990	 1	 0.0	 -0.0	 0.0	 4.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5993	 1	 0.0	 -0.0	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5994	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6010	 1	 0.0	 0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6031	 1	 0.0	 0.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6041	 1	 0.0	 0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6053	 1	 412.1	 79.3	 0.0	 7.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6071	 1	 163.5	 35.6	 0.0	 4.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6101	 1	 103.0	 40.2	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6104	 1	 93.12	 4.99	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6110	 1	 78.59	 16.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6112	 1	 45.28	 15.27	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6114	 1	 0.0	 0.0	 0.0	 8.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6115	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6119	 1	 221.25	 72.56	 0.0	 8.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6146	 1	 0.0	 -0.0	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6151	 1	 60.67	 33.2	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6153	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6163	 1	 0.0	 -0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6168	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6178	 1	 91.0	 28.4	 0.0	 10.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6194	 1	 0.0	 -0.0	 0.0	 3.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6199	 1	 -4.82	 -0.88	 0.0	 224.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6203	 1	 14.02	 5.6	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6206	 1	 -7.62	 -2.52	 0.0	 33.197994	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6219	 1	 -0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6220	 1	 231.9	 27.6	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6224	 1	 0.0	 0.0	 0.0	 58.990785	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6231	 1	 -0.0	 0.0	 0.0	 11.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6232	 1	 49.25	 12.0	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6240	 1	 0.0	 -0.0	 0.0	 6.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6246	 1	 1769.94	 -353.95	 0.0	 62.59	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6252	 1	 164.7	 44.5	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6253	 1	 128.8	 29.3	 0.0	 26.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6267	 1	 91.3	 18.1	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6271	 1	 3.7	 2.6	 0.0	 4.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6290	 1	 47.65	 20.4	 0.0	 3.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6306	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6308	 1	 0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6313	 1	 48.95	 14.9	 0.0	 4.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6332	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6337	 1	 0.0	 0.0	 0.0	 8.26	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6357	 1	 430.8	 107.9	 0.0	 11.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6371	 1	 -0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6382	 1	 75.43	 10.49	 0.0	 7.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6384	 1	 159.9	 47.4	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6405	 1	 76.48	 19.8	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6416	 1	 67.67	 16.4	 0.0	 3.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6426	 1	 10.21	 3.8	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6427	 1	 83.19	 22.9	 0.0	 28.5	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6430	 1	 0.0	 -0.0	 0.0	 6.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6450	 1	 5.51	 2.1	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6455	 1	 20.52	 13.3	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6472	 1	 0.0	 -0.0	 0.0	 9.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6475	 1	 -0.0	 0.0	 0.0	 149.047157	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6478	 1	 141.2	 34.8	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6486	 1	 31.74	 17.4	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6495	 1	 49.66	 12.3	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6510	 1	 88.2	 26.7	 0.0	 8.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6521	 1	 0.0	 0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6532	 1	 120.69	 18.1	 0.0	 15.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6552	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6555	 1	 -37.81	 -21.64	 0.0	 83.362314	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6556	 1	 -0.0	 -0.0	 0.0	 4.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6563	 1	 0.0	 -0.0	 0.0	 8.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6565	 1	 0.0	 -0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6570	 1	 -0.0	 0.0	 0.0	 32.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6581	 1	 153.8	 23.4	 0.0	 87.73	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6612	 1	 41.14	 15.25	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6616	 1	 -0.0	 -0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6619	 1	 -0.0	 -0.0	 0.0	 10.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6624	 1	 -37.33	 -11.88	 0.0	 145.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6629	 1	 62.63	 16.3	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6630	 1	 134.1	 24.8	 0.0	 13.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6636	 1	 -0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6638	 1	 61.65	 10.24	 0.0	 3.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6639	 1	 388.04	 52.61	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6648	 1	 -26.03	 -0.84	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6664	 1	 -0.0	 0.0	 0.0	 10.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6675	 1	 37.94	 7.5	 0.0	 11.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6684	 1	 -0.0	 0.0	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6691	 1	 42.55	 12.5	 0.0	 1.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6692	 1	 10.33	 3.3	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6697	 1	 309.0	 74.5	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6714	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6723	 1	 0.0	 0.0	 0.0	 1.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6730	 1	 -0.0	 0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6734	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6735	 1	 -0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6737	 1	 0.0	 -0.0	 0.0	 9.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6738	 1	 -4.91	 -2.53	 0.0	 120.576812	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6742	 1	 137.4	 23.9	 0.0	 7.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6744	 1	 244.12	 95.29	 0.0	 7.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6757	 1	 0.0	 0.0	 0.0	 6.57	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6763	 1	 0.0	 -0.0	 0.0	 5.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6772	 1	 61.37	 23.2	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6773	 1	 0.0	 -0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6785	 1	 0.0	 0.0	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6791	 1	 46.35	 9.1	 0.0	 18.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6802	 1	 -0.0	 0.0	 0.0	 7.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6806	 1	 135.84	 15.97	 0.0	 4.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6820	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6828	 1	 58.16	 16.5	 0.0	 6.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6831	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6837	 1	 47.75	 11.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6842	 1	 98.0	 21.7	 0.0	 6.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6844	 1	 -0.0	 -0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6846	 1	 44.35	 19.3	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6854	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6857	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6880	 1	 0.0	 0.0	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6887	 1	 -0.0	 -0.0	 0.0	 3.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6889	 1	 -12.49	 -5.83	 0.0	 6.235224	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6891	 1	 135.61	 26.86	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6897	 1	 176.8	 39.4	 0.0	 28.24	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6901	 1	 -37.84	 -19.23	 0.0	 28.140258	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6908	 1	 0.0	 0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6909	 1	 122.5	 8.7	 0.0	 15.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6921	 1	 -37.34	 -13.33	 0.0	 251.529665	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6922	 1	 113.6	 44.7	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6926	 1	 124.5	 101.4	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6940	 1	 0.0	 -0.0	 0.0	 10.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6947	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6952	 1	 180.9	 33.2	 0.0	 29.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6954	 1	 18.12	 10.0	 0.0	 1.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6961	 1	 56.56	 18.4	 0.0	 3.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6969	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6989	 1	 0.0	 0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6990	 1	 -0.0	 0.0	 0.0	 4.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7014	 1	 0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7019	 1	 52.56	 12.8	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7021	 1	 226.8	 53.3	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7030	 1	 0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7042	 1	 220.98	 91.0	 0.0	 1.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7047	 1	 339.9	 70.5	 0.0	 28.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7049	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7050	 1	 120.0	 26.0	 0.0	 22.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7052	 1	 111.0	 36.6	 0.0	 2.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7069	 1	 258.79	 42.82	 0.0	 9.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7070	 1	 142.9	 25.8	 0.0	 24.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7076	 1	 0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7092	 1	 44.65	 8.8	 0.0	 20.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7098	 1	 0.0	 -0.0	 0.0	 7.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7115	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7119	 1	 149.53	 34.9	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7124	 1	 -0.0	 0.0	 0.0	 16.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7129	 1	 33.34	 5.0	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7132	 1	 222.0	 90.5	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7133	 1	 102.3	 19.0	 0.0	 1.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7144	 1	 8.48	 -1.82	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7148	 1	 -0.0	 -0.0	 0.0	 10.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7162	 1	 -0.0	 0.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7163	 1	 -0.0	 0.0	 0.0	 2.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7164	 1	 -18.6	 -6.72	 0.0	 152.683271	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7165	 1	 -0.0	 -0.0	 0.0	 9.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7178	 1	 -0.0	 -0.0	 0.0	 2.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	7202	 1	 18.62	 6.1	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7209	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7222	 1	 0.0	 -0.0	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7226	 1	 144.0	 31.3	 0.0	 3.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7231	 1	 0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7253	 1	 7.51	 3.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7256	 1	 392.25	 92.02	 0.0	 9.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7259	 1	 82.39	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7264	 1	 0.0	 -0.0	 0.0	 3.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7266	 1	 -0.0	 -0.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7273	 1	 219.6	 36.4	 0.0	 17.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7274	 1	 54.93	 16.5	 0.0	 6.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7284	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7289	 1	 0.0	 -0.0	 0.0	 26.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7309	 1	 0.0	 -0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7316	 1	 -0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7325	 1	 0.0	 0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7338	 1	 0.0	 -0.0	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7341	 1	 37.44	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7342	 1	 169.0	 70.8	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7351	 1	 61.67	 16.3	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7353	 1	 127.3	 26.7	 0.0	 7.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7361	 1	 -0.0	 -0.0	 0.0	 14.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7367	 1	 1.5	 0.4	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7373	 1	 0.0	 -0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7377	 1	 0.0	 0.0	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7380	 1	 105.67	 0.56	 0.0	 18.05	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7396	 1	 -0.0	 0.0	 0.0	 5.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7422	 1	 65.67	 25.6	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7437	 1	 18.32	 5.3	 0.0	 7.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7438	 1	 121.3	 20.7	 0.0	 2.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7464	 1	 197.65	 28.23	 0.0	 5.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7466	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7471	 1	 -18.95	 -6.93	 0.0	 33.11439	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7473	 1	 113.44	 71.42	 0.0	 11.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7485	 1	 44.35	 10.8	 0.0	 8.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7491	 1	 0.0	 -0.0	 0.0	 4.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7495	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7507	 1	 4.0	 0.8	 0.0	 17.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7513	 1	 0.0	 -0.0	 0.0	 38.549494	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7519	 1	 97.97	 31.8	 0.0	 5.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7520	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7522	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7523	 1	 -0.0	 0.0	 0.0	 2.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7530	 1	 0.0	 0.0	 0.0	 31.242294	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7537	 1	 0.0	 0.0	 0.0	 17.184121	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7539	 1	 40.85	 15.7	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7541	 1	 346.42	 89.04	 0.0	 43.55	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7571	 1	 -0.0	 -0.0	 0.0	 13.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7576	 1	 0.0	 0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7577	 1	 0.0	 0.0	 0.0	 6.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7579	 1	 136.9	 11.4	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7580	 1	 0.0	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7582	 1	 0.0	 -0.0	 0.0	 3.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7583	 1	 5.01	 1.8	 0.0	 3.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7599	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7624	 1	 32.74	 10.5	 0.0	 1.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7626	 1	 78.89	 45.6	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7635	 1	 0.0	 0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7640	 1	 68.78	 35.0	 0.0	 34.52	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7647	 1	 -0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7653	 1	 33.94	 11.4	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7663	 1	 37.14	 2.7	 0.0	 2.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7691	 1	 0.0	 -0.0	 0.0	 96.48	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7694	 1	 -14.96	 -4.7	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7700	 1	 66.17	 27.4	 0.0	 14.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7702	 1	 -0.0	 -0.0	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7726	 1	 0.0	 0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7738	 1	 31.84	 9.2	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7752	 1	 524.5	 126.0	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7766	 1	 78.89	 25.6	 0.0	 1.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7770	 1	 207.9	 32.36	 0.0	 8.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7772	 1	 223.6	 51.8	 0.0	 18.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7775	 1	 151.5	 7.9	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.30000	    0.70000;
	7778	 1	 153.0	 21.5	 0.0	 28.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7791	 1	 -0.0	 0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7797	 1	 -0.0	 -0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7809	 1	 169.5	 27.7	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7824	 1	 9.21	 3.4	 0.0	 2.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7831	 1	 -17.17	 -7.1	 0.0	 57.019803	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7840	 1	 -19.28	 29.9	 0.0	 1.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7847	 1	 0.0	 -0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7857	 1	 0.0	 0.0	 0.0	 2.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7862	 1	 0.0	 0.0	 0.0	 9.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7865	 1	 84.99	 19.6	 0.0	 4.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7873	 1	 -20.94	 -6.16	 0.0	 11.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7881	 1	 -0.0	 -0.0	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7883	 1	 47.55	 17.8	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7885	 1	 142.4	 20.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7886	 1	 162.5	 42.7	 0.0	 12.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7892	 1	 36.94	 11.0	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7895	 1	 338.7	 52.5	 0.0	 11.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7903	 1	 0.0	 -0.0	 0.0	 7.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7905	 1	 347.1	 87.2	 0.0	 88.35	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7913	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7923	 1	 0.0	 -0.0	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7937	 1	 56.06	 17.0	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7943	 1	 38.44	 2.0	 0.0	 0.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7945	 1	 17.92	 5.8	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7955	 1	 111.6	 8.9	 0.0	 16.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7961	 1	 50.56	 8.1	 0.0	 8.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7967	 1	 0.0	 -0.0	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7972	 1	 237.9	 68.5	 0.0	 5.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7974	 1	 234.0	 13.1	 0.0	 51.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7982	 1	 112.0	 19.7	 0.0	 38.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7988	 1	 -3.55	 -1.43	 0.0	 11.834121	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7989	 1	 0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7994	 1	 11.91	 3.3	 0.0	 6.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7998	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8005	 1	 -0.0	 -0.0	 0.0	 16.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8030	 1	 -0.0	 0.0	 0.0	 122.13	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8035	 1	 -0.0	 0.0	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8057	 1	 69.18	 9.5	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8060	 1	 0.0	 -0.0	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8104	 1	 127.2	 40.8	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8107	 1	 68.18	 16.1	 0.0	 3.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8109	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8112	 1	 87.9	 29.3	 0.0	 1.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8128	 1	 -0.0	 0.0	 0.0	 8.1	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8151	 1	 0.0	 0.0	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8165	 1	 0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8180	 1	 291.6	 47.0	 0.0	 2.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8189	 1	 0.0	 -0.0	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8190	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8191	 1	 0.0	 0.0	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8195	 1	 -101.01	 -129.29	 0.0	 37.176703	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8200	 1	 0.0	 -0.0	 0.0	 39.58	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8209	 1	 83.39	 16.5	 0.0	 16.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8214	 1	 58.97	 11.1	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8250	 1	 196.1	 32.1	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8255	 1	 39.04	 13.1	 0.0	 3.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8265	 1	 40.44	 20.5	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8291	 1	 0.0	 -0.0	 0.0	 6.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8293	 1	 112.7	 14.5	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8294	 1	 14.22	 6.3	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8307	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8310	 1	 -0.0	 0.0	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8311	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8312	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8316	 1	 0.0	 0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8328	 1	 82.39	 14.4	 0.0	 13.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8331	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8334	 1	 263.96	 -98.64	 0.0	 27.848535	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8347	 1	 -2.09	 -1.43	 0.0	 48.358243	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8361	 1	 126.54	 29.1	 0.0	 12.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8367	 1	 77.99	 19.3	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8369	 1	 -0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8373	 1	 216.3	 -6.9	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8397	 1	 -0.0	 0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8405	 1	 40.75	 12.5	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8406	 1	 0.0	 0.0	 0.0	 14.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8411	 1	 39.64	 9.6	 0.0	 1.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8439	 1	 380.8	 62.8	 0.0	 7.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8448	 1	 286.1	 89.3	 0.0	 8.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8466	 1	 0.0	 -0.0	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8467	 1	 216.2	 75.3	 0.0	 2.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8468	 1	 21.42	 11.8	 0.0	 28.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8475	 1	 -0.0	 0.0	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8477	 1	 0.0	 0.0	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8478	 1	 -0.0	 0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8485	 1	 149.0	 99.8	 0.0	 9.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8487	 1	 44.45	 7.68	 0.0	 17.83	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8494	 1	 235.97	 34.52	 0.0	 7.15	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8497	 1	 38.84	 14.2	 0.0	 3.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8507	 1	 37.44	 9.1	 0.0	 7.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8511	 1	 93.6	 -43.5	 0.0	 33.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8515	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8522	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8535	 1	 72.68	 24.3	 0.0	 3.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8542	 1	 87.7	 26.0	 0.0	 47.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8546	 1	 5.01	 1.8	 0.0	 0.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8560	 1	 -0.0	 0.0	 0.0	 1.11	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8568	 1	 175.7	 56.2	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8578	 1	 0.0	 -0.0	 0.0	 4.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8592	 1	 -0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8626	 1	 136.0	 36.1	 0.0	 6.07	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8627	 1	 -0.0	 0.0	 0.0	 4.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8628	 1	 277.1	 37.0	 0.0	 21.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8636	 1	 31.43	 10.6	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8651	 1	 162.49	 45.11	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8653	 1	 44.55	 7.5	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8656	 1	 5.51	 1.3	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8669	 1	 74.98	 10.5	 0.0	 12.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8672	 1	 -0.0	 -0.0	 0.0	 28.515005	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8677	 1	 0.0	 0.0	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8683	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8689	 1	 42.65	 18.2	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8691	 1	 305.04	 77.16	 0.0	 17.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8704	 1	 180.7	 71.8	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8707	 1	 101.9	 24.3	 0.0	 8.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8711	 1	 0.0	 0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8722	 1	 -0.0	 0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8732	 1	 66.27	 19.3	 0.0	 12.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8743	 1	 11.61	 7.6	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8748	 1	 279.7	 4.6	 0.0	 3.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8763	 1	 -233.23	 29.6	 0.0	 207.55	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8765	 1	 -0.0	 -0.0	 0.0	 11.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8787	 1	 22.83	 8.0	 0.0	 3.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8788	 1	 143.8	 46.45	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8791	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8795	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8804	 1	 22.02	 4.4	 0.0	 4.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8808	 1	 203.6	 19.81	 0.0	 15.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8809	 1	 101.2	 -2.9	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8818	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8825	 1	 406.04	 95.5	 0.0	 35.34	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8829	 1	 91.6	 27.1	 0.0	 10.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8834	 1	 -0.0	 0.0	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8835	 1	 113.7	 22.3	 0.0	 15.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8843	 1	 208.7	 63.0	 0.0	 3.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8846	 1	 20.82	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8853	 1	 410.3	 91.6	 0.0	 13.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8854	 1	 69.18	 35.1	 0.0	 12.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8860	 1	 57.16	 19.7	 0.0	 22.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8864	 1	 63.31	 -9.8	 0.0	 5.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8872	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8873	 1	 0.0	 -0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8874	 1	 285.2	 61.4	 0.0	 26.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8877	 1	 -0.0	 0.0	 0.0	 1.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8879	 1	 0.0	 0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8886	 1	 0.0	 -0.0	 0.0	 -1.392036	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8887	 1	 0.0	 0.0	 0.0	 102.70867	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8893	 1	 278.3	 33.6	 0.0	 25.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8900	 1	 3.1	 1.6	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8906	 1	 91.0	 21.0	 0.0	 11.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8913	 1	 -0.0	 0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8930	 1	 139.4	 21.2	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8931	 1	 -0.56	 -0.0	 0.0	 108.21	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8947	 1	 3.7	 0.2	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8950	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8961	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8975	 1	 0.0	 -0.0	 0.0	 11.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8980	 1	 63.97	 12.8	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8989	 1	 88.5	 24.5	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8992	 1	 -0.0	 -0.0	 0.0	 14.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8997	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8999	 1	 41.15	 10.3	 0.0	 2.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9002	 1	 119.02	 12.54	 0.0	 23.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9011	 1	 88.4	 25.2	 0.0	 12.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9012	 1	 25.63	 6.5	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9014	 1	 70.78	 19.6	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9018	 1	 55.46	 16.9	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9019	 1	 91.4	 18.1	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9021	 1	 152.18	 21.63	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9033	 1	 76.88	 16.4	 0.0	 6.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9045	 1	 60.57	 18.9	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9051	 1	 0.0	 -0.0	 0.0	 2.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9059	 1	 0.0	 -0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9065	 1	 -0.0	 -0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9066	 1	 23.26	 3.01	 0.0	 9.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9067	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9091	 1	 0.0	 0.0	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9101	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9108	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9109	 1	 0.0	 -0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9112	 1	 0.0	 -0.0	 0.0	 19.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9119	 1	 -0.0	 0.0	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9128	 1	 50.56	 8.7	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9130	 1	 245.51	 9.17	 0.0	 24.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9131	 1	 -0.0	 -0.0	 0.0	 6.62	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9140	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9155	 1	 -0.0	 -0.0	 0.0	 5.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9158	 1	 54.96	 9.42	 0.0	 5.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9164	 1	 7.71	 2.4	 0.0	 6.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9173	 1	 66.07	 15.6	 0.0	 5.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9174	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9176	 1	 -0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9180	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9181	 1	 2.43	 1.35	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9185	 1	 66.97	 18.6	 0.0	 18.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9189	 1	 62.57	 -61.0	 0.0	 55.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9191	 1	 -0.0	 -0.0	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9203	 1	 627.36	 -73.13	 0.0	 27.185221	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9213	 1	 -0.0	 -0.0	 0.0	 10.210952	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9217	 1	 -0.0	 0.0	 0.0	 6.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9222	 1	 -5.15	 -2.04	 0.0	 154.446402	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9231	 1	 242.08	 59.98	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9241	 1	 0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	124	 666.665	 133.865	 440.32	 -172.59	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	150	 80.0	 27.275	 77.09	 -22.54	 1.0	 100.0	 1	 160.0	 0.0; % NG
	221	 -53.59	 59.31	 183.92	 -65.3	 1.0	 100.0	 1	 100.0	 -207.18; % COW
	338	 60.0	 18.19	 55.54	 -19.16	 1.0	 100.0	 1	 120.0	 0.0; % NG
	352	 1333.335	 314.335	 926.35	 -297.68	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	413	 140.0	 37.14	 124.12	 -49.84	 1.0	 100.0	 1	 280.0	 0.0; % NG
	453	 270.0	 91.415	 257.23	 -74.4	 1.0	 100.0	 1	 540.0	 0.0; % NG
	516	 400.0	 77.56	 261.79	 -106.67	 1.0	 100.0	 1	 600.0	 200.0; % NUC
	564	 15.555	 -0.44	 18.47	 -19.35	 1.0	 100.0	 1	 100.0	 -68.89; % COW
	583	 -130.0	 5.425	 17.88	 -7.03	 1.0	 100.0	 1	 100.0	 -360.0; % NG
	615	 20.0	 4.65	 17.09	 -7.79	 1.0	 100.0	 1	 40.0	 0.0; % NG
	616	 320.0	 68.37	 217.9	 -81.16	 1.0	 100.0	 1	 480.0	 160.0; % NG
	639	 19.2	 48.31	 135.52	 -38.9	 1.0	 100.0	 1	 100.0	 -61.6; % NG
	682	 40.0	 13.855	 38.77	 -11.06	 1.0	 100.0	 1	 80.0	 0.0; % NG
	749	 120.0	 30.925	 105.69	 -43.84	 1.0	 100.0	 1	 240.0	 0.0; % COW
	757	 60.0	 13.945	 51.3	 -23.41	 1.0	 100.0	 1	 120.0	 0.0; % NG
	776	 -24.265	 5.715	 18.16	 -6.73	 1.0	 100.0	 1	 100.0	 -148.53; % NG
	778	 16.79	 1.505	 12.37	 -9.36	 1.0	 100.0	 1	 33.58	 0.0; % NG
	795	 40.0	 11.855	 36.75	 -13.04	 1.0	 100.0	 1	 80.0	 0.0; % NG
	803	 -9.465	 24.245	 74.03	 -25.54	 1.0	 100.0	 1	 100.0	 -118.93; % COW
	823	 1333.335	 314.185	 926.68	 -298.31	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	851	 100.0	 34.415	 96.64	 -27.81	 1.0	 100.0	 1	 200.0	 0.0; % COW
	858	 666.665	 134.26	 440.67	 -172.15	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	891	 1600.0	 361.75	 1097.41	 -373.91	 1.0	 100.0	 1	 2400.0	 800.0; % COW
	972	 1333.335	 321.605	 934.73	 -291.52	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1001	 60.0	 17.605	 55.02	 -19.81	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1002	 100.0	 27.2	 89.55	 -35.15	 1.0	 100.0	 1	 200.0	 0.0; % NG
	1043	 600.0	 112.24	 387.88	 -163.4	 1.0	 100.0	 1	 900.0	 300.0; % NG
	1083	 60.0	 17.515	 54.91	 -19.88	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1093	 800.0	 182.77	 550.69	 -185.15	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	1100	 40.0	 11.895	 36.8	 -13.01	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1102	 -32.77	 13.23	 38.05	 -11.59	 1.0	 100.0	 1	 100.0	 -165.54; % NG
	1237	 1333.335	 293.585	 906.61	 -319.44	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1251	 800.0	 182.77	 550.69	 -185.15	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	1295	 -32.735	 12.02	 36.92	 -12.88	 1.0	 100.0	 1	 100.0	 -165.47; % NG
	1341	 60.0	 19.705	 57.03	 -17.62	 1.0	 100.0	 1	 120.0	 0.0; % NG
	1354	 -114.335	 13.175	 38.08	 -11.73	 1.0	 100.0	 1	 100.0	 -328.67; % NG
	1422	 -17.335	 5.65	 18.09	 -6.79	 1.0	 100.0	 1	 100.0	 -134.67; % NG
	1436	 40.0	 12.815	 37.72	 -12.09	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1478	 40.0	 11.48	 36.4	 -13.44	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1604	 40.0	 12.745	 37.66	 -12.17	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1642	 40.0	 12.815	 37.74	 -12.11	 1.0	 100.0	 1	 80.0	 0.0; % NG
	1680	 1333.335	 316.395	 928.89	 -296.1	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1708	 666.665	 133.035	 439.37	 -173.3	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	1721	 20.0	 6.065	 18.52	 -6.39	 1.0	 100.0	 1	 40.0	 0.0; % NG
	1754	 20.53	 4.535	 16.99	 -7.92	 1.0	 100.0	 1	 41.06	 0.0; % NG
	1794	 1333.335	 314.335	 926.35	 -297.68	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	1808	 49.6	 36.535	 111.23	 -38.16	 1.0	 100.0	 1	 100.0	 -0.8; % COW
	1851	 15.96	 1.435	 11.76	 -8.89	 1.0	 100.0	 1	 31.92	 0.0; % NG
	1852	 -111.2	 20.82	 58.16	 -16.52	 1.0	 100.0	 1	 100.0	 -322.4; % NG
	1888	 612.78	 120.095	 396.02	 -155.83	 1.0	 100.0	 1	 912.78	 312.78; % NUC
	1914	 255.755	 4.705	 160.36	 -150.95	 1.0	 100.0	 1	 472.16	 39.35; % PEL
	1959	 20.0	 5.695	 18.14	 -6.75	 1.0	 100.0	 1	 40.0	 0.0; % NG
	2035	 666.665	 135.29	 441.85	 -171.27	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	2050	 1333.335	 349.275	 962.2	 -263.65	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2085	 100.0	 26.1	 88.39	 -36.19	 1.0	 100.0	 1	 200.0	 0.0; % NG
	2177	 -30.865	 21.045	 58.35	 -16.26	 1.0	 100.0	 1	 100.0	 -161.73; % COW
	2197	 14.475	 2.385	 19.51	 -14.74	 1.0	 100.0	 1	 100.0	 -71.05; % NG
	2276	 59.65	 2.585	 41.67	 -36.5	 1.0	 100.0	 1	 119.3	 0.0; % NG
	2291	 100.0	 33.38	 95.69	 -28.93	 1.0	 100.0	 1	 200.0	 0.0; % NG
	2359	 40.0	 9.425	 34.35	 -15.5	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2421	 -163.6	 12.47	 37.39	 -12.45	 1.0	 100.0	 1	 100.0	 -427.2; % NG
	2425	 -17.0	 16.905	 54.3	 -20.49	 1.0	 100.0	 1	 100.0	 -134.0; % NG
	2426	 21.2	 3.16	 105.34	 -99.02	 1.0	 100.0	 1	 100.0	 -57.6; % NG
	2446	 1333.335	 308.445	 921.62	 -304.73	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	2468	 40.0	 13.105	 38.02	 -11.81	 1.0	 100.0	 1	 80.0	 0.0; % COW
	2481	 40.0	 14.205	 39.12	 -10.71	 1.0	 100.0	 1	 80.0	 0.0; % NG
	2489	 180.0	 50.305	 162.4	 -61.79	 1.0	 100.0	 1	 360.0	 0.0; % NG
	2550	 60.0	 20.87	 58.23	 -16.49	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2600	 80.0	 26.245	 76.08	 -23.59	 1.0	 100.0	 1	 160.0	 0.0; % NG
	2627	 1333.335	 308.365	 921.52	 -304.79	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2653	 60.0	 14.57	 51.94	 -22.8	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2719	 98.36	 6.025	 70.15	 -58.1	 1.0	 100.0	 1	 196.72	 0.0; % NG
	2786	 1333.335	 321.67	 934.81	 -291.47	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2797	 -13.4	 26.0	 88.33	 -36.33	 1.0	 100.0	 1	 100.0	 -126.8; % NG
	2799	 80.0	 28.125	 77.91	 -21.66	 1.0	 100.0	 1	 160.0	 0.0; % NG
	2816	 1333.335	 314.26	 926.26	 -297.74	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	2841	 60.0	 18.61	 55.98	 -18.76	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2842	 20.0	 5.725	 18.19	 -6.74	 1.0	 100.0	 1	 40.0	 0.0; % COW
	2872	 4.525	 0.385	 3.31	 -2.54	 1.0	 100.0	 1	 9.05	 0.0; % NG
	2878	 107.43	 2.12	 72.95	 -68.71	 1.0	 100.0	 1	 214.86	 0.0; % NG
	2886	 60.0	 20.335	 57.69	 -17.02	 1.0	 100.0	 1	 120.0	 0.0; % NG
	2902	 20.0	 6.735	 19.19	 -5.72	 1.0	 100.0	 1	 40.0	 0.0; % NG
	2930	 40.0	 12.35	 37.24	 -12.54	 1.0	 100.0	 1	 80.0	 0.0; % COW
	2934	 3.415	 0.3	 2.51	 -1.91	 1.0	 100.0	 1	 6.83	 0.0; % COW
	2985	 246.675	 25.895	 184.46	 -132.67	 1.0	 100.0	 1	 493.35	 0.0; % COW
	3018	 100.0	 27.395	 89.61	 -34.82	 1.0	 100.0	 1	 200.0	 0.0; % NG
	3028	 666.665	 135.29	 441.85	 -171.27	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3114	 20.0	 4.86	 17.33	 -7.61	 1.0	 100.0	 1	 40.0	 0.0; % NG
	3133	 120.0	 39.205	 113.97	 -35.56	 1.0	 100.0	 1	 240.0	 0.0; % COW
	3134	 -40.865	 20.46	 70.25	 -29.33	 1.0	 100.0	 1	 100.0	 -181.73; % NG
	3183	 60.0	 16.36	 53.7	 -20.98	 1.0	 100.0	 1	 120.0	 0.0; % COW
	3205	 270.0	 77.575	 243.61	 -88.46	 1.0	 100.0	 1	 540.0	 0.0; % NG
	3218	 -21.6	 11.895	 36.79	 -13.0	 1.0	 100.0	 1	 100.0	 -143.2; % COW
	3240	 21.8	 5.43	 62.23	 -51.37	 1.0	 100.0	 1	 100.0	 -56.4; % NG
	3306	 666.665	 132.885	 439.2	 -173.43	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	3324	 32.35	 13.245	 38.13	 -11.64	 1.0	 100.0	 1	 100.0	 -35.3; % NG
	3346	 40.0	 12.17	 37.1	 -12.76	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3353	 40.0	 13.295	 38.2	 -11.61	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	3364	 67.635	 2.875	 47.19	 -41.44	 1.0	 100.0	 1	 135.27	 0.0; % NG
	3390	 60.0	 17.2	 54.59	 -20.19	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3422	 60.0	 20.845	 58.19	 -16.5	 1.0	 100.0	 1	 120.0	 0.0; % NG
	3436	 800.0	 183.04	 550.97	 -184.89	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	3492	 -197.2	 16.335	 53.75	 -21.08	 1.0	 100.0	 1	 100.0	 -494.4; % NG
	3513	 600.0	 112.24	 387.88	 -163.4	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	3565	 40.0	 13.93	 38.83	 -10.97	 1.0	 100.0	 1	 80.0	 0.0; % NG
	3580	 300.0	 77.17	 261.7	 -107.36	 1.0	 100.0	 1	 600.0	 0.0; % NG
	3611	 -33.6	 17.235	 54.59	 -20.12	 1.0	 100.0	 1	 100.0	 -167.2; % NG
	3656	 32.535	 41.375	 116.07	 -33.32	 1.0	 100.0	 1	 100.0	 -34.93; % NG
	3661	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % PEL
	3698	 41.61	 11.435	 36.34	 -13.47	 1.0	 100.0	 1	 100.0	 -16.78; % COW
	3741	 800.0	 180.705	 548.57	 -187.16	 1.0	 100.0	 1	 1200.0	 400.0; % NUC
	3809	 466.665	 98.14	 313.01	 -116.73	 1.0	 100.0	 1	 700.0	 233.33; % COW
	3825	 600.0	 112.385	 388.17	 -163.4	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	3869	 666.665	 134.275	 440.69	 -172.14	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	3876	 33.265	 9.375	 34.27	 -15.52	 1.0	 100.0	 1	 100.0	 -33.47; % COW
	3916	 35.815	 13.125	 38.02	 -11.77	 1.0	 100.0	 1	 100.0	 -28.37; % COW
	3951	 31.935	 -0.7	 126.16	 -127.56	 1.0	 100.0	 1	 100.0	 -36.13; % NG
	3971	 -39.665	 18.29	 55.67	 -19.09	 1.0	 100.0	 1	 100.0	 -179.33; % NG
	4024	 100.0	 34.815	 97.07	 -27.44	 1.0	 100.0	 1	 200.0	 0.0; % NG
	4056	 -1.265	 13.14	 38.05	 -11.77	 1.0	 100.0	 1	 100.0	 -102.53; % NG
	4084	 300.0	 80.6	 264.94	 -103.74	 1.0	 100.0	 1	 600.0	 0.0; % NG
	4118	 40.0	 13.485	 38.37	 -11.4	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4125	 40.0	 11.945	 36.89	 -13.0	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4128	 60.0	 19.7	 57.03	 -17.63	 1.0	 100.0	 1	 120.0	 0.0; % COW
	4231	 2761.14	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 4188.95	 1333.33; % NUC
	4331	 40.0	 11.805	 36.73	 -13.12	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4395	 -36.065	 13.575	 38.48	 -11.33	 1.0	 100.0	 1	 100.0	 -172.13; % NG
	4419	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	4480	 666.665	 132.885	 439.2	 -173.43	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	4482	 40.0	 13.95	 38.85	 -10.95	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4506	 -64.535	 12.955	 37.86	 -11.95	 1.0	 100.0	 1	 100.0	 -229.07; % NG
	4566	 29.745	 13.035	 37.94	 -11.87	 1.0	 100.0	 1	 100.0	 -40.51; % NG
	4624	 40.0	 10.715	 35.62	 -14.19	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4661	 -2.6	 6.685	 19.14	 -5.77	 1.0	 100.0	 1	 100.0	 -105.2; % COW
	4701	 140.925	 6.055	 98.4	 -86.29	 1.0	 100.0	 1	 281.85	 0.0; % NG
	4783	 666.665	 132.885	 439.2	 -173.43	 1.0	 100.0	 1	 1000.0	 333.33; % NUC
	4816	 32.615	 13.465	 38.37	 -11.44	 1.0	 100.0	 1	 100.0	 -34.77; % NG
	4819	 666.665	 134.275	 440.69	 -172.14	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	4823	 5.23	 1.185	 4.44	 -2.07	 1.0	 100.0	 1	 10.46	 0.0; % NG
	4850	 80.0	 26.665	 76.52	 -23.19	 1.0	 100.0	 1	 160.0	 0.0; % NG
	4880	 23.135	 25.83	 75.62	 -23.96	 1.0	 100.0	 1	 100.0	 -53.73; % NG
	4918	 40.0	 12.35	 37.27	 -12.57	 1.0	 100.0	 1	 80.0	 0.0; % NG
	4952	 41.615	 12.31	 37.23	 -12.61	 1.0	 100.0	 1	 100.0	 -16.77; % NG
	5004	 110.06	 2.16	 74.73	 -70.41	 1.0	 100.0	 1	 220.12	 0.0; % NG
	5019	 40.0	 12.815	 37.72	 -12.09	 1.0	 100.0	 1	 80.0	 0.0; % COW
	5051	 80.0	 24.79	 74.55	 -24.97	 1.0	 100.0	 1	 160.0	 0.0; % PEL
	5067	 300.0	 74.665	 258.91	 -109.58	 1.0	 100.0	 1	 600.0	 0.0; % COW
	5110	 14.995	 13.39	 38.28	 -11.5	 1.0	 100.0	 1	 100.0	 -70.01; % COW
	5120	 60.0	 18.965	 56.35	 -18.42	 1.0	 100.0	 1	 120.0	 0.0; % NG
	5144	 1333.335	 269.81	 882.86	 -343.24	 1.0	 100.0	 1	 2000.0	 666.67; % NG
	5237	 80.0	 25.14	 75.02	 -24.74	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5278	 60.0	 13.905	 51.3	 -23.49	 1.0	 100.0	 1	 120.0	 0.0; % NG
	5340	 -56.0	 11.47	 36.37	 -13.43	 1.0	 100.0	 1	 100.0	 -212.0; % NG
	5365	 20.0	 5.695	 18.14	 -6.75	 1.0	 100.0	 1	 40.0	 0.0; % NG
	5379	 1333.335	 314.42	 926.47	 -297.63	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	5395	 -213.865	 20.7	 58.06	 -16.66	 1.0	 100.0	 1	 100.0	 -527.73; % NG
	5461	 40.0	 13.355	 38.26	 -11.55	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5481	 1333.335	 307.335	 920.31	 -305.64	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	5482	 124.53	 26.6	 101.32	 -48.12	 1.0	 100.0	 1	 249.06	 0.0; % NG
	5486	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	5488	 -14.265	 12.58	 37.49	 -12.33	 1.0	 100.0	 1	 100.0	 -128.53; % NG
	5490	 2666.665	 539.345	 1765.36	 -686.67	 1.0	 100.0	 1	 4000.0	 1333.33; % COW
	5533	 100.0	 26.58	 88.87	 -35.71	 1.0	 100.0	 1	 200.0	 0.0; % NG
	5546	 20.0	 6.705	 19.16	 -5.75	 1.0	 100.0	 1	 40.0	 0.0; % COW
	5564	 40.0	 11.905	 36.8	 -12.99	 1.0	 100.0	 1	 80.0	 0.0; % NG
	5658	 120.0	 28.465	 103.18	 -46.25	 1.0	 100.0	 1	 240.0	 0.0; % COW
	5664	 80.0	 22.83	 72.71	 -27.05	 1.0	 100.0	 1	 160.0	 0.0; % NG
	5709	 800.0	 182.77	 550.69	 -185.15	 1.0	 100.0	 1	 1200.0	 400.0; % COW
	5781	 1200.0	 227.25	 779.29	 -324.79	 1.0	 100.0	 1	 1800.0	 600.0; % NG
	5814	 293.335	 59.905	 196.98	 -77.17	 1.0	 100.0	 1	 440.0	 146.67; % NG
	5856	 320.0	 64.565	 214.13	 -85.0	 1.0	 100.0	 1	 480.0	 160.0; % NG
	5881	 40.0	 11.795	 36.72	 -13.13	 1.0	 100.0	 1	 80.0	 0.0; % PEL
	5940	 0.065	 4.74	 17.21	 -7.73	 1.0	 100.0	 1	 100.0	 -99.87; % NG
	5971	 1333.335	 321.45	 934.54	 -291.64	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	5983	 -18.335	 12.34	 37.27	 -12.59	 1.0	 100.0	 1	 100.0	 -136.67; % NG
	5994	 -8.2	 -0.285	 60.51	 -61.08	 1.0	 100.0	 1	 100.0	 -116.4; % COW
	6036	 600.0	 114.62	 390.4	 -161.16	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	6153	 401.01	 -6.085	 249.65	 -261.82	 1.0	 100.0	 1	 769.94	 32.08; % COW
	6168	 26.88	 2.465	 19.86	 -14.93	 1.0	 100.0	 1	 53.76	 0.0; % NG
	6291	 60.0	 20.76	 58.12	 -16.6	 1.0	 100.0	 1	 120.0	 0.0; % NG
	6331	 40.0	 12.855	 37.76	 -12.05	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6332	 100.0	 34.305	 96.56	 -27.95	 1.0	 100.0	 1	 200.0	 0.0; % COW
	6351	 40.0	 13.365	 38.29	 -11.56	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6368	 -46.865	 13.825	 51.11	 -23.46	 1.0	 100.0	 1	 100.0	 -193.73; % NG
	6376	 31.465	 48.96	 148.65	 -50.73	 1.0	 100.0	 1	 100.0	 -37.07; % COW
	6429	 100.0	 26.57	 88.83	 -35.69	 1.0	 100.0	 1	 200.0	 0.0; % NG
	6474	 666.665	 132.285	 438.72	 -174.15	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	6516	 140.0	 39.45	 126.73	 -47.83	 1.0	 100.0	 1	 280.0	 0.0; % COW
	6552	 -86.135	 12.71	 37.58	 -12.16	 1.0	 100.0	 1	 100.0	 -272.27; % NG
	6734	 360.0	 89.715	 311.52	 -132.09	 1.0	 100.0	 1	 720.0	 0.0; % COW
	6807	 80.0	 27.34	 77.14	 -22.46	 1.0	 100.0	 1	 160.0	 0.0; % COW
	6816	 80.0	 27.545	 77.35	 -22.26	 1.0	 100.0	 1	 160.0	 0.0; % COW
	6820	 16.265	 1.465	 11.99	 -9.06	 1.0	 100.0	 1	 32.53	 0.0; % PEL
	6831	 11.665	 10.685	 35.62	 -14.25	 1.0	 100.0	 1	 100.0	 -76.67; % COW
	6845	 60.0	 15.885	 53.24	 -21.47	 1.0	 100.0	 1	 120.0	 0.0; % COW
	6852	 -179.935	 6.11	 18.56	 -6.34	 1.0	 100.0	 1	 100.0	 -459.87; % NG
	6857	 2666.665	 639.94	 1865.83	 -585.95	 1.0	 100.0	 1	 4000.0	 1333.33; % COW
	6888	 194.335	 64.72	 189.31	 -59.87	 1.0	 100.0	 1	 300.0	 88.67; % NG
	6947	 140.0	 38.9	 126.09	 -48.29	 1.0	 100.0	 1	 280.0	 0.0; % NG
	6969	 40.0	 13.63	 38.53	 -11.27	 1.0	 100.0	 1	 80.0	 0.0; % NG
	6982	 41.6	 18.89	 56.22	 -18.44	 1.0	 100.0	 1	 100.0	 -16.8; % NG
	7036	 40.0	 11.22	 36.16	 -13.72	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7049	 60.0	 20.81	 58.18	 -16.56	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7056	 400.0	 83.19	 267.36	 -100.98	 1.0	 100.0	 1	 600.0	 200.0; % NG
	7115	 136.14	 5.86	 95.06	 -83.34	 1.0	 100.0	 1	 272.28	 0.0; % NG
	7159	 666.665	 134.495	 441.04	 -172.05	 1.0	 100.0	 1	 1000.0	 333.33; % PEL
	7183	 1333.335	 314.42	 926.47	 -297.63	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7209	 3.675	 0.83	 3.12	 -1.46	 1.0	 100.0	 1	 7.35	 0.0; % NG
	7267	 23.535	 27.5	 89.84	 -34.84	 1.0	 100.0	 1	 100.0	 -52.93; % COW
	7282	 2666.665	 637.065	 1862.29	 -588.16	 1.0	 100.0	 1	 4000.0	 1333.33; % COW
	7327	 80.0	 26.245	 76.11	 -23.62	 1.0	 100.0	 1	 160.0	 0.0; % NG
	7328	 40.0	 12.53	 37.45	 -12.39	 1.0	 100.0	 1	 80.0	 0.0; % NG
	7466	 -85.02	 -0.605	 75.85	 -77.06	 1.0	 100.0	 1	 100.0	 -270.04; % COW
	7474	 60.0	 18.93	 56.27	 -18.41	 1.0	 100.0	 1	 120.0	 0.0; % NG
	7495	 125.265	 77.23	 214.23	 -59.77	 1.0	 100.0	 1	 200.0	 50.53; % NG
	7520	 533.335	 104.815	 350.36	 -140.73	 1.0	 100.0	 1	 800.0	 266.67; % PEL
	7522	 533.335	 125.72	 371.11	 -119.67	 1.0	 100.0	 1	 800.0	 266.67; % COW
	7641	 540.0	 107.93	 378.21	 -162.35	 1.0	 100.0	 1	 880.0	 200.0; % COW
	7697	 140.0	 39.45	 126.73	 -47.83	 1.0	 100.0	 1	 280.0	 0.0; % NG
	7776	 1333.335	 321.605	 934.73	 -291.52	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7808	 1333.335	 314.335	 926.35	 -297.68	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	7842	 100.0	 27.76	 90.08	 -34.56	 1.0	 100.0	 1	 200.0	 0.0; % NG
	7913	 1333.335	 307.415	 920.41	 -305.58	 1.0	 100.0	 1	 2000.0	 666.67; % COW
	7998	 600.0	 115.31	 391.57	 -160.95	 1.0	 100.0	 1	 900.0	 300.0; % NUC
	8043	 32.0	 25.855	 75.67	 -23.96	 1.0	 100.0	 1	 100.0	 -36.0; % NG
	8109	 520.8	 0.0	 99999.0	 -99999.0	 1.0	 100.0	 1	 1041.6	 0.0; % COW
	8158	 100.0	 29.33	 91.67	 -33.01	 1.0	 100.0	 1	 200.0	 0.0; % NG
	8222	 40.0	 10.855	 35.76	 -14.05	 1.0	 100.0	 1	 80.0	 0.0; % NG
	8225	 20.0	 7.035	 19.49	 -5.42	 1.0	 100.0	 1	 40.0	 0.0; % COW
	8267	 120.0	 32.14	 106.84	 -42.56	 1.0	 100.0	 1	 240.0	 0.0; % NG
	8311	 44.17	 5.335	 17.8	 -7.13	 1.0	 100.0	 1	 100.0	 -11.66; % NG
	8312	 1600.0	 360.845	 1096.33	 -374.64	 1.0	 100.0	 1	 2400.0	 800.0; % COW
	8458	 666.665	 167.965	 474.42	 -138.49	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	8473	 -40.0	 27.88	 90.21	 -34.45	 1.0	 100.0	 1	 100.0	 -180.0; % NG
	8486	 40.0	 9.245	 34.16	 -15.67	 1.0	 100.0	 1	 80.0	 0.0; % COW
	8515	 100.0	 30.8	 93.03	 -31.43	 1.0	 100.0	 1	 200.0	 0.0; % NG
	8522	 -0.46	 0.96	 3.61	 -1.69	 1.0	 100.0	 1	 100.0	 -100.92; % NG
	8564	 6.665	 14.525	 51.91	 -22.86	 1.0	 100.0	 1	 100.0	 -86.67; % NG
	8670	 -42.2	 12.47	 37.4	 -12.46	 1.0	 100.0	 1	 100.0	 -184.4; % COW
	8676	 -122.735	 9.98	 34.92	 -14.96	 1.0	 100.0	 1	 100.0	 -345.47; % NG
	8683	 25.15	 16.965	 54.32	 -20.39	 1.0	 100.0	 1	 100.0	 -49.7; % COW
	8721	 1333.335	 319.77	 932.68	 -293.14	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	8795	 120.0	 36.925	 111.7	 -37.85	 1.0	 100.0	 1	 240.0	 0.0; % NG
	8807	 -152.665	 10.885	 35.84	 -14.07	 1.0	 100.0	 1	 100.0	 -405.33; % COW
	8818	 80.0	 27.06	 76.87	 -22.75	 1.0	 100.0	 1	 160.0	 0.0; % NG
	8872	 1333.335	 319.77	 932.68	 -293.14	 1.0	 100.0	 1	 2000.0	 666.67; % NUC
	8903	 43.365	 0.29	 28.99	 -28.41	 1.0	 100.0	 1	 86.73	 0.0; % NG
	8950	 -120.47	 13.31	 38.23	 -11.61	 1.0	 100.0	 1	 100.0	 -340.94; % NG
	8961	 8.8	 1.57	 53.52	 -50.38	 1.0	 100.0	 1	 100.0	 -82.4; % NG
	8976	 100.0	 33.35	 95.65	 -28.95	 1.0	 100.0	 1	 200.0	 0.0; % NG
	8997	 158.545	 3.055	 107.59	 -101.48	 1.0	 100.0	 1	 317.09	 0.0; % NG
	9067	 293.335	 60.865	 198.07	 -76.34	 1.0	 100.0	 1	 440.0	 146.67; % NG
	9101	 666.665	 136.535	 442.99	 -169.92	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	9108	 -109.485	 2.245	 18.65	 -14.16	 1.0	 100.0	 1	 100.0	 -318.97; % NG
	9137	 64.235	 121.365	 335.96	 -93.23	 1.0	 100.0	 1	 100.0	 28.47; % COW
	9140	 25.2	 23.355	 73.19	 -26.48	 1.0	 100.0	 1	 100.0	 -49.6; % NG
	9150	 666.665	 133.05	 439.38	 -173.28	 1.0	 100.0	 1	 1000.0	 333.33; % COW
	9174	 -170.935	 62.92	 175.0	 -49.16	 1.0	 100.0	 1	 100.0	 -441.87; % NG
	9180	 80.0	 27.86	 77.69	 -21.97	 1.0	 100.0	 1	 160.0	 0.0; % NG
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  10.258323	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.739304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.382856	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.570530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.410748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.397266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.602967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.171706	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.392883	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.720369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.601645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.829521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.010680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.860522	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.144193	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.348478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.480340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.260283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.185912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.876654	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.050011	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.693424	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.179452	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.782950	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.077711	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.254765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.888316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.064806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.093256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.895058	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.531078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.703485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.144125	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.146988	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.283038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.961897	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.001968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.922445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.934071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.194991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.793039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.399752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.054935	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.252906	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.981874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.982040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.220225	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.265424	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.662994	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.838148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.883722	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	 118.076690	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.828960	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.889404	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.470152	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.491829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.981434	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.427501	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.894704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.810352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.089221	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.960517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.587389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.445820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.803769	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.474887	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.188143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.672537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.476158	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.324360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.361646	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.894604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.066585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.656581	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.138451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.209845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.094682	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.965438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.765406	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.752977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.474015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.978644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.995415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.020307	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.902755	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.059178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.565151	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.865040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.680050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.499589	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.385891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.235310	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.599182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.647840	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.311440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.517541	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  14.951813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.810462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  79.708144	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.802999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.702382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.611659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.619883	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  42.195400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.253371	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.314915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.383243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.446061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.981934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.586864	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.204589	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.122779	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  18.666900	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.550981	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  35.604133	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.804309	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.144799	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.147810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.562693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.807424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.446996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.538670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.909880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.544167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.965332	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.051011	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  42.356822	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.296003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.938094	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.931033	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.588806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.302716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.977313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.345048	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.462959	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.814769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.016700	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.456068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.670249	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.366752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.105171	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.107671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.943609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.086316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.303918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.260622	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  98.992318	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.405063	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.378434	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.198047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.694475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.735549	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.912924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.250898	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.979523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.538110	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.424853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.296805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.861628	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.670276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.798273	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.336670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.404323	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.060039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.080860	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.555466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.210681	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.184103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.825774	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.459416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.825995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.704435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.881521	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  48.679477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.090734	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.629615	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.688000	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.924707	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  15.196866	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.536394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.051660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.290422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.038621	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.583295	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.644095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.524756	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.090071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.804954	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.393553	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.182687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.350508	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.275729	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.479866	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.612148	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.065876	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.385085	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.659346	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.602100	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  58.771001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.431582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.723693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.352216	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.730786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.377738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.796242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.862032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.591549	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.581419	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.043459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.416613	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.046106	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.516844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.480527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.949368	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.930196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.338887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 125.432468	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.267272	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.167106	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.880191	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.496344	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.877423	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  16.624602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.486972	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.223432	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  36.240526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.992726	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.110680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.712216	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.618848	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.436310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.891711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.267867	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.024605	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.694214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.018016	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.414252	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.775924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.154391	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.881811	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.611359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.035248	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.254581	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  20.431142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.627975	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.290669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.788336	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.955551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.216139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.401074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.847228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.538048	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.039685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.919809	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.912024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.875199	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.648506	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.222299	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.645603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.579005	   0.000000; % NG
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	7351	 5441	 0.00018	 0.000781	 0.0	 39412	 39412	 39412	 0.0	 0.0	 1	 -30.0	 30.0;
	4314	 7571	 0.002961	 0.01669	 0.0	 319.0	 1864	 1864	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 3916	 0.00056	 0.00432	 0.0	 7252	 7252	 7252	 0.0	 0.0	 1	 -30.0	 30.0;
	6757	 6036	 0.0002	 0.00246	 0.0	 657.0	 12799	 12799	 0.0	 0.0	 1	 -30.0	 30.0;
	6757	 6921	 0.0003	 0.00377	 0.0	 1315.0	 8353	 8353	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 9112	 0.00014	 0.00057	 0.0	 53817	 53817	 53817	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 9112	 0.00013	 0.000729	 0.0	 42657	 42657	 42657	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 9112	 0.00012	 0.000581	 0.0	 53244	 53244	 53244	 0.0	 0.0	 1	 -30.0	 30.0;
	1851	 9112	 0.00011	 0.00064	 0.0	 48642	 48642	 48642	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 9112	 0.00019	 0.00056	 0.0	 53416	 53416	 53416	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 8791	 0.00062	 0.004909	 0.0	 529.0	 6384	 6384	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 7842	 7e-05	 0.00076	 0.0	 887.0	 41388	 41388	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 8997	 0.00066	 0.00622	 0.0	 1611.0	 5051	 5051	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 2129	 0.00054	 0.00752	 0.0	 4190	 4190	 4190	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 29	 0.00105	 0.00877	 0.0	 1315.0	 3577	 3577	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 8903	 8e-05	 0.00091	 0.0	 657.0	 34578	 34578	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 4598	 0.00056	 0.00719	 0.0	 953.0	 4380	 4380	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 5533	 0.000531	 0.002039	 0.0	 319.0	 14992	 14992	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 4831	 0.008659	 0.03769	 0.0	 300.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 8961	 0.003849	 0.021099	 0.0	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 8522	 0.00688	 0.035969	 0.0	 300.0	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 6888	 0.006729	 0.03713	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 3401	 0.00111	 0.006651	 0.0	 414.0	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 641	 0.0023	 0.008909	 0.0	 3433	 3433	 3433	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 2600	 0.000841	 0.00313	 0.0	 9747	 9747	 9747	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 5351	 0.003521	 0.017479	 0.0	 300.0	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 718	 3.9e-05	 0.00025	 0.0	 510.0	 124840	 124840	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 2327	 0.000159	 0.000729	 0.0	 357.0	 42335	 42335	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 7473	 0.005281	 0.032099	 0.0	 395.0	 972	 972	 0.0	 0.0	 1	 -30.0	 30.0;
	8651	 7473	 0.005651	 0.029419	 0.0	 376.0	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	903	 3654	 0.000271	 0.00036	 0.0	 70101	 70101	 70101	 0.0	 0.0	 1	 -30.0	 30.0;
	8732	 7050	 0.00044	 0.00143	 0.0	 472.0	 21113	 21113	 0.0	 0.0	 1	 -30.0	 30.0;
	8732	 3912	 0.000159	 0.00074	 0.0	 453.0	 41734	 41734	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 1973	 0.00019	 0.000591	 0.0	 338.0	 50883	 50883	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 2928	 0.00019	 0.00087	 0.0	 35472	 35472	 35472	 0.0	 0.0	 1	 -30.0	 30.0;
	6629	 4918	 0.002591	 0.013659	 0.0	 319.0	 2273	 2273	 0.0	 0.0	 1	 -30.0	 30.0;
	6629	 7309	 0.00305	 0.01168	 0.0	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	413	 1102	 0.000159	 0.000599	 0.0	 433.0	 50969	 50969	 0.0	 0.0	 1	 -30.0	 30.0;
	413	 1102	 0.000159	 0.00062	 0.0	 395.0	 49351	 49351	 0.0	 0.0	 1	 -30.0	 30.0;
	3248	 4918	 0.00101	 0.004229	 0.0	 472.0	 7265	 7265	 0.0	 0.0	 1	 -30.0	 30.0;
	3248	 4281	 0.00319	 0.018651	 0.0	 453.0	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	3248	 7309	 0.000729	 0.00337	 0.0	 9162	 9162	 9162	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 1187	 0.002961	 0.012831	 0.0	 281.0	 2399	 2399	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 7945	 0.000591	 0.00339	 0.0	 9180	 9180	 9180	 0.0	 0.0	 1	 -30.0	 30.0;
	8900	 2421	 0.00024	 0.001219	 0.0	 25425	 25425	 25425	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 2972	 0.006219	 0.036341	 0.0	 376.0	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 6031	 0.001841	 0.01193	 0.0	 472.0	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 7264	 0.001409	 0.01113	 0.0	 414.0	 2816	 2816	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 283	 0.00151	 0.00768	 0.0	 376.0	 4036	 4036	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 3069	 0.00599	 0.03313	 0.0	 395.0	 939	 939	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 3390	 0.001771	 0.010151	 0.0	 357.0	 3066	 3066	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 4936	 0.00074	 0.00311	 0.0	 9881	 9881	 9881	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 4936	 0.000729	 0.003159	 0.0	 9744	 9744	 9744	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 7809	 0.005271	 0.01906	 0.0	 281.0	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 5455	 0.00906	 0.053151	 0.0	 319.0	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 1857	 0.00405	 0.0153	 0.0	 1996	 1996	 1996	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 5410	 0.00055	 0.003961	 0.0	 395.0	 7899	 7899	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 5410	 0.00055	 0.003729	 0.0	 338.0	 8381	 8381	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1609	 0.00107	 0.007789	 0.0	 414.0	 4018	 4018	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1609	 0.00112	 0.00775	 0.0	 472.0	 4034	 4034	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 1609	 0.001031	 0.00775	 0.0	 4041	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 2438	 0.00062	 0.003219	 0.0	 9636	 9636	 9636	 0.0	 0.0	 1	 -30.0	 30.0;
	6806	 954	 0.00068	 0.002659	 0.0	 414.0	 11510	 11510	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 502	 0.00193	 0.012479	 0.0	 491.0	 2502	 2502	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 3013	 0.001159	 0.007229	 0.0	 4315	 4315	 4315	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 2949	 0.00137	 0.008729	 0.0	 395.0	 3575	 3575	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 2949	 0.001401	 0.00855	 0.0	 433.0	 3646	 3646	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 2949	 0.001331	 0.008521	 0.0	 433.0	 3663	 3663	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 2208	 0.00031	 0.00081	 0.0	 281.0	 36421	 36421	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 8060	 0.000341	 0.00119	 0.0	 281.0	 25518	 25518	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 4484	 0.00031	 0.001281	 0.0	 376.0	 23967	 23967	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 4239	 0.00094	 0.0035	 0.0	 433.0	 8717	 8717	 0.0	 0.0	 1	 -30.0	 30.0;
	8535	 7047	 7e-05	 0.000651	 0.0	 48244	 48244	 48244	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 3657	 0.00019	 0.00124	 0.0	 491.0	 25180	 25180	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 2928	 0.000331	 0.002539	 0.0	 433.0	 12337	 12337	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 2918	 0.0016	 0.02113	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	7770	 5317	 0.000909	 0.004711	 0.0	 357.0	 6584	 6584	 0.0	 0.0	 1	 -30.0	 30.0;
	7770	 5317	 0.00088	 0.004969	 0.0	 319.0	 6260	 6260	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 8676	 0.001841	 0.0088	 0.0	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 8189	 0.01013	 0.04238	 0.0	 395.0	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 2938	 0.00059	 0.00802	 0.0	 723.0	 3928	 3928	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 2938	 0.00054	 0.0079	 0.0	 657.0	 3990	 3990	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 3918	 0.00171	 0.02128	 0.0	 986.0	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 3918	 0.00174	 0.02084	 0.0	 854.0	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 6581	 0.00086	 0.01433	 0.0	 1151.0	 2201	 2201	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 6581	 0.00087	 0.01404	 0.0	 723.0	 2246	 2246	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 3830	 0.00126	 0.01447	 0.0	 1118.0	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 5648	 0.00122	 0.01509	 0.0	 1052.0	 2087	 2087	 0.0	 0.0	 1	 -30.0	 30.0;
	7267	 5648	 0.00154	 0.019	 0.0	 1282.0	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 4907	 0.00474	 0.03564	 0.0	 472.0	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 5957	 0.006	 0.047849	 0.0	 433.0	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	4918	 5233	 0.008039	 0.03375	 0.0	 281.0	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	6854	 7309	 2.1e-05	 0.000211	 0.0	 510.0	 148968	 148968	 0.0	 0.0	 1	 -30.0	 30.0;
	8311	 3680	 0.00045	 0.002341	 0.0	 13251	 13251	 13251	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 8804	 0.000669	 0.004281	 0.0	 433.0	 7291	 7291	 0.0	 0.0	 1	 -30.0	 30.0;
	9241	 8804	 0.00068	 0.00419	 0.0	 7442	 7442	 7442	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 7124	 0.000729	 0.00431	 0.0	 510.0	 7227	 7227	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 7124	 0.000591	 0.004651	 0.0	 453.0	 6738	 6738	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 8873	 0.00099	 0.005081	 0.0	 338.0	 6103	 6103	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 7582	 0.00212	 0.013031	 0.0	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 3541	 0.002159	 0.01275	 0.0	 2443	 2443	 2443	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 3698	 0.00025	 0.00095	 0.0	 32156	 32156	 32156	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 3698	 0.000271	 0.00089	 0.0	 33953	 33953	 33953	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 2801	 0.001961	 0.012409	 0.0	 281.0	 2515	 2515	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8328	 0.00044	 0.00207	 0.0	 472.0	 14927	 14927	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8511	 0.000469	 0.00143	 0.0	 529.0	 20990	 20990	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 6570	 0.001271	 0.01406	 0.0	 529.0	 2238	 2238	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 6570	 0.00124	 0.013021	 0.0	 529.0	 2415	 2415	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 8975	 0.000409	 0.00239	 0.0	 13028	 13028	 13028	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 216	 0.00094	 0.005	 0.0	 338.0	 6209	 6209	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 2961	 0.000219	 0.0007	 0.0	 529.0	 43067	 43067	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 6773	 6e-05	 0.00025	 0.0	 122861	 122861	 122861	 0.0	 0.0	 1	 -30.0	 30.0;
	8683	 5278	 5e-05	 0.000229	 0.0	 134762	 134762	 134762	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 2751	 0.00019	 0.000909	 0.0	 34015	 34015	 34015	 0.0	 0.0	 1	 -30.0	 30.0;
	2276	 5546	 0.001711	 0.00782	 0.0	 3946	 3946	 3946	 0.0	 0.0	 1	 -30.0	 30.0;
	2276	 6816	 0.002651	 0.01176	 0.0	 319.0	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 444	 0.001409	 0.010599	 0.0	 2955	 2955	 2955	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 5334	 0.001419	 0.010219	 0.0	 3062	 3062	 3062	 0.0	 0.0	 1	 -30.0	 30.0;
	839	 3918	 0.00013	 0.00212	 0.0	 756.0	 14872	 14872	 0.0	 0.0	 1	 -30.0	 30.0;
	839	 809	 0.00026	 0.00313	 0.0	 1282.0	 10058	 10058	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 2286	 0.0047	 0.0318	 0.0	 376.0	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 6802	 0.00136	 0.00768	 0.0	 338.0	 4050	 4050	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 3520	 0.005669	 0.027789	 0.0	 300.0	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 6271	 0.004409	 0.033091	 0.0	 281.0	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 1435	 0.01056	 0.044469	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7148	 0.01963	 0.07736	 0.0	 338.0	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7437	 0.01157	 0.04694	 0.0	 357.0	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 871	 0.000479	 0.00255	 0.0	 357.0	 12175	 12175	 0.0	 0.0	 1	 -30.0	 30.0;
	7580	 871	 0.000469	 0.00236	 0.0	 13128	 13128	 13128	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 1539	 0.01237	 0.067039	 0.0	 281.0	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 8515	 0.0132	 0.056229	 0.0	 281.0	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 4084	 0.00026	 0.001711	 0.0	 18252	 18252	 18252	 0.0	 0.0	 1	 -30.0	 30.0;
	3971	 4084	 0.000271	 0.001669	 0.0	 18682	 18682	 18682	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 5340	 0.000211	 0.000401	 0.0	 69711	 69711	 69711	 0.0	 0.0	 1	 -30.0	 30.0;
	8294	 5814	 0.00105	 0.005159	 0.0	 6000	 6000	 6000	 0.0	 0.0	 1	 -30.0	 30.0;
	7115	 6807	 0.00212	 0.00931	 0.0	 319.0	 3309	 3309	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 6791	 0.000151	 0.00068	 0.0	 45348	 45348	 45348	 0.0	 0.0	 1	 -30.0	 30.0;
	5418	 4908	 0.00019	 0.00082	 0.0	 37527	 37527	 37527	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 6816	 0.003219	 0.01405	 0.0	 300.0	 2192	 2192	 0.0	 0.0	 1	 -30.0	 30.0;
	6692	 9158	 0.007271	 0.033159	 0.0	 281.0	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	6692	 8035	 0.006659	 0.03132	 0.0	 300.0	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 2848	 0.00057	 0.00668	 0.0	 1480.0	 4712	 4712	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 7056	 0.00057	 0.00758	 0.0	 1414.0	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 7056	 0.00039	 0.00607	 0.0	 821.0	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 1642	 0.00155	 0.0179	 0.0	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 4594	 0.00036	 0.00485	 0.0	 1545.0	 6495	 6495	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 1692	 0.000581	 0.004229	 0.0	 338.0	 7400	 7400	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 8190	 0.00056	 0.00431	 0.0	 7268	 7268	 7268	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 5836	 0.003099	 0.020531	 0.0	 472.0	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 3191	 0.00118	 0.016919	 0.0	 510.0	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 5300	 0.00188	 0.01407	 0.0	 2226	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 4889	 0.00545	 0.04082	 0.0	 357.0	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 444	 0.00214	 0.01639	 0.0	 453.0	 1912	 1912	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 4747	 0.002479	 0.01549	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 9011	 0.000159	 0.001229	 0.0	 472.0	 25490	 25490	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 6675	 0.00026	 0.00162	 0.0	 453.0	 19252	 19252	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 6909	 0.000159	 0.00113	 0.0	 376.0	 27681	 27681	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 8835	 0.000461	 0.003219	 0.0	 472.0	 9714	 9714	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 4186	 0.000159	 0.001229	 0.0	 25490	 25490	 25490	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 502	 0.000229	 0.00139	 0.0	 376.0	 22423	 22423	 0.0	 0.0	 1	 -30.0	 30.0;
	2842	 502	 0.0002	 0.00156	 0.0	 338.0	 20084	 20084	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 513	 0.00145	 0.00824	 0.0	 281.0	 3776	 3776	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 502	 0.00069	 0.005	 0.0	 491.0	 6259	 6259	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 3697	 0.00036	 0.00455	 0.0	 1809.0	 6921	 6921	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 3697	 0.00036	 0.00453	 0.0	 1776.0	 6952	 6952	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 7541	 0.00066	 0.00997	 0.0	 1348.0	 3162	 3162	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 7541	 0.00064	 0.01016	 0.0	 986.0	 3103	 3103	 0.0	 0.0	 1	 -30.0	 30.0;
	6306	 4826	 9.9e-05	 0.00044	 0.0	 529.0	 70039	 70039	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 4418	 6e-05	 0.000469	 0.0	 66806	 66806	 66806	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 1605	 3.9e-05	 0.000341	 0.0	 92032	 92032	 92032	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 6952	 0.002531	 0.01943	 0.0	 433.0	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 7124	 0.00945	 0.06418	 0.0	 414.0	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	9128	 217	 0.000591	 0.002831	 0.0	 357.0	 10923	 10923	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 217	 0.00087	 0.00387	 0.0	 7964	 7964	 7964	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 5350	 0.0015	 0.01785	 0.0	 1183.0	 1764	 1764	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 5350	 0.00147	 0.0182	 0.0	 1151.0	 1730	 1730	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 639	 0.00151	 0.0113	 0.0	 376.0	 2771	 2771	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 639	 0.001479	 0.011521	 0.0	 395.0	 2720	 2720	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 9130	 0.00174	 0.010341	 0.0	 414.0	 3013	 3013	 0.0	 0.0	 1	 -30.0	 30.0;
	1711	 9130	 0.001659	 0.01206	 0.0	 453.0	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 1998	 0.00069	 0.000479	 0.0	 37606	 37606	 37606	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 7974	 0.00044	 0.00139	 0.0	 21666	 21666	 21666	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 8180	 0.002039	 0.01601	 0.0	 1958	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 7466	 0.01349	 0.05662	 0.0	 357.0	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 305	 0.00082	 0.00438	 0.0	 300.0	 7089	 7089	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 305	 0.0008	 0.004461	 0.0	 281.0	 6970	 6970	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 5106	 0.001091	 0.00888	 0.0	 453.0	 3531	 3531	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 5106	 0.00111	 0.007039	 0.0	 491.0	 4433	 4433	 0.0	 0.0	 1	 -30.0	 30.0;
	2527	 8466	 0.000849	 0.00537	 0.0	 433.0	 5811	 5811	 0.0	 0.0	 1	 -30.0	 30.0;
	8669	 8893	 0.00061	 0.00275	 0.0	 357.0	 11214	 11214	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 7691	 0.00141	 0.0188	 0.0	 1315.0	 1676	 1676	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 6624	 0.00121	 0.01427	 0.0	 1545.0	 2206	 2206	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 8158	 0.001711	 0.007159	 0.0	 338.0	 4292	 4292	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 8795	 0.00545	 0.02381	 0.0	 300.0	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 4143	 0.000771	 0.004331	 0.0	 7181	 7181	 7181	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 2797	 0.00414	 0.03282	 0.0	 453.0	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 6331	 0.00264	 0.011521	 0.0	 338.0	 2673	 2673	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 6384	 0.00261	 0.011	 0.0	 376.0	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 7523	 0.00239	 0.00919	 0.0	 319.0	 3327	 3327	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 2889	 0.000539	 0.00226	 0.0	 13596	 13596	 13596	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 6887	 0.00325	 0.017979	 0.0	 472.0	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	1249	 4541	 0.00076	 0.0071	 0.0	 1216.0	 4424	 4424	 0.0	 0.0	 1	 -30.0	 30.0;
	819	 7523	 0.000651	 0.00343	 0.0	 9048	 9048	 9048	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 4353	 0.001219	 0.00812	 0.0	 338.0	 3847	 3847	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 4816	 0.00243	 0.01439	 0.0	 491.0	 2165	 2165	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 6246	 0.0006	 0.00839	 0.0	 1151.0	 3756	 3756	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 6246	 0.00059	 0.00856	 0.0	 1085.0	 3682	 3682	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 5658	 0.00087	 0.01328	 0.0	 1677.0	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 5658	 0.00073	 0.01595	 0.0	 1249.0	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 3645	 0.00163	 0.002039	 0.0	 12101	 12101	 12101	 0.0	 0.0	 1	 -30.0	 30.0;
	2924	 3645	 0.001659	 0.002	 0.0	 12156	 12156	 12156	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 5764	 0.00339	 0.019669	 0.0	 472.0	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 2360	 0.00239	 0.017281	 0.0	 529.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 9033	 0.00032	 0.00112	 0.0	 395.0	 27118	 27118	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 5918	 0.0018	 0.01401	 0.0	 395.0	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 5918	 0.00212	 0.012469	 0.0	 433.0	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	1275	 2850	 0.00063	 0.00411	 0.0	 7597	 7597	 7597	 0.0	 0.0	 1	 -30.0	 30.0;
	6426	 4110	 0.009729	 0.03505	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	6426	 3558	 0.01007	 0.03056	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 2816	 0.00042	 0.00623	 0.0	 5059	 5059	 5059	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 352	 0.00036	 0.00722	 0.0	 1743.0	 4370	 4370	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 6581	 0.00053	 0.0078	 0.0	 854.0	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 1923	 0.00109	 0.0173	 0.0	 723.0	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 5837	 0.00071	 0.01144	 0.0	 2756	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 3830	 0.00157	 0.01884	 0.0	 1151.0	 1671	 1671	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 3577	 0.00032	 0.00384	 0.0	 756.0	 8198	 8198	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 1794	 0.00041	 0.00649	 0.0	 1447.0	 4858	 4858	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 7808	 0.0004	 0.00658	 0.0	 4792	 4792	 4792	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 6581	 0.00054	 0.00763	 0.0	 854.0	 4130	 4130	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 1923	 0.00107	 0.01602	 0.0	 821.0	 1968	 1968	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 5837	 0.0007	 0.01165	 0.0	 2707	 2707	 2707	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 5648	 0.0016	 0.01844	 0.0	 1249.0	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	8030	 3577	 0.00032	 0.00376	 0.0	 854.0	 8371	 8371	 0.0	 0.0	 1	 -30.0	 30.0;
	4615	 171	 0.00212	 0.01207	 0.0	 395.0	 2578	 2578	 0.0	 0.0	 1	 -30.0	 30.0;
	3137	 2341	 5e-05	 0.00037	 0.0	 84603	 84603	 84603	 0.0	 0.0	 1	 -30.0	 30.0;
	6271	 8787	 0.00355	 0.024651	 0.0	 319.0	 1269	 1269	 0.0	 0.0	 1	 -30.0	 30.0;
	6252	 9137	 0.00675	 0.04145	 0.0	 433.0	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	5533	 7133	 0.00195	 0.014341	 0.0	 338.0	 2183	 2183	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 4355	 0.00018	 0.00043	 0.0	 281.0	 67762	 67762	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 2928	 0.00037	 0.000969	 0.0	 357.0	 30454	 30454	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 1341	 0.00257	 0.017169	 0.0	 376.0	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 5419	 0.00076	 0.00399	 0.0	 395.0	 7777	 7777	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 5419	 0.00075	 0.00406	 0.0	 395.0	 7651	 7651	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 2079	 0.003901	 0.023961	 0.0	 472.0	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 772	 0.00249	 0.019211	 0.0	 357.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	3654	 2928	 0.00025	 0.001159	 0.0	 376.0	 26642	 26642	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 7282	 0.00195	 0.02924	 0.0	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 2197	 0.00152	 0.01527	 0.0	 1381.0	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 7640	 0.00149	 0.01558	 0.0	 1513.0	 2019	 2019	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 1081	 0.00253	 0.0276	 0.0	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 1081	 0.00263	 0.02648	 0.0	 1188	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 2359	 0.00077	 0.0092	 0.0	 1315.0	 3422	 3422	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 4196	 0.00112	 0.01705	 0.0	 657.0	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 8546	 0.00226	 0.01101	 0.0	 2811	 2811	 2811	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 5987	 0.004531	 0.029039	 0.0	 395.0	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 8005	 0.002081	 0.030409	 0.0	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 3925	 0.0053	 0.03257	 0.0	 338.0	 958	 958	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 3324	 0.00513	 0.041901	 0.0	 453.0	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	5856	 4748	 0.001461	 0.01056	 0.0	 357.0	 2964	 2964	 0.0	 0.0	 1	 -30.0	 30.0;
	8265	 4816	 0.0005	 0.002591	 0.0	 11971	 11971	 11971	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6313	 0.00055	 0.0033	 0.0	 357.0	 9442	 9442	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 6532	 0.002289	 0.01763	 0.0	 376.0	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 2177	 0.0075	 0.043531	 0.0	 357.0	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 2079	 0.00138	 0.019961	 0.0	 1579	 1579	 1579	 0.0	 0.0	 1	 -30.0	 30.0;
	5723	 789	 0.00126	 0.018729	 0.0	 491.0	 1683	 1683	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 9189	 0.00038	 0.001331	 0.0	 395.0	 22821	 22821	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 3400	 0.00019	 0.001461	 0.0	 21440	 21440	 21440	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 4747	 0.002151	 0.013401	 0.0	 376.0	 2328	 2328	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 7791	 0.000789	 0.005669	 0.0	 472.0	 5519	 5519	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 6735	 3e-05	 0.00042	 0.0	 657.0	 75017	 75017	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 666	 0.00079	 0.00899	 0.0	 1282.0	 3501	 3501	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 666	 0.0008	 0.00879	 0.0	 1447.0	 3579	 3579	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 4435	 0.00334	 0.03393	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 1644	 0.00063	 0.00789	 0.0	 3991	 3991	 3991	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 3483	 0.0006	 0.00842	 0.0	 1216.0	 3742	 3742	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 7989	 0.00011	 0.00125	 0.0	 25173	 25173	 25173	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 6516	 0.00012	 0.001091	 0.0	 28780	 28780	 28780	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 7697	 9.9e-05	 0.00125	 0.0	 25191	 25191	 25191	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 416	 0.00294	 0.02443	 0.0	 529.0	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2847	 0.00144	 0.011151	 0.0	 395.0	 2810	 2810	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2563	 0.001831	 0.010849	 0.0	 491.0	 2871	 2871	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2563	 0.001599	 0.01055	 0.0	 472.0	 2961	 2961	 0.0	 0.0	 1	 -30.0	 30.0;
	4683	 2995	 0.00144	 0.019591	 0.0	 281.0	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 1001	 0.0133	 0.09551	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	5691	 4426	 0.009591	 0.073961	 0.0	 414.0	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 2721	 0.0007	 0.00671	 0.0	 1447.0	 4683	 4683	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 2721	 0.00072	 0.00658	 0.0	 1480.0	 4773	 4773	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 4936	 0.001901	 0.00964	 0.0	 529.0	 3215	 3215	 0.0	 0.0	 1	 -30.0	 30.0;
	2361	 5179	 0.001711	 0.01189	 0.0	 510.0	 2630	 2630	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 4748	 0.00025	 0.00187	 0.0	 16743	 16743	 16743	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 5522	 0.00043	 0.002211	 0.0	 14024	 14024	 14024	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 8670	 0.000401	 0.00243	 0.0	 12826	 12826	 12826	 0.0	 0.0	 1	 -30.0	 30.0;
	7809	 5110	 0.00336	 0.017	 0.0	 357.0	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	7222	 4816	 0.005521	 0.031031	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 3817	 9.9e-05	 0.00026	 0.0	 113538	 113538	 113538	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 2732	 0.00045	 0.00718	 0.0	 986.0	 4391	 4391	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 4550	 0.00044	 0.00665	 0.0	 821.0	 4740	 4740	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 4339	 0.00103	 0.01516	 0.0	 1183.0	 2079	 2079	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 7513	 0.00101	 0.01546	 0.0	 854.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 26	 0.00045	 0.00608	 0.0	 1414.0	 5182	 5182	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 9213	 0.0004	 0.00501	 0.0	 1249.0	 6285	 6285	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 9002	 0.001729	 0.01337	 0.0	 491.0	 2344	 2344	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 6231	 0.00264	 0.01489	 0.0	 414.0	 2089	 2089	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 883	 0.002341	 0.018961	 0.0	 414.0	 1654	 1654	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 5738	 0.001841	 0.01363	 0.0	 376.0	 2297	 2297	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 7700	 0.001219	 0.00949	 0.0	 395.0	 3302	 3302	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 9002	 0.002271	 0.01151	 0.0	 395.0	 2693	 2693	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 5990	 0.010781	 0.05775	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 6450	 0.00251	 0.013919	 0.0	 300.0	 2234	 2234	 0.0	 0.0	 1	 -30.0	 30.0;
	8860	 7726	 0.00101	 0.007331	 0.0	 414.0	 4269	 4269	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 4110	 0.00061	 0.003909	 0.0	 529.0	 7985	 7985	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 6376	 0.004289	 0.019331	 0.0	 1596	 1596	 1596	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 4110	 0.0008	 0.004401	 0.0	 529.0	 7062	 7062	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 4829	 0.008099	 0.03519	 0.0	 510.0	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 7857	 0.00063	 0.004591	 0.0	 414.0	 6817	 6817	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 7857	 0.000651	 0.00456	 0.0	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 9012	 0.00114	 0.00581	 0.0	 5335	 5335	 5335	 0.0	 0.0	 1	 -30.0	 30.0;
	2489	 2231	 0.001211	 0.00538	 0.0	 5728	 5728	 5728	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 3793	 0.00418	 0.030159	 0.0	 472.0	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 8497	 0.00324	 0.02413	 0.0	 510.0	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 8497	 0.003169	 0.024591	 0.0	 529.0	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 9002	 0.000219	 0.00088	 0.0	 395.0	 34833	 34833	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 9002	 0.000289	 0.00095	 0.0	 414.0	 31811	 31811	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 44	 0.0035	 0.022211	 0.0	 453.0	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 7582	 0.00313	 0.02256	 0.0	 1387	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	5944	 8808	 0.000831	 0.00162	 0.0	 17349	 17349	 17349	 0.0	 0.0	 1	 -30.0	 30.0;
	3183	 8515	 0.002099	 0.01068	 0.0	 300.0	 2903	 2903	 0.0	 0.0	 1	 -30.0	 30.0;
	1005	 8515	 0.00224	 0.00976	 0.0	 3155	 3155	 3155	 0.0	 0.0	 1	 -30.0	 30.0;
	8787	 1448	 0.00169	 0.01231	 0.0	 529.0	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	6636	 9051	 0.00011	 0.00076	 0.0	 41134	 41134	 41134	 0.0	 0.0	 1	 -30.0	 30.0;
	9109	 9051	 0.00011	 0.00068	 0.0	 45856	 45856	 45856	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 6376	 0.005479	 0.021909	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 8818	 0.003331	 0.017039	 0.0	 338.0	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	5077	 4353	 0.000479	 0.001271	 0.0	 23256	 23256	 23256	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 5241	 0.00109	 0.01629	 0.0	 723.0	 1935	 1935	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 8200	 4e-05	 0.00063	 0.0	 1710.0	 50038	 50038	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 6290	 0.0053	 0.024531	 0.0	 472.0	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 2291	 0.004659	 0.021919	 0.0	 319.0	 1410	 1410	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 3656	 0.001659	 0.01043	 0.0	 472.0	 2991	 2991	 0.0	 0.0	 1	 -30.0	 30.0;
	5002	 4144	 0.006961	 0.053539	 0.0	 395.0	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 5441	 0.00036	 0.00288	 0.0	 529.0	 10884	 10884	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 5441	 0.00038	 0.003	 0.0	 529.0	 10446	 10446	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4970	 0.00048	 0.00643	 0.0	 4899	 4899	 4899	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4970	 0.00051	 0.0066	 0.0	 4772	 4772	 4772	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 4970	 0.00046	 0.00729	 0.0	 1776.0	 4325	 4325	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 5461	 0.0006	 0.00868	 0.0	 1710.0	 3631	 3631	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 7778	 0.00068	 0.01076	 0.0	 1842.0	 2930	 2930	 0.0	 0.0	 1	 -30.0	 30.0;
	5490	 6897	 0.00066	 0.01096	 0.0	 1809.0	 2877	 2877	 0.0	 0.0	 1	 -30.0	 30.0;
	3075	 4562	 0.00101	 0.005099	 0.0	 300.0	 6077	 6077	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 8475	 0.003901	 0.02437	 0.0	 1280	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 2252	 0.00276	 0.016461	 0.0	 453.0	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	564	 7903	 0.00588	 0.047081	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	4331	 1857	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	2877	 3674	 0.00131	 0.00538	 0.0	 5705	 5705	 5705	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 1081	 0.00679	 0.04679	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	2854	 8267	 0.00138	 0.01466	 0.0	 986.0	 2146	 2146	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 9176	 0.003531	 0.01724	 0.0	 1795	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1422	 0.01324	 0.06936	 0.0	 376.0	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 8515	 0.00363	 0.01743	 0.0	 338.0	 1775	 1775	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 8515	 0.00257	 0.01662	 0.0	 433.0	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 5051	 0.01399	 0.056289	 0.0	 319.0	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1051	 0.00343	 0.01751	 0.0	 357.0	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1397	 0.00301	 0.015409	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 1584	 0.00857	 0.033091	 0.0	 376.0	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6888	 0.003341	 0.01689	 0.0	 1835	 1835	 1835	 0.0	 0.0	 1	 -30.0	 30.0;
	7653	 3019	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	7341	 7098	 0.00087	 0.00714	 0.0	 357.0	 4392	 4392	 0.0	 0.0	 1	 -30.0	 30.0;
	4701	 8267	 0.00011	 0.001	 0.0	 657.0	 31398	 31398	 0.0	 0.0	 1	 -30.0	 30.0;
	1672	 5365	 0.000219	 0.00101	 0.0	 30565	 30565	 30565	 0.0	 0.0	 1	 -30.0	 30.0;
	3880	 5365	 0.000219	 0.001031	 0.0	 29969	 29969	 29969	 0.0	 0.0	 1	 -30.0	 30.0;
	6648	 5365	 0.000271	 0.00101	 0.0	 30207	 30207	 30207	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 5365	 0.000271	 0.000979	 0.0	 31096	 31096	 31096	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 5365	 0.000289	 0.00107	 0.0	 28500	 28500	 28500	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 5365	 0.000289	 0.00105	 0.0	 29005	 29005	 29005	 0.0	 0.0	 1	 -30.0	 30.0;
	4353	 6053	 0.001591	 0.012289	 0.0	 281.0	 2550	 2550	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 5237	 0.000271	 0.001901	 0.0	 395.0	 16450	 16450	 0.0	 0.0	 1	 -30.0	 30.0;
	2166	 2886	 0.00186	 0.010711	 0.0	 414.0	 2906	 2906	 0.0	 0.0	 1	 -30.0	 30.0;
	1043	 3513	 1e-05	 0.0002	 0.0	 157740	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	4049	 883	 0.000169	 0.000271	 0.0	 98903	 98903	 98903	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 883	 0.000169	 0.00031	 0.0	 89464	 89464	 89464	 0.0	 0.0	 1	 -30.0	 30.0;
	1704	 5814	 0.00526	 0.03787	 0.0	 453.0	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	8107	 1486	 0.000229	 0.000599	 0.0	 49257	 49257	 49257	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 5522	 0.00089	 0.004091	 0.0	 338.0	 7545	 7545	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 8670	 0.00093	 0.004	 0.0	 300.0	 7692	 7692	 0.0	 0.0	 1	 -30.0	 30.0;
	8795	 7523	 0.00289	 0.013099	 0.0	 300.0	 2355	 2355	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 6430	 0.002599	 0.016479	 0.0	 433.0	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 7775	 0.00369	 0.02712	 0.0	 453.0	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 3857	 0.0062	 0.04864	 0.0	 529.0	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 333	 0.008021	 0.059031	 0.0	 529.0	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	455	 6940	 0.004979	 0.0295	 0.0	 472.0	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	8225	 3656	 0.001159	 0.005281	 0.0	 5843	 5843	 5843	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 7752	 0.00361	 0.01824	 0.0	 1699	 1699	 1699	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 1940	 0.001521	 0.01075	 0.0	 2910	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 4234	 0.00868	 0.041711	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 6828	 0.01118	 0.05986	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7571	 0.003229	 0.02543	 0.0	 491.0	 1233	 1233	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7571	 0.00218	 0.01869	 0.0	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7571	 0.001901	 0.021909	 0.0	 472.0	 1437	 1437	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7994	 0.00974	 0.043969	 0.0	 300.0	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 7226	 0.003461	 0.01814	 0.0	 357.0	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 1554	 0.00487	 0.027669	 0.0	 319.0	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	9011	 1156	 0.000651	 0.003961	 0.0	 510.0	 7870	 7870	 0.0	 0.0	 1	 -30.0	 30.0;
	8689	 5502	 0.00169	 0.00887	 0.0	 300.0	 3499	 3499	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 8873	 0.001711	 0.01336	 0.0	 414.0	 2346	 2346	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 980	 0.00031	 0.000539	 0.0	 300.0	 50801	 50801	 0.0	 0.0	 1	 -30.0	 30.0;
	3204	 3331	 0.0027	 0.01157	 0.0	 2659	 2659	 2659	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 639	 0.000909	 0.006901	 0.0	 414.0	 4539	 4539	 0.0	 0.0	 1	 -30.0	 30.0;
	3557	 4936	 0.001729	 0.01214	 0.0	 414.0	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 3492	 0.00614	 0.03106	 0.0	 338.0	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 7937	 0.00418	 0.02388	 0.0	 414.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	3255	 1262	 0.00238	 0.017771	 0.0	 1762	 1762	 1762	 0.0	 0.0	 1	 -30.0	 30.0;
	3255	 1803	 8.1e-05	 0.00063	 0.0	 49730	 49730	 49730	 0.0	 0.0	 1	 -30.0	 30.0;
	7373	 367	 0.001599	 0.01618	 0.0	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 2132	 0.00532	 0.026961	 0.0	 319.0	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 2132	 0.00361	 0.02814	 0.0	 453.0	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	4251	 5567	 0.002469	 0.01025	 0.0	 433.0	 2996	 2996	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 1808	 0.005229	 0.02675	 0.0	 300.0	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 1808	 0.00512	 0.02726	 0.0	 319.0	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 7857	 0.00355	 0.01694	 0.0	 300.0	 1826	 1826	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 7289	 0.00139	 0.007659	 0.0	 357.0	 4058	 4058	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 3999	 0.000169	 0.000669	 0.0	 414.0	 45778	 45778	 0.0	 0.0	 1	 -30.0	 30.0;
	8653	 2303	 0.00111	 0.00712	 0.0	 376.0	 4384	 4384	 0.0	 0.0	 1	 -30.0	 30.0;
	908	 6474	 0.00031	 0.001901	 0.0	 433.0	 16400	 16400	 0.0	 0.0	 1	 -30.0	 30.0;
	7030	 6474	 0.000281	 0.002091	 0.0	 14972	 14972	 14972	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 6556	 0.000281	 0.001651	 0.0	 18862	 18862	 18862	 0.0	 0.0	 1	 -30.0	 30.0;
	7325	 6556	 0.000271	 0.00169	 0.0	 18455	 18455	 18455	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 3391	 0.001521	 0.00843	 0.0	 281.0	 3688	 3688	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 3760	 0.000841	 0.0062	 0.0	 433.0	 5049	 5049	 0.0	 0.0	 1	 -30.0	 30.0;
	3707	 8765	 0.00019	 0.00126	 0.0	 414.0	 24790	 24790	 0.0	 0.0	 1	 -30.0	 30.0;
	900	 6619	 0.000219	 0.00143	 0.0	 21835	 21835	 21835	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 8109	 0.00121	 0.01796	 0.0	 1755	 1755	 1755	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 8109	 0.0014	 0.01512	 0.0	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 2177	 0.008409	 0.063651	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 5317	 0.00918	 0.07344	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 608	 0.004219	 0.0345	 0.0	 414.0	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	6532	 608	 0.0042	 0.031651	 0.0	 357.0	 990	 990	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 8763	 0.00121	 0.01381	 0.0	 1447.0	 2279	 2279	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 7056	 0.00107	 0.01326	 0.0	 1480.0	 2375	 2375	 0.0	 0.0	 1	 -30.0	 30.0;
	6828	 5814	 0.003401	 0.02607	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	3670	 21	 0.000289	 0.00138	 0.0	 319.0	 22404	 22404	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 7702	 0.001031	 0.006039	 0.0	 5156	 5156	 5156	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 7702	 0.00105	 0.005909	 0.0	 5264	 5264	 5264	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 7624	 0.001091	 0.007901	 0.0	 319.0	 3961	 3961	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 1129	 0.00332	 0.024021	 0.0	 453.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 3070	 0.00344	 0.021419	 0.0	 300.0	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 306	 0.00095	 0.010419	 0.0	 414.0	 3020	 3020	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 306	 0.00093	 0.01062	 0.0	 376.0	 2963	 2963	 0.0	 0.0	 1	 -30.0	 30.0;
	8448	 7491	 0.00474	 0.025409	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 2089	 0.000271	 0.000841	 0.0	 281.0	 35750	 35750	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 6253	 0.000271	 0.00119	 0.0	 281.0	 25882	 25882	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 1562	 0.000289	 0.00076	 0.0	 38849	 38849	 38849	 0.0	 0.0	 1	 -30.0	 30.0;
	7776	 1644	 0.00031	 0.00454	 0.0	 1842.0	 10592	 10592	 0.0	 0.0	 1	 -30.0	 30.0;
	5971	 3483	 0.00032	 0.0044	 0.0	 10925	 10925	 10925	 0.0	 0.0	 1	 -30.0	 30.0;
	2786	 1644	 0.00028	 0.00494	 0.0	 9741	 9741	 9741	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 3483	 0.00028	 0.00508	 0.0	 9474	 9474	 9474	 0.0	 0.0	 1	 -30.0	 30.0;
	8906	 923	 0.000531	 0.00093	 0.0	 29496	 29496	 29496	 0.0	 0.0	 1	 -30.0	 30.0;
	8906	 4914	 0.0003	 0.001031	 0.0	 395.0	 29418	 29418	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 9101	 0.00139	 0.02163	 0.0	 657.0	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	2656	 7164	 0.00164	 0.02321	 0.0	 1358	 1358	 1358	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 9101	 0.00136	 0.02205	 0.0	 657.0	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	3519	 7164	 0.0016	 0.02367	 0.0	 657.0	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 9137	 0.002091	 0.01174	 0.0	 281.0	 2649	 2649	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 9137	 0.001719	 0.00961	 0.0	 453.0	 3236	 3236	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 1026	 0.012341	 0.076781	 0.0	 319.0	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	5641	 9137	 0.00176	 0.009419	 0.0	 491.0	 3297	 3297	 0.0	 0.0	 1	 -30.0	 30.0;
	1096	 2889	 0.00031	 0.00182	 0.0	 17110	 17110	 17110	 0.0	 0.0	 1	 -30.0	 30.0;
	7380	 2732	 0.00386	 0.02348	 0.0	 1183.0	 1328	 1328	 0.0	 0.0	 1	 -30.0	 30.0;
	7380	 4787	 0.00017	 0.00104	 0.0	 1052.0	 29975	 29975	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 5308	 0.00061	 0.00808	 0.0	 1513.0	 3899	 3899	 0.0	 0.0	 1	 -30.0	 30.0;
	3543	 3830	 0.00059	 0.0067	 0.0	 4697	 4697	 4697	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 1027	 0.00059	 0.00748	 0.0	 1381.0	 4210	 4210	 0.0	 0.0	 1	 -30.0	 30.0;
	2372	 5648	 0.00061	 0.0063	 0.0	 4991	 4991	 4991	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 1172	 0.001031	 0.008789	 0.0	 529.0	 3570	 3570	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 9191	 0.00051	 0.006169	 0.0	 529.0	 5103	 5103	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 8722	 0.0005	 0.00619	 0.0	 529.0	 5087	 5087	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 3610	 0.00049	 0.00376	 0.0	 472.0	 8331	 8331	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 3610	 0.000539	 0.003229	 0.0	 433.0	 9649	 9649	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 3962	 0.001031	 0.00882	 0.0	 3558	 3558	 3558	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 1838	 0.000711	 0.00463	 0.0	 357.0	 6744	 6744	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 2230	 0.000711	 0.004539	 0.0	 6876	 6876	 6876	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 2467	 0.00206	 0.015341	 0.0	 414.0	 2041	 2041	 0.0	 0.0	 1	 -30.0	 30.0;
	5388	 2467	 0.002021	 0.01564	 0.0	 414.0	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 8853	 0.00094	 0.005781	 0.0	 510.0	 5394	 5394	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 1001	 0.002219	 0.016969	 0.0	 529.0	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	7583	 1808	 0.00238	 0.01187	 0.0	 281.0	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	7583	 2889	 0.00707	 0.03095	 0.0	 281.0	 995	 995	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 6624	 0.00256	 0.03401	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 2479	 0.00203	 0.02416	 0.0	 1052.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 4598	 0.001	 0.01459	 0.0	 2160	 2160	 2160	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 4231	 0.00103	 0.00987	 0.0	 1513.0	 3184	 3184	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 5144	 0.00038	 0.00483	 0.0	 1348.0	 6520	 6520	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 5144	 0.00041	 0.00398	 0.0	 1216.0	 7895	 7895	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 2479	 0.00167	 0.01721	 0.0	 1282.0	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 2129	 0.00098	 0.01487	 0.0	 887.0	 2120	 2120	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 9213	 0.00042	 0.00342	 0.0	 1249.0	 9168	 9168	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 9213	 0.00019	 0.00248	 0.0	 1480.0	 12700	 12700	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 4231	 0.00105	 0.00966	 0.0	 1809.0	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 3513	 0.00043	 0.00473	 0.0	 1282.0	 6651	 6651	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 3513	 0.00041	 0.00397	 0.0	 1216.0	 7915	 7915	 0.0	 0.0	 1	 -30.0	 30.0;
	1876	 3906	 0.00051	 0.00514	 0.0	 1118.0	 6116	 6116	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 3906	 0.00053	 0.00503	 0.0	 1315.0	 6246	 6246	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 3758	 0.00455	 0.022771	 0.0	 300.0	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 3758	 0.00557	 0.02055	 0.0	 281.0	 1484	 1484	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 3758	 0.00339	 0.02026	 0.0	 1538	 1538	 1538	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 8976	 0.00237	 0.01068	 0.0	 338.0	 2888	 2888	 0.0	 0.0	 1	 -30.0	 30.0;
	4952	 8189	 0.0037	 0.019479	 0.0	 281.0	 1594	 1594	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 7886	 0.01407	 0.056849	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 4544	 0.001669	 0.015409	 0.0	 510.0	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 4544	 0.001711	 0.015091	 0.0	 2080	 2080	 2080	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 3697	 0.00172	 0.01619	 0.0	 1578.0	 1941	 1941	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 7541	 0.00029	 0.00447	 0.0	 887.0	 7052	 7052	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 7541	 0.00033	 0.00387	 0.0	 1019.0	 8133	 8133	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 4141	 0.00079	 0.01154	 0.0	 887.0	 2731	 2731	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 4141	 0.00077	 0.01177	 0.0	 887.0	 2678	 2678	 0.0	 0.0	 1	 -30.0	 30.0;
	7905	 3022	 0.00127	 0.01498	 0.0	 1447.0	 2102	 2102	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 163	 0.00214	 0.012599	 0.0	 395.0	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	4245	 2425	 0.000159	 0.00125	 0.0	 357.0	 25068	 25068	 0.0	 0.0	 1	 -30.0	 30.0;
	3698	 5297	 0.000211	 0.000669	 0.0	 357.0	 45030	 45030	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 8328	 0.000341	 0.001169	 0.0	 414.0	 25940	 25940	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 870	 0.00024	 0.001469	 0.0	 472.0	 21222	 21222	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 2961	 0.00018	 0.000669	 0.0	 433.0	 45595	 45595	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 7988	 0.00033	 0.00683	 0.0	 821.0	 4620	 4620	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 2197	 0.00121	 0.01211	 0.0	 1315.0	 2596	 2596	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 7640	 0.00123	 0.01185	 0.0	 1348.0	 2652	 2652	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 4231	 0.00058	 0.0097	 0.0	 1085.0	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 5144	 0.00103	 0.01292	 0.0	 1151.0	 2438	 2438	 0.0	 0.0	 1	 -30.0	 30.0;
	3499	 3513	 0.00116	 0.01266	 0.0	 821.0	 2485	 2485	 0.0	 0.0	 1	 -30.0	 30.0;
	7289	 3999	 0.0013	 0.006841	 0.0	 357.0	 4537	 4537	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 1051	 6e-05	 0.000349	 0.0	 338.0	 89200	 89200	 0.0	 0.0	 1	 -30.0	 30.0;
	2702	 3435	 0.000169	 0.0007	 0.0	 300.0	 43865	 43865	 0.0	 0.0	 1	 -30.0	 30.0;
	9131	 2020	 0.000169	 0.000719	 0.0	 42767	 42767	 42767	 0.0	 0.0	 1	 -30.0	 30.0;
	6308	 6684	 0.000271	 0.001031	 0.0	 29632	 29632	 29632	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 3680	 0.008271	 0.036841	 0.0	 837	 837	 837	 0.0	 0.0	 1	 -30.0	 30.0;
	5410	 2751	 0.002969	 0.02299	 0.0	 319.0	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 4623	 0.00124	 0.01273	 0.0	 1118.0	 2470	 2470	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 4339	 0.00106	 0.00989	 0.0	 1381.0	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 5288	 7e-05	 0.00029	 0.0	 657.0	 105881	 105881	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 5421	 9e-05	 0.00079	 0.0	 657.0	 39728	 39728	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 6475	 0.00196	 0.02049	 0.0	 1513.0	 1535	 1535	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 8468	 0.00158	 0.01519	 0.0	 1183.0	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 2732	 0.00172	 0.01811	 0.0	 1513.0	 1737	 1737	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 7513	 0.00096	 0.01121	 0.0	 1644.0	 2808	 2808	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 6475	 0.00147	 0.01707	 0.0	 1844	 1844	 1844	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 4623	 0.00129	 0.0129	 0.0	 1216.0	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 4550	 0.00179	 0.01737	 0.0	 1545.0	 1809	 1809	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 6475	 0.00131	 0.01935	 0.0	 1629	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 9231	 0.003901	 0.01614	 0.0	 319.0	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 9231	 0.002591	 0.014771	 0.0	 453.0	 2107	 2107	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 9231	 0.00224	 0.0173	 0.0	 376.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 4054	 0.00012	 0.000849	 0.0	 36840	 36840	 36840	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 3481	 0.00394	 0.03039	 0.0	 395.0	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 3602	 0.00189	 0.01	 0.0	 3104	 3104	 3104	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 2794	 0.00032	 0.00257	 0.0	 12197	 12197	 12197	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 2794	 0.00038	 0.00224	 0.0	 13903	 13903	 13903	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 8467	 0.00751	 0.03955	 0.0	 395.0	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 1136	 0.00086	 0.006531	 0.0	 4796	 4796	 4796	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 22	 0.00087	 0.006591	 0.0	 4752	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 1001	 0.003031	 0.02276	 0.0	 529.0	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 4950	 0.006331	 0.03911	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 4410	 0.00605	 0.02986	 0.0	 281.0	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 6697	 0.003919	 0.01612	 0.0	 338.0	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 1159	 0.002039	 0.0108	 0.0	 338.0	 2874	 2874	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 7165	 0.006289	 0.026271	 0.0	 414.0	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 2848	 0.00042	 0.00547	 0.0	 756.0	 5758	 5758	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 2848	 0.00043	 0.00536	 0.0	 657.0	 5875	 5875	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 7522	 0.00147	 0.01373	 0.0	 1677.0	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 7522	 0.00131	 0.01555	 0.0	 1447.0	 2025	 2025	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 1642	 0.00221	 0.02217	 0.0	 1418	 1418	 1418	 0.0	 0.0	 1	 -30.0	 30.0;
	2938	 809	 0.00224	 0.0217	 0.0	 1448	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 6791	 0.00095	 0.003289	 0.0	 300.0	 9227	 9227	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 3400	 0.000229	 0.00082	 0.0	 37102	 37102	 37102	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7092	 0.00068	 0.00306	 0.0	 10077	 10077	 10077	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 3718	 0.00049	 0.00256	 0.0	 319.0	 12119	 12119	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 3701	 0.000531	 0.0022	 0.0	 13958	 13958	 13958	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7507	 0.00136	 0.00956	 0.0	 414.0	 3272	 3272	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7507	 0.0012	 0.010729	 0.0	 376.0	 2926	 2926	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 7507	 0.00105	 0.00861	 0.0	 3642	 3642	 3642	 0.0	 0.0	 1	 -30.0	 30.0;
	9189	 2406	 0.000591	 0.006969	 0.0	 4517	 4517	 4517	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 8511	 0.00025	 0.0008	 0.0	 37687	 37687	 37687	 0.0	 0.0	 1	 -30.0	 30.0;
	2801	 216	 0.00113	 0.00632	 0.0	 300.0	 4920	 4920	 0.0	 0.0	 1	 -30.0	 30.0;
	453	 2129	 0.0003	 0.00275	 0.0	 854.0	 11419	 11419	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 6952	 0.00836	 0.051659	 0.0	 529.0	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 6952	 0.01338	 0.073469	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 1183	 0.0027	 0.02089	 0.0	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 4410	 0.003419	 0.02636	 0.0	 510.0	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 8743	 0.009531	 0.033711	 0.0	 357.0	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	2446	 8763	 0.0004	 0.00707	 0.0	 4461	 4461	 4461	 0.0	 0.0	 1	 -30.0	 30.0;
	2627	 8763	 0.00035	 0.00701	 0.0	 4501	 4501	 4501	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 6785	 0.00194	 0.01751	 0.0	 433.0	 1793	 1793	 0.0	 0.0	 1	 -30.0	 30.0;
	4951	 6785	 0.00156	 0.01936	 0.0	 414.0	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 964	 0.00078	 0.00941	 0.0	 1249.0	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 964	 0.00074	 0.00969	 0.0	 1480.0	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8347	 0.00042	 0.00532	 0.0	 1578.0	 5920	 5920	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8347	 0.0004	 0.00473	 0.0	 1743.0	 6655	 6655	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 8347	 0.0006	 0.00499	 0.0	 1447.0	 6285	 6285	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 6552	 0.00086	 0.00638	 0.0	 510.0	 4907	 4907	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 6552	 0.000969	 0.00625	 0.0	 510.0	 4995	 4995	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 8999	 0.002781	 0.01725	 0.0	 357.0	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 4816	 0.005031	 0.028081	 0.0	 453.0	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 960	 1e-05	 0.00021	 0.0	 150246	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	7913	 960	 1e-05	 0.00025	 0.0	 126249	 126249	 126249	 0.0	 0.0	 1	 -30.0	 30.0;
	506	 960	 2e-05	 0.00031	 0.0	 657.0	 101684	 101684	 0.0	 0.0	 1	 -30.0	 30.0;
	2980	 960	 3e-05	 0.0004	 0.0	 657.0	 78748	 78748	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 6382	 0.000841	 0.00474	 0.0	 433.0	 6562	 6562	 0.0	 0.0	 1	 -30.0	 30.0;
	4554	 6382	 0.00082	 0.00487	 0.0	 433.0	 6397	 6397	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 1595	 0.00186	 0.011979	 0.0	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	3672	 5334	 0.00056	 0.003021	 0.0	 281.0	 10281	 10281	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 5334	 0.00055	 0.003081	 0.0	 10093	 10093	 10093	 0.0	 0.0	 1	 -30.0	 30.0;
	8997	 6153	 0.00114	 0.01063	 0.0	 2955	 2955	 2955	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 5935	 0.003719	 0.02295	 0.0	 529.0	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 5695	 0.006669	 0.04288	 0.0	 414.0	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 5799	 0.00243	 0.0198	 0.0	 1584	 1584	 1584	 0.0	 0.0	 1	 -30.0	 30.0;
	2931	 7124	 0.00845	 0.04339	 0.0	 433.0	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 3674	 0.00219	 0.015169	 0.0	 281.0	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 2132	 0.00357	 0.0302	 0.0	 319.0	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	2558	 7571	 0.005849	 0.032419	 0.0	 319.0	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	8834	 1129	 0.00406	 0.01688	 0.0	 1820	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	7377	 3324	 0.00113	 0.0065	 0.0	 4788	 4788	 4788	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 4426	 0.0068	 0.04613	 0.0	 414.0	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 1965	 0.00337	 0.02011	 0.0	 319.0	 1550	 1550	 0.0	 0.0	 1	 -30.0	 30.0;
	8060	 7162	 0.00011	 0.0005	 0.0	 61700	 61700	 61700	 0.0	 0.0	 1	 -30.0	 30.0;
	6922	 5482	 0.003711	 0.018521	 0.0	 338.0	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	6922	 1295	 0.000271	 0.00145	 0.0	 357.0	 21414	 21414	 0.0	 0.0	 1	 -30.0	 30.0;
	8369	 4710	 0.00326	 0.01824	 0.0	 1705	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	8961	 7133	 0.00118	 0.00712	 0.0	 319.0	 4377	 4377	 0.0	 0.0	 1	 -30.0	 30.0;
	8961	 6888	 0.00482	 0.02232	 0.0	 281.0	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 7019	 0.00013	 0.000469	 0.0	 281.0	 64904	 64904	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 6253	 0.000229	 0.00075	 0.0	 319.0	 40281	 40281	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 3391	 0.004591	 0.035021	 0.0	 433.0	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 1448	 0.005469	 0.03924	 0.0	 510.0	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 1448	 0.00536	 0.0403	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 115	 0.00424	 0.033031	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 4306	 2e-05	 0.00024	 0.0	 657.0	 131160	 131160	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 1763	 1e-05	 0.00021	 0.0	 657.0	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3697	 0.00286	 0.03653	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3794	 0.00117	 0.01183	 0.0	 1644.0	 2658	 2658	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3613	 0.00103	 0.01336	 0.0	 1381.0	 2358	 2358	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 1502	 0.00156	 0.01969	 0.0	 1447.0	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 6555	 0.00449	 0.05772	 0.0	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 3608	 0.00259	 0.03469	 0.0	 909	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 4134	 0.000219	 0.00118	 0.0	 26320	 26320	 26320	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 1979	 6e-05	 0.00095	 0.0	 33184	 33184	 33184	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 516	 6e-05	 0.000651	 0.0	 529.0	 48317	 48317	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 3580	 8.1e-05	 0.000841	 0.0	 529.0	 37387	 37387	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 3809	 0.00274	 0.020831	 0.0	 414.0	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 5616	 0.004781	 0.027729	 0.0	 453.0	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 5616	 0.002849	 0.02093	 0.0	 472.0	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 6697	 0.00513	 0.03014	 0.0	 414.0	 1034	 1034	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 7165	 0.00113	 0.00651	 0.0	 4781	 4781	 4781	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 892	 0.00125	 0.00707	 0.0	 472.0	 4400	 4400	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 5334	 0.003349	 0.01463	 0.0	 2105	 2105	 2105	 0.0	 0.0	 1	 -30.0	 30.0;
	7438	 1526	 0.00245	 0.0122	 0.0	 395.0	 2539	 2539	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6952	 0.00587	 0.036521	 0.0	 300.0	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6952	 0.00569	 0.03774	 0.0	 828	 828	 828	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6952	 0.006031	 0.03545	 0.0	 529.0	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 7883	 0.000531	 0.00301	 0.0	 10335	 10335	 10335	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 6430	 0.00076	 0.006099	 0.0	 414.0	 5140	 5140	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 7209	 0.008841	 0.028919	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 1910	 0.00169	 0.007091	 0.0	 4334	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 6820	 0.001031	 0.00361	 0.0	 8414	 8414	 8414	 0.0	 0.0	 1	 -30.0	 30.0;
	778	 3071	 0.00813	 0.030961	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 6267	 0.00013	 0.00068	 0.0	 433.0	 45626	 45626	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 3855	 0.000211	 0.000729	 0.0	 529.0	 41622	 41622	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 3855	 0.000169	 0.000669	 0.0	 491.0	 45778	 45778	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2928	 0.000669	 0.00251	 0.0	 395.0	 12161	 12161	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 2928	 0.000711	 0.00238	 0.0	 376.0	 12717	 12717	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 1172	 0.000229	 0.00238	 0.0	 491.0	 13211	 13211	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 9191	 0.0007	 0.0065	 0.0	 453.0	 4832	 4832	 0.0	 0.0	 1	 -30.0	 30.0;
	3657	 8722	 0.00061	 0.006031	 0.0	 414.0	 5211	 5211	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 5362	 0.000281	 0.0018	 0.0	 529.0	 17339	 17339	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 3962	 0.000211	 0.002409	 0.0	 13063	 13063	 13063	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 1343	 0.00056	 0.00773	 0.0	 657.0	 4076	 4076	 0.0	 0.0	 1	 -30.0	 30.0;
	1198	 29	 0.0023	 0.01581	 0.0	 1118.0	 1978	 1978	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 3680	 0.005039	 0.032151	 0.0	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 96	 0.00364	 0.01713	 0.0	 357.0	 1804	 1804	 0.0	 0.0	 1	 -30.0	 30.0;
	7473	 1868	 0.002169	 0.012409	 0.0	 2508	 2508	 2508	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 3184	 0.00113	 0.004719	 0.0	 6510	 6510	 6510	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 6570	 0.00113	 0.004979	 0.0	 376.0	 6187	 6187	 0.0	 0.0	 1	 -30.0	 30.0;
	3184	 4728	 0.00264	 0.01174	 0.0	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 7886	 0.00494	 0.03181	 0.0	 376.0	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	2654	 2132	 0.003711	 0.023961	 0.0	 510.0	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 8874	 0.001409	 0.01101	 0.0	 357.0	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 1625	 0.001169	 0.00593	 0.0	 281.0	 5227	 5227	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 1625	 0.00118	 0.00587	 0.0	 5276	 5276	 5276	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 3786	 0.00264	 0.012469	 0.0	 433.0	 2479	 2479	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 3786	 0.002349	 0.01414	 0.0	 395.0	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	3422	 4100	 0.00014	 0.0007	 0.0	 44249	 44249	 44249	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 4419	 3e-05	 0.00054	 0.0	 1776.0	 58406	 58406	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 7159	 3e-05	 0.00055	 0.0	 1710.0	 57347	 57347	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 3661	 4e-05	 0.00058	 0.0	 1677.0	 54332	 54332	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 5486	 4e-05	 0.00054	 0.0	 1776.0	 58336	 58336	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 4231	 0.00171	 0.02197	 0.0	 1282.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 4231	 0.00164	 0.02064	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 6921	 0.00136	 0.01756	 0.0	 1611.0	 1794	 1794	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 432	 0.00097	 0.00942	 0.0	 1381.0	 3336	 3336	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 432	 0.00086	 0.01109	 0.0	 1381.0	 2840	 2840	 0.0	 0.0	 1	 -30.0	 30.0;
	6624	 432	 0.00085	 0.0113	 0.0	 1348.0	 2788	 2788	 0.0	 0.0	 1	 -30.0	 30.0;
	3353	 6887	 0.000979	 0.0058	 0.0	 300.0	 5371	 5371	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 2050	 0.00052	 0.00593	 0.0	 1809.0	 5307	 5307	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 2050	 0.00046	 0.00672	 0.0	 1809.0	 4690	 4690	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 8704	 0.001151	 0.00636	 0.0	 472.0	 4888	 4888	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 8704	 0.001031	 0.007211	 0.0	 491.0	 4337	 4337	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 4710	 0.002341	 0.02286	 0.0	 433.0	 1375	 1375	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 1295	 0.002281	 0.02518	 0.0	 300.0	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 1910	 0.005479	 0.02114	 0.0	 281.0	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 2985	 0.011159	 0.08856	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 5853	 0.000669	 0.00249	 0.0	 300.0	 12252	 12252	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 7824	 0.00193	 0.01643	 0.0	 472.0	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 3071	 0.00024	 0.0017	 0.0	 338.0	 18399	 18399	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 195	 0.010159	 0.065849	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 7367	 0.00294	 0.02131	 0.0	 414.0	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 9155	 0.018841	 0.07469	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 6357	 0.015599	 0.052169	 0.0	 300.0	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 3126	 0.005831	 0.03969	 0.0	 395.0	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 8564	 0.00087	 0.00661	 0.0	 357.0	 4738	 4738	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 5567	 0.00637	 0.024659	 0.0	 281.0	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 3069	 0.0027	 0.020419	 0.0	 453.0	 1534	 1534	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 3876	 0.000409	 0.00314	 0.0	 338.0	 9976	 9976	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 8804	 0.001669	 0.01301	 0.0	 376.0	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 8804	 0.00164	 0.01325	 0.0	 395.0	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 4550	 0.00089	 0.00556	 0.0	 1183.0	 5610	 5610	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 4125	 0.00186	 0.01809	 0.0	 1513.0	 1737	 1737	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 3346	 0.00381	 0.02853	 0.0	 920.0	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2377	 0.012419	 0.072151	 0.0	 300.0	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 1401	 0.0042	 0.02556	 0.0	 300.0	 1220	 1220	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2850	 0.010771	 0.0493	 0.0	 376.0	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 2430	 0.010159	 0.04995	 0.0	 300.0	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 9164	 0.013169	 0.05113	 0.0	 395.0	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	8511	 1033	 0.000469	 0.001159	 0.0	 300.0	 25264	 25264	 0.0	 0.0	 1	 -30.0	 30.0;
	8511	 6178	 0.000229	 0.00105	 0.0	 357.0	 29393	 29393	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 980	 0.000271	 0.001271	 0.0	 433.0	 24306	 24306	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 4598	 0.00099	 0.01194	 0.0	 1545.0	 2637	 2637	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 4541	 0.00077	 0.01184	 0.0	 2663	 2663	 2663	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 5144	 0.00034	 0.00426	 0.0	 7392	 7392	 7392	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 2129	 0.00101	 0.01168	 0.0	 1644.0	 2695	 2695	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 4541	 0.00086	 0.01046	 0.0	 1710.0	 3010	 3010	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 3513	 0.00035	 0.00417	 0.0	 7549	 7549	 7549	 0.0	 0.0	 1	 -30.0	 30.0;
	6675	 1486	 0.000159	 0.00069	 0.0	 433.0	 44610	 44610	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 5836	 0.000781	 0.00488	 0.0	 529.0	 6392	 6392	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 575	 0.000781	 0.00511	 0.0	 433.0	 6111	 6111	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 8214	 0.00064	 0.003539	 0.0	 357.0	 8784	 8784	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 8214	 0.00057	 0.003781	 0.0	 338.0	 8261	 8261	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 3021	 0.000531	 0.00111	 0.0	 25671	 25671	 25671	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 7967	 0.000521	 0.00113	 0.0	 25386	 25386	 25386	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 5993	 0.00176	 0.00843	 0.0	 338.0	 3668	 3668	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 8804	 0.002461	 0.01975	 0.0	 472.0	 1588	 1588	 0.0	 0.0	 1	 -30.0	 30.0;
	4513	 6831	 0.000591	 0.00105	 0.0	 26216	 26216	 26216	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 1422	 0.00012	 0.00064	 0.0	 48510	 48510	 48510	 0.0	 0.0	 1	 -30.0	 30.0;
	6714	 1808	 0.000581	 0.004419	 0.0	 7088	 7088	 7088	 0.0	 0.0	 1	 -30.0	 30.0;
	6371	 1808	 0.000651	 0.004331	 0.0	 7213	 7213	 7213	 0.0	 0.0	 1	 -30.0	 30.0;
	513	 2866	 0.001289	 0.008289	 0.0	 395.0	 3766	 3766	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 9222	 0.00233	 0.03502	 0.0	 657.0	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 9222	 0.00238	 0.03781	 0.0	 657.0	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 2072	 0.00052	 0.00605	 0.0	 1282.0	 5202	 5202	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 5461	 0.00023	 0.00275	 0.0	 1414.0	 11447	 11447	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 8109	 0.00134	 0.01343	 0.0	 1611.0	 2341	 2341	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 8109	 0.00116	 0.01552	 0.0	 1381.0	 2030	 2030	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 707	 0.004169	 0.027919	 0.0	 414.0	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 4816	 0.00063	 0.008	 0.0	 3937	 3937	 3937	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 1866	 0.004841	 0.028581	 0.0	 529.0	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	7955	 5488	 0.007419	 0.05787	 0.0	 491.0	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 2467	 0.002719	 0.020331	 0.0	 395.0	 1540	 1540	 0.0	 0.0	 1	 -30.0	 30.0;
	2328	 7178	 0.000789	 0.005	 0.0	 6241	 6241	 6241	 0.0	 0.0	 1	 -30.0	 30.0;
	9180	 195	 0.00238	 0.013219	 0.0	 357.0	 2352	 2352	 0.0	 0.0	 1	 -30.0	 30.0;
	9180	 3133	 0.003771	 0.02701	 0.0	 395.0	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 4544	 0.001271	 0.00939	 0.0	 3334	 3334	 3334	 0.0	 0.0	 1	 -30.0	 30.0;
	9002	 6737	 0.000841	 0.00131	 0.0	 20291	 20291	 20291	 0.0	 0.0	 1	 -30.0	 30.0;
	8439	 3758	 0.005711	 0.043039	 0.0	 491.0	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	8439	 3758	 0.00562	 0.041901	 0.0	 395.0	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 2940	 0.00356	 0.019781	 0.0	 433.0	 1572	 1572	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 163	 0.004841	 0.03149	 0.0	 433.0	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	747	 8507	 0.00057	 0.00107	 0.0	 26055	 26055	 26055	 0.0	 0.0	 1	 -30.0	 30.0;
	6909	 4914	 0.000539	 0.00213	 0.0	 414.0	 14377	 14377	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 4747	 0.0007	 0.00425	 0.0	 7334	 7334	 7334	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 6495	 0.0012	 0.009531	 0.0	 3289	 3289	 3289	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 2751	 0.00206	 0.015901	 0.0	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 4728	 0.00063	 0.00312	 0.0	 9924	 9924	 9924	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 6475	 3e-05	 0.00041	 0.0	 1381.0	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	1093	 6475	 2e-05	 0.00043	 0.0	 73380	 73380	 73380	 0.0	 0.0	 1	 -30.0	 30.0;
	5709	 6475	 3e-05	 0.00039	 0.0	 1183.0	 80755	 80755	 0.0	 0.0	 1	 -30.0	 30.0;
	3825	 6475	 3e-05	 0.00038	 0.0	 82867	 82867	 82867	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 3503	 0.0008	 0.004151	 0.0	 7473	 7473	 7473	 0.0	 0.0	 1	 -30.0	 30.0;
	4549	 3503	 0.000901	 0.00381	 0.0	 8069	 8069	 8069	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 639	 0.000591	 0.004341	 0.0	 376.0	 7210	 7210	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 639	 0.000591	 0.00405	 0.0	 395.0	 7718	 7718	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 4541	 0.00218	 0.0275	 0.0	 1052.0	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 8195	 0.00184	 0.01677	 0.0	 986.0	 1873	 1873	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 964	 0.00058	 0.00807	 0.0	 986.0	 3905	 3905	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 964	 0.00056	 0.00823	 0.0	 821.0	 3830	 3830	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 3906	 0.00123	 0.01146	 0.0	 1315.0	 2741	 2741	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 3906	 0.0011	 0.01298	 0.0	 1381.0	 2425	 2425	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 8347	 0.00156	 0.01585	 0.0	 1677.0	 1984	 1984	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 2919	 0.00226	 0.02781	 0.0	 1133	 1133	 1133	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 188	 0.00614	 0.02831	 0.0	 300.0	 1091	 1091	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 2242	 0.00513	 0.03401	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	3903	 4114	 0.013219	 0.0597	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 6990	 0.012969	 0.06087	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	8626	 8930	 0.00437	 0.032831	 0.0	 453.0	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	8626	 2467	 0.005651	 0.033229	 0.0	 491.0	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 5488	 0.008969	 0.03625	 0.0	 338.0	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 7772	 0.012409	 0.05645	 0.0	 319.0	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 6382	 0.00038	 0.002271	 0.0	 300.0	 13719	 13719	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 4084	 0.00138	 0.01089	 0.0	 472.0	 2878	 2878	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 4084	 0.001539	 0.012521	 0.0	 491.0	 2504	 2504	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 53	 0.00205	 0.014229	 0.0	 433.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 7259	 0.00026	 0.00164	 0.0	 395.0	 19023	 19023	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 2475	 0.000289	 0.00169	 0.0	 18424	 18424	 18424	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 7577	 0.003349	 0.051211	 0.0	 357.0	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	7961	 2288	 0.00038	 0.001479	 0.0	 20686	 20686	 20686	 0.0	 0.0	 1	 -30.0	 30.0;
	1592	 7098	 0.00082	 0.00625	 0.0	 453.0	 5012	 5012	 0.0	 0.0	 1	 -30.0	 30.0;
	3187	 2079	 0.00275	 0.015581	 0.0	 472.0	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	6041	 5926	 0.000909	 0.00739	 0.0	 4243	 4243	 4243	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 8486	 0.00082	 0.01038	 0.0	 1447.0	 3034	 3034	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 7530	 0.00093	 0.01017	 0.0	 1282.0	 3094	 3094	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 1502	 0.00137	 0.01431	 0.0	 1776.0	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	3697	 1552	 0.00215	 0.02021	 0.0	 1555	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	6952	 3793	 0.01189	 0.058841	 0.0	 357.0	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2526	 0.00104	 0.01241	 0.0	 1151.0	 2537	 2537	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2526	 0.00092	 0.014	 0.0	 1151.0	 2252	 2252	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2365	 0.00055	 0.00845	 0.0	 1052.0	 3731	 3731	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 2365	 0.00054	 0.00861	 0.0	 887.0	 3662	 3662	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 3794	 0.00105	 0.01057	 0.0	 1710.0	 2974	 2974	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 3613	 0.00089	 0.01122	 0.0	 1513.0	 2807	 2807	 0.0	 0.0	 1	 -30.0	 30.0;
	6738	 6901	 0.00223	 0.02584	 0.0	 1218	 1218	 1218	 0.0	 0.0	 1	 -30.0	 30.0;
	8180	 5106	 0.00101	 0.007841	 0.0	 453.0	 3996	 3996	 0.0	 0.0	 1	 -30.0	 30.0;
	8180	 5106	 0.001081	 0.008099	 0.0	 472.0	 3866	 3866	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 7165	 0.011081	 0.068479	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 8721	 2e-05	 0.00033	 0.0	 95544	 95544	 95544	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 8872	 1e-05	 0.00029	 0.0	 1677.0	 108858	 108858	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 8672	 0.00071	 0.00892	 0.0	 1480.0	 3531	 3531	 0.0	 0.0	 1	 -30.0	 30.0;
	9222	 7164	 0.00136	 0.01526	 0.0	 1348.0	 2062	 2062	 0.0	 0.0	 1	 -30.0	 30.0;
	5935	 7772	 0.005401	 0.036021	 0.0	 491.0	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 3430	 0.00437	 0.033719	 0.0	 357.0	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 1051	 0.005151	 0.034919	 0.0	 414.0	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 800	 0.00038	 0.00139	 0.0	 21921	 21921	 21921	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 1077	 0.00037	 0.0015	 0.0	 20446	 20446	 20446	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 4747	 0.00069	 0.004461	 0.0	 433.0	 6998	 6998	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 5213	 0.00688	 0.040591	 0.0	 281.0	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 115	 0.001341	 0.008349	 0.0	 376.0	 3736	 3736	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 115	 0.001229	 0.009669	 0.0	 529.0	 3241	 3241	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 5753	 0.00137	 0.006039	 0.0	 319.0	 5101	 5101	 0.0	 0.0	 1	 -30.0	 30.0;
	7539	 6556	 0.001919	 0.01261	 0.0	 376.0	 2477	 2477	 0.0	 0.0	 1	 -30.0	 30.0;
	7539	 871	 0.00163	 0.0095	 0.0	 433.0	 3278	 3278	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 8874	 0.00488	 0.0497	 0.0	 472.0	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 4505	 0.001289	 0.0087	 0.0	 453.0	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 3436	 0.00211	 0.01524	 0.0	 472.0	 2054	 2054	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 3436	 0.00206	 0.015539	 0.0	 491.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 3436	 0.00276	 0.01631	 0.0	 414.0	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 6556	 0.00305	 0.019521	 0.0	 510.0	 1599	 1599	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 8765	 0.000409	 0.0023	 0.0	 395.0	 13522	 13522	 0.0	 0.0	 1	 -30.0	 30.0;
	8893	 6619	 0.00036	 0.00268	 0.0	 414.0	 11682	 11682	 0.0	 0.0	 1	 -30.0	 30.0;
	8165	 6734	 0.00032	 0.00049	 0.0	 53974	 53974	 53974	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 6734	 0.00013	 0.000349	 0.0	 84816	 84816	 84816	 0.0	 0.0	 1	 -30.0	 30.0;
	7988	 4231	 0.0002	 0.00327	 0.0	 9642	 9642	 9642	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 2142	 0.000919	 0.00561	 0.0	 433.0	 5557	 5557	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 2142	 0.00094	 0.00549	 0.0	 433.0	 5672	 5672	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 7519	 0.00175	 0.01976	 0.0	 433.0	 1593	 1593	 0.0	 0.0	 1	 -30.0	 30.0;
	804	 6744	 0.001729	 0.019331	 0.0	 376.0	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 6802	 0.00406	 0.02581	 0.0	 472.0	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	2286	 769	 0.00526	 0.025961	 0.0	 414.0	 1193	 1193	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 1081	 0.00179	 0.02098	 0.0	 1249.0	 1501	 1501	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 5983	 0.00162	 0.02148	 0.0	 1282.0	 1467	 1467	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 8267	 0.00492	 0.04991	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 960	 0.00109	 0.01361	 0.0	 986.0	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 960	 0.00097	 0.0153	 0.0	 789.0	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	3239	 3906	 0.00322	 0.03022	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 7361	 0.032831	 0.074151	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 6852	 0.01411	 0.058711	 0.0	 414.0	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 8515	 0.02725	 0.102979	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 3166	 0.012229	 0.04049	 0.0	 300.0	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 2676	 0.01994	 0.066719	 0.0	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 3793	 0.018591	 0.07462	 0.0	 338.0	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 4529	 0.008979	 0.03251	 0.0	 937	 937	 937	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 4234	 0.016531	 0.086031	 0.0	 281.0	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 44	 0.003591	 0.02137	 0.0	 491.0	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 6630	 0.00124	 0.008	 0.0	 300.0	 3902	 3902	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 6630	 0.001271	 0.007831	 0.0	 338.0	 3982	 3982	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 1545	 0.000469	 0.00294	 0.0	 395.0	 10610	 10610	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 4215	 0.000841	 0.003289	 0.0	 395.0	 9305	 9305	 0.0	 0.0	 1	 -30.0	 30.0;
	7163	 1917	 0.00219	 0.016539	 0.0	 300.0	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	7163	 5519	 0.002901	 0.020901	 0.0	 300.0	 1497	 1497	 0.0	 0.0	 1	 -30.0	 30.0;
	7647	 225	 0.0002	 0.001211	 0.0	 25736	 25736	 25736	 0.0	 0.0	 1	 -30.0	 30.0;
	4864	 1397	 9.1e-05	 0.000479	 0.0	 64786	 64786	 64786	 0.0	 0.0	 1	 -30.0	 30.0;
	7021	 7119	 0.005461	 0.029469	 0.0	 319.0	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	7021	 3324	 0.001979	 0.011289	 0.0	 491.0	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	1248	 163	 0.0023	 0.01289	 0.0	 2413	 2413	 2413	 0.0	 0.0	 1	 -30.0	 30.0;
	9045	 2457	 0.000159	 0.00037	 0.0	 78436	 78436	 78436	 0.0	 0.0	 1	 -30.0	 30.0;
	8874	 3786	 0.002789	 0.01562	 0.0	 433.0	 1991	 1991	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 5574	 0.002531	 0.012331	 0.0	 281.0	 2510	 2510	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 7663	 0.00357	 0.023289	 0.0	 300.0	 1341	 1341	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 4889	 0.00076	 0.006039	 0.0	 414.0	 5190	 5190	 0.0	 0.0	 1	 -30.0	 30.0;
	3997	 1526	 0.000469	 0.00075	 0.0	 35710	 35710	 35710	 0.0	 0.0	 1	 -30.0	 30.0;
	184	 1526	 0.00044	 0.00069	 0.0	 38599	 38599	 38599	 0.0	 0.0	 1	 -30.0	 30.0;
	2972	 2088	 0.00561	 0.035521	 0.0	 491.0	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 933	 0.004539	 0.03468	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 933	 0.00175	 0.0067	 0.0	 319.0	 4562	 4562	 0.0	 0.0	 1	 -30.0	 30.0;
	8676	 3643	 0.007461	 0.031419	 0.0	 300.0	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	8704	 6723	 0.00224	 0.012909	 0.0	 510.0	 2411	 2411	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 21	 0.0003	 0.000961	 0.0	 319.0	 31376	 31376	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 21	 0.00032	 0.001409	 0.0	 21862	 21862	 21862	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 1551	 0.002031	 0.0157	 0.0	 453.0	 1996	 1996	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 4103	 0.00038	 0.00306	 0.0	 414.0	 10244	 10244	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 7862	 0.00118	 0.0083	 0.0	 453.0	 3768	 3768	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 5458	 0.001229	 0.00787	 0.0	 472.0	 3966	 3966	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 5666	 0.00301	 0.01538	 0.0	 414.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 5458	 0.00063	 0.00114	 0.0	 281.0	 24252	 24252	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 7862	 0.00064	 0.00111	 0.0	 24653	 24653	 24653	 0.0	 0.0	 1	 -30.0	 30.0;
	7775	 3857	 0.004919	 0.03837	 0.0	 529.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 3436	 0.001831	 0.008349	 0.0	 338.0	 3696	 3696	 0.0	 0.0	 1	 -30.0	 30.0;
	3430	 401	 0.00536	 0.03188	 0.0	 433.0	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	2967	 8976	 0.00038	 0.001461	 0.0	 20925	 20925	 20925	 0.0	 0.0	 1	 -30.0	 30.0;
	2967	 8976	 0.000289	 0.001521	 0.0	 20403	 20403	 20403	 0.0	 0.0	 1	 -30.0	 30.0;
	8976	 2481	 0.00305	 0.016841	 0.0	 376.0	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	8976	 9108	 0.001781	 0.012729	 0.0	 357.0	 2458	 2458	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 7520	 0.00041	 0.00461	 0.0	 854.0	 6825	 6825	 0.0	 0.0	 1	 -30.0	 30.0;
	2056	 7520	 0.0004	 0.0047	 0.0	 920.0	 6697	 6697	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 5340	 0.00213	 0.01401	 0.0	 529.0	 2230	 2230	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 2319	 0.001271	 0.00887	 0.0	 338.0	 3526	 3526	 0.0	 0.0	 1	 -30.0	 30.0;
	4084	 2878	 0.00462	 0.02743	 0.0	 433.0	 1136	 1136	 0.0	 0.0	 1	 -30.0	 30.0;
	2597	 7422	 0.001539	 0.00776	 0.0	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	7183	 8931	 0.00025	 0.00478	 0.0	 10070	 10070	 10070	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 8931	 0.00025	 0.00487	 0.0	 9884	 9884	 9884	 0.0	 0.0	 1	 -30.0	 30.0;
	8128	 8931	 0.00025	 0.00435	 0.0	 723.0	 7250	 7250	 0.0	 0.0	 1	 -30.0	 30.0;
	6337	 8931	 0.00026	 0.00426	 0.0	 657.0	 7402	 7402	 0.0	 0.0	 1	 -30.0	 30.0;
	1237	 8931	 0.00025	 0.00479	 0.0	 10049	 10049	 10049	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 9173	 0.000169	 0.00076	 0.0	 338.0	 40572	 40572	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 7974	 0.00039	 0.00126	 0.0	 395.0	 23949	 23949	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 4816	 0.011229	 0.074659	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 1866	 0.014521	 0.058081	 0.0	 300.0	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 8809	 0.00064	 0.003919	 0.0	 433.0	 7955	 7955	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 5146	 0.014789	 0.07768	 0.0	 338.0	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 6940	 0.00938	 0.05355	 0.0	 472.0	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 1742	 0.00124	 0.004289	 0.0	 319.0	 7075	 7075	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 8627	 0.00968	 0.04388	 0.0	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 174	 0.008531	 0.067151	 0.0	 357.0	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 7437	 0.00731	 0.04106	 0.0	 338.0	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 5940	 0.004349	 0.02555	 0.0	 433.0	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 7495	 0.00599	 0.03462	 0.0	 376.0	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 4816	 0.002961	 0.021591	 0.0	 453.0	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 4816	 0.002901	 0.02206	 0.0	 472.0	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 6053	 0.002979	 0.016969	 0.0	 376.0	 1834	 1834	 0.0	 0.0	 1	 -30.0	 30.0;
	5764	 4189	 0.00312	 0.020021	 0.0	 376.0	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	8507	 1973	 0.000219	 0.000909	 0.0	 33783	 33783	 33783	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 1973	 0.000219	 0.00093	 0.0	 357.0	 33061	 33061	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 2128	 0.000151	 0.000289	 0.0	 96873	 96873	 96873	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 8255	 0.00563	 0.043599	 0.0	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	4942	 4748	 0.000969	 0.00612	 0.0	 414.0	 5098	 5098	 0.0	 0.0	 1	 -30.0	 30.0;
	3486	 3594	 0.005021	 0.020719	 0.0	 338.0	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	3486	 4679	 0.00988	 0.041039	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 4235	 0.003159	 0.02011	 0.0	 376.0	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	4656	 4235	 0.003219	 0.01969	 0.0	 376.0	 1584	 1584	 0.0	 0.0	 1	 -30.0	 30.0;
	7129	 5441	 0.00049	 0.00238	 0.0	 13000	 13000	 13000	 0.0	 0.0	 1	 -30.0	 30.0;
	7129	 5441	 0.000479	 0.002419	 0.0	 12810	 12810	 12810	 0.0	 0.0	 1	 -30.0	 30.0;
	8250	 5720	 0.00264	 0.019729	 0.0	 433.0	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	8250	 5720	 0.002581	 0.02011	 0.0	 395.0	 1558	 1558	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 6723	 0.00037	 0.002831	 0.0	 453.0	 11064	 11064	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 5686	 0.00213	 0.012789	 0.0	 414.0	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	2377	 805	 0.018669	 0.092281	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	907	 9091	 3.9e-05	 0.000401	 0.0	 78402	 78402	 78402	 0.0	 0.0	 1	 -30.0	 30.0;
	4056	 9091	 6e-05	 0.00044	 0.0	 281.0	 71132	 71132	 0.0	 0.0	 1	 -30.0	 30.0;
	6837	 2142	 6e-05	 0.0005	 0.0	 414.0	 62725	 62725	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 2641	 0.001271	 0.007031	 0.0	 376.0	 4421	 4421	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 7577	 0.00055	 0.003159	 0.0	 510.0	 9851	 9851	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 7577	 0.00055	 0.00338	 0.0	 491.0	 9225	 9225	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 7577	 0.00105	 0.004771	 0.0	 395.0	 6466	 6466	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 1629	 0.003289	 0.015039	 0.0	 281.0	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 687	 0.00036	 0.004349	 0.0	 510.0	 7239	 7239	 0.0	 0.0	 1	 -30.0	 30.0;
	3526	 687	 0.00038	 0.003669	 0.0	 8564	 8564	 8564	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 2425	 0.00118	 0.00701	 0.0	 4444	 4444	 4444	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 2425	 0.001229	 0.00686	 0.0	 433.0	 4533	 4533	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 5907	 0.00301	 0.0217	 0.0	 1442	 1442	 1442	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 5907	 0.003409	 0.01924	 0.0	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	6382	 5907	 0.003409	 0.01938	 0.0	 472.0	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	7847	 9217	 0.002719	 0.02131	 0.0	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	2981	 1448	 0.00295	 0.01956	 0.0	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 5686	 0.001091	 0.00831	 0.0	 376.0	 3769	 3769	 0.0	 0.0	 1	 -30.0	 30.0;
	2968	 5907	 0.00111	 0.008211	 0.0	 453.0	 3813	 3813	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2155	 0.002469	 0.015271	 0.0	 529.0	 2042	 2042	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 8112	 0.00212	 0.01601	 0.0	 1956	 1956	 1956	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 2535	 0.00037	 0.0028	 0.0	 433.0	 11184	 11184	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 7098	 0.00162	 0.01238	 0.0	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 7098	 0.001909	 0.01162	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 7098	 0.001909	 0.010729	 0.0	 453.0	 2899	 2899	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 3737	 0.00089	 0.00526	 0.0	 319.0	 5922	 5922	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 5529	 0.00087	 0.00536	 0.0	 5818	 5818	 5818	 0.0	 0.0	 1	 -30.0	 30.0;
	5441	 5753	 0.001521	 0.01176	 0.0	 433.0	 2664	 2664	 0.0	 0.0	 1	 -30.0	 30.0;
	9019	 6563	 0.00014	 0.000591	 0.0	 376.0	 52008	 52008	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 1101	 0.003531	 0.028781	 0.0	 1090	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 8291	 0.004599	 0.03657	 0.0	 453.0	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 8367	 0.00307	 0.019159	 0.0	 491.0	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 1100	 0.000581	 0.004461	 0.0	 414.0	 7022	 7022	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 6887	 0.00164	 0.01161	 0.0	 491.0	 2694	 2694	 0.0	 0.0	 1	 -30.0	 30.0;
	4939	 6880	 0.00057	 0.003281	 0.0	 433.0	 9486	 9486	 0.0	 0.0	 1	 -30.0	 30.0;
	7738	 6982	 0.020419	 0.063669	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	6565	 3121	 0.01424	 0.04751	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	8707	 280	 0.00157	 0.008849	 0.0	 453.0	 3515	 3515	 0.0	 0.0	 1	 -30.0	 30.0;
	8707	 2510	 0.01218	 0.07524	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 766	 0.00037	 0.00151	 0.0	 20318	 20318	 20318	 0.0	 0.0	 1	 -30.0	 30.0;
	8411	 6232	 0.000219	 0.000531	 0.0	 54993	 54993	 54993	 0.0	 0.0	 1	 -30.0	 30.0;
	3951	 1397	 0.002849	 0.0137	 0.0	 2258	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 7282	 0.00116	 0.01692	 0.0	 1183.0	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 7282	 0.00133	 0.01462	 0.0	 1315.0	 2152	 2152	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 6475	 0.00063	 0.00821	 0.0	 887.0	 3837	 3837	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 6475	 0.00064	 0.00804	 0.0	 1183.0	 3917	 3917	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 5420	 0.00126	 0.01272	 0.0	 1282.0	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 8267	 0.00337	 0.0494	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 7328	 0.0014	 0.0214	 0.0	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 7328	 0.00137	 0.02182	 0.0	 1445	 1445	 1445	 0.0	 0.0	 1	 -30.0	 30.0;
	5658	 7164	 0.00212	 0.02063	 0.0	 1118.0	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 410	 0.00186	 0.01045	 0.0	 510.0	 2976	 2976	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 7579	 0.00426	 0.021771	 0.0	 338.0	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 7579	 0.002659	 0.020539	 0.0	 395.0	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 4189	 0.00606	 0.049919	 0.0	 357.0	 629	 629	 0.0	 0.0	 1	 -30.0	 30.0;
	7282	 4196	 0.00109	 0.01192	 0.0	 789.0	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 3916	 0.013021	 0.049219	 0.0	 338.0	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 4747	 0.00236	 0.01239	 0.0	 338.0	 2505	 2505	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 4747	 0.0027	 0.015169	 0.0	 319.0	 2051	 2051	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 3346	 0.00285	 0.03283	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	4541	 3346	 0.00529	 0.03969	 0.0	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 3346	 0.00254	 0.03721	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2719	 0.000159	 0.00069	 0.0	 44610	 44610	 44610	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2719	 0.000229	 0.000979	 0.0	 31417	 31417	 31417	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 2719	 0.00024	 0.00082	 0.0	 36971	 36971	 36971	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 795	 0.000169	 0.00075	 0.0	 41087	 41087	 41087	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 4880	 0.00368	 0.01756	 0.0	 1761	 1761	 1761	 0.0	 0.0	 1	 -30.0	 30.0;
	3680	 1868	 0.002599	 0.020659	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 5564	 0.00018	 0.00064	 0.0	 47512	 47512	 47512	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 7036	 0.000159	 0.000771	 0.0	 281.0	 40125	 40125	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 5940	 0.00357	 0.01981	 0.0	 376.0	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 7495	 0.006021	 0.03205	 0.0	 433.0	 969	 969	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 2886	 0.001781	 0.01164	 0.0	 433.0	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 7049	 0.002781	 0.018831	 0.0	 414.0	 1660	 1660	 0.0	 0.0	 1	 -30.0	 30.0;
	2510	 6146	 0.000349	 0.00281	 0.0	 11156	 11156	 11156	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 1860	 0.00313	 0.02444	 0.0	 510.0	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 1860	 0.00368	 0.02074	 0.0	 491.0	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 3276	 9.1e-05	 0.001539	 0.0	 20489	 20489	 20489	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 3545	 0.00251	 0.01111	 0.0	 2774	 2774	 2774	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 6842	 0.003081	 0.017961	 0.0	 319.0	 1734	 1734	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 6744	 0.005341	 0.030419	 0.0	 338.0	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	2142	 7635	 9.9e-05	 0.00126	 0.0	 414.0	 24993	 24993	 0.0	 0.0	 1	 -30.0	 30.0;
	9091	 1040	 0.002169	 0.017901	 0.0	 319.0	 1752	 1752	 0.0	 0.0	 1	 -30.0	 30.0;
	2457	 6178	 0.00011	 0.00038	 0.0	 79847	 79847	 79847	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 1462	 0.00212	 0.00494	 0.0	 5876	 5876	 5876	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 7772	 0.018901	 0.077349	 0.0	 376.0	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	7881	 5365	 0.00957	 0.0395	 0.0	 357.0	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	7881	 6982	 0.02324	 0.063469	 0.0	 300.0	 468	 468	 0.0	 0.0	 1	 -30.0	 30.0;
	6926	 3327	 0.000531	 0.004331	 0.0	 510.0	 7240	 7240	 0.0	 0.0	 1	 -30.0	 30.0;
	1959	 615	 0.002581	 0.006229	 0.0	 4685	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	6455	 1262	 0.00031	 0.002211	 0.0	 319.0	 14149	 14149	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 6982	 0.01087	 0.06114	 0.0	 338.0	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 5918	 0.011581	 0.061099	 0.0	 319.0	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	7624	 3070	 0.002099	 0.016271	 0.0	 300.0	 1926	 1926	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 1547	 0.00093	 0.005461	 0.0	 5703	 5703	 5703	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 5237	 0.009591	 0.037039	 0.0	 319.0	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 772	 0.002591	 0.017211	 0.0	 453.0	 1815	 1815	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 8950	 0.00164	 0.013651	 0.0	 395.0	 2298	 2298	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 2079	 0.003219	 0.014719	 0.0	 357.0	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 2229	 0.00401	 0.022229	 0.0	 357.0	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 7049	 0.00126	 0.010211	 0.0	 491.0	 3071	 3071	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 7873	 0.009169	 0.03993	 0.0	 772	 772	 772	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 3865	 0.001349	 0.006081	 0.0	 5072	 5072	 5072	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 8486	 0.00156	 0.01931	 0.0	 1480.0	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 7530	 0.00152	 0.01968	 0.0	 1381.0	 1601	 1601	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 7778	 0.00094	 0.01433	 0.0	 1578.0	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 6897	 0.00092	 0.01461	 0.0	 1348.0	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 960	 0.00137	 0.02012	 0.0	 1019.0	 1567	 1567	 0.0	 0.0	 1	 -30.0	 30.0;
	1754	 960	 0.00134	 0.02051	 0.0	 821.0	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 4491	 0.00314	 0.042151	 0.0	 472.0	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 6010	 0.000651	 0.00494	 0.0	 6340	 6340	 6340	 0.0	 0.0	 1	 -30.0	 30.0;
	3857	 6940	 0.003961	 0.02426	 0.0	 491.0	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 1642	 0.00013	 0.0015	 0.0	 20980	 20980	 20980	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 809	 0.00013	 0.00147	 0.0	 1776.0	 21405	 21405	 0.0	 0.0	 1	 -30.0	 30.0;
	4819	 1642	 0.00011	 0.00172	 0.0	 1776.0	 18328	 18328	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 809	 0.00012	 0.00166	 0.0	 18979	 18979	 18979	 0.0	 0.0	 1	 -30.0	 30.0;
	3869	 1642	 0.00012	 0.00168	 0.0	 1809.0	 18755	 18755	 0.0	 0.0	 1	 -30.0	 30.0;
	3741	 809	 0.00012	 0.00172	 0.0	 1809.0	 18321	 18321	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 687	 0.00093	 0.005669	 0.0	 5499	 5499	 5499	 0.0	 0.0	 1	 -30.0	 30.0;
	2910	 7098	 0.00105	 0.00506	 0.0	 6113	 6113	 6113	 0.0	 0.0	 1	 -30.0	 30.0;
	5688	 6231	 0.00113	 0.006539	 0.0	 4761	 4761	 4761	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 5455	 0.00037	 0.002919	 0.0	 10736	 10736	 10736	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 5695	 0.005169	 0.03738	 0.0	 376.0	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	3814	 954	 0.00125	 0.006669	 0.0	 357.0	 4656	 4656	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 2438	 0.001281	 0.00661	 0.0	 4692	 4692	 4692	 0.0	 0.0	 1	 -30.0	 30.0;
	195	 2985	 0.00226	 0.0138	 0.0	 357.0	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 3513	 0.00213	 0.02677	 0.0	 1177	 1177	 1177	 0.0	 0.0	 1	 -30.0	 30.0;
	2518	 3346	 0.00154	 0.01919	 0.0	 1249.0	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 601	 0.00687	 0.04413	 0.0	 708	 708	 708	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 3241	 0.0045	 0.04725	 0.0	 357.0	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	4544	 7338	 0.00138	 0.00837	 0.0	 3724	 3724	 3724	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 1538	 0.000419	 0.001901	 0.0	 16227	 16227	 16227	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 1538	 0.00043	 0.00186	 0.0	 16547	 16547	 16547	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 4729	 0.003331	 0.015099	 0.0	 491.0	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	3344	 6616	 0.002099	 0.01631	 0.0	 433.0	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 5616	 0.001331	 0.01082	 0.0	 491.0	 2898	 2898	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 6691	 0.00199	 0.00818	 0.0	 281.0	 3753	 3753	 0.0	 0.0	 1	 -30.0	 30.0;
	3809	 6691	 0.00169	 0.008831	 0.0	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 892	 0.001771	 0.014281	 0.0	 2196	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	601	 616	 0.003099	 0.01844	 0.0	 395.0	 1690	 1690	 0.0	 0.0	 1	 -30.0	 30.0;
	3496	 1551	 0.003409	 0.01819	 0.0	 338.0	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	4925	 2230	 0.00057	 0.00369	 0.0	 8460	 8460	 8460	 0.0	 0.0	 1	 -30.0	 30.0;
	8057	 5907	 0.001081	 0.00468	 0.0	 6577	 6577	 6577	 0.0	 0.0	 1	 -30.0	 30.0;
	5354	 5907	 0.00105	 0.004771	 0.0	 6466	 6466	 6466	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 616	 0.001979	 0.01549	 0.0	 491.0	 2023	 2023	 0.0	 0.0	 1	 -30.0	 30.0;
	3674	 7338	 0.001469	 0.015151	 0.0	 2076	 2076	 2076	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 5083	 0.000711	 0.003969	 0.0	 319.0	 7834	 7834	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 7576	 0.00051	 0.00274	 0.0	 11334	 11334	 11334	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 3191	 0.000521	 0.00306	 0.0	 395.0	 10177	 10177	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 3488	 0.00188	 0.011841	 0.0	 2635	 2635	 2635	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 1578	 0.002469	 0.010539	 0.0	 2919	 2919	 2919	 0.0	 0.0	 1	 -30.0	 30.0;
	575	 5300	 0.00045	 0.00351	 0.0	 414.0	 8927	 8927	 0.0	 0.0	 1	 -30.0	 30.0;
	3929	 9173	 0.00037	 0.000659	 0.0	 41796	 41796	 41796	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 3818	 0.000401	 0.0007	 0.0	 39156	 39156	 39156	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 6232	 0.00014	 0.000531	 0.0	 57521	 57521	 57521	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 1643	 0.000289	 0.0013	 0.0	 395.0	 23719	 23719	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 6253	 7e-05	 0.000289	 0.0	 106228	 106228	 106228	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 6684	 0.00051	 0.002151	 0.0	 281.0	 14289	 14289	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 8151	 0.00037	 0.00157	 0.0	 433.0	 19583	 19583	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 449	 0.00022	 0.00277	 0.0	 1348.0	 11368	 11368	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 449	 0.00025	 0.00271	 0.0	 1447.0	 11607	 11607	 0.0	 0.0	 1	 -30.0	 30.0;
	7641	 3037	 0.000271	 0.002081	 0.0	 472.0	 15052	 15052	 0.0	 0.0	 1	 -30.0	 30.0;
	7641	 3037	 0.00025	 0.00231	 0.0	 433.0	 13595	 13595	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 2340	 0.00095	 0.00331	 0.0	 9173	 9173	 9173	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 8711	 0.00093	 0.00336	 0.0	 9061	 9061	 9061	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 8722	 0.000341	 0.002211	 0.0	 491.0	 14120	 14120	 0.0	 0.0	 1	 -30.0	 30.0;
	2644	 9191	 0.00032	 0.00232	 0.0	 13488	 13488	 13488	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 8522	 3.9e-05	 0.000271	 0.0	 414.0	 115370	 115370	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 7522	 0.00075	 0.0101	 0.0	 1513.0	 3119	 3119	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 4000	 0.00118	 0.01455	 0.0	 1447.0	 2164	 2164	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 9021	 0.0017	 0.0098	 0.0	 414.0	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 9021	 0.001521	 0.01111	 0.0	 2817	 2817	 2817	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 2042	 0.000169	 0.001401	 0.0	 22385	 22385	 22385	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 687	 0.002591	 0.01725	 0.0	 510.0	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 3520	 0.000169	 0.001159	 0.0	 338.0	 26969	 26969	 0.0	 0.0	 1	 -30.0	 30.0;
	2155	 4729	 0.00307	 0.01339	 0.0	 433.0	 2300	 2300	 0.0	 0.0	 1	 -30.0	 30.0;
	2641	 4889	 0.002591	 0.013521	 0.0	 414.0	 2295	 2295	 0.0	 0.0	 1	 -30.0	 30.0;
	9067	 9051	 0.000581	 0.005031	 0.0	 453.0	 6238	 6238	 0.0	 0.0	 1	 -30.0	 30.0;
	6969	 5573	 0.001419	 0.00595	 0.0	 281.0	 5164	 5164	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 1494	 0.00205	 0.02664	 0.0	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 2732	 0.00295	 0.03721	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 4550	 0.00335	 0.03648	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 1607	 0.00022	 0.00251	 0.0	 1151.0	 12537	 12537	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 2093	 0.00059	 0.00651	 0.0	 1545.0	 4833	 4833	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2177	 0.008539	 0.041979	 0.0	 281.0	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	3565	 2841	 0.001349	 0.0052	 0.0	 300.0	 5880	 5880	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 7972	 0.00245	 0.013909	 0.0	 414.0	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	3611	 2481	 0.001469	 0.008419	 0.0	 453.0	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 7164	 0.00084	 0.00836	 0.0	 1249.0	 3760	 3760	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 2078	 0.002591	 0.017789	 0.0	 414.0	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 7873	 0.009651	 0.05968	 0.0	 319.0	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 7519	 0.00143	 0.00799	 0.0	 281.0	 3892	 3892	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 6744	 0.001969	 0.014909	 0.0	 472.0	 2101	 2101	 0.0	 0.0	 1	 -30.0	 30.0;
	1026	 1860	 0.01039	 0.06406	 0.0	 395.0	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 3327	 0.000719	 0.005331	 0.0	 338.0	 5873	 5873	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 6921	 0.00052	 0.00565	 0.0	 1315.0	 5568	 5568	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 7069	 0.002409	 0.019479	 0.0	 395.0	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 7069	 0.00256	 0.019151	 0.0	 319.0	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 2866	 0.00656	 0.02288	 0.0	 281.0	 1328	 1328	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 6450	 0.0027	 0.014901	 0.0	 300.0	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 5738	 0.003591	 0.01362	 0.0	 300.0	 2243	 2243	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 2481	 0.002211	 0.01188	 0.0	 2614	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 8189	 0.00068	 0.00357	 0.0	 300.0	 8692	 8692	 0.0	 0.0	 1	 -30.0	 30.0;
	7474	 1584	 0.000211	 0.000969	 0.0	 300.0	 31852	 31852	 0.0	 0.0	 1	 -30.0	 30.0;
	8947	 3390	 9.9e-05	 0.000539	 0.0	 57640	 57640	 57640	 0.0	 0.0	 1	 -30.0	 30.0;
	1808	 6384	 0.00645	 0.0263	 0.0	 319.0	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	4624	 6031	 0.00063	 0.001901	 0.0	 15773	 15773	 15773	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 3558	 0.000281	 0.000669	 0.0	 43532	 43532	 43532	 0.0	 0.0	 1	 -30.0	 30.0;
	7694	 3865	 0.000219	 0.00064	 0.0	 46697	 46697	 46697	 0.0	 0.0	 1	 -30.0	 30.0;
	9181	 6723	 0.00014	 0.00105	 0.0	 29820	 29820	 29820	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 8748	 0.003219	 0.020729	 0.0	 433.0	 1506	 1506	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 8475	 0.00051	 0.003151	 0.0	 472.0	 9896	 9896	 0.0	 0.0	 1	 -30.0	 30.0;
	8373	 8475	 0.000409	 0.00331	 0.0	 414.0	 9471	 9471	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 6639	 0.002289	 0.017479	 0.0	 491.0	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 1187	 0.002831	 0.01895	 0.0	 433.0	 1649	 1649	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 7274	 0.006289	 0.036521	 0.0	 853	 853	 853	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 8992	 0.005651	 0.032169	 0.0	 338.0	 968	 968	 0.0	 0.0	 1	 -30.0	 30.0;
	5630	 7266	 0.00414	 0.02262	 0.0	 376.0	 1374	 1374	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 6734	 0.01095	 0.05814	 0.0	 357.0	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 1015	 0.009	 0.0368	 0.0	 395.0	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 8310	 0.000229	 0.00181	 0.0	 453.0	 17314	 17314	 0.0	 0.0	 1	 -30.0	 30.0;
	1980	 6570	 0.00119	 0.00726	 0.0	 510.0	 4294	 4294	 0.0	 0.0	 1	 -30.0	 30.0;
	9137	 749	 0.011771	 0.051669	 0.0	 529.0	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	7522	 2183	 0.00209	 0.02279	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 3916	 0.002031	 0.01443	 0.0	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 6891	 0.00145	 0.008479	 0.0	 453.0	 3673	 3673	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 6199	 0.00124	 0.01433	 0.0	 1414.0	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	2526	 6199	 0.00127	 0.01402	 0.0	 1776.0	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 3649	 0.013039	 0.052841	 0.0	 529.0	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 6199	 0.00235	 0.02739	 0.0	 854.0	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 6199	 0.0024	 0.02681	 0.0	 1118.0	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 4141	 0.00135	 0.02056	 0.0	 657.0	 1534	 1534	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 1311	 0.00087	 0.01124	 0.0	 854.0	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	8316	 174	 0.0012	 0.00818	 0.0	 529.0	 3821	 3821	 0.0	 0.0	 1	 -30.0	 30.0;
	174	 6430	 0.006961	 0.05561	 0.0	 395.0	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 7892	 0.00105	 0.00763	 0.0	 376.0	 4102	 4102	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 561	 0.000219	 0.00182	 0.0	 17232	 17232	 17232	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 8843	 3.9e-05	 0.0002	 0.0	 155017	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 8843	 4.5e-05	 0.000195	 0.0	 157839	 157839	 157839	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 4239	 0.0035	 0.022651	 0.0	 433.0	 1379	 1379	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 1860	 0.004281	 0.02319	 0.0	 357.0	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	3866	 5395	 0.003729	 0.014021	 0.0	 319.0	 2178	 2178	 0.0	 0.0	 1	 -30.0	 30.0;
	7042	 2177	 0.00212	 0.01582	 0.0	 472.0	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	8672	 7164	 0.00056	 0.00784	 0.0	 657.0	 4019	 4019	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 7772	 0.004401	 0.01813	 0.0	 1694	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 7772	 0.005021	 0.02144	 0.0	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	4885	 2928	 0.00018	 0.000219	 0.0	 281.0	 111427	 111427	 0.0	 0.0	 1	 -30.0	 30.0;
	4157	 2928	 0.000151	 0.000211	 0.0	 121741	 121741	 121741	 0.0	 0.0	 1	 -30.0	 30.0;
	4432	 2928	 0.000151	 0.000211	 0.0	 121741	 121741	 121741	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 5983	 0.00282	 0.02591	 0.0	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 6552	 0.00131	 0.008539	 0.0	 433.0	 3657	 3657	 0.0	 0.0	 1	 -30.0	 30.0;
	3956	 7507	 0.002159	 0.015969	 0.0	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 1838	 0.00019	 0.000281	 0.0	 93122	 93122	 93122	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 2230	 0.0002	 0.000281	 0.0	 91583	 91583	 91583	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 8005	 0.00139	 0.00774	 0.0	 472.0	 4017	 4017	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 6351	 0.01101	 0.06739	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 2749	 0.00063	 0.00463	 0.0	 338.0	 6761	 6761	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 9130	 0.002341	 0.009599	 0.0	 376.0	 3197	 3197	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 4189	 0.00375	 0.021659	 0.0	 376.0	 1438	 1438	 0.0	 0.0	 1	 -30.0	 30.0;
	1494	 5781	 0.00056	 0.00749	 0.0	 1183.0	 4206	 4206	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 6616	 0.00118	 0.00926	 0.0	 433.0	 3384	 3384	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 6031	 0.002039	 0.013081	 0.0	 414.0	 2386	 2386	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 7507	 0.00155	 0.010961	 0.0	 2854	 2854	 2854	 0.0	 0.0	 1	 -30.0	 30.0;
	3276	 7635	 3.9e-05	 0.00036	 0.0	 319.0	 87233	 87233	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 196	 0.00024	 0.000409	 0.0	 281.0	 66610	 66610	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 7132	 0.000341	 0.001659	 0.0	 453.0	 18651	 18651	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 5351	 0.005461	 0.024919	 0.0	 357.0	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 7056	 0.00158	 0.02413	 0.0	 854.0	 1307	 1307	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8825	 0.00155	 0.02458	 0.0	 756.0	 1283	 1283	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 6889	 0.00021	 0.00256	 0.0	 1315.0	 12298	 12298	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 6889	 0.00024	 0.00243	 0.0	 1414.0	 12936	 12936	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8887	 0.00144	 0.02266	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8887	 0.0014	 0.02098	 0.0	 1447.0	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	8763	 8487	 0.00086	 0.01074	 0.0	 2932	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	8748	 8475	 0.003341	 0.02611	 0.0	 453.0	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 6785	 0.00387	 0.02063	 0.0	 414.0	 1505	 1505	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 6785	 0.00405	 0.018271	 0.0	 414.0	 1688	 1688	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 1179	 0.00101	 0.00462	 0.0	 300.0	 6680	 6680	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 2575	 0.00088	 0.00389	 0.0	 319.0	 7921	 7921	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 7274	 0.005081	 0.039	 0.0	 414.0	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 8189	 0.00257	 0.0208	 0.0	 453.0	 1508	 1508	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 8189	 0.00251	 0.01926	 0.0	 414.0	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 1039	 0.002531	 0.01314	 0.0	 2361	 2361	 2361	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7840	 0.00132	 0.00869	 0.0	 3594	 3594	 3594	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 8913	 0.00082	 0.004021	 0.0	 319.0	 7698	 7698	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 4852	 0.00143	 0.007479	 0.0	 338.0	 4149	 4149	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 1183	 0.000659	 0.005771	 0.0	 5439	 5439	 5439	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 1183	 0.000591	 0.006539	 0.0	 4811	 4811	 4811	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 6291	 0.00589	 0.025599	 0.0	 376.0	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 6982	 0.00614	 0.02343	 0.0	 338.0	 1305	 1305	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 1798	 0.00155	 0.01994	 0.0	 1381.0	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	2732	 3346	 0.00205	 0.03218	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	4550	 3346	 0.00233	 0.03154	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	4725	 5738	 0.002341	 0.01982	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 8310	 8.1e-05	 0.000521	 0.0	 433.0	 59909	 59909	 0.0	 0.0	 1	 -30.0	 30.0;
	1398	 5567	 9.9e-05	 0.00069	 0.0	 491.0	 45315	 45315	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 4580	 0.00276	 0.016419	 0.0	 453.0	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 4908	 0.00036	 0.001229	 0.0	 357.0	 24666	 24666	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 3740	 0.000229	 0.000711	 0.0	 414.0	 42288	 42288	 0.0	 0.0	 1	 -30.0	 30.0;
	6563	 870	 0.00013	 0.00099	 0.0	 414.0	 31635	 31635	 0.0	 0.0	 1	 -30.0	 30.0;
	8999	 6495	 0.001159	 0.00689	 0.0	 319.0	 4522	 4522	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 5994	 0.008531	 0.03045	 0.0	 281.0	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 8005	 0.000781	 0.004531	 0.0	 414.0	 6871	 6871	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 8005	 0.00075	 0.00474	 0.0	 433.0	 6583	 6583	 0.0	 0.0	 1	 -30.0	 30.0;
	5881	 4031	 0.002159	 0.008349	 0.0	 3663	 3663	 3663	 0.0	 0.0	 1	 -30.0	 30.0;
	8195	 8334	 0.00162	 0.01651	 0.0	 1447.0	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 6357	 0.01236	 0.044211	 0.0	 300.0	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 6357	 0.00825	 0.03989	 0.0	 319.0	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 3775	 0.02187	 0.066961	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 3975	 0.01212	 0.06661	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 1642	 0.00036	 0.00534	 0.0	 789.0	 5902	 5902	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 1153	 0.000229	 0.00063	 0.0	 47123	 47123	 47123	 0.0	 0.0	 1	 -30.0	 30.0;
	6802	 7599	 0.000219	 0.000581	 0.0	 50874	 50874	 50874	 0.0	 0.0	 1	 -30.0	 30.0;
	4025	 3994	 0.000281	 0.00063	 0.0	 45791	 45791	 45791	 0.0	 0.0	 1	 -30.0	 30.0;
	1595	 1414	 0.005021	 0.035659	 0.0	 319.0	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	3114	 3656	 0.00174	 0.007901	 0.0	 3905	 3905	 3905	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 2229	 0.003919	 0.020581	 0.0	 395.0	 1508	 1508	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 9108	 0.003341	 0.016349	 0.0	 395.0	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 1478	 0.003271	 0.016669	 0.0	 357.0	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	2799	 8515	 0.000151	 0.000659	 0.0	 319.0	 46722	 46722	 0.0	 0.0	 1	 -30.0	 30.0;
	6405	 7873	 0.00736	 0.035659	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	6405	 3894	 0.00944	 0.042169	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 4734	 0.00068	 0.00652	 0.0	 756.0	 4819	 4819	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 3483	 0.00188	 0.02281	 0.0	 1282.0	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 7052	 0.00168	 0.00956	 0.0	 433.0	 3255	 3255	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 7052	 0.001669	 0.00981	 0.0	 414.0	 3175	 3175	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 772	 0.002229	 0.01599	 0.0	 491.0	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 772	 0.00218	 0.01631	 0.0	 510.0	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 6475	 0.00238	 0.02124	 0.0	 953.0	 1478	 1478	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 6475	 0.00194	 0.02023	 0.0	 1151.0	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	7361	 3166	 0.013831	 0.05955	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	7361	 426	 0.00876	 0.04875	 0.0	 319.0	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 1857	 0.0002	 0.00099	 0.0	 300.0	 31275	 31275	 0.0	 0.0	 1	 -30.0	 30.0;
	1364	 2430	 0.00105	 0.00826	 0.0	 376.0	 3794	 3794	 0.0	 0.0	 1	 -30.0	 30.0;
	2177	 749	 0.0172	 0.06637	 0.0	 376.0	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 2850	 0.00305	 0.015781	 0.0	 376.0	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	6555	 3608	 0.00208	 0.02105	 0.0	 1381.0	 1494	 1494	 0.0	 0.0	 1	 -30.0	 30.0;
	8475	 1965	 0.00614	 0.043729	 0.0	 376.0	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	8475	 5926	 0.000229	 0.001849	 0.0	 453.0	 16954	 16954	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 6053	 0.00386	 0.025789	 0.0	 338.0	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 2341	 0.002031	 0.012	 0.0	 491.0	 2596	 2596	 0.0	 0.0	 1	 -30.0	 30.0;
	2629	 7507	 0.000591	 0.004	 0.0	 395.0	 7813	 7813	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 2406	 9.1e-05	 0.00051	 0.0	 60973	 60973	 60973	 0.0	 0.0	 1	 -30.0	 30.0;
	7577	 5814	 0.00732	 0.039969	 0.0	 319.0	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	7577	 3231	 0.004581	 0.02031	 0.0	 529.0	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	7663	 5814	 0.00132	 0.00537	 0.0	 357.0	 5713	 5713	 0.0	 0.0	 1	 -30.0	 30.0;
	1183	 1159	 0.007521	 0.0387	 0.0	 376.0	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	6852	 5051	 0.005159	 0.031281	 0.0	 433.0	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 8807	 9.9e-05	 0.001159	 0.0	 27156	 27156	 27156	 0.0	 0.0	 1	 -30.0	 30.0;
	6947	 8807	 9.9e-05	 0.00113	 0.0	 27847	 27847	 27847	 0.0	 0.0	 1	 -30.0	 30.0;
	4505	 4357	 0.00019	 0.000909	 0.0	 281.0	 34015	 34015	 0.0	 0.0	 1	 -30.0	 30.0;
	7144	 7791	 0.00107	 0.00413	 0.0	 7404	 7404	 7404	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 2085	 9e-05	 0.00058	 0.0	 1151.0	 53817	 53817	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 4024	 9e-05	 0.00059	 0.0	 1052.0	 52926	 52926	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 9065	 8e-05	 0.00053	 0.0	 657.0	 58932	 58932	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 661	 8e-05	 0.00052	 0.0	 657.0	 60039	 60039	 0.0	 0.0	 1	 -30.0	 30.0;
	6612	 8864	 0.000271	 0.00151	 0.0	 395.0	 20590	 20590	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00053	 0.00585	 0.0	 1809.0	 5378	 5378	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00047	 0.00663	 0.0	 1348.0	 4753	 4753	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00046	 0.00676	 0.0	 1151.0	 4662	 4662	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 6199	 0.00045	 0.00689	 0.0	 1151.0	 4575	 4575	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 8494	 0.00028	 0.00338	 0.0	 1480.0	 9314	 9314	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 8494	 0.0003	 0.00319	 0.0	 1249.0	 9859	 9859	 0.0	 0.0	 1	 -30.0	 30.0;
	1643	 4511	 0.00025	 0.00101	 0.0	 376.0	 30359	 30359	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 1973	 0.000281	 0.00119	 0.0	 25834	 25834	 25834	 0.0	 0.0	 1	 -30.0	 30.0;
	2902	 5573	 0.00018	 0.00063	 0.0	 48210	 48210	 48210	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 4410	 0.00382	 0.02868	 0.0	 1092	 1092	 1092	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 333	 0.00361	 0.0235	 0.0	 472.0	 1329	 1329	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 6908	 0.00538	 0.03569	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 7726	 6e-05	 0.000409	 0.0	 414.0	 76413	 76413	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 3243	 9e-05	 0.00102	 0.0	 657.0	 30849	 30849	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 2458	 0.0014	 0.01649	 0.0	 1611.0	 1909	 1909	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 2919	 0.00034	 0.00427	 0.0	 1019.0	 7375	 7375	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 8560	 0.0001	 0.00109	 0.0	 657.0	 28859	 28859	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 6427	 0.00137	 0.01682	 0.0	 1677.0	 1872	 1872	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 8347	 0.00131	 0.01262	 0.0	 1414.0	 2490	 2490	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 5610	 0.00262	 0.019669	 0.0	 433.0	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2421	 0.00082	 0.00526	 0.0	 376.0	 5934	 5934	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2421	 0.000841	 0.005151	 0.0	 357.0	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 2421	 0.000669	 0.005081	 0.0	 376.0	 6164	 6164	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 6989	 0.001919	 0.012669	 0.0	 376.0	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 1545	 0.002659	 0.02	 0.0	 1566	 1566	 1566	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 3541	 0.003031	 0.02343	 0.0	 472.0	 1338	 1338	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 4710	 0.01176	 0.059159	 0.0	 300.0	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 8367	 0.002469	 0.017531	 0.0	 395.0	 1785	 1785	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 2288	 0.000669	 0.005729	 0.0	 5477	 5477	 5477	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 8473	 0.000781	 0.00876	 0.0	 281.0	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 5455	 0.00062	 0.00482	 0.0	 453.0	 6500	 6500	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 7635	 0.001349	 0.012599	 0.0	 433.0	 2493	 2493	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 8473	 0.000979	 0.0082	 0.0	 3825	 3825	 3825	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 883	 0.008091	 0.028831	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	6842	 2288	 0.000711	 0.005969	 0.0	 414.0	 5255	 5255	 0.0	 0.0	 1	 -30.0	 30.0;
	3969	 7726	 0.00145	 0.00857	 0.0	 3635	 3635	 3635	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 1129	 0.00869	 0.03768	 0.0	 300.0	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 3070	 0.001719	 0.00837	 0.0	 357.0	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 5365	 0.01582	 0.067349	 0.0	 338.0	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 5365	 0.01457	 0.06469	 0.0	 300.0	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 4529	 0.021711	 0.090539	 0.0	 281.0	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 3364	 0.00019	 0.000729	 0.0	 300.0	 41929	 41929	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 5383	 0.001271	 0.00638	 0.0	 300.0	 4856	 4856	 0.0	 0.0	 1	 -30.0	 30.0;
	920	 6570	 3.9e-05	 0.0002	 0.0	 300.0	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	6664	 4426	 0.000281	 0.00236	 0.0	 529.0	 13291	 13291	 0.0	 0.0	 1	 -30.0	 30.0;
	4339	 2183	 0.00019	 0.00329	 0.0	 1644.0	 9586	 9586	 0.0	 0.0	 1	 -30.0	 30.0;
	7513	 4000	 0.00035	 0.00324	 0.0	 9693	 9693	 9693	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 8542	 0.00049	 0.00349	 0.0	 319.0	 8963	 8963	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 8542	 0.000469	 0.00331	 0.0	 319.0	 9449	 9449	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 1662	 0.00313	 0.01324	 0.0	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 9119	 0.001031	 0.006719	 0.0	 376.0	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 1151	 0.00038	 0.00401	 0.0	 7843	 7843	 7843	 0.0	 0.0	 1	 -30.0	 30.0;
	502	 3589	 0.00037	 0.002849	 0.0	 395.0	 10995	 10995	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 1040	 0.00032	 0.00256	 0.0	 376.0	 12244	 12244	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 145	 0.00037	 0.00118	 0.0	 281.0	 25543	 25543	 0.0	 0.0	 1	 -30.0	 30.0;
	8473	 4267	 0.00068	 0.001151	 0.0	 23628	 23628	 23628	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 5179	 0.00168	 0.009841	 0.0	 395.0	 3164	 3164	 0.0	 0.0	 1	 -30.0	 30.0;
	5317	 8854	 0.000599	 0.002401	 0.0	 300.0	 12765	 12765	 0.0	 0.0	 1	 -30.0	 30.0;
	9018	 4	 0.002169	 0.00911	 0.0	 300.0	 3374	 3374	 0.0	 0.0	 1	 -30.0	 30.0;
	9018	 4829	 0.002849	 0.01282	 0.0	 357.0	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 5383	 0.001229	 0.01207	 0.0	 453.0	 2604	 2604	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 7507	 0.001289	 0.01089	 0.0	 510.0	 2881	 2881	 0.0	 0.0	 1	 -30.0	 30.0;
	8887	 1644	 0.00093	 0.01036	 0.0	 756.0	 3037	 3037	 0.0	 0.0	 1	 -30.0	 30.0;
	8887	 3483	 0.00083	 0.01174	 0.0	 723.0	 2684	 2684	 0.0	 0.0	 1	 -30.0	 30.0;
	6639	 7840	 0.00118	 0.009469	 0.0	 3311	 3311	 3311	 0.0	 0.0	 1	 -30.0	 30.0;
	6639	 7840	 0.001151	 0.009651	 0.0	 3250	 3250	 3250	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 8109	 0.00101	 0.01327	 0.0	 1480.0	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	6291	 4189	 0.00364	 0.02486	 0.0	 472.0	 1258	 1258	 0.0	 0.0	 1	 -30.0	 30.0;
	8405	 4747	 0.00056	 0.00425	 0.0	 433.0	 7369	 7369	 0.0	 0.0	 1	 -30.0	 30.0;
	8405	 4580	 0.00369	 0.02681	 0.0	 433.0	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	338	 7824	 0.000531	 0.00276	 0.0	 300.0	 11239	 11239	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 7824	 0.000521	 0.00281	 0.0	 281.0	 11053	 11053	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 7824	 0.000419	 0.00232	 0.0	 13399	 13399	 13399	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 7824	 0.000409	 0.00237	 0.0	 13134	 13134	 13134	 0.0	 0.0	 1	 -30.0	 30.0;
	8458	 8267	 0.00014	 0.00193	 0.0	 1414.0	 16324	 16324	 0.0	 0.0	 1	 -30.0	 30.0;
	2676	 5987	 0.003211	 0.01481	 0.0	 319.0	 2085	 2085	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 5712	 0.00381	 0.01175	 0.0	 2558	 2558	 2558	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 6521	 0.003781	 0.02676	 0.0	 319.0	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 8636	 0.000919	 0.005461	 0.0	 453.0	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 8829	 0.000271	 0.001211	 0.0	 281.0	 25455	 25455	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 4235	 0.002229	 0.017401	 0.0	 472.0	 1801	 1801	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 4235	 0.00243	 0.017659	 0.0	 510.0	 1773	 1773	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 4235	 0.002531	 0.01705	 0.0	 491.0	 1833	 1833	 0.0	 0.0	 1	 -30.0	 30.0;
	8818	 5099	 0.012531	 0.05451	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 4734	 0.00087	 0.01212	 0.0	 1249.0	 2600	 2600	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 905	 0.0006	 0.00802	 0.0	 1611.0	 3928	 3928	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 8334	 0.00072	 0.00667	 0.0	 1743.0	 4709	 4709	 0.0	 0.0	 1	 -30.0	 30.0;
	5781	 2093	 0.00234	 0.02626	 0.0	 1199	 1199	 1199	 0.0	 0.0	 1	 -30.0	 30.0;
	6772	 6989	 0.00038	 0.002969	 0.0	 414.0	 10553	 10553	 0.0	 0.0	 1	 -30.0	 30.0;
	7885	 3912	 0.00024	 0.00045	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	6730	 3912	 0.000229	 0.000409	 0.0	 67388	 67388	 67388	 0.0	 0.0	 1	 -30.0	 30.0;
	4301	 3912	 0.000281	 0.000401	 0.0	 64510	 64510	 64510	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 5610	 0.001211	 0.005271	 0.0	 5841	 5841	 5841	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 350	 0.000281	 0.00107	 0.0	 338.0	 28553	 28553	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 6763	 0.00025	 0.001091	 0.0	 28222	 28222	 28222	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 1973	 0.00019	 0.00081	 0.0	 529.0	 37967	 37967	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 1973	 0.00045	 0.00136	 0.0	 491.0	 22051	 22051	 0.0	 0.0	 1	 -30.0	 30.0;
	3481	 554	 0.003461	 0.023289	 0.0	 1342	 1342	 1342	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 8222	 0.0013	 0.01609	 0.0	 1743.0	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 8222	 0.00128	 0.0164	 0.0	 1611.0	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 2721	 0.00089	 0.01082	 0.0	 1480.0	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 2721	 0.00087	 0.01102	 0.0	 1545.0	 2858	 2858	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 8578	 0.003349	 0.02514	 0.0	 433.0	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 2653	 0.0003	 0.00061	 0.0	 46468	 46468	 46468	 0.0	 0.0	 1	 -30.0	 30.0;
	148	 7069	 0.000289	 0.001211	 0.0	 414.0	 25372	 25372	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 8743	 0.01301	 0.044091	 0.0	 338.0	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 1742	 0.02162	 0.065969	 0.0	 300.0	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	8930	 314	 0.006461	 0.05275	 0.0	 414.0	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	6954	 7974	 0.0002	 0.000271	 0.0	 93784	 93784	 93784	 0.0	 0.0	 1	 -30.0	 30.0;
	3325	 7974	 0.00018	 0.00026	 0.0	 99888	 99888	 99888	 0.0	 0.0	 1	 -30.0	 30.0;
	5627	 1742	 0.00032	 0.00188	 0.0	 16564	 16564	 16564	 0.0	 0.0	 1	 -30.0	 30.0;
	5610	 6989	 0.00105	 0.006591	 0.0	 376.0	 4733	 4733	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 6163	 0.00013	 0.00055	 0.0	 55892	 55892	 55892	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 5365	 0.006151	 0.04013	 0.0	 529.0	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 6982	 0.007159	 0.040591	 0.0	 433.0	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 3133	 0.00874	 0.048461	 0.0	 300.0	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 4738	 0.004159	 0.01606	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 3656	 0.002919	 0.01912	 0.0	 433.0	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 4300	 0.00094	 0.00394	 0.0	 319.0	 7799	 7799	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 5789	 0.000901	 0.00395	 0.0	 7797	 7797	 7797	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 2467	 0.003159	 0.017789	 0.0	 472.0	 1749	 1749	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 2467	 0.002419	 0.018331	 0.0	 1709	 1709	 1709	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 5256	 0.00375	 0.018281	 0.0	 319.0	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 2653	 0.00025	 0.001031	 0.0	 319.0	 29775	 29775	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 4852	 0.00264	 0.01238	 0.0	 319.0	 2496	 2496	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 4852	 0.001289	 0.00795	 0.0	 357.0	 3923	 3923	 0.0	 0.0	 1	 -30.0	 30.0;
	4679	 1151	 0.00087	 0.003081	 0.0	 376.0	 9867	 9867	 0.0	 0.0	 1	 -30.0	 30.0;
	8568	 5215	 0.000401	 0.00224	 0.0	 319.0	 13881	 13881	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 221	 0.0003	 0.00385	 0.0	 8180	 8180	 8180	 0.0	 0.0	 1	 -30.0	 30.0;
	6807	 851	 0.00126	 0.008219	 0.0	 433.0	 3799	 3799	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 5099	 0.01905	 0.055729	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 3558	 0.00201	 0.00444	 0.0	 6482	 6482	 6482	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 2934	 0.00101	 0.00324	 0.0	 9308	 9308	 9308	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 4787	 0.00105	 0.00677	 0.0	 1118.0	 4611	 4611	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 3830	 0.00039	 0.00502	 0.0	 1052.0	 6274	 6274	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 5648	 0.0004	 0.00492	 0.0	 854.0	 6400	 6400	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 4000	 0.00051	 0.00617	 0.0	 1249.0	 5103	 5103	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 3485	 0.0003	 0.00314	 0.0	 1480.0	 10015	 10015	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 3830	 0.00051	 0.00668	 0.0	 1545.0	 4715	 4715	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 5648	 0.0005	 0.00678	 0.0	 1677.0	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 2424	 0.002909	 0.017	 0.0	 1832	 1832	 1832	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 1156	 0.00245	 0.011281	 0.0	 376.0	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 4914	 0.0027	 0.01532	 0.0	 357.0	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 4914	 0.00105	 0.011151	 0.0	 2821	 2821	 2821	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 3834	 0.00036	 0.002669	 0.0	 11729	 11729	 11729	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 556	 0.0018	 0.011169	 0.0	 357.0	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 3019	 0.000711	 0.007771	 0.0	 4048	 4048	 4048	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 7923	 0.00036	 0.00257	 0.0	 12172	 12172	 12172	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 4103	 0.00201	 0.01195	 0.0	 510.0	 2607	 2607	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 7862	 0.001091	 0.00731	 0.0	 472.0	 4274	 4274	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 5458	 0.00105	 0.007591	 0.0	 529.0	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	1551	 1838	 0.00299	 0.02256	 0.0	 376.0	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	3070	 2888	 0.00036	 0.00288	 0.0	 10884	 10884	 10884	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 4504	 0.00589	 0.045599	 0.0	 453.0	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 3579	 0.00157	 0.0127	 0.0	 376.0	 2469	 2469	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 3579	 0.00168	 0.011969	 0.0	 2614	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	4874	 7903	 0.00289	 0.021031	 0.0	 338.0	 1488	 1488	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 1102	 0.00395	 0.025211	 0.0	 472.0	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 9217	 0.002771	 0.021659	 0.0	 376.0	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	6368	 5653	 0.002979	 0.016901	 0.0	 453.0	 1841	 1841	 0.0	 0.0	 1	 -30.0	 30.0;
	8478	 5907	 0.007419	 0.034021	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 6921	 0.00056	 0.00813	 0.0	 789.0	 3877	 3877	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 1813	 0.00361	 0.015211	 0.0	 338.0	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	8950	 7049	 0.000409	 0.003331	 0.0	 529.0	 9413	 9413	 0.0	 0.0	 1	 -30.0	 30.0;
	6846	 8788	 0.004091	 0.019599	 0.0	 376.0	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	6846	 6734	 0.00294	 0.012841	 0.0	 395.0	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 5616	 0.020771	 0.080479	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 1965	 0.00662	 0.0513	 0.0	 453.0	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	4426	 1767	 0.00607	 0.04581	 0.0	 433.0	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 1102	 0.000669	 0.0042	 0.0	 376.0	 7428	 7428	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 8485	 0.001271	 0.007419	 0.0	 376.0	 4197	 4197	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 5653	 0.001599	 0.012271	 0.0	 472.0	 2553	 2553	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 4661	 0.009599	 0.05024	 0.0	 319.0	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 520	 0.00149	 0.009219	 0.0	 338.0	 3383	 3383	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 6816	 0.01488	 0.06724	 0.0	 300.0	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 5918	 0.003599	 0.024031	 0.0	 319.0	 1300	 1300	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 5918	 0.00519	 0.024	 0.0	 338.0	 1287	 1287	 0.0	 0.0	 1	 -30.0	 30.0;
	8636	 1380	 0.003461	 0.013349	 0.0	 300.0	 2291	 2291	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 4239	 0.00105	 0.01236	 0.0	 2547	 2547	 2547	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 4239	 0.00199	 0.012331	 0.0	 395.0	 2529	 2529	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 3656	 0.00711	 0.044711	 0.0	 338.0	 698	 698	 0.0	 0.0	 1	 -30.0	 30.0;
	6203	 7124	 0.006729	 0.02543	 0.0	 1201	 1201	 1201	 0.0	 0.0	 1	 -30.0	 30.0;
	9059	 7124	 0.005771	 0.02999	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	5994	 96	 0.0048	 0.021771	 0.0	 1417	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	5049	 306	 0.00286	 0.02212	 0.0	 433.0	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 8397	 0.00351	 0.02175	 0.0	 414.0	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 6982	 0.008401	 0.0448	 0.0	 472.0	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 8807	 0.0018	 0.01187	 0.0	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	7202	 8807	 0.001831	 0.01163	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	8592	 2995	 0.00075	 0.00538	 0.0	 5816	 5816	 5816	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 823	 2e-05	 0.00033	 0.0	 95544	 95544	 95544	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 1680	 1e-05	 0.00034	 0.0	 1710.0	 92864	 92864	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 953	 0.00023	 0.00258	 0.0	 723.0	 12195	 12195	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 1817	 0.00023	 0.00252	 0.0	 657.0	 12483	 12483	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 1504	 0.002031	 0.008531	 0.0	 3602	 3602	 3602	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 7226	 0.005349	 0.020789	 0.0	 319.0	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 7865	 0.0002	 0.00082	 0.0	 395.0	 37425	 37425	 0.0	 0.0	 1	 -30.0	 30.0;
	3916	 6891	 0.002091	 0.011219	 0.0	 2768	 2768	 2768	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 171	 0.00262	 0.016979	 0.0	 433.0	 1839	 1839	 0.0	 0.0	 1	 -30.0	 30.0;
	6053	 171	 0.002669	 0.01663	 0.0	 491.0	 1876	 1876	 0.0	 0.0	 1	 -30.0	 30.0;
	8829	 3044	 0.00025	 0.00118	 0.0	 414.0	 26188	 26188	 0.0	 0.0	 1	 -30.0	 30.0;
	1552	 1194	 0.00056	 0.00715	 0.0	 1545.0	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 3740	 0.0007	 0.00455	 0.0	 338.0	 6862	 6862	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 2695	 0.000331	 0.001711	 0.0	 281.0	 18126	 18126	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 2695	 0.00011	 0.000781	 0.0	 453.0	 40050	 40050	 0.0	 0.0	 1	 -30.0	 30.0;
	3912	 8877	 0.00111	 0.00664	 0.0	 338.0	 4693	 4693	 0.0	 0.0	 1	 -30.0	 30.0;
	7520	 8222	 0.00066	 0.00838	 0.0	 1447.0	 3758	 3758	 0.0	 0.0	 1	 -30.0	 30.0;
	7520	 8222	 0.00064	 0.00854	 0.0	 1447.0	 3689	 3689	 0.0	 0.0	 1	 -30.0	 30.0;
	2421	 3610	 0.003091	 0.017091	 0.0	 472.0	 1819	 1819	 0.0	 0.0	 1	 -30.0	 30.0;
	2421	 1414	 0.00643	 0.03687	 0.0	 529.0	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	8879	 3610	 0.00275	 0.01937	 0.0	 1615	 1615	 1615	 0.0	 0.0	 1	 -30.0	 30.0;
	8397	 5918	 0.00357	 0.021289	 0.0	 414.0	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	1914	 6982	 0.000289	 0.002789	 0.0	 11266	 11266	 11266	 0.0	 0.0	 1	 -30.0	 30.0;
	7873	 6638	 0.002531	 0.01345	 0.0	 281.0	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 7702	 0.00162	 0.012159	 0.0	 414.0	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 7702	 0.00262	 0.01168	 0.0	 319.0	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	8835	 1156	 0.00099	 0.006081	 0.0	 5127	 5127	 5127	 0.0	 0.0	 1	 -30.0	 30.0;
	8835	 1233	 0.000909	 0.005979	 0.0	 5224	 5224	 5224	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 408	 0.00011	 0.0008	 0.0	 39117	 39117	 39117	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 7231	 0.00011	 0.00068	 0.0	 45856	 45856	 45856	 0.0	 0.0	 1	 -30.0	 30.0;
	3390	 5993	 0.00207	 0.008341	 0.0	 395.0	 3676	 3676	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 2550	 0.00019	 0.001031	 0.0	 30131	 30131	 30131	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 7353	 0.014039	 0.0667	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	3126	 7495	 0.004961	 0.03043	 0.0	 338.0	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	2689	 5753	 0.00056	 0.003531	 0.0	 8836	 8836	 8836	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 4235	 0.001461	 0.00889	 0.0	 414.0	 3507	 3507	 0.0	 0.0	 1	 -30.0	 30.0;
	7626	 7076	 6e-05	 0.000419	 0.0	 395.0	 74627	 74627	 0.0	 0.0	 1	 -30.0	 30.0;
	4823	 4060	 0.00139	 0.005169	 0.0	 5902	 5902	 5902	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 1311	 0.00069	 0.00825	 0.0	 657.0	 3816	 3816	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 4566	 0.004969	 0.030781	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 8873	 0.00012	 0.000969	 0.0	 491.0	 32351	 32351	 0.0	 0.0	 1	 -30.0	 30.0;
	6684	 5383	 0.001091	 0.010159	 0.0	 472.0	 3092	 3092	 0.0	 0.0	 1	 -30.0	 30.0;
	8151	 5383	 0.000969	 0.00887	 0.0	 453.0	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	4357	 6619	 0.00099	 0.006789	 0.0	 414.0	 4605	 4605	 0.0	 0.0	 1	 -30.0	 30.0;
	8191	 8765	 0.001031	 0.00586	 0.0	 281.0	 5309	 5309	 0.0	 0.0	 1	 -30.0	 30.0;
	7466	 5469	 0.00401	 0.03345	 0.0	 529.0	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	3401	 5351	 9.1e-05	 0.000349	 0.0	 87580	 87580	 87580	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 225	 0.00125	 0.00745	 0.0	 491.0	 4182	 4182	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 4031	 0.003711	 0.024219	 0.0	 414.0	 1290	 1290	 0.0	 0.0	 1	 -30.0	 30.0;
	8222	 6921	 0.00169	 0.02156	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	8222	 6921	 0.00171	 0.02114	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 4239	 0.00088	 0.00562	 0.0	 433.0	 5553	 5553	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 4239	 0.0008	 0.00618	 0.0	 472.0	 5069	 5069	 0.0	 0.0	 1	 -30.0	 30.0;
	2940	 7178	 0.00161	 0.01014	 0.0	 3077	 3077	 3077	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 2563	 0.00032	 0.002031	 0.0	 433.0	 15364	 15364	 0.0	 0.0	 1	 -30.0	 30.0;
	3928	 6521	 0.00011	 0.000659	 0.0	 395.0	 47279	 47279	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 3830	 0.00042	 0.00505	 0.0	 986.0	 6234	 6234	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 5648	 0.00043	 0.00494	 0.0	 1151.0	 6371	 6371	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 4914	 0.00038	 0.000711	 0.0	 39182	 39182	 39182	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 4914	 0.00037	 0.000659	 0.0	 41796	 41796	 41796	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 1644	 0.00248	 0.03096	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 3498	 0.00375	 0.019729	 0.0	 395.0	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 2430	 0.00518	 0.020021	 0.0	 338.0	 1528	 1528	 0.0	 0.0	 1	 -30.0	 30.0;
	7943	 9108	 0.000771	 0.003711	 0.0	 395.0	 8334	 8334	 0.0	 0.0	 1	 -30.0	 30.0;
	7943	 1478	 0.00076	 0.003789	 0.0	 357.0	 8174	 8174	 0.0	 0.0	 1	 -30.0	 30.0;
	2308	 3541	 0.000781	 0.00574	 0.0	 5453	 5453	 5453	 0.0	 0.0	 1	 -30.0	 30.0;
	3535	 7582	 0.00089	 0.00562	 0.0	 5552	 5552	 5552	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 8542	 0.000331	 0.001401	 0.0	 21943	 21943	 21943	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 8542	 0.000401	 0.00137	 0.0	 22129	 22129	 22129	 0.0	 0.0	 1	 -30.0	 30.0;
	7945	 5215	 0.00051	 0.003349	 0.0	 9325	 9325	 9325	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 9130	 0.000461	 0.00168	 0.0	 18132	 18132	 18132	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 9130	 0.000469	 0.00164	 0.0	 18519	 18519	 18519	 0.0	 0.0	 1	 -30.0	 30.0;
	4661	 6816	 0.006081	 0.03114	 0.0	 357.0	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	7519	 776	 0.005831	 0.02218	 0.0	 395.0	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	8989	 3435	 0.00013	 0.000461	 0.0	 65948	 65948	 65948	 0.0	 0.0	 1	 -30.0	 30.0;
	7797	 2020	 0.00013	 0.000461	 0.0	 65948	 65948	 65948	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 4031	 0.00262	 0.020289	 0.0	 414.0	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 2878	 0.00164	 0.01194	 0.0	 453.0	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	7353	 9164	 0.006479	 0.02845	 0.0	 414.0	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 2012	 0.00294	 0.014419	 0.0	 395.0	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 2012	 0.00238	 0.01463	 0.0	 395.0	 2132	 2132	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 1750	 0.002219	 0.00993	 0.0	 376.0	 3105	 3105	 0.0	 0.0	 1	 -30.0	 30.0;
	1401	 2303	 0.008651	 0.04886	 0.0	 300.0	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 7903	 0.00464	 0.030979	 0.0	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 449	 0.00092	 0.00889	 0.0	 1447.0	 3535	 3535	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 449	 0.00093	 0.00869	 0.0	 1348.0	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 1817	 0.0022	 0.03485	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 2458	 0.00074	 0.00941	 0.0	 1743.0	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 6427	 0.00087	 0.00884	 0.0	 1578.0	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 1730	 0.00139	 0.01662	 0.0	 1894	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	9217	 594	 0.002781	 0.022979	 0.0	 300.0	 1365	 1365	 0.0	 0.0	 1	 -30.0	 30.0;
	6351	 5393	 0.000521	 0.00407	 0.0	 529.0	 7699	 7699	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 7702	 0.008479	 0.032841	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	2503	 7491	 0.005669	 0.02901	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 2872	 0.001031	 0.004099	 0.0	 7474	 7474	 7474	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 8043	 0.00301	 0.018719	 0.0	 376.0	 1667	 1667	 0.0	 0.0	 1	 -30.0	 30.0;
	1813	 2866	 0.00257	 0.01713	 0.0	 338.0	 1824	 1824	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 5417	 0.010461	 0.03836	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 4100	 0.001719	 0.011531	 0.0	 414.0	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	5365	 1556	 9.1e-05	 0.00056	 0.0	 300.0	 55676	 55676	 0.0	 0.0	 1	 -30.0	 30.0;
	3894	 3865	 0.00476	 0.025289	 0.0	 1228	 1228	 1228	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 1554	 0.000219	 0.00164	 0.0	 319.0	 19092	 19092	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 7994	 0.002159	 0.01163	 0.0	 2671	 2671	 2671	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 1554	 0.00295	 0.01539	 0.0	 300.0	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 3133	 0.007789	 0.033039	 0.0	 300.0	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 3071	 0.00026	 0.0013	 0.0	 23827	 23827	 23827	 0.0	 0.0	 1	 -30.0	 30.0;
	6486	 8992	 0.00162	 0.013229	 0.0	 338.0	 2371	 2371	 0.0	 0.0	 1	 -30.0	 30.0;
	8485	 594	 0.007919	 0.04194	 0.0	 338.0	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	682	 8477	 0.001229	 0.00401	 0.0	 300.0	 7532	 7532	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 5488	 0.008021	 0.042831	 0.0	 338.0	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	6638	 776	 0.007711	 0.03006	 0.0	 338.0	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	8788	 789	 0.00261	 0.015469	 0.0	 319.0	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 1556	 0.00139	 0.00536	 0.0	 5705	 5705	 5705	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 1556	 0.001419	 0.00525	 0.0	 5809	 5809	 5809	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 7702	 0.006289	 0.032271	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	1883	 2132	 0.011031	 0.05625	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	171	 2341	 0.001841	 0.01324	 0.0	 472.0	 2364	 2364	 0.0	 0.0	 1	 -30.0	 30.0;
	6630	 10	 0.000599	 0.00186	 0.0	 453.0	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	4484	 4239	 0.00036	 0.001591	 0.0	 433.0	 19365	 19365	 0.0	 0.0	 1	 -30.0	 30.0;
	3044	 4235	 0.003849	 0.027651	 0.0	 453.0	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 4454	 0.00186	 0.00874	 0.0	 491.0	 3535	 3535	 0.0	 0.0	 1	 -30.0	 30.0;
	3485	 2183	 0.00025	 0.00285	 0.0	 1480.0	 11041	 11041	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 7923	 0.00207	 0.008841	 0.0	 319.0	 3479	 3479	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 1233	 6e-05	 0.00039	 0.0	 453.0	 80052	 80052	 0.0	 0.0	 1	 -30.0	 30.0;
	8913	 4852	 0.002159	 0.008909	 0.0	 357.0	 3446	 3446	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 1233	 0.000219	 0.00039	 0.0	 70621	 70621	 70621	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 2653	 0.00011	 0.000521	 0.0	 300.0	 59321	 59321	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 2653	 0.00011	 0.00049	 0.0	 300.0	 62899	 62899	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 556	 0.000771	 0.003789	 0.0	 338.0	 8170	 8170	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 3019	 0.000229	 0.002849	 0.0	 11052	 11052	 11052	 0.0	 0.0	 1	 -30.0	 30.0;
	7994	 5256	 0.00445	 0.027599	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 3346	 0.00218	 0.02	 0.0	 1381.0	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 8468	 0.00074	 0.00865	 0.0	 1118.0	 3639	 3639	 0.0	 0.0	 1	 -30.0	 30.0;
	7702	 1234	 0.002531	 0.019419	 0.0	 300.0	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	7702	 8035	 0.003	 0.01631	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 3331	 0.008461	 0.025081	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	8189	 3643	 0.00382	 0.013669	 0.0	 395.0	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	3133	 8477	 0.002581	 0.01814	 0.0	 414.0	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	6744	 6101	 0.00201	 0.012219	 0.0	 433.0	 2551	 2551	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 4313	 0.00087	 0.001599	 0.0	 17353	 17353	 17353	 0.0	 0.0	 1	 -30.0	 30.0;
	769	 5233	 0.00455	 0.02394	 0.0	 319.0	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	1965	 5926	 0.005651	 0.041771	 0.0	 357.0	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	9014	 3999	 0.00069	 0.001271	 0.0	 21842	 21842	 21842	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 8406	 0.00068	 0.00269	 0.0	 300.0	 11385	 11385	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 2021	 0.00036	 0.00261	 0.0	 376.0	 11989	 11989	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 8293	 0.001669	 0.012031	 0.0	 319.0	 2601	 2601	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 3656	 0.009669	 0.03513	 0.0	 867	 867	 867	 0.0	 0.0	 1	 -30.0	 30.0;
	4738	 8477	 0.001099	 0.00862	 0.0	 3636	 3636	 3636	 0.0	 0.0	 1	 -30.0	 30.0;
	7998	 1644	 0.0005	 0.00711	 0.0	 657.0	 4432	 4432	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 1015	 0.003919	 0.017781	 0.0	 395.0	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 8992	 0.00161	 0.019781	 0.0	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	6734	 789	 0.0007	 0.01256	 0.0	 510.0	 2512	 2512	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 5393	 0.000409	 0.0018	 0.0	 17113	 17113	 17113	 0.0	 0.0	 1	 -30.0	 30.0;
	1708	 3906	 2e-05	 0.00043	 0.0	 73380	 73380	 73380	 0.0	 0.0	 1	 -30.0	 30.0;
	9150	 3906	 3e-05	 0.0004	 0.0	 1710.0	 78748	 78748	 0.0	 0.0	 1	 -30.0	 30.0;
	280	 9158	 0.00968	 0.056659	 0.0	 357.0	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	8043	 3656	 0.003969	 0.02925	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 8992	 0.00219	 0.01468	 0.0	 414.0	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 8466	 0.000401	 0.003159	 0.0	 376.0	 9920	 9920	 0.0	 0.0	 1	 -30.0	 30.0;
	5712	 6880	 0.000531	 0.003	 0.0	 376.0	 10368	 10368	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 7266	 0.00136	 0.00576	 0.0	 376.0	 5338	 5338	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8992	 0.000849	 0.006289	 0.0	 357.0	 4978	 4978	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8992	 0.000841	 0.006409	 0.0	 357.0	 4887	 4887	 0.0	 0.0	 1	 -30.0	 30.0;
	8807	 8992	 0.00045	 0.00506	 0.0	 6219	 6219	 6219	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 2088	 0.003669	 0.02988	 0.0	 395.0	 1050	 1050	 0.0	 0.0	 1	 -30.0	 30.0;
	520	 5918	 0.002	 0.01568	 0.0	 414.0	 1999	 1999	 0.0	 0.0	 1	 -30.0	 30.0;
	2653	 2128	 0.00031	 0.0008	 0.0	 319.0	 36817	 36817	 0.0	 0.0	 1	 -30.0	 30.0;
	1216	 5233	 0.00043	 0.00038	 0.0	 55045	 55045	 55045	 0.0	 0.0	 1	 -30.0	 30.0;
	8980	 5993	 0.00043	 0.002229	 0.0	 13915	 13915	 13915	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 5993	 0.00049	 0.00218	 0.0	 14137	 14137	 14137	 0.0	 0.0	 1	 -30.0	 30.0;
	3656	 4060	 0.00282	 0.01844	 0.0	 529.0	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	883	 3331	 0.00462	 0.014849	 0.0	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 3346	 0.00263	 0.04076	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	3498	 2563	 0.01062	 0.056719	 0.0	 357.0	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	1896	 8200	 0.0001	 0.00105	 0.0	 657.0	 29948	 29948	 0.0	 0.0	 1	 -30.0	 30.0;
	9130	 8864	 0.00239	 0.017341	 0.0	 376.0	 1805	 1805	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 2510	 0.001341	 0.010581	 0.0	 433.0	 2962	 2962	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 6146	 0.00101	 0.007599	 0.0	 472.0	 4121	 4121	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 1584	 0.00011	 0.000289	 0.0	 395.0	 102150	 102150	 0.0	 0.0	 1	 -30.0	 30.0;
	7328	 6921	 0.00146	 0.01769	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	7328	 6921	 0.0013	 0.02004	 0.0	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	6816	 5573	 0.007909	 0.028349	 0.0	 319.0	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 8564	 0.00012	 0.00049	 0.0	 62614	 62614	 62614	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 8564	 0.00012	 0.000479	 0.0	 63968	 63968	 63968	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.00076	 0.01018	 0.0	 1513.0	 3095	 3095	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.0009	 0.00865	 0.0	 1677.0	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.00096	 0.01294	 0.0	 1545.0	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.0004	 0.00756	 0.0	 1611.0	 4173	 4173	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 432	 0.00039	 0.00771	 0.0	 1447.0	 4092	 4092	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 8200	 0.00163	 0.02291	 0.0	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 3121	 0.00636	 0.03855	 0.0	 395.0	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 3121	 0.00639	 0.03863	 0.0	 414.0	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 1730	 0.00113	 0.01362	 0.0	 690.0	 2312	 2312	 0.0	 0.0	 1	 -30.0	 30.0;
	1767	 892	 0.00861	 0.05318	 0.0	 529.0	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 4889	 0.0012	 0.004669	 0.0	 338.0	 6553	 6553	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 7076	 0.00018	 0.001091	 0.0	 414.0	 28567	 28567	 0.0	 0.0	 1	 -30.0	 30.0;
	1234	 8035	 0.001401	 0.00612	 0.0	 357.0	 5032	 5032	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 225	 0.00068	 0.00387	 0.0	 491.0	 8039	 8039	 0.0	 0.0	 1	 -30.0	 30.0;
	5720	 8578	 0.0043	 0.033591	 0.0	 414.0	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	3579	 5469	 0.003039	 0.01911	 0.0	 491.0	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 124	 6e-05	 0.00111	 0.0	 853.0	 28416	 28416	 0.0	 0.0	 1	 -30.0	 30.0;
	8846	 4783	 5e-05	 0.001091	 0.0	 853.0	 28923	 28923	 0.0	 0.0	 1	 -30.0	 30.0;
	2393	 3306	 3.9e-05	 0.00089	 0.0	 853.0	 35458	 35458	 0.0	 0.0	 1	 -30.0	 30.0;
	1895	 4480	 3.9e-05	 0.000901	 0.0	 853.0	 35026	 35026	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 4454	 0.000169	 0.00111	 0.0	 510.0	 28133	 28133	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 4852	 0.000331	 0.0027	 0.0	 11613	 11613	 11613	 0.0	 0.0	 1	 -30.0	 30.0;
	6429	 2012	 0.00026	 0.00369	 0.0	 8540	 8540	 8540	 0.0	 0.0	 1	 -30.0	 30.0;
	4889	 7076	 0.000341	 0.00274	 0.0	 11440	 11440	 11440	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 7491	 0.00038	 0.00506	 0.0	 414.0	 6226	 6226	 0.0	 0.0	 1	 -30.0	 30.0;
	2563	 6521	 0.00012	 0.000831	 0.0	 376.0	 37622	 37622	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 594	 0.003031	 0.0123	 0.0	 2494	 2494	 2494	 0.0	 0.0	 1	 -30.0	 30.0;
	4747	 7791	 0.001521	 0.00774	 0.0	 395.0	 4005	 4005	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 3022	 0.00059	 0.00552	 0.0	 1611.0	 5690	 5690	 0.0	 0.0	 1	 -30.0	 30.0;
	3906	 1194	 0.00053	 0.00625	 0.0	 1545.0	 5036	 5036	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 8804	 0.00143	 0.01076	 0.0	 529.0	 2911	 2911	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 8487	 0.00056	 0.00593	 0.0	 5304	 5304	 5304	 0.0	 0.0	 1	 -30.0	 30.0;
	2467	 7178	 0.00205	 0.01461	 0.0	 414.0	 2142	 2142	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 2303	 0.01068	 0.054521	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 8466	 0.00194	 0.011039	 0.0	 433.0	 2819	 2819	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 6880	 0.00131	 0.010099	 0.0	 433.0	 3102	 3102	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 2995	 0.001289	 0.014229	 0.0	 319.0	 2211	 2211	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 3221	 0.00455	 0.027031	 0.0	 395.0	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 3327	 0.00239	 0.01414	 0.0	 510.0	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 8310	 0.004039	 0.029669	 0.0	 491.0	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 2088	 0.001099	 0.007771	 0.0	 529.0	 4025	 4025	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 2021	 0.00082	 0.00762	 0.0	 414.0	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 4114	 0.000719	 0.0033	 0.0	 9353	 9353	 9353	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 5519	 0.000599	 0.00361	 0.0	 300.0	 8632	 8632	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 8293	 0.000521	 0.004039	 0.0	 376.0	 7757	 7757	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 3435	 0.000901	 0.0088	 0.0	 433.0	 3571	 3571	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 6990	 0.000781	 0.00306	 0.0	 10003	 10003	 10003	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 2406	 0.000419	 0.00399	 0.0	 7874	 7874	 7874	 0.0	 0.0	 1	 -30.0	 30.0;
	7507	 2020	 0.000841	 0.009841	 0.0	 281.0	 3199	 3199	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 6146	 0.004021	 0.03064	 0.0	 414.0	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2695	 0.0023	 0.009031	 0.0	 338.0	 3390	 3390	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 2695	 0.002081	 0.009469	 0.0	 376.0	 3259	 3259	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 5502	 0.00164	 0.008831	 0.0	 3517	 3517	 3517	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 8877	 0.00094	 0.00488	 0.0	 319.0	 6356	 6356	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 9119	 0.000901	 0.00551	 0.0	 453.0	 5658	 5658	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 1151	 0.00051	 0.005961	 0.0	 5280	 5280	 5280	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 1750	 0.00113	 0.004349	 0.0	 433.0	 7030	 7030	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 6616	 0.002081	 0.013031	 0.0	 395.0	 2394	 2394	 0.0	 0.0	 1	 -30.0	 30.0;
	809	 4594	 0.00116	 0.01438	 0.0	 2190	 2190	 2190	 0.0	 0.0	 1	 -30.0	 30.0;
	8656	 4729	 0.00013	 0.001031	 0.0	 30397	 30397	 30397	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 615	 0.00036	 0.002659	 0.0	 414.0	 11773	 11773	 0.0	 0.0	 1	 -30.0	 30.0;
	4060	 5393	 0.000771	 0.004539	 0.0	 529.0	 6861	 6861	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 2426	 0.000695	 0.049098	 0.0	 644	 644	 644	 0.982143	 0.0	 1	 -30.0	 30.0;
	9203	 2426	 0.000355	 0.024893	 0.0	 591.0	 1269	 1269	 0.93617	 0.0	 1	 -30.0	 30.0;
	118	 2426	 0.000365	 0.024372	 0.0	 591.0	 1296	 1296	 0.979227	 0.0	 1	 -30.0	 30.0;
	3145	 7770	 0.000411	 0.023652	 0.0	 591.0	 1336	 1336	 0.93617	 0.0	 1	 -30.0	 30.0;
	7267	 4918	 0.000386	 0.025673	 0.0	 591.0	 1231	 1231	 0.93617	 0.0	 1	 -30.0	 30.0;
	7267	 4918	 0.000344	 0.029336	 0.0	 591.0	 1077	 1077	 0.93617	 0.0	 1	 -30.0	 30.0;
	839	 4506	 0.000653	 0.052104	 0.0	 607	 607	 607	 0.982143	 0.0	 1	 -30.0	 30.0;
	839	 4506	 0.000767	 0.043531	 0.0	 726	 726	 726	 0.982143	 0.0	 1	 -30.0	 30.0;
	3445	 6114	 0.000323	 0.028314	 0.0	 591.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	3445	 6114	 0.000323	 0.025999	 0.0	 591.0	 1215	 1215	 0.93617	 0.0	 1	 -30.0	 30.0;
	3445	 7264	 0.000365	 0.025478	 0.0	 591.0	 1240	 1240	 0.93617	 0.0	 1	 -30.0	 30.0;
	891	 6306	 0.00086	 0.039291	 0.0	 804	 804	 804	 0.982143	 0.0	 1	 -30.0	 30.0;
	720	 1711	 0.000355	 0.026586	 0.0	 591.0	 1189	 1189	 0.93617	 0.0	 1	 -30.0	 30.0;
	720	 1711	 0.000375	 0.026313	 0.0	 591.0	 1201	 1201	 0.93617	 0.0	 1	 -30.0	 30.0;
	6206	 3240	 0.000344	 0.023329	 0.0	 591.0	 1354	 1354	 0.979227	 0.0	 1	 -30.0	 30.0;
	6206	 3240	 0.000302	 0.026375	 0.0	 591.0	 1198	 1198	 0.979227	 0.0	 1	 -30.0	 30.0;
	9174	 2924	 0.000788	 0.04323	 0.0	 731	 731	 731	 0.982143	 0.0	 1	 -30.0	 30.0;
	9174	 2924	 0.000767	 0.04407	 0.0	 717	 717	 717	 0.982143	 0.0	 1	 -30.0	 30.0;
	1355	 5856	 0.000767	 0.043562	 0.0	 725	 725	 725	 0.982143	 0.0	 1	 -30.0	 30.0;
	1355	 5856	 0.000788	 0.041281	 0.0	 766	 766	 766	 0.982143	 0.0	 1	 -30.0	 30.0;
	1355	 5856	 0.000892	 0.040524	 0.0	 780	 780	 780	 0.982143	 0.0	 1	 -30.0	 30.0;
	3205	 4683	 0.000975	 0.043562	 0.0	 725	 725	 725	 0.982143	 0.0	 1	 -30.0	 30.0;
	3205	 4683	 0.000757	 0.042649	 0.0	 741	 741	 741	 0.982143	 0.0	 1	 -30.0	 30.0;
	5350	 2361	 0.000261	 0.030762	 0.0	 591.0	 1027	 1027	 0.93617	 0.0	 1	 -30.0	 30.0;
	5350	 2361	 0.000261	 0.030088	 0.0	 591.0	 1050	 1050	 0.93617	 0.0	 1	 -30.0	 30.0;
	5016	 6112	 0.000323	 0.026447	 0.0	 591.0	 1195	 1195	 0.979227	 0.0	 1	 -30.0	 30.0;
	5016	 8860	 0.000323	 0.026885	 0.0	 591.0	 1175	 1175	 0.979227	 0.0	 1	 -30.0	 30.0;
	7471	 549	 0.000323	 0.02748	 0.0	 591.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	7471	 549	 0.000292	 0.028158	 0.0	 591.0	 1122	 1122	 0.93617	 0.0	 1	 -30.0	 30.0;
	549	 5002	 0.0	 0.009197	 0.0	 567.0	 3435	 3435	 1.0	 0.072386	 1	 -30.0	 30.0;
	5490	 3817	 0.000736	 0.044526	 0.0	 710	 710	 710	 0.982143	 0.0	 1	 -30.0	 30.0;
	2854	 9112	 0.00086	 0.039488	 0.0	 800	 800	 800	 0.982143	 0.0	 1	 -30.0	 30.0;
	2918	 6532	 0.000365	 0.024372	 0.0	 591.0	 1296	 1296	 0.93617	 0.0	 1	 -30.0	 30.0;
	2918	 6532	 0.000375	 0.023986	 0.0	 591.0	 1317	 1317	 0.93617	 0.0	 1	 -30.0	 30.0;
	4494	 7284	 0.000386	 0.025673	 0.0	 591.0	 1231	 1231	 0.93617	 0.0	 1	 -30.0	 30.0;
	2656	 1775	 0.000809	 0.042318	 0.0	 747	 747	 747	 0.982143	 0.0	 1	 -30.0	 30.0;
	3519	 5641	 0.000705	 0.042038	 0.0	 752	 752	 752	 0.982143	 0.0	 1	 -30.0	 30.0;
	3543	 367	 0.000334	 0.028022	 0.0	 591.0	 1128	 1128	 0.93617	 0.0	 1	 -30.0	 30.0;
	3543	 1833	 0.000353	 0.022403	 0.0	 591.0	 1410	 1410	 0.982143	 0.0	 1	 -30.0	 30.0;
	2372	 367	 0.000313	 0.026354	 0.0	 591.0	 1199	 1199	 0.93617	 0.0	 1	 -30.0	 30.0;
	2372	 367	 0.000323	 0.025478	 0.0	 591.0	 1240	 1240	 0.93617	 0.0	 1	 -30.0	 30.0;
	1876	 7752	 0.000344	 0.024622	 0.0	 591.0	 1283	 1283	 0.979227	 0.0	 1	 -30.0	 30.0;
	113	 7752	 0.000355	 0.024038	 0.0	 591.0	 1314	 1314	 0.979227	 0.0	 1	 -30.0	 30.0;
	3499	 7289	 0.000881	 0.038244	 0.0	 826	 826	 826	 0.982143	 0.0	 1	 -30.0	 30.0;
	3499	 7289	 0.000757	 0.040959	 0.0	 772	 772	 772	 0.982143	 0.0	 1	 -30.0	 30.0;
	3082	 2083	 0.000354	 0.028765	 0.0	 591.0	 1099	 1099	 0.93617	 0.0	 1	 -30.0	 30.0;
	6224	 2083	 0.000354	 0.027114	 0.0	 591.0	 1165	 1165	 0.93617	 0.0	 1	 -30.0	 30.0;
	2174	 2083	 0.000695	 0.04748	 0.0	 666	 666	 666	 0.982143	 0.0	 1	 -30.0	 30.0;
	4623	 1609	 0.000323	 0.028314	 0.0	 591.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	4623	 1609	 0.000323	 0.026354	 0.0	 591.0	 1199	 1199	 0.93617	 0.0	 1	 -30.0	 30.0;
	4623	 1609	 0.000323	 0.025696	 0.0	 591.0	 1230	 1230	 0.93617	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000355	 0.027305	 0.0	 591.0	 1157	 1157	 0.979227	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000355	 0.026666	 0.0	 591.0	 1185	 1185	 0.979227	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000923	 0.037456	 0.0	 844	 844	 844	 0.982143	 0.0	 1	 -30.0	 30.0;
	5589	 1001	 0.000788	 0.035217	 0.0	 897	 897	 897	 0.982143	 0.0	 1	 -30.0	 30.0;
	1198	 7473	 0.000323	 0.026739	 0.0	 591.0	 1182	 1182	 0.93617	 0.0	 1	 -30.0	 30.0;
	1198	 7473	 0.000323	 0.02749	 0.0	 591.0	 1149	 1149	 0.93617	 0.0	 1	 -30.0	 30.0;
	2479	 5482	 0.000313	 0.027324	 0.0	 591.0	 1156	 1156	 0.93617	 0.0	 1	 -30.0	 30.0;
	2479	 5482	 0.000313	 0.028074	 0.0	 591.0	 1126	 1126	 0.93617	 0.0	 1	 -30.0	 30.0;
	7831	 5525	 0.000601	 0.024984	 0.0	 1264	 1264	 1264	 0.982143	 0.0	 1	 -30.0	 30.0;
	7831	 5525	 0.000715	 0.022797	 0.0	 1385	 1385	 1385	 0.982143	 0.0	 1	 -30.0	 30.0;
	7831	 5525	 0.000344	 0.024893	 0.0	 591.0	 1269	 1269	 0.93617	 0.0	 1	 -30.0	 30.0;
	4970	 7955	 0.000365	 0.024163	 0.0	 591.0	 1308	 1308	 0.979227	 0.0	 1	 -30.0	 30.0;
	4970	 7955	 0.000344	 0.02385	 0.0	 591.0	 1325	 1325	 0.979227	 0.0	 1	 -30.0	 30.0;
	5007	 7367	 0.000757	 0.040182	 0.0	 786	 786	 786	 0.982143	 0.0	 1	 -30.0	 30.0;
	757	 3758	 0.000323	 0.028937	 0.0	 591.0	 1092	 1092	 0.979227	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000354	 0.026958	 0.0	 591.0	 1172	 1172	 0.93617	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000778	 0.045656	 0.0	 692	 692	 692	 0.982143	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000695	 0.048932	 0.0	 646	 646	 646	 0.982143	 0.0	 1	 -30.0	 30.0;
	3697	 6952	 0.000302	 0.025926	 0.0	 591.0	 1219	 1219	 0.93617	 0.0	 1	 -30.0	 30.0;
	6738	 8180	 0.000355	 0.027328	 0.0	 591.0	 1156	 1156	 0.93617	 0.0	 1	 -30.0	 30.0;
	6738	 8180	 0.000365	 0.027156	 0.0	 591.0	 1164	 1164	 0.93617	 0.0	 1	 -30.0	 30.0;
	9222	 5935	 0.000355	 0.024299	 0.0	 591.0	 1300	 1300	 0.979227	 0.0	 1	 -30.0	 30.0;
	7988	 804	 0.000375	 0.026313	 0.0	 591.0	 1201	 1201	 0.93617	 0.0	 1	 -30.0	 30.0;
	7988	 804	 0.000375	 0.025605	 0.0	 591.0	 1234	 1234	 0.93617	 0.0	 1	 -30.0	 30.0;
	3239	 1539	 0.000334	 0.026291	 0.0	 591.0	 1202	 1202	 0.979227	 0.0	 1	 -30.0	 30.0;
	3239	 1539	 0.000705	 0.046735	 0.0	 676	 676	 676	 0.982143	 0.0	 1	 -30.0	 30.0;
	2056	 4084	 0.000313	 0.026875	 0.0	 591.0	 1176	 1176	 0.979227	 0.0	 1	 -30.0	 30.0;
	2056	 4084	 0.000302	 0.027376	 0.0	 591.0	 1154	 1154	 0.979227	 0.0	 1	 -30.0	 30.0;
	4598	 5110	 0.000664	 0.044868	 0.0	 704	 704	 704	 0.982143	 0.0	 1	 -30.0	 30.0;
	2129	 5110	 0.000809	 0.044526	 0.0	 710	 710	 710	 0.982143	 0.0	 1	 -30.0	 30.0;
	5658	 5550	 0.00086	 0.034253	 0.0	 922	 922	 922	 0.982143	 0.0	 1	 -30.0	 30.0;
	5658	 5550	 0.000355	 0.024372	 0.0	 591.0	 1296	 1296	 0.93617	 0.0	 1	 -30.0	 30.0;
	2848	 1526	 0.000365	 0.023788	 0.0	 591.0	 1328	 1328	 0.93617	 0.0	 1	 -30.0	 30.0;
	4541	 7464	 0.000375	 0.023204	 0.0	 591.0	 1362	 1362	 0.979227	 0.0	 1	 -30.0	 30.0;
	4541	 7464	 0.000302	 0.026593	 0.0	 591.0	 1188	 1188	 0.979227	 0.0	 1	 -30.0	 30.0;
	1754	 3857	 0.000323	 0.029256	 0.0	 591.0	 1080	 1080	 0.93617	 0.0	 1	 -30.0	 30.0;
	1754	 3857	 0.000334	 0.029986	 0.0	 591.0	 1054	 1054	 0.93617	 0.0	 1	 -30.0	 30.0;
	1754	 3857	 0.000355	 0.030979	 0.0	 591.0	 1020	 1020	 0.93617	 0.0	 1	 -30.0	 30.0;
	2518	 4544	 0.000302	 0.025707	 0.0	 591.0	 1229	 1229	 0.93617	 0.0	 1	 -30.0	 30.0;
	2518	 4544	 0.000344	 0.025405	 0.0	 591.0	 1244	 1244	 0.93617	 0.0	 1	 -30.0	 30.0;
	3069	 6115	 0.00012	 0.008908	 0.0	 491.0	 3546	 3546	 1.0	 -0.072388	 1	 -30.0	 30.0;
	5067	 7641	 0.000365	 0.023715	 0.0	 591.0	 1332	 1332	 0.93617	 0.0	 1	 -30.0	 30.0;
	6036	 8670	 0.000365	 0.023517	 0.0	 591.0	 1344	 1344	 0.979227	 0.0	 1	 -30.0	 30.0;
	6036	 5522	 0.000334	 0.026812	 0.0	 591.0	 1179	 1179	 0.979227	 0.0	 1	 -30.0	 30.0;
	8486	 8791	 0.000695	 0.047253	 0.0	 669	 669	 669	 0.982143	 0.0	 1	 -30.0	 30.0;
	7530	 8791	 0.000778	 0.043759	 0.0	 722	 722	 722	 0.982143	 0.0	 1	 -30.0	 30.0;
	7522	 7571	 0.000313	 0.030636	 0.0	 591.0	 1031	 1031	 0.93617	 0.0	 1	 -30.0	 30.0;
	7522	 7571	 0.000313	 0.028286	 0.0	 591.0	 1117	 1117	 0.93617	 0.0	 1	 -30.0	 30.0;
	7522	 7571	 0.000344	 0.028115	 0.0	 591.0	 1124	 1124	 0.93617	 0.0	 1	 -30.0	 30.0;
	2526	 1483	 0.000902	 0.039425	 0.0	 801	 801	 801	 0.982143	 0.0	 1	 -30.0	 30.0;
	2365	 8316	 0.000355	 0.024237	 0.0	 591.0	 1304	 1304	 0.93617	 0.0	 1	 -30.0	 30.0;
	8672	 1860	 0.000375	 0.023986	 0.0	 591.0	 1317	 1317	 0.93617	 0.0	 1	 -30.0	 30.0;
	8672	 1860	 0.000375	 0.023861	 0.0	 591.0	 1324	 1324	 0.93617	 0.0	 1	 -30.0	 30.0;
	1494	 583	 0.000819	 0.04153	 0.0	 761	 761	 761	 0.982143	 0.0	 1	 -30.0	 30.0;
	1494	 583	 0.000809	 0.042701	 0.0	 740	 740	 740	 0.982143	 0.0	 1	 -30.0	 30.0;
	1502	 2795	 0.000334	 0.028022	 0.0	 591.0	 1128	 1128	 0.93617	 0.0	 1	 -30.0	 30.0;
	8195	 933	 0.000632	 0.048237	 0.0	 655	 655	 655	 0.982143	 0.0	 1	 -30.0	 30.0;
	8195	 933	 0.000632	 0.045159	 0.0	 700	 700	 700	 0.982143	 0.0	 1	 -30.0	 30.0;
	8195	 933	 0.000715	 0.044039	 0.0	 718	 718	 718	 0.982143	 0.0	 1	 -30.0	 30.0;
	3918	 6802	 0.00074	 0.044479	 0.0	 711	 711	 711	 0.986547	 0.0	 1	 -30.0	 30.0;
	3918	 4025	 0.00074	 0.043811	 0.0	 721	 721	 721	 0.986547	 0.0	 1	 -30.0	 30.0;
	4435	 2079	 0.000375	 0.02385	 0.0	 591.0	 1325	 1325	 0.93617	 0.0	 1	 -30.0	 30.0;
	4435	 2079	 0.000365	 0.023267	 0.0	 591.0	 1358	 1358	 0.93617	 0.0	 1	 -30.0	 30.0;
	4435	 2079	 0.000323	 0.026739	 0.0	 591.0	 1182	 1182	 0.93617	 0.0	 1	 -30.0	 30.0;
	1081	 7361	 0.000684	 0.047025	 0.0	 672	 672	 672	 0.982143	 0.0	 1	 -30.0	 30.0;
	9101	 2177	 0.000313	 0.02748	 0.0	 591.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	6555	 8475	 0.000323	 0.028554	 0.0	 591.0	 1107	 1107	 0.93617	 0.0	 1	 -30.0	 30.0;
	6555	 8475	 0.000302	 0.026437	 0.0	 591.0	 1195	 1195	 0.93617	 0.0	 1	 -30.0	 30.0;
	7056	 7577	 0.000365	 0.025551	 0.0	 591.0	 1237	 1237	 0.93617	 0.0	 1	 -30.0	 30.0;
	7056	 7577	 0.000344	 0.024893	 0.0	 591.0	 1269	 1269	 0.93617	 0.0	 1	 -30.0	 30.0;
	7056	 9051	 0.000375	 0.024508	 0.0	 591.0	 1289	 1289	 0.979227	 0.0	 1	 -30.0	 30.0;
	6889	 6785	 0.000778	 0.041157	 0.0	 768	 768	 768	 0.982143	 0.0	 1	 -30.0	 30.0;
	6889	 6785	 0.000923	 0.03702	 0.0	 853	 853	 853	 0.982143	 0.0	 1	 -30.0	 30.0;
	6889	 6785	 0.000302	 0.026593	 0.0	 591.0	 1188	 1188	 0.979227	 0.0	 1	 -30.0	 30.0;
	1027	 7148	 0.000344	 0.029667	 0.0	 591.0	 1065	 1065	 0.93617	 0.0	 1	 -30.0	 30.0;
	1027	 44	 0.000334	 0.02748	 0.0	 591.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	5308	 7148	 0.000323	 0.030636	 0.0	 591.0	 1031	 1031	 0.89674	 0.0	 1	 -30.0	 30.0;
	5308	 44	 0.000323	 0.028526	 0.0	 591.0	 1108	 1108	 0.93617	 0.0	 1	 -30.0	 30.0;
	9213	 6231	 0.000344	 0.025332	 0.0	 591.0	 1247	 1247	 0.979227	 0.0	 1	 -30.0	 30.0;
	9213	 8291	 0.000334	 0.024674	 0.0	 591.0	 1281	 1281	 0.979227	 0.0	 1	 -30.0	 30.0;
	9213	 6842	 0.000344	 0.02457	 0.0	 591.0	 1286	 1286	 0.979227	 0.0	 1	 -30.0	 30.0;
	3608	 6664	 0.000365	 0.023788	 0.0	 591.0	 1328	 1328	 0.93617	 0.0	 1	 -30.0	 30.0;
	4339	 6570	 0.000365	 0.023601	 0.0	 591.0	 1339	 1339	 0.93617	 0.0	 1	 -30.0	 30.0;
	4339	 6570	 0.000344	 0.02652	 0.0	 591.0	 1191	 1191	 0.93617	 0.0	 1	 -30.0	 30.0;
	7513	 6570	 0.000344	 0.027272	 0.0	 591.0	 1159	 1159	 0.93617	 0.0	 1	 -30.0	 30.0;
	7513	 6570	 0.000334	 0.027563	 0.0	 591.0	 1146	 1146	 0.93617	 0.0	 1	 -30.0	 30.0;
	8887	 6639	 0.000313	 0.030636	 0.0	 591.0	 1031	 1031	 0.979227	 0.0	 1	 -30.0	 30.0;
	8887	 6639	 0.000313	 0.028286	 0.0	 591.0	 1117	 1117	 0.979227	 0.0	 1	 -30.0	 30.0;
	5461	 4816	 0.000881	 0.036803	 0.0	 859	 859	 859	 0.982143	 0.0	 1	 -30.0	 30.0;
	5461	 4816	 0.000902	 0.036668	 0.0	 862	 862	 862	 0.982143	 0.0	 1	 -30.0	 30.0;
	5461	 4816	 0.000881	 0.034014	 0.0	 929	 929	 929	 0.982143	 0.0	 1	 -30.0	 30.0;
	5460	 3786	 0.000365	 0.026027	 0.0	 591.0	 1214	 1214	 0.93617	 0.0	 1	 -30.0	 30.0;
	5460	 3786	 0.000386	 0.025673	 0.0	 591.0	 1231	 1231	 0.93617	 0.0	 1	 -30.0	 30.0;
	7256	 4491	 0.00012	 0.011186	 0.0	 586.0	 2824	 2824	 1.0	 0.084507	 1	 -30.0	 30.0;
	6153	 58	 0.00017	 0.006789	 0.0	 1216.0	 4652	 4652	 1.0	 -0.086984	 1	 -30.0	 30.0;
	6153	 6807	 0.000664	 0.047107	 0.0	 671	 671	 671	 0.982143	 0.0	 1	 -30.0	 30.0;
	1465	 1262	 0.000313	 0.028314	 0.0	 591.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	1465	 1262	 0.000334	 0.025707	 0.0	 591.0	 1229	 1229	 0.93617	 0.0	 1	 -30.0	 30.0;
	1465	 1551	 0.000344	 0.025478	 0.0	 591.0	 1240	 1240	 0.93617	 0.0	 1	 -30.0	 30.0;
	7537	 1551	 0.000344	 0.027236	 0.0	 591.0	 1160	 1160	 0.93617	 0.0	 1	 -30.0	 30.0;
	7537	 1551	 0.000375	 0.026518	 0.0	 591.0	 1192	 1192	 0.93617	 0.0	 1	 -30.0	 30.0;
	6901	 4874	 0.000386	 0.02646	 0.0	 591.0	 1194	 1194	 0.93617	 0.0	 1	 -30.0	 30.0;
	5241	 4	 0.000788	 0.040317	 0.0	 784	 784	 784	 0.982143	 0.0	 1	 -30.0	 30.0;
	7520	 561	 0.000323	 0.025863	 0.0	 591.0	 1222	 1222	 0.979227	 0.0	 1	 -30.0	 30.0;
	749	 4324	 1e-05	 0.022863	 0.0	 948.0	 1382	 1382	 1.0	 0.04898	 1	 -30.0	 30.0;
	4141	 7124	 0.000334	 0.030306	 0.0	 591.0	 1043	 1043	 0.93617	 0.0	 1	 -30.0	 30.0;
	4141	 7124	 0.000302	 0.030636	 0.0	 591.0	 1032	 1032	 0.93617	 0.0	 1	 -30.0	 30.0;
	7466	 3649	 0.00011	 0.010476	 0.0	 472.0	 3016	 3016	 1.0	 -0.06138	 1	 -30.0	 30.0;
	8222	 6556	 0.000344	 0.024841	 0.0	 591.0	 1272	 1272	 0.979227	 0.0	 1	 -30.0	 30.0;
	8222	 6556	 0.000365	 0.025029	 0.0	 591.0	 1262	 1262	 0.979227	 0.0	 1	 -30.0	 30.0;
	8222	 6556	 0.000355	 0.024101	 0.0	 591.0	 1311	 1311	 0.979227	 0.0	 1	 -30.0	 30.0;
	4125	 163	 0.000344	 0.02385	 0.0	 591.0	 1325	 1325	 0.93617	 0.0	 1	 -30.0	 30.0;
	4125	 163	 0.000411	 0.02313	 0.0	 591.0	 1366	 1366	 0.93617	 0.0	 1	 -30.0	 30.0;
	4125	 163	 0.000829	 0.042764	 0.0	 739	 739	 739	 0.982143	 0.0	 1	 -30.0	 30.0;
	5837	 9217	 0.000705	 0.04748	 0.0	 666	 666	 666	 0.982143	 0.0	 1	 -30.0	 30.0;
	5837	 1448	 0.000323	 0.029986	 0.0	 591.0	 1054	 1054	 0.93617	 0.0	 1	 -30.0	 30.0;
	5837	 1448	 0.000302	 0.029952	 0.0	 591.0	 1055	 1055	 0.93617	 0.0	 1	 -30.0	 30.0;
	8267	 5365	 0.000746	 0.041064	 0.0	 770	 770	 770	 0.982143	 0.0	 1	 -30.0	 30.0;
	8267	 5365	 0.000881	 0.042214	 0.0	 749	 749	 749	 0.982143	 0.0	 1	 -30.0	 30.0;
	2359	 8005	 0.00086	 0.041209	 0.0	 767	 767	 767	 0.982143	 0.0	 1	 -30.0	 30.0;
	2359	 8005	 0.000912	 0.038669	 0.0	 817	 817	 817	 0.982143	 0.0	 1	 -30.0	 30.0;
	8109	 171	 0.000375	 0.026244	 0.0	 591.0	 1204	 1204	 0.979227	 0.0	 1	 -30.0	 30.0;
	8109	 171	 0.000375	 0.025457	 0.0	 591.0	 1241	 1241	 0.979227	 0.0	 1	 -30.0	 30.0;
	3485	 1156	 0.000302	 0.029096	 0.0	 591.0	 1086	 1086	 0.93617	 0.0	 1	 -30.0	 30.0;
	4734	 2229	 0.000302	 0.029667	 0.0	 591.0	 1065	 1065	 0.93617	 0.0	 1	 -30.0	 30.0;
	1709	 7702	 0.000334	 0.027563	 0.0	 591.0	 1146	 1146	 0.979227	 0.0	 1	 -30.0	 30.0;
	1709	 7702	 0.000323	 0.028074	 0.0	 591.0	 1126	 1126	 0.979227	 0.0	 1	 -30.0	 30.0;
	905	 8189	 0.000736	 0.041064	 0.0	 770	 770	 770	 0.982143	 0.0	 1	 -30.0	 30.0;
	8334	 8189	 0.001234	 0.040109	 0.0	 788	 788	 788	 0.982143	 0.0	 1	 -30.0	 30.0;
	8334	 8189	 0.000757	 0.043209	 0.0	 731	 731	 731	 0.982143	 0.0	 1	 -30.0	 30.0;
	7998	 6734	 0.000323	 0.026586	 0.0	 854.0	 1189	 1189	 0.93617	 0.0	 1	 -30.0	 30.0;
	4196	 280	 0.000788	 0.040296	 0.0	 784	 784	 784	 0.982143	 0.0	 1	 -30.0	 30.0;
	4196	 280	 0.000912	 0.040514	 0.0	 780	 780	 780	 0.982143	 0.0	 1	 -30.0	 30.0;
	6475	 3503	 0.000798	 0.042183	 0.0	 749	 749	 749	 0.982143	 0.0	 1	 -30.0	 30.0;
	6475	 3503	 0.000778	 0.043147	 0.0	 732	 732	 732	 0.982143	 0.0	 1	 -30.0	 30.0;
	7328	 4235	 0.000323	 0.027793	 0.0	 591.0	 1137	 1137	 0.93617	 0.0	 1	 -30.0	 30.0;
	7328	 4235	 0.000302	 0.027918	 0.0	 591.0	 1132	 1132	 0.93617	 0.0	 1	 -30.0	 30.0;
	7328	 4235	 0.000302	 0.025926	 0.0	 591.0	 1219	 1219	 0.93617	 0.0	 1	 -30.0	 30.0;
	6921	 2949	 0.000344	 0.024956	 0.0	 591.0	 1266	 1266	 0.979227	 0.0	 1	 -30.0	 30.0;
	6921	 2949	 0.000355	 0.024435	 0.0	 591.0	 1293	 1293	 0.979227	 0.0	 1	 -30.0	 30.0;
	3830	 306	 0.000386	 0.026392	 0.0	 591.0	 1197	 1197	 0.93617	 0.0	 1	 -30.0	 30.0;
	5648	 306	 0.000365	 0.025525	 0.0	 591.0	 1238	 1238	 0.93617	 0.0	 1	 -30.0	 30.0;
	1730	 115	 0.000344	 0.029986	 0.0	 591.0	 1054	 1054	 0.93617	 0.0	 1	 -30.0	 30.0;
	1730	 115	 0.000323	 0.029838	 0.0	 591.0	 1059	 1059	 0.93617	 0.0	 1	 -30.0	 30.0;
	2721	 5720	 0.000323	 0.02748	 0.0	 591.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	2721	 5720	 0.000313	 0.028001	 0.0	 591.0	 1129	 1129	 0.93617	 0.0	 1	 -30.0	 30.0;
	432	 3246	 0.000179	 0.012988	 0.0	 1151.0	 2432	 2432	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 8846	 0.000198	 0.012724	 0.0	 1151.0	 2483	 2483	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 2393	 0.000207	 0.012469	 0.0	 1151.0	 2533	 2533	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 1895	 0.000207	 0.012206	 0.0	 1151.0	 2588	 2588	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 3412	 0.000217	 0.012912	 0.0	 1151.0	 2447	 2447	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 5586	 0.000217	 0.012627	 0.0	 1151.0	 2502	 2502	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 3112	 0.000198	 0.014317	 0.0	 1151.0	 2207	 2207	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 3112	 0.000189	 0.014592	 0.0	 1151.0	 2165	 2165	 0.990991	 0.0	 1	 -30.0	 30.0;
	432	 7857	 0.000354	 0.02725	 0.0	 591.0	 1160	 1160	 0.979227	 0.0	 1	 -30.0	 30.0;
	960	 8497	 0.000628	 0.042428	 0.0	 745	 745	 745	 1.009174	 0.0	 1	 -30.0	 30.0;
	960	 8497	 0.000726	 0.044039	 0.0	 718	 718	 718	 0.982143	 0.0	 1	 -30.0	 30.0;
	3577	 5907	 0.000365	 0.024893	 0.0	 591.0	 1269	 1269	 0.979227	 0.0	 1	 -30.0	 30.0;
	3577	 5907	 0.000438	 0.02457	 0.0	 591.0	 1286	 1286	 0.979227	 0.0	 1	 -30.0	 30.0;
	3577	 5907	 0.000365	 0.023986	 0.0	 591.0	 1317	 1317	 0.979227	 0.0	 1	 -30.0	 30.0;
	7164	 5918	 0.000375	 0.023267	 0.0	 591.0	 1358	 1358	 0.979227	 0.0	 1	 -30.0	 30.0;
	7164	 5918	 0.000323	 0.026375	 0.0	 591.0	 1198	 1198	 0.93617	 0.0	 1	 -30.0	 30.0;
	1798	 2467	 0.000334	 0.029735	 0.0	 591.0	 1063	 1063	 0.93617	 0.0	 1	 -30.0	 30.0;
	1798	 2467	 0.000313	 0.030237	 0.0	 591.0	 1045	 1045	 0.93617	 0.0	 1	 -30.0	 30.0;
	3346	 2132	 0.000767	 0.044049	 0.0	 717	 717	 717	 0.982143	 0.0	 1	 -30.0	 30.0;
	3346	 2132	 0.000302	 0.026072	 0.0	 591.0	 1212	 1212	 0.93617	 0.0	 1	 -30.0	 30.0;
	3346	 2132	 0.00085	 0.039892	 0.0	 792	 792	 792	 0.982143	 0.0	 1	 -30.0	 30.0;
	3483	 8992	 0.000344	 0.024956	 0.0	 591.0	 1266	 1266	 0.979227	 0.0	 1	 -30.0	 30.0;
	8886	 8992	 0.000334	 0.026666	 0.0	 591.0	 1185	 1185	 0.93617	 0.0	 1	 -30.0	 30.0;
	2093	 805	 0.000365	 0.023788	 0.0	 591.0	 1328	 1328	 0.93617	 0.0	 1	 -30.0	 30.0;
	2093	 805	 0.000365	 0.023465	 0.0	 591.0	 1346	 1346	 0.93617	 0.0	 1	 -30.0	 30.0;
	221	 1541	 0.000334	 0.026447	 0.0	 591.0	 1195	 1195	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 5383	 0.000323	 0.027042	 0.0	 591.0	 1169	 1169	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 5383	 0.000313	 0.02748	 0.0	 591.0	 1150	 1150	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 5383	 0.000302	 0.028314	 0.0	 591.0	 1116	 1116	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 7507	 0.000323	 0.025853	 0.0	 591.0	 1222	 1222	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 7507	 0.000365	 0.026197	 0.0	 591.0	 1206	 1206	 0.93617	 0.0	 1	 -30.0	 30.0;
	8347	 7507	 0.000365	 0.025165	 0.0	 591.0	 1256	 1256	 0.93617	 0.0	 1	 -30.0	 30.0;
	4000	 4852	 0.000355	 0.024237	 0.0	 591.0	 1304	 1304	 0.979227	 0.0	 1	 -30.0	 30.0;
	4000	 2012	 0.000375	 0.024247	 0.0	 591.0	 1303	 1303	 0.93617	 0.0	 1	 -30.0	 30.0;
	2183	 4852	 0.000365	 0.023267	 0.0	 591.0	 1358	 1358	 0.979227	 0.0	 1	 -30.0	 30.0;
	2183	 2012	 0.000342	 0.023139	 0.0	 591.0	 1365	 1365	 0.982143	 0.0	 1	 -30.0	 30.0;
	1642	 7098	 0.000344	 0.026666	 0.0	 591.0	 1185	 1185	 0.979227	 0.0	 1	 -30.0	 30.0;
	1642	 687	 0.000334	 0.027021	 0.0	 591.0	 1169	 1169	 0.93617	 0.0	 1	 -30.0	 30.0;
	809	 7098	 0.000302	 0.027615	 0.0	 591.0	 1144	 1144	 0.979227	 0.0	 1	 -30.0	 30.0;
	809	 687	 0.000313	 0.026135	 0.0	 591.0	 1209	 1209	 0.93617	 0.0	 1	 -30.0	 30.0;
	4594	 8804	 0.000365	 0.025905	 0.0	 591.0	 1220	 1220	 0.93617	 0.0	 1	 -30.0	 30.0;
	4594	 8804	 0.000355	 0.025238	 0.0	 591.0	 1252	 1252	 0.93617	 0.0	 1	 -30.0	 30.0;
	2919	 4215	 0.000334	 0.026814	 0.0	 591.0	 1178	 1178	 0.93617	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    8   -     3.64
% INFO    : NUC    15  -    20.38
% INFO    : COW    85  -    65.80
% INFO    : NG     152 -    10.19
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.2583225542 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7393042549 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3828561955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5705303811 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4107477431 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3972662827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.6029672233 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.17170563892 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3928828564 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7203685328 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6016445828 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8295208545 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.0106798188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.86052188458 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.1441925166 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 0.348477717251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4803396308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.2602828262 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1859121961 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8766542534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0500111073 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6934242085 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1794515127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.7829502151 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.0777111134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2547646967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8883164493 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.064806041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0932563991 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.895057761 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5310775758 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7034854695 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.1441250359 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.1469883386 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2830379486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9618973058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0019683045 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9224450449 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9340709149 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1949909445 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7930390554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.399752247 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0549345215 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.2529057887 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9818740844 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9820401453 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.2202250099 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2654236183 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.6629940877 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.8381482566 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.88372222357 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.076690439 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8289597191 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8894037378 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4701519837 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4918285153 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9814335734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4275012425 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8947043097 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8103519621 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.089221177 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9605168182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5873889827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4458199792 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.80376946736 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4748869617 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1881433827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6725366884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4761578069 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3243595134 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3616461215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8946037999 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0665847519 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.6565806805 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.1384513203 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2098447168 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.09468199 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.965438242 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7654064864 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7529772593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4740145857 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9786440736 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9954152306 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0203070632 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.902755199 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0591775553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5651511178 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8650396983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.6800499253 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4995889855 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3858905278 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.2353102342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5991818172 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.647840049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3114404789 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.51754058293 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.9518127896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8104624145 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 79.7081442037 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8029991593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7023822607 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.611659025 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.6198834465 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1953997657 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.25337128157 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3149153945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3832432087 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4460612456 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9819344545 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.586863581 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2045893426 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.12277934508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.6669000315 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.55098080899 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.6041326083 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.804309332 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1447992064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1478101806 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5626928743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8074240742 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4469963979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.5386699248 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.909879668 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5441665798 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.9653321081 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.05101123257 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3568215368 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.296003208 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9380942999 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9310325466 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5888064235 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3027158354 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9773125012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 4.3450484512 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4629593961 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8147687648 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.01670001539 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4560681948 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 44.6702488326 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3667518234 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1051708029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1076710265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9436092745 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0863161319 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3039180897 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2606215594 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 98.9923180966 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4050631792 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.378434086 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1980465994 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6944754309 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7355493392 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.91292412153 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2508983568 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.979522848 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5381097058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4248530842 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2968046953 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.8616275568 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6702757342 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.798273431 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3366699832 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.404323102 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0600393341 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0808597855 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5554656121 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.2106810578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1841026037 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.8257741638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4594161904 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8259948497 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7044351084 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.881521427 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.6794771632 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.0907341932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.629615227 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 4.68799981739 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.9247069196 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.19686641 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5363942991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0516604755 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2904215601 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.0386214817 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5832953139 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.644094652 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5247558517 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0900714581 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.8049535297 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3935529398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1826872257 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3505079991 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.2757293258 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4798656213 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.61214767 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0658763807 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3850850871 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6593457649 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 4.60210023178 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.7710011421 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.4315823136 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.7236931135 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3522163556 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.7307858967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.3777377287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7962424693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8620317584 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.59154864 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5814185604 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0434591297 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4166131391 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0461063075 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.51684375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4805270136 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9493679922 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9301964547 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3388868363 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 125.432468161 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2672717917 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.1671064466 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8801912862 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4963435915 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.87742335692 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.6246015279 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4869716835 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.22343241955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2405262035 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9927260377 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1106800852 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7122161651 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6188475053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4363098151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.8917112881 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.2678666412 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.024605281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.6942139478 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0180155031 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.4142523767 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7759240119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1543914963 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.881810665 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6113590664 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0352481086 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.25458111639 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4311422074 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.62797458409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2906691874 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.78833598441 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9555510795 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2161387125 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4010744432 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8472279931 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5380479298 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0396854075 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9198091364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.9120235752 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.87519858374 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6485063758 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.2222992715 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6456034488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5790050723 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Transformer 549-5002 has a phase shift of 0.072386, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 3069-6115 has a phase shift of -0.072388, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 7256-4491 has a phase shift of 0.084507, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 6153-58 has a phase shift of -0.086984, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 749-4324 has a phase shift of 0.04898, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 7466-3649 has a phase shift of -0.06138, changing tap ratio 0.0 => 1.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 7351-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39412
% INFO    : Updated Thermal Rating: on line 4314-7571 : Rate B, Rate C , 0.0, 0.0 -> 1864
% INFO    : Updated Thermal Rating: on line 5803-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7252
% INFO    : Updated Thermal Rating: on line 6757-6036 : Rate B, Rate C , 0.0, 0.0 -> 12799
% INFO    : Updated Thermal Rating: on line 6757-6921 : Rate B, Rate C , 0.0, 0.0 -> 8353
% INFO    : Updated Thermal Rating: on line 5019-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53817
% INFO    : Updated Thermal Rating: on line 2930-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42657
% INFO    : Updated Thermal Rating: on line 1436-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53244
% INFO    : Updated Thermal Rating: on line 1851-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48642
% INFO    : Updated Thermal Rating: on line 8331-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53416
% INFO    : Updated Thermal Rating: on line 6220-8791 : Rate B, Rate C , 0.0, 0.0 -> 6384
% INFO    : Updated Thermal Rating: on line 9203-7842 : Rate B, Rate C , 0.0, 0.0 -> 41388
% INFO    : Updated Thermal Rating: on line 9203-8997 : Rate B, Rate C , 0.0, 0.0 -> 5051
% INFO    : Updated Thermal Rating: on line 9203-2129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4190
% INFO    : Updated Thermal Rating: on line 9203-29 : Rate B, Rate C , 0.0, 0.0 -> 3577
% INFO    : Updated Thermal Rating: on line 118-8903 : Rate B, Rate C , 0.0, 0.0 -> 34578
% INFO    : Updated Thermal Rating: on line 118-4598 : Rate B, Rate C , 0.0, 0.0 -> 4380
% INFO    : Updated Thermal Rating: on line 2426-5533 : Rate B, Rate C , 0.0, 0.0 -> 14992
% INFO    : Updated Thermal Rating: on line 2426-4831 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 2426-8961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 2426-8522 : Rate B, Rate C , 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 2426-6888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 2426-3401 : Rate B, Rate C , 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 2426-641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3433
% INFO    : Updated Thermal Rating: on line 2426-2600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9747
% INFO    : Updated Thermal Rating: on line 2426-5351 : Rate B, Rate C , 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 3051-718 : Rate B, Rate C , 0.0, 0.0 -> 124840
% INFO    : Updated Thermal Rating: on line 3036-2327 : Rate B, Rate C , 0.0, 0.0 -> 42335
% INFO    : Updated Thermal Rating: on line 8651-7473 : Rate B, Rate C , 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on line 8651-7473 : Rate B, Rate C , 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 903-3654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70101
% INFO    : Updated Thermal Rating: on line 8732-7050 : Rate B, Rate C , 0.0, 0.0 -> 21113
% INFO    : Updated Thermal Rating: on line 8732-3912 : Rate B, Rate C , 0.0, 0.0 -> 41734
% INFO    : Updated Thermal Rating: on line 2273-1973 : Rate B, Rate C , 0.0, 0.0 -> 50883
% INFO    : Updated Thermal Rating: on line 5131-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35472
% INFO    : Updated Thermal Rating: on line 6629-4918 : Rate B, Rate C , 0.0, 0.0 -> 2273
% INFO    : Updated Thermal Rating: on line 6629-7309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 413-1102 : Rate B, Rate C , 0.0, 0.0 -> 50969
% INFO    : Updated Thermal Rating: on line 413-1102 : Rate B, Rate C , 0.0, 0.0 -> 49351
% INFO    : Updated Thermal Rating: on line 3248-4918 : Rate B, Rate C , 0.0, 0.0 -> 7265
% INFO    : Updated Thermal Rating: on line 3248-4281 : Rate B, Rate C , 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 3248-7309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9162
% INFO    : Updated Thermal Rating: on line 1146-1187 : Rate B, Rate C , 0.0, 0.0 -> 2399
% INFO    : Updated Thermal Rating: on line 1146-7945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9180
% INFO    : Updated Thermal Rating: on line 8900-2421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25425
% INFO    : Updated Thermal Rating: on line 6071-2972 : Rate B, Rate C , 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 6071-6031 : Rate B, Rate C , 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 3293-7264 : Rate B, Rate C , 0.0, 0.0 -> 2816
% INFO    : Updated Thermal Rating: on line 3293-283 : Rate B, Rate C , 0.0, 0.0 -> 4036
% INFO    : Updated Thermal Rating: on line 3293-3069 : Rate B, Rate C , 0.0, 0.0 -> 939
% INFO    : Updated Thermal Rating: on line 3293-3390 : Rate B, Rate C , 0.0, 0.0 -> 3066
% INFO    : Updated Thermal Rating: on line 4689-4936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9881
% INFO    : Updated Thermal Rating: on line 4689-4936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9744
% INFO    : Updated Thermal Rating: on line 3218-7809 : Rate B, Rate C , 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 3218-5455 : Rate B, Rate C , 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 3218-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1996
% INFO    : Updated Thermal Rating: on line 6806-5410 : Rate B, Rate C , 0.0, 0.0 -> 7899
% INFO    : Updated Thermal Rating: on line 6806-5410 : Rate B, Rate C , 0.0, 0.0 -> 8381
% INFO    : Updated Thermal Rating: on line 6806-1609 : Rate B, Rate C , 0.0, 0.0 -> 4018
% INFO    : Updated Thermal Rating: on line 6806-1609 : Rate B, Rate C , 0.0, 0.0 -> 4034
% INFO    : Updated Thermal Rating: on line 6806-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 6806-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9636
% INFO    : Updated Thermal Rating: on line 6806-954 : Rate B, Rate C , 0.0, 0.0 -> 11510
% INFO    : Updated Thermal Rating: on line 9140-502 : Rate B, Rate C , 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on line 9140-3013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4315
% INFO    : Updated Thermal Rating: on line 9140-2949 : Rate B, Rate C , 0.0, 0.0 -> 3575
% INFO    : Updated Thermal Rating: on line 9140-2949 : Rate B, Rate C , 0.0, 0.0 -> 3646
% INFO    : Updated Thermal Rating: on line 9140-2949 : Rate B, Rate C , 0.0, 0.0 -> 3663
% INFO    : Updated Thermal Rating: on line 7070-2208 : Rate B, Rate C , 0.0, 0.0 -> 36421
% INFO    : Updated Thermal Rating: on line 7070-8060 : Rate B, Rate C , 0.0, 0.0 -> 25518
% INFO    : Updated Thermal Rating: on line 7070-4484 : Rate B, Rate C , 0.0, 0.0 -> 23967
% INFO    : Updated Thermal Rating: on line 7070-4239 : Rate B, Rate C , 0.0, 0.0 -> 8717
% INFO    : Updated Thermal Rating: on line 8535-7047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48244
% INFO    : Updated Thermal Rating: on line 5477-3657 : Rate B, Rate C , 0.0, 0.0 -> 25180
% INFO    : Updated Thermal Rating: on line 5477-2928 : Rate B, Rate C , 0.0, 0.0 -> 12337
% INFO    : Updated Thermal Rating: on line 3145-2918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 7770-5317 : Rate B, Rate C , 0.0, 0.0 -> 6584
% INFO    : Updated Thermal Rating: on line 7770-5317 : Rate B, Rate C , 0.0, 0.0 -> 6260
% INFO    : Updated Thermal Rating: on line 3-8676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 3-8189 : Rate B, Rate C , 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 7267-2938 : Rate B, Rate C , 0.0, 0.0 -> 3928
% INFO    : Updated Thermal Rating: on line 7267-2938 : Rate B, Rate C , 0.0, 0.0 -> 3990
% INFO    : Updated Thermal Rating: on line 7267-3918 : Rate B, Rate C , 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 7267-3918 : Rate B, Rate C , 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 7267-6581 : Rate B, Rate C , 0.0, 0.0 -> 2201
% INFO    : Updated Thermal Rating: on line 7267-6581 : Rate B, Rate C , 0.0, 0.0 -> 2246
% INFO    : Updated Thermal Rating: on line 7267-3830 : Rate B, Rate C , 0.0, 0.0 -> 2175
% INFO    : Updated Thermal Rating: on line 7267-5648 : Rate B, Rate C , 0.0, 0.0 -> 2087
% INFO    : Updated Thermal Rating: on line 7267-5648 : Rate B, Rate C , 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 4918-4907 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 4918-5957 : Rate B, Rate C , 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 4918-5233 : Rate B, Rate C , 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 6854-7309 : Rate B, Rate C , 0.0, 0.0 -> 148968
% INFO    : Updated Thermal Rating: on line 8311-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13251
% INFO    : Updated Thermal Rating: on line 2770-8804 : Rate B, Rate C , 0.0, 0.0 -> 7291
% INFO    : Updated Thermal Rating: on line 9241-8804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7442
% INFO    : Updated Thermal Rating: on line 3083-7124 : Rate B, Rate C , 0.0, 0.0 -> 7227
% INFO    : Updated Thermal Rating: on line 3083-7124 : Rate B, Rate C , 0.0, 0.0 -> 6738
% INFO    : Updated Thermal Rating: on line 3083-8873 : Rate B, Rate C , 0.0, 0.0 -> 6103
% INFO    : Updated Thermal Rating: on line 1566-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 1566-3541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2443
% INFO    : Updated Thermal Rating: on line 8683-3698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32156
% INFO    : Updated Thermal Rating: on line 8683-3698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33953
% INFO    : Updated Thermal Rating: on line 8683-2801 : Rate B, Rate C , 0.0, 0.0 -> 2515
% INFO    : Updated Thermal Rating: on line 8683-8328 : Rate B, Rate C , 0.0, 0.0 -> 14927
% INFO    : Updated Thermal Rating: on line 8683-8511 : Rate B, Rate C , 0.0, 0.0 -> 20990
% INFO    : Updated Thermal Rating: on line 8683-6570 : Rate B, Rate C , 0.0, 0.0 -> 2238
% INFO    : Updated Thermal Rating: on line 8683-6570 : Rate B, Rate C , 0.0, 0.0 -> 2415
% INFO    : Updated Thermal Rating: on line 8683-8975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13028
% INFO    : Updated Thermal Rating: on line 8683-216 : Rate B, Rate C , 0.0, 0.0 -> 6209
% INFO    : Updated Thermal Rating: on line 8683-2961 : Rate B, Rate C , 0.0, 0.0 -> 43067
% INFO    : Updated Thermal Rating: on line 8683-6773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122861
% INFO    : Updated Thermal Rating: on line 8683-5278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134762
% INFO    : Updated Thermal Rating: on line 3768-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34015
% INFO    : Updated Thermal Rating: on line 2276-5546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3946
% INFO    : Updated Thermal Rating: on line 2276-6816 : Rate B, Rate C , 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 7766-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on line 7766-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3062
% INFO    : Updated Thermal Rating: on line 839-3918 : Rate B, Rate C , 0.0, 0.0 -> 14872
% INFO    : Updated Thermal Rating: on line 839-809 : Rate B, Rate C , 0.0, 0.0 -> 10058
% INFO    : Updated Thermal Rating: on line 4506-2286 : Rate B, Rate C , 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 4506-6802 : Rate B, Rate C , 0.0, 0.0 -> 4050
% INFO    : Updated Thermal Rating: on line 4506-3520 : Rate B, Rate C , 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 7273-6271 : Rate B, Rate C , 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 7273-1435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 7273-7148 : Rate B, Rate C , 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 7273-7437 : Rate B, Rate C , 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 6104-871 : Rate B, Rate C , 0.0, 0.0 -> 12175
% INFO    : Updated Thermal Rating: on line 7580-871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13128
% INFO    : Updated Thermal Rating: on line 1188-1539 : Rate B, Rate C , 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1188-8515 : Rate B, Rate C , 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 3971-4084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18252
% INFO    : Updated Thermal Rating: on line 3971-4084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18682
% INFO    : Updated Thermal Rating: on line 6845-5340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69711
% INFO    : Updated Thermal Rating: on line 8294-5814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6000
% INFO    : Updated Thermal Rating: on line 7115-6807 : Rate B, Rate C , 0.0, 0.0 -> 3309
% INFO    : Updated Thermal Rating: on line 619-6791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45348
% INFO    : Updated Thermal Rating: on line 5418-4908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37527
% INFO    : Updated Thermal Rating: on line 5120-6816 : Rate B, Rate C , 0.0, 0.0 -> 2192
% INFO    : Updated Thermal Rating: on line 6692-9158 : Rate B, Rate C , 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 6692-8035 : Rate B, Rate C , 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 3445-2848 : Rate B, Rate C , 0.0, 0.0 -> 4712
% INFO    : Updated Thermal Rating: on line 3445-7056 : Rate B, Rate C , 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 3445-7056 : Rate B, Rate C , 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 3445-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on line 3445-4594 : Rate B, Rate C , 0.0, 0.0 -> 6495
% INFO    : Updated Thermal Rating: on line 6114-1692 : Rate B, Rate C , 0.0, 0.0 -> 7400
% INFO    : Updated Thermal Rating: on line 6114-8190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7268
% INFO    : Updated Thermal Rating: on line 6114-5836 : Rate B, Rate C , 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 6114-3191 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 6114-5300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 6114-4889 : Rate B, Rate C , 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 7264-444 : Rate B, Rate C , 0.0, 0.0 -> 1912
% INFO    : Updated Thermal Rating: on line 7264-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 7982-9011 : Rate B, Rate C , 0.0, 0.0 -> 25490
% INFO    : Updated Thermal Rating: on line 7982-6675 : Rate B, Rate C , 0.0, 0.0 -> 19252
% INFO    : Updated Thermal Rating: on line 7982-6909 : Rate B, Rate C , 0.0, 0.0 -> 27681
% INFO    : Updated Thermal Rating: on line 7982-8835 : Rate B, Rate C , 0.0, 0.0 -> 9714
% INFO    : Updated Thermal Rating: on line 7982-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25490
% INFO    : Updated Thermal Rating: on line 1604-502 : Rate B, Rate C , 0.0, 0.0 -> 22423
% INFO    : Updated Thermal Rating: on line 2842-502 : Rate B, Rate C , 0.0, 0.0 -> 20084
% INFO    : Updated Thermal Rating: on line 1354-513 : Rate B, Rate C , 0.0, 0.0 -> 3776
% INFO    : Updated Thermal Rating: on line 1354-502 : Rate B, Rate C , 0.0, 0.0 -> 6259
% INFO    : Updated Thermal Rating: on line 891-3697 : Rate B, Rate C , 0.0, 0.0 -> 6921
% INFO    : Updated Thermal Rating: on line 891-3697 : Rate B, Rate C , 0.0, 0.0 -> 6952
% INFO    : Updated Thermal Rating: on line 8312-7541 : Rate B, Rate C , 0.0, 0.0 -> 3162
% INFO    : Updated Thermal Rating: on line 8312-7541 : Rate B, Rate C , 0.0, 0.0 -> 3103
% INFO    : Updated Thermal Rating: on line 6306-4826 : Rate B, Rate C , 0.0, 0.0 -> 70039
% INFO    : Updated Thermal Rating: on line 4826-4418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66806
% INFO    : Updated Thermal Rating: on line 4826-1605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92032
% INFO    : Updated Thermal Rating: on line 4826-6952 : Rate B, Rate C , 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 4826-7124 : Rate B, Rate C , 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 9128-217 : Rate B, Rate C , 0.0, 0.0 -> 10923
% INFO    : Updated Thermal Rating: on line 7014-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7964
% INFO    : Updated Thermal Rating: on line 720-5350 : Rate B, Rate C , 0.0, 0.0 -> 1764
% INFO    : Updated Thermal Rating: on line 720-5350 : Rate B, Rate C , 0.0, 0.0 -> 1730
% INFO    : Updated Thermal Rating: on line 1711-639 : Rate B, Rate C , 0.0, 0.0 -> 2771
% INFO    : Updated Thermal Rating: on line 1711-639 : Rate B, Rate C , 0.0, 0.0 -> 2720
% INFO    : Updated Thermal Rating: on line 1711-9130 : Rate B, Rate C , 0.0, 0.0 -> 3013
% INFO    : Updated Thermal Rating: on line 1711-9130 : Rate B, Rate C , 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 8209-1998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37606
% INFO    : Updated Thermal Rating: on line 8209-7974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21666
% INFO    : Updated Thermal Rating: on line 1035-8180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 1035-7466 : Rate B, Rate C , 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 1035-305 : Rate B, Rate C , 0.0, 0.0 -> 7089
% INFO    : Updated Thermal Rating: on line 1035-305 : Rate B, Rate C , 0.0, 0.0 -> 6970
% INFO    : Updated Thermal Rating: on line 1035-5106 : Rate B, Rate C , 0.0, 0.0 -> 3531
% INFO    : Updated Thermal Rating: on line 1035-5106 : Rate B, Rate C , 0.0, 0.0 -> 4433
% INFO    : Updated Thermal Rating: on line 2527-8466 : Rate B, Rate C , 0.0, 0.0 -> 5811
% INFO    : Updated Thermal Rating: on line 8669-8893 : Rate B, Rate C , 0.0, 0.0 -> 11214
% INFO    : Updated Thermal Rating: on line 6206-7691 : Rate B, Rate C , 0.0, 0.0 -> 1676
% INFO    : Updated Thermal Rating: on line 6206-6624 : Rate B, Rate C , 0.0, 0.0 -> 2206
% INFO    : Updated Thermal Rating: on line 3240-8158 : Rate B, Rate C , 0.0, 0.0 -> 4292
% INFO    : Updated Thermal Rating: on line 3240-8795 : Rate B, Rate C , 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 3240-4143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7181
% INFO    : Updated Thermal Rating: on line 3240-2797 : Rate B, Rate C , 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 3240-6331 : Rate B, Rate C , 0.0, 0.0 -> 2673
% INFO    : Updated Thermal Rating: on line 3240-6384 : Rate B, Rate C , 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 3240-7523 : Rate B, Rate C , 0.0, 0.0 -> 3327
% INFO    : Updated Thermal Rating: on line 3240-2889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13596
% INFO    : Updated Thermal Rating: on line 3240-6887 : Rate B, Rate C , 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 1249-4541 : Rate B, Rate C , 0.0, 0.0 -> 4424
% INFO    : Updated Thermal Rating: on line 819-7523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9048
% INFO    : Updated Thermal Rating: on line 2304-4353 : Rate B, Rate C , 0.0, 0.0 -> 3847
% INFO    : Updated Thermal Rating: on line 2304-4816 : Rate B, Rate C , 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on line 9174-6246 : Rate B, Rate C , 0.0, 0.0 -> 3756
% INFO    : Updated Thermal Rating: on line 9174-6246 : Rate B, Rate C , 0.0, 0.0 -> 3682
% INFO    : Updated Thermal Rating: on line 9174-5658 : Rate B, Rate C , 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 9174-5658 : Rate B, Rate C , 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 2924-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12101
% INFO    : Updated Thermal Rating: on line 2924-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12156
% INFO    : Updated Thermal Rating: on line 59-5764 : Rate B, Rate C , 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 59-2360 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 6510-9033 : Rate B, Rate C , 0.0, 0.0 -> 27118
% INFO    : Updated Thermal Rating: on line 6510-5918 : Rate B, Rate C , 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 6510-5918 : Rate B, Rate C , 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 1275-2850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7597
% INFO    : Updated Thermal Rating: on line 6426-4110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 6426-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 1758-2816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5059
% INFO    : Updated Thermal Rating: on line 1758-352 : Rate B, Rate C , 0.0, 0.0 -> 4370
% INFO    : Updated Thermal Rating: on line 1758-6581 : Rate B, Rate C , 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 1758-1923 : Rate B, Rate C , 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 1758-5837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 1758-3830 : Rate B, Rate C , 0.0, 0.0 -> 1671
% INFO    : Updated Thermal Rating: on line 1758-3577 : Rate B, Rate C , 0.0, 0.0 -> 8198
% INFO    : Updated Thermal Rating: on line 8030-1794 : Rate B, Rate C , 0.0, 0.0 -> 4858
% INFO    : Updated Thermal Rating: on line 8030-7808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4792
% INFO    : Updated Thermal Rating: on line 8030-6581 : Rate B, Rate C , 0.0, 0.0 -> 4130
% INFO    : Updated Thermal Rating: on line 8030-1923 : Rate B, Rate C , 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on line 8030-5837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2707
% INFO    : Updated Thermal Rating: on line 8030-5648 : Rate B, Rate C , 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 8030-3577 : Rate B, Rate C , 0.0, 0.0 -> 8371
% INFO    : Updated Thermal Rating: on line 4615-171 : Rate B, Rate C , 0.0, 0.0 -> 2578
% INFO    : Updated Thermal Rating: on line 3137-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84603
% INFO    : Updated Thermal Rating: on line 6271-8787 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on line 6252-9137 : Rate B, Rate C , 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 5533-7133 : Rate B, Rate C , 0.0, 0.0 -> 2183
% INFO    : Updated Thermal Rating: on line 8361-4355 : Rate B, Rate C , 0.0, 0.0 -> 67762
% INFO    : Updated Thermal Rating: on line 8361-2928 : Rate B, Rate C , 0.0, 0.0 -> 30454
% INFO    : Updated Thermal Rating: on line 609-1341 : Rate B, Rate C , 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 609-5419 : Rate B, Rate C , 0.0, 0.0 -> 7777
% INFO    : Updated Thermal Rating: on line 609-5419 : Rate B, Rate C , 0.0, 0.0 -> 7651
% INFO    : Updated Thermal Rating: on line 609-2079 : Rate B, Rate C , 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 609-772 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 3654-2928 : Rate B, Rate C , 0.0, 0.0 -> 26642
% INFO    : Updated Thermal Rating: on line 1355-7282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 1355-2197 : Rate B, Rate C , 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 1355-7640 : Rate B, Rate C , 0.0, 0.0 -> 2019
% INFO    : Updated Thermal Rating: on line 1355-1081 : Rate A, Rate B, Rate C , 1282.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 1355-1081 : Rate A, Rate B, Rate C , 1480.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 1355-2359 : Rate B, Rate C , 0.0, 0.0 -> 3422
% INFO    : Updated Thermal Rating: on line 1355-4196 : Rate B, Rate C , 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 5856-8546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2811
% INFO    : Updated Thermal Rating: on line 5856-5987 : Rate B, Rate C , 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 5856-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 5856-3925 : Rate B, Rate C , 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on line 5856-3324 : Rate B, Rate C , 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 5856-4748 : Rate B, Rate C , 0.0, 0.0 -> 2964
% INFO    : Updated Thermal Rating: on line 8265-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11971
% INFO    : Updated Thermal Rating: on line 6151-6313 : Rate B, Rate C , 0.0, 0.0 -> 9442
% INFO    : Updated Thermal Rating: on line 4005-6532 : Rate B, Rate C , 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 4005-2177 : Rate B, Rate C , 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 5723-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on line 5723-789 : Rate B, Rate C , 0.0, 0.0 -> 1683
% INFO    : Updated Thermal Rating: on line 2327-9189 : Rate B, Rate C , 0.0, 0.0 -> 22821
% INFO    : Updated Thermal Rating: on line 2327-3400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21440
% INFO    : Updated Thermal Rating: on line 207-4747 : Rate B, Rate C , 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on line 207-7791 : Rate B, Rate C , 0.0, 0.0 -> 5519
% INFO    : Updated Thermal Rating: on line 3205-6735 : Rate B, Rate C , 0.0, 0.0 -> 75017
% INFO    : Updated Thermal Rating: on line 3205-666 : Rate B, Rate C , 0.0, 0.0 -> 3501
% INFO    : Updated Thermal Rating: on line 3205-666 : Rate B, Rate C , 0.0, 0.0 -> 3579
% INFO    : Updated Thermal Rating: on line 3205-4435 : Rate A, Rate B, Rate C , 1282.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 3205-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3991
% INFO    : Updated Thermal Rating: on line 3205-3483 : Rate B, Rate C , 0.0, 0.0 -> 3742
% INFO    : Updated Thermal Rating: on line 4683-7989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25173
% INFO    : Updated Thermal Rating: on line 4683-6516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28780
% INFO    : Updated Thermal Rating: on line 4683-7697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25191
% INFO    : Updated Thermal Rating: on line 4683-416 : Rate B, Rate C , 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 4683-2847 : Rate B, Rate C , 0.0, 0.0 -> 2810
% INFO    : Updated Thermal Rating: on line 4683-2563 : Rate B, Rate C , 0.0, 0.0 -> 2871
% INFO    : Updated Thermal Rating: on line 4683-2563 : Rate B, Rate C , 0.0, 0.0 -> 2961
% INFO    : Updated Thermal Rating: on line 4683-2995 : Rate B, Rate C , 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 5691-1001 : Rate A, Rate B, Rate C , 510.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 5691-4426 : Rate B, Rate C , 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 5350-2721 : Rate B, Rate C , 0.0, 0.0 -> 4683
% INFO    : Updated Thermal Rating: on line 5350-2721 : Rate B, Rate C , 0.0, 0.0 -> 4773
% INFO    : Updated Thermal Rating: on line 2361-4936 : Rate B, Rate C , 0.0, 0.0 -> 3215
% INFO    : Updated Thermal Rating: on line 2361-5179 : Rate B, Rate C , 0.0, 0.0 -> 2630
% INFO    : Updated Thermal Rating: on line 2044-4748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16743
% INFO    : Updated Thermal Rating: on line 4197-5522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14024
% INFO    : Updated Thermal Rating: on line 5699-8670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12826
% INFO    : Updated Thermal Rating: on line 7809-5110 : Rate B, Rate C , 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 7222-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 4402-3817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113538
% INFO    : Updated Thermal Rating: on line 6857-2732 : Rate B, Rate C , 0.0, 0.0 -> 4391
% INFO    : Updated Thermal Rating: on line 6857-4550 : Rate B, Rate C , 0.0, 0.0 -> 4740
% INFO    : Updated Thermal Rating: on line 6857-4339 : Rate B, Rate C , 0.0, 0.0 -> 2079
% INFO    : Updated Thermal Rating: on line 6857-7513 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 5016-26 : Rate B, Rate C , 0.0, 0.0 -> 5182
% INFO    : Updated Thermal Rating: on line 5016-9213 : Rate B, Rate C , 0.0, 0.0 -> 6285
% INFO    : Updated Thermal Rating: on line 6112-9002 : Rate B, Rate C , 0.0, 0.0 -> 2344
% INFO    : Updated Thermal Rating: on line 6112-6231 : Rate B, Rate C , 0.0, 0.0 -> 2089
% INFO    : Updated Thermal Rating: on line 6112-883 : Rate B, Rate C , 0.0, 0.0 -> 1654
% INFO    : Updated Thermal Rating: on line 6112-5738 : Rate B, Rate C , 0.0, 0.0 -> 2297
% INFO    : Updated Thermal Rating: on line 8860-7700 : Rate B, Rate C , 0.0, 0.0 -> 3302
% INFO    : Updated Thermal Rating: on line 8860-9002 : Rate B, Rate C , 0.0, 0.0 -> 2693
% INFO    : Updated Thermal Rating: on line 8860-5990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 8860-6450 : Rate B, Rate C , 0.0, 0.0 -> 2234
% INFO    : Updated Thermal Rating: on line 8860-7726 : Rate B, Rate C , 0.0, 0.0 -> 4269
% INFO    : Updated Thermal Rating: on line 2489-4110 : Rate B, Rate C , 0.0, 0.0 -> 7985
% INFO    : Updated Thermal Rating: on line 3985-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1596
% INFO    : Updated Thermal Rating: on line 3985-4110 : Rate B, Rate C , 0.0, 0.0 -> 7062
% INFO    : Updated Thermal Rating: on line 3985-4829 : Rate B, Rate C , 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 3985-7857 : Rate B, Rate C , 0.0, 0.0 -> 6817
% INFO    : Updated Thermal Rating: on line 2806-7857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 2489-9012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5335
% INFO    : Updated Thermal Rating: on line 2489-2231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5728
% INFO    : Updated Thermal Rating: on line 658-3793 : Rate B, Rate C , 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 658-8497 : Rate B, Rate C , 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 658-8497 : Rate B, Rate C , 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 3502-9002 : Rate B, Rate C , 0.0, 0.0 -> 34833
% INFO    : Updated Thermal Rating: on line 3502-9002 : Rate B, Rate C , 0.0, 0.0 -> 31811
% INFO    : Updated Thermal Rating: on line 6313-44 : Rate B, Rate C , 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 6313-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 5944-8808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17349
% INFO    : Updated Thermal Rating: on line 3183-8515 : Rate B, Rate C , 0.0, 0.0 -> 2903
% INFO    : Updated Thermal Rating: on line 1005-8515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3155
% INFO    : Updated Thermal Rating: on line 8787-1448 : Rate B, Rate C , 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 6636-9051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41134
% INFO    : Updated Thermal Rating: on line 9109-9051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45856
% INFO    : Updated Thermal Rating: on line 6961-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 6961-8818 : Rate B, Rate C , 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 5077-4353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23256
% INFO    : Updated Thermal Rating: on line 7471-5241 : Rate B, Rate C , 0.0, 0.0 -> 1935
% INFO    : Updated Thermal Rating: on line 7471-8200 : Rate B, Rate C , 0.0, 0.0 -> 50038
% INFO    : Updated Thermal Rating: on line 549-6290 : Rate B, Rate C , 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 549-2291 : Rate B, Rate C , 0.0, 0.0 -> 1410
% INFO    : Updated Thermal Rating: on line 549-3656 : Rate B, Rate C , 0.0, 0.0 -> 2991
% INFO    : Updated Thermal Rating: on line 5002-4144 : Rate B, Rate C , 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 1888-5441 : Rate B, Rate C , 0.0, 0.0 -> 10884
% INFO    : Updated Thermal Rating: on line 1888-5441 : Rate B, Rate C , 0.0, 0.0 -> 10446
% INFO    : Updated Thermal Rating: on line 5490-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4899
% INFO    : Updated Thermal Rating: on line 5490-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4772
% INFO    : Updated Thermal Rating: on line 5490-4970 : Rate B, Rate C , 0.0, 0.0 -> 4325
% INFO    : Updated Thermal Rating: on line 5490-5461 : Rate B, Rate C , 0.0, 0.0 -> 3631
% INFO    : Updated Thermal Rating: on line 5490-7778 : Rate B, Rate C , 0.0, 0.0 -> 2930
% INFO    : Updated Thermal Rating: on line 5490-6897 : Rate B, Rate C , 0.0, 0.0 -> 2877
% INFO    : Updated Thermal Rating: on line 3075-4562 : Rate B, Rate C , 0.0, 0.0 -> 6077
% INFO    : Updated Thermal Rating: on line 564-8475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 564-2252 : Rate B, Rate C , 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 564-7903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 4331-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 2877-3674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5705
% INFO    : Updated Thermal Rating: on line 2854-1081 : Rate A, Rate B, Rate C , 920.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 2854-8267 : Rate B, Rate C , 0.0, 0.0 -> 2146
% INFO    : Updated Thermal Rating: on line 9112-9176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 9112-1422 : Rate B, Rate C , 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 9112-8515 : Rate B, Rate C , 0.0, 0.0 -> 1775
% INFO    : Updated Thermal Rating: on line 9112-8515 : Rate B, Rate C , 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 9112-5051 : Rate B, Rate C , 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 9112-1051 : Rate B, Rate C , 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 9112-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 9112-1584 : Rate B, Rate C , 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 6168-6888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on line 7653-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 7341-7098 : Rate B, Rate C , 0.0, 0.0 -> 4392
% INFO    : Updated Thermal Rating: on line 4701-8267 : Rate B, Rate C , 0.0, 0.0 -> 31398
% INFO    : Updated Thermal Rating: on line 1672-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30565
% INFO    : Updated Thermal Rating: on line 3880-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29969
% INFO    : Updated Thermal Rating: on line 6648-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30207
% INFO    : Updated Thermal Rating: on line 3609-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31096
% INFO    : Updated Thermal Rating: on line 2782-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28500
% INFO    : Updated Thermal Rating: on line 1844-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29005
% INFO    : Updated Thermal Rating: on line 4353-6053 : Rate B, Rate C , 0.0, 0.0 -> 2550
% INFO    : Updated Thermal Rating: on line 2166-5237 : Rate B, Rate C , 0.0, 0.0 -> 16450
% INFO    : Updated Thermal Rating: on line 2166-2886 : Rate B, Rate C , 0.0, 0.0 -> 2906
% INFO    : Updated Thermal Rating: on line 1043-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 4049-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98903
% INFO    : Updated Thermal Rating: on line 4520-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89464
% INFO    : Updated Thermal Rating: on line 1704-5814 : Rate B, Rate C , 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 8107-1486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49257
% INFO    : Updated Thermal Rating: on line 5664-5522 : Rate B, Rate C , 0.0, 0.0 -> 7545
% INFO    : Updated Thermal Rating: on line 4482-8670 : Rate B, Rate C , 0.0, 0.0 -> 7692
% INFO    : Updated Thermal Rating: on line 8795-7523 : Rate B, Rate C , 0.0, 0.0 -> 2355
% INFO    : Updated Thermal Rating: on line 2337-6430 : Rate B, Rate C , 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 455-7775 : Rate B, Rate C , 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 455-3857 : Rate B, Rate C , 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 455-333 : Rate B, Rate C , 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 455-6940 : Rate B, Rate C , 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 8225-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5843
% INFO    : Updated Thermal Rating: on line 5413-7752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1699
% INFO    : Updated Thermal Rating: on line 5413-1940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 5413-4234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 2591-6828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 2591-7571 : Rate B, Rate C , 0.0, 0.0 -> 1233
% INFO    : Updated Thermal Rating: on line 2591-7571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 2591-7571 : Rate B, Rate C , 0.0, 0.0 -> 1437
% INFO    : Updated Thermal Rating: on line 2591-7994 : Rate B, Rate C , 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 2591-7226 : Rate B, Rate C , 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 2591-1554 : Rate B, Rate C , 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 9011-1156 : Rate B, Rate C , 0.0, 0.0 -> 7870
% INFO    : Updated Thermal Rating: on line 8689-5502 : Rate B, Rate C , 0.0, 0.0 -> 3499
% INFO    : Updated Thermal Rating: on line 3085-8873 : Rate B, Rate C , 0.0, 0.0 -> 2346
% INFO    : Updated Thermal Rating: on line 1568-980 : Rate B, Rate C , 0.0, 0.0 -> 50801
% INFO    : Updated Thermal Rating: on line 3204-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2659
% INFO    : Updated Thermal Rating: on line 3557-639 : Rate B, Rate C , 0.0, 0.0 -> 4539
% INFO    : Updated Thermal Rating: on line 3557-4936 : Rate B, Rate C , 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 416-3492 : Rate B, Rate C , 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 416-7937 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 3255-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1762
% INFO    : Updated Thermal Rating: on line 3255-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49730
% INFO    : Updated Thermal Rating: on line 7373-367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 4251-2132 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 4251-2132 : Rate B, Rate C , 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 4251-5567 : Rate B, Rate C , 0.0, 0.0 -> 2996
% INFO    : Updated Thermal Rating: on line 6376-1808 : Rate B, Rate C , 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 6376-1808 : Rate B, Rate C , 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 6376-7857 : Rate B, Rate C , 0.0, 0.0 -> 1826
% INFO    : Updated Thermal Rating: on line 9185-7289 : Rate B, Rate C , 0.0, 0.0 -> 4058
% INFO    : Updated Thermal Rating: on line 9185-3999 : Rate B, Rate C , 0.0, 0.0 -> 45778
% INFO    : Updated Thermal Rating: on line 8653-2303 : Rate B, Rate C , 0.0, 0.0 -> 4384
% INFO    : Updated Thermal Rating: on line 908-6474 : Rate B, Rate C , 0.0, 0.0 -> 16400
% INFO    : Updated Thermal Rating: on line 7030-6474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14972
% INFO    : Updated Thermal Rating: on line 4205-6556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18862
% INFO    : Updated Thermal Rating: on line 7325-6556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18455
% INFO    : Updated Thermal Rating: on line 5857-3391 : Rate B, Rate C , 0.0, 0.0 -> 3688
% INFO    : Updated Thermal Rating: on line 5857-3760 : Rate B, Rate C , 0.0, 0.0 -> 5049
% INFO    : Updated Thermal Rating: on line 3707-8765 : Rate B, Rate C , 0.0, 0.0 -> 24790
% INFO    : Updated Thermal Rating: on line 900-6619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21835
% INFO    : Updated Thermal Rating: on line 2918-8109 : Rate A, Rate B, Rate C , 1776.0, 0.0, 0.0 -> 1755
% INFO    : Updated Thermal Rating: on line 2918-8109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 6532-2177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 6532-5317 : Rate A, Rate B, Rate C , 510.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 6532-608 : Rate B, Rate C , 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 6532-608 : Rate B, Rate C , 0.0, 0.0 -> 990
% INFO    : Updated Thermal Rating: on line 4494-8763 : Rate B, Rate C , 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on line 4494-7056 : Rate B, Rate C , 0.0, 0.0 -> 2375
% INFO    : Updated Thermal Rating: on line 6828-5814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 3670-21 : Rate B, Rate C , 0.0, 0.0 -> 22404
% INFO    : Updated Thermal Rating: on line 5137-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5156
% INFO    : Updated Thermal Rating: on line 1334-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5264
% INFO    : Updated Thermal Rating: on line 8448-7624 : Rate B, Rate C , 0.0, 0.0 -> 3961
% INFO    : Updated Thermal Rating: on line 8448-1129 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 8448-3070 : Rate B, Rate C , 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 8448-306 : Rate B, Rate C , 0.0, 0.0 -> 3020
% INFO    : Updated Thermal Rating: on line 8448-306 : Rate B, Rate C , 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on line 8448-7491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 4685-2089 : Rate B, Rate C , 0.0, 0.0 -> 35750
% INFO    : Updated Thermal Rating: on line 7485-6253 : Rate B, Rate C , 0.0, 0.0 -> 25882
% INFO    : Updated Thermal Rating: on line 7485-1562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38849
% INFO    : Updated Thermal Rating: on line 7776-1644 : Rate B, Rate C , 0.0, 0.0 -> 10592
% INFO    : Updated Thermal Rating: on line 5971-3483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10925
% INFO    : Updated Thermal Rating: on line 2786-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9741
% INFO    : Updated Thermal Rating: on line 972-3483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9474
% INFO    : Updated Thermal Rating: on line 8906-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29496
% INFO    : Updated Thermal Rating: on line 8906-4914 : Rate B, Rate C , 0.0, 0.0 -> 29418
% INFO    : Updated Thermal Rating: on line 2656-9101 : Rate B, Rate C , 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 2656-7164 : Rate A, Rate B, Rate C , 1776.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on line 3519-9101 : Rate B, Rate C , 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 3519-7164 : Rate B, Rate C , 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 1775-9137 : Rate B, Rate C , 0.0, 0.0 -> 2649
% INFO    : Updated Thermal Rating: on line 1775-9137 : Rate B, Rate C , 0.0, 0.0 -> 3236
% INFO    : Updated Thermal Rating: on line 5641-1026 : Rate B, Rate C , 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 5641-9137 : Rate B, Rate C , 0.0, 0.0 -> 3297
% INFO    : Updated Thermal Rating: on line 1096-2889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17110
% INFO    : Updated Thermal Rating: on line 7380-2732 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on line 7380-4787 : Rate B, Rate C , 0.0, 0.0 -> 29975
% INFO    : Updated Thermal Rating: on line 3543-5308 : Rate B, Rate C , 0.0, 0.0 -> 3899
% INFO    : Updated Thermal Rating: on line 3543-3830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4697
% INFO    : Updated Thermal Rating: on line 2372-1027 : Rate B, Rate C , 0.0, 0.0 -> 4210
% INFO    : Updated Thermal Rating: on line 2372-5648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4991
% INFO    : Updated Thermal Rating: on line 367-1172 : Rate B, Rate C , 0.0, 0.0 -> 3570
% INFO    : Updated Thermal Rating: on line 367-9191 : Rate B, Rate C , 0.0, 0.0 -> 5103
% INFO    : Updated Thermal Rating: on line 367-8722 : Rate B, Rate C , 0.0, 0.0 -> 5087
% INFO    : Updated Thermal Rating: on line 1833-3610 : Rate B, Rate C , 0.0, 0.0 -> 8331
% INFO    : Updated Thermal Rating: on line 1833-3610 : Rate B, Rate C , 0.0, 0.0 -> 9649
% INFO    : Updated Thermal Rating: on line 1833-3962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3558
% INFO    : Updated Thermal Rating: on line 1833-1838 : Rate B, Rate C , 0.0, 0.0 -> 6744
% INFO    : Updated Thermal Rating: on line 1833-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6876
% INFO    : Updated Thermal Rating: on line 5388-2467 : Rate B, Rate C , 0.0, 0.0 -> 2041
% INFO    : Updated Thermal Rating: on line 5388-2467 : Rate B, Rate C , 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 6110-8853 : Rate B, Rate C , 0.0, 0.0 -> 5394
% INFO    : Updated Thermal Rating: on line 6110-1001 : Rate B, Rate C , 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 7583-1808 : Rate B, Rate C , 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 7583-2889 : Rate B, Rate C , 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on line 26-6624 : Rate A, Rate B, Rate C , 1545.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 26-2479 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 26-4598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2160
% INFO    : Updated Thermal Rating: on line 26-4231 : Rate B, Rate C , 0.0, 0.0 -> 3184
% INFO    : Updated Thermal Rating: on line 26-5144 : Rate B, Rate C , 0.0, 0.0 -> 6520
% INFO    : Updated Thermal Rating: on line 26-5144 : Rate B, Rate C , 0.0, 0.0 -> 7895
% INFO    : Updated Thermal Rating: on line 7691-2479 : Rate B, Rate C , 0.0, 0.0 -> 1827
% INFO    : Updated Thermal Rating: on line 7691-2129 : Rate B, Rate C , 0.0, 0.0 -> 2120
% INFO    : Updated Thermal Rating: on line 7691-9213 : Rate B, Rate C , 0.0, 0.0 -> 9168
% INFO    : Updated Thermal Rating: on line 7691-9213 : Rate B, Rate C , 0.0, 0.0 -> 12700
% INFO    : Updated Thermal Rating: on line 7691-4231 : Rate B, Rate C , 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 7691-3513 : Rate B, Rate C , 0.0, 0.0 -> 6651
% INFO    : Updated Thermal Rating: on line 7691-3513 : Rate B, Rate C , 0.0, 0.0 -> 7915
% INFO    : Updated Thermal Rating: on line 1876-3906 : Rate B, Rate C , 0.0, 0.0 -> 6116
% INFO    : Updated Thermal Rating: on line 113-3906 : Rate B, Rate C , 0.0, 0.0 -> 6246
% INFO    : Updated Thermal Rating: on line 7752-3758 : Rate B, Rate C , 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 7752-3758 : Rate B, Rate C , 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on line 7752-3758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1538
% INFO    : Updated Thermal Rating: on line 4952-8976 : Rate B, Rate C , 0.0, 0.0 -> 2888
% INFO    : Updated Thermal Rating: on line 4952-8189 : Rate B, Rate C , 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on line 6119-7886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 6119-4544 : Rate B, Rate C , 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 6119-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on line 7905-3697 : Rate B, Rate C , 0.0, 0.0 -> 1941
% INFO    : Updated Thermal Rating: on line 7905-7541 : Rate B, Rate C , 0.0, 0.0 -> 7052
% INFO    : Updated Thermal Rating: on line 7905-7541 : Rate B, Rate C , 0.0, 0.0 -> 8133
% INFO    : Updated Thermal Rating: on line 7905-4141 : Rate B, Rate C , 0.0, 0.0 -> 2731
% INFO    : Updated Thermal Rating: on line 7905-4141 : Rate B, Rate C , 0.0, 0.0 -> 2678
% INFO    : Updated Thermal Rating: on line 7905-3022 : Rate B, Rate C , 0.0, 0.0 -> 2102
% INFO    : Updated Thermal Rating: on line 1768-163 : Rate B, Rate C , 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 4245-2425 : Rate B, Rate C , 0.0, 0.0 -> 25068
% INFO    : Updated Thermal Rating: on line 3698-5297 : Rate B, Rate C , 0.0, 0.0 -> 45030
% INFO    : Updated Thermal Rating: on line 750-8328 : Rate B, Rate C , 0.0, 0.0 -> 25940
% INFO    : Updated Thermal Rating: on line 750-870 : Rate B, Rate C , 0.0, 0.0 -> 21222
% INFO    : Updated Thermal Rating: on line 750-2961 : Rate B, Rate C , 0.0, 0.0 -> 45595
% INFO    : Updated Thermal Rating: on line 3499-7988 : Rate B, Rate C , 0.0, 0.0 -> 4620
% INFO    : Updated Thermal Rating: on line 3499-2197 : Rate B, Rate C , 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on line 3499-7640 : Rate B, Rate C , 0.0, 0.0 -> 2652
% INFO    : Updated Thermal Rating: on line 3499-4231 : Rate B, Rate C , 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 3499-5144 : Rate B, Rate C , 0.0, 0.0 -> 2438
% INFO    : Updated Thermal Rating: on line 3499-3513 : Rate B, Rate C , 0.0, 0.0 -> 2485
% INFO    : Updated Thermal Rating: on line 7289-3999 : Rate B, Rate C , 0.0, 0.0 -> 4537
% INFO    : Updated Thermal Rating: on line 3018-1051 : Rate B, Rate C , 0.0, 0.0 -> 89200
% INFO    : Updated Thermal Rating: on line 2702-3435 : Rate B, Rate C , 0.0, 0.0 -> 43865
% INFO    : Updated Thermal Rating: on line 9131-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42767
% INFO    : Updated Thermal Rating: on line 6308-6684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29632
% INFO    : Updated Thermal Rating: on line 4831-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 837
% INFO    : Updated Thermal Rating: on line 5410-2751 : Rate B, Rate C , 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 3082-4623 : Rate B, Rate C , 0.0, 0.0 -> 2470
% INFO    : Updated Thermal Rating: on line 3082-4339 : Rate B, Rate C , 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 3082-5288 : Rate B, Rate C , 0.0, 0.0 -> 105881
% INFO    : Updated Thermal Rating: on line 3082-5421 : Rate B, Rate C , 0.0, 0.0 -> 39728
% INFO    : Updated Thermal Rating: on line 3082-6475 : Rate B, Rate C , 0.0, 0.0 -> 1535
% INFO    : Updated Thermal Rating: on line 3082-8468 : Rate B, Rate C , 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 6224-2732 : Rate B, Rate C , 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on line 6224-7513 : Rate B, Rate C , 0.0, 0.0 -> 2808
% INFO    : Updated Thermal Rating: on line 6224-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1844
% INFO    : Updated Thermal Rating: on line 2174-4623 : Rate B, Rate C , 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 2174-4550 : Rate B, Rate C , 0.0, 0.0 -> 1809
% INFO    : Updated Thermal Rating: on line 2174-6475 : Rate A, Rate B, Rate C , 1677.0, 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 2083-9231 : Rate B, Rate C , 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 2083-9231 : Rate B, Rate C , 0.0, 0.0 -> 2107
% INFO    : Updated Thermal Rating: on line 2083-9231 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 2083-4054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36840
% INFO    : Updated Thermal Rating: on line 2083-3481 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 2083-3602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3104
% INFO    : Updated Thermal Rating: on line 2083-2794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12197
% INFO    : Updated Thermal Rating: on line 2083-2794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13903
% INFO    : Updated Thermal Rating: on line 2083-8467 : Rate B, Rate C , 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 2083-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4796
% INFO    : Updated Thermal Rating: on line 2083-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 8853-1001 : Rate B, Rate C , 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 8853-4950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 8853-4410 : Rate B, Rate C , 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 8853-6697 : Rate B, Rate C , 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 8853-1159 : Rate B, Rate C , 0.0, 0.0 -> 2874
% INFO    : Updated Thermal Rating: on line 8853-7165 : Rate B, Rate C , 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 2938-2848 : Rate B, Rate C , 0.0, 0.0 -> 5758
% INFO    : Updated Thermal Rating: on line 2938-2848 : Rate B, Rate C , 0.0, 0.0 -> 5875
% INFO    : Updated Thermal Rating: on line 2938-7522 : Rate B, Rate C , 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 2938-7522 : Rate B, Rate C , 0.0, 0.0 -> 2025
% INFO    : Updated Thermal Rating: on line 2938-1642 : Rate A, Rate B, Rate C , 1710.0, 0.0, 0.0 -> 1418
% INFO    : Updated Thermal Rating: on line 2938-809 : Rate A, Rate B, Rate C , 1710.0, 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 9189-6791 : Rate B, Rate C , 0.0, 0.0 -> 9227
% INFO    : Updated Thermal Rating: on line 9189-3400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37102
% INFO    : Updated Thermal Rating: on line 9189-7092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10077
% INFO    : Updated Thermal Rating: on line 9189-3718 : Rate B, Rate C , 0.0, 0.0 -> 12119
% INFO    : Updated Thermal Rating: on line 9189-3701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13958
% INFO    : Updated Thermal Rating: on line 9189-7507 : Rate B, Rate C , 0.0, 0.0 -> 3272
% INFO    : Updated Thermal Rating: on line 9189-7507 : Rate B, Rate C , 0.0, 0.0 -> 2926
% INFO    : Updated Thermal Rating: on line 9189-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3642
% INFO    : Updated Thermal Rating: on line 9189-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4517
% INFO    : Updated Thermal Rating: on line 2801-8511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37687
% INFO    : Updated Thermal Rating: on line 2801-216 : Rate B, Rate C , 0.0, 0.0 -> 4920
% INFO    : Updated Thermal Rating: on line 453-2129 : Rate B, Rate C , 0.0, 0.0 -> 11419
% INFO    : Updated Thermal Rating: on line 8691-6952 : Rate B, Rate C , 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 8691-6952 : Rate A, Rate B, Rate C , 491.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 8691-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 8691-4410 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 8691-8743 : Rate B, Rate C , 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 2446-8763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4461
% INFO    : Updated Thermal Rating: on line 2627-8763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4501
% INFO    : Updated Thermal Rating: on line 4951-6785 : Rate B, Rate C , 0.0, 0.0 -> 1793
% INFO    : Updated Thermal Rating: on line 4951-6785 : Rate B, Rate C , 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 4623-964 : Rate B, Rate C , 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 4623-964 : Rate B, Rate C , 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 4623-8347 : Rate B, Rate C , 0.0, 0.0 -> 5920
% INFO    : Updated Thermal Rating: on line 4623-8347 : Rate B, Rate C , 0.0, 0.0 -> 6655
% INFO    : Updated Thermal Rating: on line 4623-8347 : Rate B, Rate C , 0.0, 0.0 -> 6285
% INFO    : Updated Thermal Rating: on line 1609-6552 : Rate B, Rate C , 0.0, 0.0 -> 4907
% INFO    : Updated Thermal Rating: on line 1609-6552 : Rate B, Rate C , 0.0, 0.0 -> 4995
% INFO    : Updated Thermal Rating: on line 1609-8999 : Rate B, Rate C , 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 4368-4816 : Rate B, Rate C , 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 5481-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 7913-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126249
% INFO    : Updated Thermal Rating: on line 506-960 : Rate B, Rate C , 0.0, 0.0 -> 101684
% INFO    : Updated Thermal Rating: on line 2980-960 : Rate B, Rate C , 0.0, 0.0 -> 78748
% INFO    : Updated Thermal Rating: on line 4554-6382 : Rate B, Rate C , 0.0, 0.0 -> 6562
% INFO    : Updated Thermal Rating: on line 4554-6382 : Rate B, Rate C , 0.0, 0.0 -> 6397
% INFO    : Updated Thermal Rating: on line 6844-1595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 3672-5334 : Rate B, Rate C , 0.0, 0.0 -> 10281
% INFO    : Updated Thermal Rating: on line 6219-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10093
% INFO    : Updated Thermal Rating: on line 8997-6153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on line 1852-5935 : Rate B, Rate C , 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 1852-5695 : Rate B, Rate C , 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 2931-5799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1584
% INFO    : Updated Thermal Rating: on line 2931-7124 : Rate B, Rate C , 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 2598-3674 : Rate B, Rate C , 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 2598-2132 : Rate B, Rate C , 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 2558-7571 : Rate B, Rate C , 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 8834-1129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 7377-3324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4788
% INFO    : Updated Thermal Rating: on line 1265-4426 : Rate B, Rate C , 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 1265-1965 : Rate B, Rate C , 0.0, 0.0 -> 1550
% INFO    : Updated Thermal Rating: on line 8060-7162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61700
% INFO    : Updated Thermal Rating: on line 6922-5482 : Rate B, Rate C , 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 6922-1295 : Rate B, Rate C , 0.0, 0.0 -> 21414
% INFO    : Updated Thermal Rating: on line 8369-4710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 8961-7133 : Rate B, Rate C , 0.0, 0.0 -> 4377
% INFO    : Updated Thermal Rating: on line 8961-6888 : Rate B, Rate C , 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 4185-7019 : Rate B, Rate C , 0.0, 0.0 -> 64904
% INFO    : Updated Thermal Rating: on line 4185-6253 : Rate B, Rate C , 0.0, 0.0 -> 40281
% INFO    : Updated Thermal Rating: on line 7895-3391 : Rate B, Rate C , 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 7895-1448 : Rate B, Rate C , 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 7895-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 7895-115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 5589-4306 : Rate B, Rate C , 0.0, 0.0 -> 131160
% INFO    : Updated Thermal Rating: on line 5589-1763 : Rate B, Rate C , 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 5589-3697 : Rate A, Rate B, Rate C , 1545.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 5589-3794 : Rate B, Rate C , 0.0, 0.0 -> 2658
% INFO    : Updated Thermal Rating: on line 5589-3613 : Rate B, Rate C , 0.0, 0.0 -> 2358
% INFO    : Updated Thermal Rating: on line 5589-1502 : Rate B, Rate C , 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 5589-6555 : Rate A, Rate B, Rate C , 1677.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 5589-3608 : Rate A, Rate B, Rate C , 1513.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 1001-4134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26320
% INFO    : Updated Thermal Rating: on line 1001-1979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33184
% INFO    : Updated Thermal Rating: on line 1001-516 : Rate B, Rate C , 0.0, 0.0 -> 48317
% INFO    : Updated Thermal Rating: on line 1001-3580 : Rate B, Rate C , 0.0, 0.0 -> 37387
% INFO    : Updated Thermal Rating: on line 1001-3809 : Rate B, Rate C , 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 1001-5616 : Rate B, Rate C , 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 1001-5616 : Rate B, Rate C , 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 1001-6697 : Rate B, Rate C , 0.0, 0.0 -> 1034
% INFO    : Updated Thermal Rating: on line 1001-7165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4781
% INFO    : Updated Thermal Rating: on line 1001-892 : Rate B, Rate C , 0.0, 0.0 -> 4400
% INFO    : Updated Thermal Rating: on line 7438-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2105
% INFO    : Updated Thermal Rating: on line 7438-1526 : Rate B, Rate C , 0.0, 0.0 -> 2539
% INFO    : Updated Thermal Rating: on line 1301-6952 : Rate B, Rate C , 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 1301-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on line 1301-6952 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 1301-7883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10335
% INFO    : Updated Thermal Rating: on line 1301-6430 : Rate B, Rate C , 0.0, 0.0 -> 5140
% INFO    : Updated Thermal Rating: on line 778-7209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 778-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 778-6820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8414
% INFO    : Updated Thermal Rating: on line 778-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 5297-6267 : Rate B, Rate C , 0.0, 0.0 -> 45626
% INFO    : Updated Thermal Rating: on line 3657-3855 : Rate B, Rate C , 0.0, 0.0 -> 41622
% INFO    : Updated Thermal Rating: on line 3657-3855 : Rate B, Rate C , 0.0, 0.0 -> 45778
% INFO    : Updated Thermal Rating: on line 3657-2928 : Rate B, Rate C , 0.0, 0.0 -> 12161
% INFO    : Updated Thermal Rating: on line 3657-2928 : Rate B, Rate C , 0.0, 0.0 -> 12717
% INFO    : Updated Thermal Rating: on line 3657-1172 : Rate B, Rate C , 0.0, 0.0 -> 13211
% INFO    : Updated Thermal Rating: on line 3657-9191 : Rate B, Rate C , 0.0, 0.0 -> 4832
% INFO    : Updated Thermal Rating: on line 3657-8722 : Rate B, Rate C , 0.0, 0.0 -> 5211
% INFO    : Updated Thermal Rating: on line 6472-5362 : Rate B, Rate C , 0.0, 0.0 -> 17339
% INFO    : Updated Thermal Rating: on line 6472-3962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13063
% INFO    : Updated Thermal Rating: on line 1198-1343 : Rate B, Rate C , 0.0, 0.0 -> 4076
% INFO    : Updated Thermal Rating: on line 1198-29 : Rate B, Rate C , 0.0, 0.0 -> 1978
% INFO    : Updated Thermal Rating: on line 7473-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 7473-96 : Rate B, Rate C , 0.0, 0.0 -> 1804
% INFO    : Updated Thermal Rating: on line 7473-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2508
% INFO    : Updated Thermal Rating: on line 346-3184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6510
% INFO    : Updated Thermal Rating: on line 346-6570 : Rate B, Rate C , 0.0, 0.0 -> 6187
% INFO    : Updated Thermal Rating: on line 3184-4728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 2654-7886 : Rate B, Rate C , 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 2654-2132 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 4144-8874 : Rate B, Rate C , 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 4144-1625 : Rate B, Rate C , 0.0, 0.0 -> 5227
% INFO    : Updated Thermal Rating: on line 4144-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5276
% INFO    : Updated Thermal Rating: on line 4144-3786 : Rate B, Rate C , 0.0, 0.0 -> 2479
% INFO    : Updated Thermal Rating: on line 4144-3786 : Rate B, Rate C , 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 3422-4100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44249
% INFO    : Updated Thermal Rating: on line 6624-4419 : Rate B, Rate C , 0.0, 0.0 -> 58406
% INFO    : Updated Thermal Rating: on line 6624-7159 : Rate B, Rate C , 0.0, 0.0 -> 57347
% INFO    : Updated Thermal Rating: on line 6624-3661 : Rate B, Rate C , 0.0, 0.0 -> 54332
% INFO    : Updated Thermal Rating: on line 6624-5486 : Rate B, Rate C , 0.0, 0.0 -> 58336
% INFO    : Updated Thermal Rating: on line 6624-4231 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 6624-4231 : Rate A, Rate B, Rate C , 1545.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 6624-6921 : Rate B, Rate C , 0.0, 0.0 -> 1794
% INFO    : Updated Thermal Rating: on line 6624-432 : Rate B, Rate C , 0.0, 0.0 -> 3336
% INFO    : Updated Thermal Rating: on line 6624-432 : Rate B, Rate C , 0.0, 0.0 -> 2840
% INFO    : Updated Thermal Rating: on line 6624-432 : Rate B, Rate C , 0.0, 0.0 -> 2788
% INFO    : Updated Thermal Rating: on line 3353-6887 : Rate B, Rate C , 0.0, 0.0 -> 5371
% INFO    : Updated Thermal Rating: on line 2479-2050 : Rate B, Rate C , 0.0, 0.0 -> 5307
% INFO    : Updated Thermal Rating: on line 2479-2050 : Rate B, Rate C , 0.0, 0.0 -> 4690
% INFO    : Updated Thermal Rating: on line 5482-8704 : Rate B, Rate C , 0.0, 0.0 -> 4888
% INFO    : Updated Thermal Rating: on line 5482-8704 : Rate B, Rate C , 0.0, 0.0 -> 4337
% INFO    : Updated Thermal Rating: on line 5482-4710 : Rate B, Rate C , 0.0, 0.0 -> 1375
% INFO    : Updated Thermal Rating: on line 5482-1295 : Rate B, Rate C , 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 5482-1910 : Rate B, Rate C , 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 5482-2985 : Rate A, Rate B, Rate C , 376.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 5482-5853 : Rate B, Rate C , 0.0, 0.0 -> 12252
% INFO    : Updated Thermal Rating: on line 5482-7824 : Rate B, Rate C , 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 5482-3071 : Rate B, Rate C , 0.0, 0.0 -> 18399
% INFO    : Updated Thermal Rating: on line 4525-195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 9066-7367 : Rate B, Rate C , 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 9066-9155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 9066-6357 : Rate B, Rate C , 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 7886-3126 : Rate B, Rate C , 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 7886-8564 : Rate B, Rate C , 0.0, 0.0 -> 4738
% INFO    : Updated Thermal Rating: on line 7886-5567 : Rate B, Rate C , 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 6416-3069 : Rate B, Rate C , 0.0, 0.0 -> 1534
% INFO    : Updated Thermal Rating: on line 6416-3876 : Rate B, Rate C , 0.0, 0.0 -> 9976
% INFO    : Updated Thermal Rating: on line 6416-8804 : Rate B, Rate C , 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 6416-8804 : Rate B, Rate C , 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 7831-4550 : Rate B, Rate C , 0.0, 0.0 -> 5610
% INFO    : Updated Thermal Rating: on line 7831-4125 : Rate B, Rate C , 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on line 7831-3346 : Rate B, Rate C , 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 5525-2377 : Rate B, Rate C , 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5525-1401 : Rate B, Rate C , 0.0, 0.0 -> 1220
% INFO    : Updated Thermal Rating: on line 5525-2850 : Rate B, Rate C , 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 5525-2430 : Rate B, Rate C , 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 5525-9164 : Rate B, Rate C , 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 8511-1033 : Rate B, Rate C , 0.0, 0.0 -> 25264
% INFO    : Updated Thermal Rating: on line 8511-6178 : Rate B, Rate C , 0.0, 0.0 -> 29393
% INFO    : Updated Thermal Rating: on line 3400-980 : Rate B, Rate C , 0.0, 0.0 -> 24306
% INFO    : Updated Thermal Rating: on line 2101-4598 : Rate B, Rate C , 0.0, 0.0 -> 2637
% INFO    : Updated Thermal Rating: on line 2101-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2663
% INFO    : Updated Thermal Rating: on line 2101-5144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7392
% INFO    : Updated Thermal Rating: on line 3919-2129 : Rate B, Rate C , 0.0, 0.0 -> 2695
% INFO    : Updated Thermal Rating: on line 3919-4541 : Rate B, Rate C , 0.0, 0.0 -> 3010
% INFO    : Updated Thermal Rating: on line 3919-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7549
% INFO    : Updated Thermal Rating: on line 6675-1486 : Rate B, Rate C , 0.0, 0.0 -> 44610
% INFO    : Updated Thermal Rating: on line 4711-5836 : Rate B, Rate C , 0.0, 0.0 -> 6392
% INFO    : Updated Thermal Rating: on line 4711-575 : Rate B, Rate C , 0.0, 0.0 -> 6111
% INFO    : Updated Thermal Rating: on line 4711-8214 : Rate B, Rate C , 0.0, 0.0 -> 8784
% INFO    : Updated Thermal Rating: on line 4711-8214 : Rate B, Rate C , 0.0, 0.0 -> 8261
% INFO    : Updated Thermal Rating: on line 4711-3021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25671
% INFO    : Updated Thermal Rating: on line 4711-7967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25386
% INFO    : Updated Thermal Rating: on line 4711-5993 : Rate B, Rate C , 0.0, 0.0 -> 3668
% INFO    : Updated Thermal Rating: on line 4711-8804 : Rate B, Rate C , 0.0, 0.0 -> 1588
% INFO    : Updated Thermal Rating: on line 4513-6831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26216
% INFO    : Updated Thermal Rating: on line 2043-1422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48510
% INFO    : Updated Thermal Rating: on line 6714-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7088
% INFO    : Updated Thermal Rating: on line 6371-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7213
% INFO    : Updated Thermal Rating: on line 513-2866 : Rate B, Rate C , 0.0, 0.0 -> 3766
% INFO    : Updated Thermal Rating: on line 4970-9222 : Rate B, Rate C , 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 4970-9222 : Rate B, Rate C , 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 4970-2072 : Rate B, Rate C , 0.0, 0.0 -> 5202
% INFO    : Updated Thermal Rating: on line 4970-5461 : Rate B, Rate C , 0.0, 0.0 -> 11447
% INFO    : Updated Thermal Rating: on line 4970-8109 : Rate B, Rate C , 0.0, 0.0 -> 2341
% INFO    : Updated Thermal Rating: on line 4970-8109 : Rate B, Rate C , 0.0, 0.0 -> 2030
% INFO    : Updated Thermal Rating: on line 7955-707 : Rate B, Rate C , 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 7955-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3937
% INFO    : Updated Thermal Rating: on line 7955-1866 : Rate B, Rate C , 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 7955-5488 : Rate B, Rate C , 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 5093-2467 : Rate B, Rate C , 0.0, 0.0 -> 1540
% INFO    : Updated Thermal Rating: on line 2328-7178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6241
% INFO    : Updated Thermal Rating: on line 9180-195 : Rate B, Rate C , 0.0, 0.0 -> 2352
% INFO    : Updated Thermal Rating: on line 9180-3133 : Rate B, Rate C , 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 292-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3334
% INFO    : Updated Thermal Rating: on line 9002-6737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20291
% INFO    : Updated Thermal Rating: on line 8439-3758 : Rate B, Rate C , 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 8439-3758 : Rate B, Rate C , 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 4974-2940 : Rate B, Rate C , 0.0, 0.0 -> 1572
% INFO    : Updated Thermal Rating: on line 4974-163 : Rate B, Rate C , 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 747-8507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26055
% INFO    : Updated Thermal Rating: on line 6909-4914 : Rate B, Rate C , 0.0, 0.0 -> 14377
% INFO    : Updated Thermal Rating: on line 444-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7334
% INFO    : Updated Thermal Rating: on line 1459-6495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3289
% INFO    : Updated Thermal Rating: on line 1459-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 3601-4728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9924
% INFO    : Updated Thermal Rating: on line 1251-6475 : Rate B, Rate C , 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 1093-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73380
% INFO    : Updated Thermal Rating: on line 5709-6475 : Rate B, Rate C , 0.0, 0.0 -> 80755
% INFO    : Updated Thermal Rating: on line 3825-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82867
% INFO    : Updated Thermal Rating: on line 1415-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7473
% INFO    : Updated Thermal Rating: on line 4549-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8069
% INFO    : Updated Thermal Rating: on line 3072-639 : Rate B, Rate C , 0.0, 0.0 -> 7210
% INFO    : Updated Thermal Rating: on line 3072-639 : Rate B, Rate C , 0.0, 0.0 -> 7718
% INFO    : Updated Thermal Rating: on line 5007-4541 : Rate B, Rate C , 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 5007-8195 : Rate B, Rate C , 0.0, 0.0 -> 1873
% INFO    : Updated Thermal Rating: on line 757-964 : Rate B, Rate C , 0.0, 0.0 -> 3905
% INFO    : Updated Thermal Rating: on line 757-964 : Rate B, Rate C , 0.0, 0.0 -> 3830
% INFO    : Updated Thermal Rating: on line 757-3906 : Rate B, Rate C , 0.0, 0.0 -> 2741
% INFO    : Updated Thermal Rating: on line 757-3906 : Rate B, Rate C , 0.0, 0.0 -> 2425
% INFO    : Updated Thermal Rating: on line 757-8347 : Rate B, Rate C , 0.0, 0.0 -> 1984
% INFO    : Updated Thermal Rating: on line 757-2919 : Rate A, Rate B, Rate C , 1381.0, 0.0, 0.0 -> 1133
% INFO    : Updated Thermal Rating: on line 3758-188 : Rate B, Rate C , 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on line 3758-2242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 3903-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 5743-6990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 8626-8930 : Rate B, Rate C , 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 8626-2467 : Rate B, Rate C , 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 2161-5488 : Rate B, Rate C , 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 2161-7772 : Rate B, Rate C , 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 5003-6382 : Rate B, Rate C , 0.0, 0.0 -> 13719
% INFO    : Updated Thermal Rating: on line 6474-4084 : Rate B, Rate C , 0.0, 0.0 -> 2878
% INFO    : Updated Thermal Rating: on line 6474-4084 : Rate B, Rate C , 0.0, 0.0 -> 2504
% INFO    : Updated Thermal Rating: on line 6474-53 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 6474-7259 : Rate B, Rate C , 0.0, 0.0 -> 19023
% INFO    : Updated Thermal Rating: on line 6474-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18424
% INFO    : Updated Thermal Rating: on line 5334-7577 : Rate B, Rate C , 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 7961-2288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20686
% INFO    : Updated Thermal Rating: on line 1592-7098 : Rate B, Rate C , 0.0, 0.0 -> 5012
% INFO    : Updated Thermal Rating: on line 3187-2079 : Rate B, Rate C , 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 6041-5926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4243
% INFO    : Updated Thermal Rating: on line 3697-8486 : Rate B, Rate C , 0.0, 0.0 -> 3034
% INFO    : Updated Thermal Rating: on line 3697-7530 : Rate B, Rate C , 0.0, 0.0 -> 3094
% INFO    : Updated Thermal Rating: on line 3697-1502 : Rate B, Rate C , 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 3697-1552 : Rate A, Rate B, Rate C , 1578.0, 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 6952-3793 : Rate B, Rate C , 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 6738-2526 : Rate B, Rate C , 0.0, 0.0 -> 2537
% INFO    : Updated Thermal Rating: on line 6738-2526 : Rate B, Rate C , 0.0, 0.0 -> 2252
% INFO    : Updated Thermal Rating: on line 6738-2365 : Rate B, Rate C , 0.0, 0.0 -> 3731
% INFO    : Updated Thermal Rating: on line 6738-2365 : Rate B, Rate C , 0.0, 0.0 -> 3662
% INFO    : Updated Thermal Rating: on line 6738-3794 : Rate B, Rate C , 0.0, 0.0 -> 2974
% INFO    : Updated Thermal Rating: on line 6738-3613 : Rate B, Rate C , 0.0, 0.0 -> 2807
% INFO    : Updated Thermal Rating: on line 6738-6901 : Rate A, Rate B, Rate C , 1677.0, 0.0, 0.0 -> 1218
% INFO    : Updated Thermal Rating: on line 8180-5106 : Rate B, Rate C , 0.0, 0.0 -> 3996
% INFO    : Updated Thermal Rating: on line 8180-5106 : Rate B, Rate C , 0.0, 0.0 -> 3866
% INFO    : Updated Thermal Rating: on line 6240-7165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 9222-8721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95544
% INFO    : Updated Thermal Rating: on line 9222-8872 : Rate B, Rate C , 0.0, 0.0 -> 108858
% INFO    : Updated Thermal Rating: on line 9222-8672 : Rate B, Rate C , 0.0, 0.0 -> 3531
% INFO    : Updated Thermal Rating: on line 9222-7164 : Rate B, Rate C , 0.0, 0.0 -> 2062
% INFO    : Updated Thermal Rating: on line 5935-7772 : Rate B, Rate C , 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 3134-3430 : Rate B, Rate C , 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 3134-1051 : Rate B, Rate C , 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 283-800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21921
% INFO    : Updated Thermal Rating: on line 283-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20446
% INFO    : Updated Thermal Rating: on line 283-4747 : Rate B, Rate C , 0.0, 0.0 -> 6998
% INFO    : Updated Thermal Rating: on line 3391-5213 : Rate B, Rate C , 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 3391-115 : Rate B, Rate C , 0.0, 0.0 -> 3736
% INFO    : Updated Thermal Rating: on line 3391-115 : Rate B, Rate C , 0.0, 0.0 -> 3241
% INFO    : Updated Thermal Rating: on line 4867-5753 : Rate B, Rate C , 0.0, 0.0 -> 5101
% INFO    : Updated Thermal Rating: on line 7539-6556 : Rate B, Rate C , 0.0, 0.0 -> 2477
% INFO    : Updated Thermal Rating: on line 7539-871 : Rate B, Rate C , 0.0, 0.0 -> 3278
% INFO    : Updated Thermal Rating: on line 8893-8874 : Rate B, Rate C , 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 8893-4505 : Rate B, Rate C , 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 8893-3436 : Rate B, Rate C , 0.0, 0.0 -> 2054
% INFO    : Updated Thermal Rating: on line 8893-3436 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 8893-3436 : Rate B, Rate C , 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 8893-6556 : Rate B, Rate C , 0.0, 0.0 -> 1599
% INFO    : Updated Thermal Rating: on line 8893-8765 : Rate B, Rate C , 0.0, 0.0 -> 13522
% INFO    : Updated Thermal Rating: on line 8893-6619 : Rate B, Rate C , 0.0, 0.0 -> 11682
% INFO    : Updated Thermal Rating: on line 8165-6734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53974
% INFO    : Updated Thermal Rating: on line 1078-6734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84816
% INFO    : Updated Thermal Rating: on line 7988-4231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9642
% INFO    : Updated Thermal Rating: on line 804-2142 : Rate B, Rate C , 0.0, 0.0 -> 5557
% INFO    : Updated Thermal Rating: on line 804-2142 : Rate B, Rate C , 0.0, 0.0 -> 5672
% INFO    : Updated Thermal Rating: on line 804-7519 : Rate B, Rate C , 0.0, 0.0 -> 1593
% INFO    : Updated Thermal Rating: on line 804-6744 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 2286-6802 : Rate B, Rate C , 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 2286-769 : Rate B, Rate C , 0.0, 0.0 -> 1193
% INFO    : Updated Thermal Rating: on line 3239-1081 : Rate B, Rate C , 0.0, 0.0 -> 1501
% INFO    : Updated Thermal Rating: on line 3239-5983 : Rate B, Rate C , 0.0, 0.0 -> 1467
% INFO    : Updated Thermal Rating: on line 3239-8267 : Rate A, Rate B, Rate C , 953.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 3239-960 : Rate B, Rate C , 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 3239-960 : Rate B, Rate C , 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 3239-3906 : Rate A, Rate B, Rate C , 1381.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 1539-7361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 1539-6852 : Rate B, Rate C , 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 1539-8515 : Rate A, Rate B, Rate C , 338.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 1539-3166 : Rate B, Rate C , 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 1539-2676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 1539-3793 : Rate B, Rate C , 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 1539-4529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 937
% INFO    : Updated Thermal Rating: on line 1539-4234 : Rate B, Rate C , 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 8628-44 : Rate B, Rate C , 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 8628-6630 : Rate B, Rate C , 0.0, 0.0 -> 3902
% INFO    : Updated Thermal Rating: on line 8628-6630 : Rate B, Rate C , 0.0, 0.0 -> 3982
% INFO    : Updated Thermal Rating: on line 8628-1545 : Rate B, Rate C , 0.0, 0.0 -> 10610
% INFO    : Updated Thermal Rating: on line 8628-4215 : Rate B, Rate C , 0.0, 0.0 -> 9305
% INFO    : Updated Thermal Rating: on line 7163-1917 : Rate B, Rate C , 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 7163-5519 : Rate B, Rate C , 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on line 7647-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25736
% INFO    : Updated Thermal Rating: on line 4864-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64786
% INFO    : Updated Thermal Rating: on line 7021-7119 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 7021-3324 : Rate B, Rate C , 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 1248-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2413
% INFO    : Updated Thermal Rating: on line 9045-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78436
% INFO    : Updated Thermal Rating: on line 8874-3786 : Rate B, Rate C , 0.0, 0.0 -> 1991
% INFO    : Updated Thermal Rating: on line 5891-5574 : Rate B, Rate C , 0.0, 0.0 -> 2510
% INFO    : Updated Thermal Rating: on line 5891-7663 : Rate B, Rate C , 0.0, 0.0 -> 1341
% INFO    : Updated Thermal Rating: on line 5891-4889 : Rate B, Rate C , 0.0, 0.0 -> 5190
% INFO    : Updated Thermal Rating: on line 3997-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35710
% INFO    : Updated Thermal Rating: on line 184-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38599
% INFO    : Updated Thermal Rating: on line 2972-2088 : Rate B, Rate C , 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 8676-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 8676-933 : Rate B, Rate C , 0.0, 0.0 -> 4562
% INFO    : Updated Thermal Rating: on line 8676-3643 : Rate B, Rate C , 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 8704-6723 : Rate B, Rate C , 0.0, 0.0 -> 2411
% INFO    : Updated Thermal Rating: on line 7047-21 : Rate B, Rate C , 0.0, 0.0 -> 31376
% INFO    : Updated Thermal Rating: on line 7047-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21862
% INFO    : Updated Thermal Rating: on line 7047-1551 : Rate B, Rate C , 0.0, 0.0 -> 1996
% INFO    : Updated Thermal Rating: on line 7047-4103 : Rate B, Rate C , 0.0, 0.0 -> 10244
% INFO    : Updated Thermal Rating: on line 7047-7862 : Rate B, Rate C , 0.0, 0.0 -> 3768
% INFO    : Updated Thermal Rating: on line 7047-5458 : Rate B, Rate C , 0.0, 0.0 -> 3966
% INFO    : Updated Thermal Rating: on line 5574-5666 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 6742-5458 : Rate B, Rate C , 0.0, 0.0 -> 24252
% INFO    : Updated Thermal Rating: on line 5270-7862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24653
% INFO    : Updated Thermal Rating: on line 7775-3857 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 6290-3436 : Rate B, Rate C , 0.0, 0.0 -> 3696
% INFO    : Updated Thermal Rating: on line 3430-401 : Rate B, Rate C , 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 2967-8976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20925
% INFO    : Updated Thermal Rating: on line 2967-8976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20403
% INFO    : Updated Thermal Rating: on line 8976-2481 : Rate B, Rate C , 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 8976-9108 : Rate B, Rate C , 0.0, 0.0 -> 2458
% INFO    : Updated Thermal Rating: on line 2056-7520 : Rate B, Rate C , 0.0, 0.0 -> 6825
% INFO    : Updated Thermal Rating: on line 2056-7520 : Rate B, Rate C , 0.0, 0.0 -> 6697
% INFO    : Updated Thermal Rating: on line 4084-5340 : Rate B, Rate C , 0.0, 0.0 -> 2230
% INFO    : Updated Thermal Rating: on line 4084-2319 : Rate B, Rate C , 0.0, 0.0 -> 3526
% INFO    : Updated Thermal Rating: on line 4084-2878 : Rate B, Rate C , 0.0, 0.0 -> 1136
% INFO    : Updated Thermal Rating: on line 2597-7422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 7183-8931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10070
% INFO    : Updated Thermal Rating: on line 5379-8931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9884
% INFO    : Updated Thermal Rating: on line 8128-8931 : Rate B, Rate C , 0.0, 0.0 -> 7250
% INFO    : Updated Thermal Rating: on line 6337-8931 : Rate B, Rate C , 0.0, 0.0 -> 7402
% INFO    : Updated Thermal Rating: on line 1237-8931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10049
% INFO    : Updated Thermal Rating: on line 4127-9173 : Rate B, Rate C , 0.0, 0.0 -> 40572
% INFO    : Updated Thermal Rating: on line 4127-7974 : Rate B, Rate C , 0.0, 0.0 -> 23949
% INFO    : Updated Thermal Rating: on line 2432-4816 : Rate A, Rate B, Rate C , 529.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 2432-1866 : Rate B, Rate C , 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 2432-8809 : Rate B, Rate C , 0.0, 0.0 -> 7955
% INFO    : Updated Thermal Rating: on line 2432-5146 : Rate B, Rate C , 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 2432-6940 : Rate B, Rate C , 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 2432-1742 : Rate B, Rate C , 0.0, 0.0 -> 7075
% INFO    : Updated Thermal Rating: on line 5213-8627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 5213-174 : Rate B, Rate C , 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 5213-7437 : Rate B, Rate C , 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 7342-5940 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 7342-7495 : Rate B, Rate C , 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 8808-4816 : Rate B, Rate C , 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 8808-4816 : Rate B, Rate C , 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 8808-6053 : Rate B, Rate C , 0.0, 0.0 -> 1834
% INFO    : Updated Thermal Rating: on line 5764-4189 : Rate B, Rate C , 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 8507-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33783
% INFO    : Updated Thermal Rating: on line 1394-1973 : Rate B, Rate C , 0.0, 0.0 -> 33061
% INFO    : Updated Thermal Rating: on line 2898-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96873
% INFO    : Updated Thermal Rating: on line 4942-8255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 4942-4748 : Rate B, Rate C , 0.0, 0.0 -> 5098
% INFO    : Updated Thermal Rating: on line 3486-3594 : Rate B, Rate C , 0.0, 0.0 -> 1482
% INFO    : Updated Thermal Rating: on line 3486-4679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 4656-4235 : Rate B, Rate C , 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on line 4656-4235 : Rate B, Rate C , 0.0, 0.0 -> 1584
% INFO    : Updated Thermal Rating: on line 7129-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13000
% INFO    : Updated Thermal Rating: on line 7129-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12810
% INFO    : Updated Thermal Rating: on line 8250-5720 : Rate B, Rate C , 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 8250-5720 : Rate B, Rate C , 0.0, 0.0 -> 1558
% INFO    : Updated Thermal Rating: on line 6831-6723 : Rate B, Rate C , 0.0, 0.0 -> 11064
% INFO    : Updated Thermal Rating: on line 6831-5686 : Rate B, Rate C , 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 2377-805 : Rate A, Rate B, Rate C , 338.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 907-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78402
% INFO    : Updated Thermal Rating: on line 4056-9091 : Rate B, Rate C , 0.0, 0.0 -> 71132
% INFO    : Updated Thermal Rating: on line 6837-2142 : Rate B, Rate C , 0.0, 0.0 -> 62725
% INFO    : Updated Thermal Rating: on line 5666-2641 : Rate B, Rate C , 0.0, 0.0 -> 4421
% INFO    : Updated Thermal Rating: on line 5666-7577 : Rate B, Rate C , 0.0, 0.0 -> 9851
% INFO    : Updated Thermal Rating: on line 5666-7577 : Rate B, Rate C , 0.0, 0.0 -> 9225
% INFO    : Updated Thermal Rating: on line 5666-7577 : Rate B, Rate C , 0.0, 0.0 -> 6466
% INFO    : Updated Thermal Rating: on line 5666-1629 : Rate B, Rate C , 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 726-687 : Rate B, Rate C , 0.0, 0.0 -> 7239
% INFO    : Updated Thermal Rating: on line 3526-687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8564
% INFO    : Updated Thermal Rating: on line 6382-2425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4444
% INFO    : Updated Thermal Rating: on line 6382-2425 : Rate B, Rate C , 0.0, 0.0 -> 4533
% INFO    : Updated Thermal Rating: on line 6382-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on line 6382-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 6382-5907 : Rate B, Rate C , 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 7847-9217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 2981-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 5110-5686 : Rate B, Rate C , 0.0, 0.0 -> 3769
% INFO    : Updated Thermal Rating: on line 2968-5907 : Rate B, Rate C , 0.0, 0.0 -> 3813
% INFO    : Updated Thermal Rating: on line 5441-2155 : Rate B, Rate C , 0.0, 0.0 -> 2042
% INFO    : Updated Thermal Rating: on line 5441-8112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1956
% INFO    : Updated Thermal Rating: on line 5441-2535 : Rate B, Rate C , 0.0, 0.0 -> 11184
% INFO    : Updated Thermal Rating: on line 5441-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 5441-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 5441-7098 : Rate B, Rate C , 0.0, 0.0 -> 2899
% INFO    : Updated Thermal Rating: on line 5441-3737 : Rate B, Rate C , 0.0, 0.0 -> 5922
% INFO    : Updated Thermal Rating: on line 5441-5529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5818
% INFO    : Updated Thermal Rating: on line 5441-5753 : Rate B, Rate C , 0.0, 0.0 -> 2664
% INFO    : Updated Thermal Rating: on line 9019-6563 : Rate B, Rate C , 0.0, 0.0 -> 52008
% INFO    : Updated Thermal Rating: on line 1341-1101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 2797-8291 : Rate B, Rate C , 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 2797-8367 : Rate B, Rate C , 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 2797-1100 : Rate B, Rate C , 0.0, 0.0 -> 7022
% INFO    : Updated Thermal Rating: on line 2797-6887 : Rate B, Rate C , 0.0, 0.0 -> 2694
% INFO    : Updated Thermal Rating: on line 4939-6880 : Rate B, Rate C , 0.0, 0.0 -> 9486
% INFO    : Updated Thermal Rating: on line 7738-6982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 6565-3121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 8707-280 : Rate B, Rate C , 0.0, 0.0 -> 3515
% INFO    : Updated Thermal Rating: on line 8707-2510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 1625-766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20318
% INFO    : Updated Thermal Rating: on line 8411-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54993
% INFO    : Updated Thermal Rating: on line 3951-1397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 964-7282 : Rate B, Rate C , 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 964-7282 : Rate B, Rate C , 0.0, 0.0 -> 2152
% INFO    : Updated Thermal Rating: on line 964-6475 : Rate B, Rate C , 0.0, 0.0 -> 3837
% INFO    : Updated Thermal Rating: on line 964-6475 : Rate B, Rate C , 0.0, 0.0 -> 3917
% INFO    : Updated Thermal Rating: on line 5658-5420 : Rate B, Rate C , 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 5658-8267 : Rate A, Rate B, Rate C , 1644.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 5658-7328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 5658-7328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1445
% INFO    : Updated Thermal Rating: on line 5658-7164 : Rate B, Rate C , 0.0, 0.0 -> 1524
% INFO    : Updated Thermal Rating: on line 5550-410 : Rate B, Rate C , 0.0, 0.0 -> 2976
% INFO    : Updated Thermal Rating: on line 5550-7579 : Rate B, Rate C , 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 5550-7579 : Rate B, Rate C , 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 5550-4189 : Rate B, Rate C , 0.0, 0.0 -> 629
% INFO    : Updated Thermal Rating: on line 7282-4196 : Rate B, Rate C , 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 1526-3916 : Rate B, Rate C , 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 1526-4747 : Rate B, Rate C , 0.0, 0.0 -> 2505
% INFO    : Updated Thermal Rating: on line 1526-4747 : Rate B, Rate C , 0.0, 0.0 -> 2051
% INFO    : Updated Thermal Rating: on line 4541-3346 : Rate A, Rate B, Rate C , 1414.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 4541-3346 : Rate A, Rate B, Rate C , 920.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 1343-3346 : Rate A, Rate B, Rate C , 1447.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 3680-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44610
% INFO    : Updated Thermal Rating: on line 3680-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31417
% INFO    : Updated Thermal Rating: on line 3680-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36971
% INFO    : Updated Thermal Rating: on line 3680-795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41087
% INFO    : Updated Thermal Rating: on line 3680-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1761
% INFO    : Updated Thermal Rating: on line 3680-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 7464-5564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47512
% INFO    : Updated Thermal Rating: on line 7464-7036 : Rate B, Rate C , 0.0, 0.0 -> 40125
% INFO    : Updated Thermal Rating: on line 7464-5940 : Rate B, Rate C , 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 7464-7495 : Rate B, Rate C , 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on line 4850-2886 : Rate B, Rate C , 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 4850-7049 : Rate B, Rate C , 0.0, 0.0 -> 1660
% INFO    : Updated Thermal Rating: on line 2510-6146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11156
% INFO    : Updated Thermal Rating: on line 90-1860 : Rate B, Rate C , 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 90-1860 : Rate B, Rate C , 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 2142-3276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20489
% INFO    : Updated Thermal Rating: on line 2142-3545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2774
% INFO    : Updated Thermal Rating: on line 2142-6842 : Rate B, Rate C , 0.0, 0.0 -> 1734
% INFO    : Updated Thermal Rating: on line 2142-6744 : Rate B, Rate C , 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 2142-7635 : Rate B, Rate C , 0.0, 0.0 -> 24993
% INFO    : Updated Thermal Rating: on line 9091-1040 : Rate B, Rate C , 0.0, 0.0 -> 1752
% INFO    : Updated Thermal Rating: on line 2457-6178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79847
% INFO    : Updated Thermal Rating: on line 1422-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5876
% INFO    : Updated Thermal Rating: on line 1422-7772 : Rate B, Rate C , 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 7881-5365 : Rate B, Rate C , 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 7881-6982 : Rate B, Rate C , 0.0, 0.0 -> 468
% INFO    : Updated Thermal Rating: on line 6926-3327 : Rate B, Rate C , 0.0, 0.0 -> 7240
% INFO    : Updated Thermal Rating: on line 1959-615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 6455-1262 : Rate B, Rate C , 0.0, 0.0 -> 14149
% INFO    : Updated Thermal Rating: on line 803-6982 : Rate B, Rate C , 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 803-5918 : Rate B, Rate C , 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 7624-3070 : Rate B, Rate C , 0.0, 0.0 -> 1926
% INFO    : Updated Thermal Rating: on line 500-1547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5703
% INFO    : Updated Thermal Rating: on line 500-5237 : Rate B, Rate C , 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 500-772 : Rate B, Rate C , 0.0, 0.0 -> 1815
% INFO    : Updated Thermal Rating: on line 500-8950 : Rate B, Rate C , 0.0, 0.0 -> 2298
% INFO    : Updated Thermal Rating: on line 2754-2079 : Rate B, Rate C , 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 2754-2229 : Rate B, Rate C , 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 2754-7049 : Rate B, Rate C , 0.0, 0.0 -> 3071
% INFO    : Updated Thermal Rating: on line 4118-7873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on line 4118-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5072
% INFO    : Updated Thermal Rating: on line 1754-8486 : Rate B, Rate C , 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 1754-7530 : Rate B, Rate C , 0.0, 0.0 -> 1601
% INFO    : Updated Thermal Rating: on line 1754-7778 : Rate B, Rate C , 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 1754-6897 : Rate B, Rate C , 0.0, 0.0 -> 2158
% INFO    : Updated Thermal Rating: on line 1754-960 : Rate B, Rate C , 0.0, 0.0 -> 1567
% INFO    : Updated Thermal Rating: on line 1754-960 : Rate B, Rate C , 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 3857-4491 : Rate B, Rate C , 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 3857-6010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6340
% INFO    : Updated Thermal Rating: on line 3857-6940 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 858-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20980
% INFO    : Updated Thermal Rating: on line 3028-809 : Rate B, Rate C , 0.0, 0.0 -> 21405
% INFO    : Updated Thermal Rating: on line 4819-1642 : Rate B, Rate C , 0.0, 0.0 -> 18328
% INFO    : Updated Thermal Rating: on line 2035-809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18979
% INFO    : Updated Thermal Rating: on line 3869-1642 : Rate B, Rate C , 0.0, 0.0 -> 18755
% INFO    : Updated Thermal Rating: on line 3741-809 : Rate B, Rate C , 0.0, 0.0 -> 18321
% INFO    : Updated Thermal Rating: on line 742-687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5499
% INFO    : Updated Thermal Rating: on line 2910-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6113
% INFO    : Updated Thermal Rating: on line 5688-6231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4761
% INFO    : Updated Thermal Rating: on line 5182-5455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10736
% INFO    : Updated Thermal Rating: on line 707-5695 : Rate B, Rate C , 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 3814-954 : Rate B, Rate C , 0.0, 0.0 -> 4656
% INFO    : Updated Thermal Rating: on line 2313-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4692
% INFO    : Updated Thermal Rating: on line 195-2985 : Rate B, Rate C , 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 2518-3513 : Rate A, Rate B, Rate C , 1513.0, 0.0, 0.0 -> 1177
% INFO    : Updated Thermal Rating: on line 2518-3346 : Rate B, Rate C , 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 4544-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on line 4544-3241 : Rate B, Rate C , 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 4544-7338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3724
% INFO    : Updated Thermal Rating: on line 3069-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16227
% INFO    : Updated Thermal Rating: on line 3069-1538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16547
% INFO    : Updated Thermal Rating: on line 6115-4729 : Rate B, Rate C , 0.0, 0.0 -> 2043
% INFO    : Updated Thermal Rating: on line 3344-6616 : Rate B, Rate C , 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 3809-5616 : Rate B, Rate C , 0.0, 0.0 -> 2898
% INFO    : Updated Thermal Rating: on line 3809-6691 : Rate B, Rate C , 0.0, 0.0 -> 3753
% INFO    : Updated Thermal Rating: on line 3809-6691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 1326-892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 601-616 : Rate B, Rate C , 0.0, 0.0 -> 1690
% INFO    : Updated Thermal Rating: on line 3496-1551 : Rate B, Rate C , 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 4925-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8460
% INFO    : Updated Thermal Rating: on line 8057-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6577
% INFO    : Updated Thermal Rating: on line 5354-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6466
% INFO    : Updated Thermal Rating: on line 3674-616 : Rate B, Rate C , 0.0, 0.0 -> 2023
% INFO    : Updated Thermal Rating: on line 3674-7338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2076
% INFO    : Updated Thermal Rating: on line 5836-5083 : Rate B, Rate C , 0.0, 0.0 -> 7834
% INFO    : Updated Thermal Rating: on line 5836-7576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11334
% INFO    : Updated Thermal Rating: on line 5836-3191 : Rate B, Rate C , 0.0, 0.0 -> 10177
% INFO    : Updated Thermal Rating: on line 5836-3488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2635
% INFO    : Updated Thermal Rating: on line 5836-1578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2919
% INFO    : Updated Thermal Rating: on line 575-5300 : Rate B, Rate C , 0.0, 0.0 -> 8927
% INFO    : Updated Thermal Rating: on line 3929-9173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41796
% INFO    : Updated Thermal Rating: on line 2089-3818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39156
% INFO    : Updated Thermal Rating: on line 2089-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57521
% INFO    : Updated Thermal Rating: on line 2089-1643 : Rate B, Rate C , 0.0, 0.0 -> 23719
% INFO    : Updated Thermal Rating: on line 2089-6253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106228
% INFO    : Updated Thermal Rating: on line 2089-6684 : Rate B, Rate C , 0.0, 0.0 -> 14289
% INFO    : Updated Thermal Rating: on line 2089-8151 : Rate B, Rate C , 0.0, 0.0 -> 19583
% INFO    : Updated Thermal Rating: on line 5067-449 : Rate B, Rate C , 0.0, 0.0 -> 11368
% INFO    : Updated Thermal Rating: on line 5067-449 : Rate B, Rate C , 0.0, 0.0 -> 11607
% INFO    : Updated Thermal Rating: on line 7641-3037 : Rate B, Rate C , 0.0, 0.0 -> 15052
% INFO    : Updated Thermal Rating: on line 7641-3037 : Rate B, Rate C , 0.0, 0.0 -> 13595
% INFO    : Updated Thermal Rating: on line 3191-2340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9173
% INFO    : Updated Thermal Rating: on line 3191-8711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9061
% INFO    : Updated Thermal Rating: on line 8104-8722 : Rate B, Rate C , 0.0, 0.0 -> 14120
% INFO    : Updated Thermal Rating: on line 2644-9191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13488
% INFO    : Updated Thermal Rating: on line 4128-8522 : Rate B, Rate C , 0.0, 0.0 -> 115370
% INFO    : Updated Thermal Rating: on line 604-7522 : Rate B, Rate C , 0.0, 0.0 -> 3119
% INFO    : Updated Thermal Rating: on line 604-4000 : Rate B, Rate C , 0.0, 0.0 -> 2164
% INFO    : Updated Thermal Rating: on line 2155-9021 : Rate B, Rate C , 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 2155-9021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2817
% INFO    : Updated Thermal Rating: on line 2155-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22385
% INFO    : Updated Thermal Rating: on line 2155-687 : Rate B, Rate C , 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 2155-3520 : Rate B, Rate C , 0.0, 0.0 -> 26969
% INFO    : Updated Thermal Rating: on line 2155-4729 : Rate B, Rate C , 0.0, 0.0 -> 2300
% INFO    : Updated Thermal Rating: on line 2641-4889 : Rate B, Rate C , 0.0, 0.0 -> 2295
% INFO    : Updated Thermal Rating: on line 9067-9051 : Rate B, Rate C , 0.0, 0.0 -> 6238
% INFO    : Updated Thermal Rating: on line 6969-5573 : Rate B, Rate C , 0.0, 0.0 -> 5164
% INFO    : Updated Thermal Rating: on line 666-1494 : Rate A, Rate B, Rate C , 1348.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 666-2732 : Rate A, Rate B, Rate C , 1414.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 666-4550 : Rate A, Rate B, Rate C , 1381.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 666-1607 : Rate B, Rate C , 0.0, 0.0 -> 12537
% INFO    : Updated Thermal Rating: on line 666-2093 : Rate B, Rate C , 0.0, 0.0 -> 4833
% INFO    : Updated Thermal Rating: on line 3565-2177 : Rate B, Rate C , 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 3565-2841 : Rate B, Rate C , 0.0, 0.0 -> 5880
% INFO    : Updated Thermal Rating: on line 3611-7972 : Rate B, Rate C , 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 3611-2481 : Rate B, Rate C , 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 5420-7164 : Rate B, Rate C , 0.0, 0.0 -> 3760
% INFO    : Updated Thermal Rating: on line 7119-2078 : Rate B, Rate C , 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 7119-7873 : Rate B, Rate C , 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 7422-7519 : Rate B, Rate C , 0.0, 0.0 -> 3892
% INFO    : Updated Thermal Rating: on line 7422-6744 : Rate B, Rate C , 0.0, 0.0 -> 2101
% INFO    : Updated Thermal Rating: on line 1026-1860 : Rate B, Rate C , 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 4765-3327 : Rate B, Rate C , 0.0, 0.0 -> 5873
% INFO    : Updated Thermal Rating: on line 6036-6921 : Rate B, Rate C , 0.0, 0.0 -> 5568
% INFO    : Updated Thermal Rating: on line 8670-7069 : Rate B, Rate C , 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 8670-7069 : Rate B, Rate C , 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 8670-2866 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on line 4032-6450 : Rate B, Rate C , 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 4032-5738 : Rate B, Rate C , 0.0, 0.0 -> 2243
% INFO    : Updated Thermal Rating: on line 7327-2481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 7327-8189 : Rate B, Rate C , 0.0, 0.0 -> 8692
% INFO    : Updated Thermal Rating: on line 7474-1584 : Rate B, Rate C , 0.0, 0.0 -> 31852
% INFO    : Updated Thermal Rating: on line 8947-3390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57640
% INFO    : Updated Thermal Rating: on line 1808-6384 : Rate B, Rate C , 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 4624-6031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15773
% INFO    : Updated Thermal Rating: on line 1721-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43532
% INFO    : Updated Thermal Rating: on line 7694-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46697
% INFO    : Updated Thermal Rating: on line 9181-6723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29820
% INFO    : Updated Thermal Rating: on line 8373-8748 : Rate B, Rate C , 0.0, 0.0 -> 1506
% INFO    : Updated Thermal Rating: on line 8373-8475 : Rate B, Rate C , 0.0, 0.0 -> 9896
% INFO    : Updated Thermal Rating: on line 8373-8475 : Rate B, Rate C , 0.0, 0.0 -> 9471
% INFO    : Updated Thermal Rating: on line 5630-6639 : Rate B, Rate C , 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 5630-1187 : Rate B, Rate C , 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on line 5630-7274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on line 5630-8992 : Rate B, Rate C , 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on line 5630-7266 : Rate B, Rate C , 0.0, 0.0 -> 1374
% INFO    : Updated Thermal Rating: on line 3492-6734 : Rate B, Rate C , 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 3492-1015 : Rate B, Rate C , 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 3492-8310 : Rate B, Rate C , 0.0, 0.0 -> 17314
% INFO    : Updated Thermal Rating: on line 1980-6570 : Rate B, Rate C , 0.0, 0.0 -> 4294
% INFO    : Updated Thermal Rating: on line 9137-749 : Rate B, Rate C , 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 7522-2183 : Rate A, Rate B, Rate C , 1611.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 7571-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 7571-6891 : Rate B, Rate C , 0.0, 0.0 -> 3673
% INFO    : Updated Thermal Rating: on line 2526-6199 : Rate B, Rate C , 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 2526-6199 : Rate B, Rate C , 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 1483-3649 : Rate B, Rate C , 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 2365-6199 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 2365-6199 : Rate B, Rate C , 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 2365-4141 : Rate B, Rate C , 0.0, 0.0 -> 1534
% INFO    : Updated Thermal Rating: on line 2365-1311 : Rate B, Rate C , 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 8316-174 : Rate B, Rate C , 0.0, 0.0 -> 3821
% INFO    : Updated Thermal Rating: on line 174-6430 : Rate B, Rate C , 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 5340-7892 : Rate B, Rate C , 0.0, 0.0 -> 4102
% INFO    : Updated Thermal Rating: on line 5340-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17232
% INFO    : Updated Thermal Rating: on line 5340-8843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 5340-8843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157839
% INFO    : Updated Thermal Rating: on line 5340-4239 : Rate B, Rate C , 0.0, 0.0 -> 1379
% INFO    : Updated Thermal Rating: on line 3866-1860 : Rate B, Rate C , 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 3866-5395 : Rate B, Rate C , 0.0, 0.0 -> 2178
% INFO    : Updated Thermal Rating: on line 7042-2177 : Rate B, Rate C , 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 8672-7164 : Rate B, Rate C , 0.0, 0.0 -> 4019
% INFO    : Updated Thermal Rating: on line 1860-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 1860-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on line 4885-2928 : Rate B, Rate C , 0.0, 0.0 -> 111427
% INFO    : Updated Thermal Rating: on line 4157-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121741
% INFO    : Updated Thermal Rating: on line 4432-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121741
% INFO    : Updated Thermal Rating: on line 2072-5983 : Rate A, Rate B, Rate C , 1381.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 3450-6552 : Rate B, Rate C , 0.0, 0.0 -> 3657
% INFO    : Updated Thermal Rating: on line 3956-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 5286-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93122
% INFO    : Updated Thermal Rating: on line 5571-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91583
% INFO    : Updated Thermal Rating: on line 2078-8005 : Rate B, Rate C , 0.0, 0.0 -> 4017
% INFO    : Updated Thermal Rating: on line 639-6351 : Rate A, Rate B, Rate C , 529.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 639-2749 : Rate B, Rate C , 0.0, 0.0 -> 6761
% INFO    : Updated Thermal Rating: on line 639-9130 : Rate B, Rate C , 0.0, 0.0 -> 3197
% INFO    : Updated Thermal Rating: on line 410-4189 : Rate B, Rate C , 0.0, 0.0 -> 1438
% INFO    : Updated Thermal Rating: on line 1494-5781 : Rate B, Rate C , 0.0, 0.0 -> 4206
% INFO    : Updated Thermal Rating: on line 583-6616 : Rate B, Rate C , 0.0, 0.0 -> 3384
% INFO    : Updated Thermal Rating: on line 583-6031 : Rate B, Rate C , 0.0, 0.0 -> 2386
% INFO    : Updated Thermal Rating: on line 1746-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2854
% INFO    : Updated Thermal Rating: on line 3276-7635 : Rate B, Rate C , 0.0, 0.0 -> 87233
% INFO    : Updated Thermal Rating: on line 1105-196 : Rate B, Rate C , 0.0, 0.0 -> 66610
% INFO    : Updated Thermal Rating: on line 8522-7132 : Rate B, Rate C , 0.0, 0.0 -> 18651
% INFO    : Updated Thermal Rating: on line 8522-5351 : Rate B, Rate C , 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 8763-7056 : Rate B, Rate C , 0.0, 0.0 -> 1307
% INFO    : Updated Thermal Rating: on line 8763-8825 : Rate B, Rate C , 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on line 8763-6889 : Rate B, Rate C , 0.0, 0.0 -> 12298
% INFO    : Updated Thermal Rating: on line 8763-6889 : Rate B, Rate C , 0.0, 0.0 -> 12936
% INFO    : Updated Thermal Rating: on line 8763-8887 : Rate A, Rate B, Rate C , 1414.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 8763-8887 : Rate B, Rate C , 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 8763-8487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 8748-8475 : Rate B, Rate C , 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 217-6785 : Rate B, Rate C , 0.0, 0.0 -> 1505
% INFO    : Updated Thermal Rating: on line 217-6785 : Rate B, Rate C , 0.0, 0.0 -> 1688
% INFO    : Updated Thermal Rating: on line 217-1179 : Rate B, Rate C , 0.0, 0.0 -> 6680
% INFO    : Updated Thermal Rating: on line 217-2575 : Rate B, Rate C , 0.0, 0.0 -> 7921
% INFO    : Updated Thermal Rating: on line 217-7274 : Rate B, Rate C , 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 7972-8189 : Rate B, Rate C , 0.0, 0.0 -> 1508
% INFO    : Updated Thermal Rating: on line 7972-8189 : Rate B, Rate C , 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 7972-1039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2361
% INFO    : Updated Thermal Rating: on line 7253-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3594
% INFO    : Updated Thermal Rating: on line 4395-8913 : Rate B, Rate C , 0.0, 0.0 -> 7698
% INFO    : Updated Thermal Rating: on line 4395-4852 : Rate B, Rate C , 0.0, 0.0 -> 4149
% INFO    : Updated Thermal Rating: on line 2795-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5439
% INFO    : Updated Thermal Rating: on line 2795-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4811
% INFO    : Updated Thermal Rating: on line 1305-6291 : Rate B, Rate C , 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 1305-6982 : Rate B, Rate C , 0.0, 0.0 -> 1305
% INFO    : Updated Thermal Rating: on line 2732-1798 : Rate B, Rate C , 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 2732-3346 : Rate A, Rate B, Rate C , 1480.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 4550-3346 : Rate A, Rate B, Rate C , 1480.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 4725-5738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 1083-8310 : Rate B, Rate C , 0.0, 0.0 -> 59909
% INFO    : Updated Thermal Rating: on line 1398-5567 : Rate B, Rate C , 0.0, 0.0 -> 45315
% INFO    : Updated Thermal Rating: on line 4281-4580 : Rate B, Rate C , 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 7050-4908 : Rate B, Rate C , 0.0, 0.0 -> 24666
% INFO    : Updated Thermal Rating: on line 7050-3740 : Rate B, Rate C , 0.0, 0.0 -> 42288
% INFO    : Updated Thermal Rating: on line 6563-870 : Rate B, Rate C , 0.0, 0.0 -> 31635
% INFO    : Updated Thermal Rating: on line 8999-6495 : Rate B, Rate C , 0.0, 0.0 -> 4522
% INFO    : Updated Thermal Rating: on line 6888-5994 : Rate B, Rate C , 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 5400-8005 : Rate B, Rate C , 0.0, 0.0 -> 6871
% INFO    : Updated Thermal Rating: on line 5400-8005 : Rate B, Rate C , 0.0, 0.0 -> 6583
% INFO    : Updated Thermal Rating: on line 5881-4031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3663
% INFO    : Updated Thermal Rating: on line 8195-8334 : Rate B, Rate C , 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 933-6357 : Rate B, Rate C , 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 933-6357 : Rate B, Rate C , 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 933-3775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 933-3975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3918-1642 : Rate B, Rate C , 0.0, 0.0 -> 5902
% INFO    : Updated Thermal Rating: on line 6802-1153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47123
% INFO    : Updated Thermal Rating: on line 6802-7599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50874
% INFO    : Updated Thermal Rating: on line 4025-3994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45791
% INFO    : Updated Thermal Rating: on line 1595-1414 : Rate B, Rate C , 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 3114-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3905
% INFO    : Updated Thermal Rating: on line 5237-2229 : Rate B, Rate C , 0.0, 0.0 -> 1508
% INFO    : Updated Thermal Rating: on line 5237-9108 : Rate B, Rate C , 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 5237-1478 : Rate B, Rate C , 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 2799-8515 : Rate B, Rate C , 0.0, 0.0 -> 46722
% INFO    : Updated Thermal Rating: on line 6405-7873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 6405-3894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 4435-4734 : Rate B, Rate C , 0.0, 0.0 -> 4819
% INFO    : Updated Thermal Rating: on line 4435-3483 : Rate B, Rate C , 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 2079-7052 : Rate B, Rate C , 0.0, 0.0 -> 3255
% INFO    : Updated Thermal Rating: on line 2079-7052 : Rate B, Rate C , 0.0, 0.0 -> 3175
% INFO    : Updated Thermal Rating: on line 2079-772 : Rate B, Rate C , 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 2079-772 : Rate B, Rate C , 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 1081-6475 : Rate B, Rate C , 0.0, 0.0 -> 1478
% INFO    : Updated Thermal Rating: on line 1081-6475 : Rate B, Rate C , 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 7361-3166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 7361-426 : Rate B, Rate C , 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 2863-1857 : Rate B, Rate C , 0.0, 0.0 -> 31275
% INFO    : Updated Thermal Rating: on line 1364-2430 : Rate B, Rate C , 0.0, 0.0 -> 3794
% INFO    : Updated Thermal Rating: on line 2177-749 : Rate B, Rate C , 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 3594-2850 : Rate B, Rate C , 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 6555-3608 : Rate B, Rate C , 0.0, 0.0 -> 1494
% INFO    : Updated Thermal Rating: on line 8475-1965 : Rate B, Rate C , 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 8475-5926 : Rate B, Rate C , 0.0, 0.0 -> 16954
% INFO    : Updated Thermal Rating: on line 5735-6053 : Rate B, Rate C , 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 5735-2341 : Rate B, Rate C , 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on line 2629-7507 : Rate B, Rate C , 0.0, 0.0 -> 7813
% INFO    : Updated Thermal Rating: on line 1137-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60973
% INFO    : Updated Thermal Rating: on line 7577-5814 : Rate B, Rate C , 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 7577-3231 : Rate B, Rate C , 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 7663-5814 : Rate B, Rate C , 0.0, 0.0 -> 5713
% INFO    : Updated Thermal Rating: on line 1183-1159 : Rate B, Rate C , 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 6852-5051 : Rate B, Rate C , 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 8307-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27156
% INFO    : Updated Thermal Rating: on line 6947-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27847
% INFO    : Updated Thermal Rating: on line 4505-4357 : Rate B, Rate C , 0.0, 0.0 -> 34015
% INFO    : Updated Thermal Rating: on line 7144-7791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7404
% INFO    : Updated Thermal Rating: on line 6889-2085 : Rate B, Rate C , 0.0, 0.0 -> 53817
% INFO    : Updated Thermal Rating: on line 6889-4024 : Rate B, Rate C , 0.0, 0.0 -> 52926
% INFO    : Updated Thermal Rating: on line 6889-9065 : Rate B, Rate C , 0.0, 0.0 -> 58932
% INFO    : Updated Thermal Rating: on line 6889-661 : Rate B, Rate C , 0.0, 0.0 -> 60039
% INFO    : Updated Thermal Rating: on line 6612-8864 : Rate B, Rate C , 0.0, 0.0 -> 20590
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 5378
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 4753
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 4662
% INFO    : Updated Thermal Rating: on line 8931-6199 : Rate B, Rate C , 0.0, 0.0 -> 4575
% INFO    : Updated Thermal Rating: on line 8931-8494 : Rate B, Rate C , 0.0, 0.0 -> 9314
% INFO    : Updated Thermal Rating: on line 8931-8494 : Rate B, Rate C , 0.0, 0.0 -> 9859
% INFO    : Updated Thermal Rating: on line 1643-4511 : Rate B, Rate C , 0.0, 0.0 -> 30359
% INFO    : Updated Thermal Rating: on line 196-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25834
% INFO    : Updated Thermal Rating: on line 2902-5573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48210
% INFO    : Updated Thermal Rating: on line 4950-4410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on line 4950-333 : Rate B, Rate C , 0.0, 0.0 -> 1329
% INFO    : Updated Thermal Rating: on line 4950-6908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 3377-7726 : Rate B, Rate C , 0.0, 0.0 -> 76413
% INFO    : Updated Thermal Rating: on line 1027-3243 : Rate B, Rate C , 0.0, 0.0 -> 30849
% INFO    : Updated Thermal Rating: on line 1027-2458 : Rate B, Rate C , 0.0, 0.0 -> 1909
% INFO    : Updated Thermal Rating: on line 1027-2919 : Rate B, Rate C , 0.0, 0.0 -> 7375
% INFO    : Updated Thermal Rating: on line 5308-8560 : Rate B, Rate C , 0.0, 0.0 -> 28859
% INFO    : Updated Thermal Rating: on line 5308-6427 : Rate B, Rate C , 0.0, 0.0 -> 1872
% INFO    : Updated Thermal Rating: on line 5308-8347 : Rate B, Rate C , 0.0, 0.0 -> 2490
% INFO    : Updated Thermal Rating: on line 7148-5610 : Rate B, Rate C , 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 7148-2421 : Rate B, Rate C , 0.0, 0.0 -> 5934
% INFO    : Updated Thermal Rating: on line 7148-2421 : Rate B, Rate C , 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 7148-2421 : Rate B, Rate C , 0.0, 0.0 -> 6164
% INFO    : Updated Thermal Rating: on line 7148-6989 : Rate B, Rate C , 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 44-1545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on line 44-3541 : Rate B, Rate C , 0.0, 0.0 -> 1338
% INFO    : Updated Thermal Rating: on line 6231-4710 : Rate B, Rate C , 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 6231-8367 : Rate B, Rate C , 0.0, 0.0 -> 1785
% INFO    : Updated Thermal Rating: on line 6231-2288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5477
% INFO    : Updated Thermal Rating: on line 8291-8473 : Rate B, Rate C , 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 8291-5455 : Rate B, Rate C , 0.0, 0.0 -> 6500
% INFO    : Updated Thermal Rating: on line 8291-7635 : Rate B, Rate C , 0.0, 0.0 -> 2493
% INFO    : Updated Thermal Rating: on line 6842-8473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3825
% INFO    : Updated Thermal Rating: on line 6842-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 6842-2288 : Rate B, Rate C , 0.0, 0.0 -> 5255
% INFO    : Updated Thermal Rating: on line 3969-7726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3635
% INFO    : Updated Thermal Rating: on line 1090-1129 : Rate B, Rate C , 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 1090-3070 : Rate B, Rate C , 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 8515-5365 : Rate B, Rate C , 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 8515-5365 : Rate B, Rate C , 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 8515-4529 : Rate B, Rate C , 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 8515-3364 : Rate B, Rate C , 0.0, 0.0 -> 41929
% INFO    : Updated Thermal Rating: on line 935-5383 : Rate B, Rate C , 0.0, 0.0 -> 4856
% INFO    : Updated Thermal Rating: on line 920-6570 : Rate B, Rate C , 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 6664-4426 : Rate B, Rate C , 0.0, 0.0 -> 13291
% INFO    : Updated Thermal Rating: on line 4339-2183 : Rate B, Rate C , 0.0, 0.0 -> 9586
% INFO    : Updated Thermal Rating: on line 7513-4000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9693
% INFO    : Updated Thermal Rating: on line 6570-8542 : Rate B, Rate C , 0.0, 0.0 -> 8963
% INFO    : Updated Thermal Rating: on line 6570-8542 : Rate B, Rate C , 0.0, 0.0 -> 9449
% INFO    : Updated Thermal Rating: on line 6570-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 6570-9119 : Rate B, Rate C , 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 6570-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7843
% INFO    : Updated Thermal Rating: on line 502-3589 : Rate B, Rate C , 0.0, 0.0 -> 10995
% INFO    : Updated Thermal Rating: on line 8473-1040 : Rate B, Rate C , 0.0, 0.0 -> 12244
% INFO    : Updated Thermal Rating: on line 8473-145 : Rate B, Rate C , 0.0, 0.0 -> 25543
% INFO    : Updated Thermal Rating: on line 8473-4267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23628
% INFO    : Updated Thermal Rating: on line 4936-5179 : Rate B, Rate C , 0.0, 0.0 -> 3164
% INFO    : Updated Thermal Rating: on line 5317-8854 : Rate B, Rate C , 0.0, 0.0 -> 12765
% INFO    : Updated Thermal Rating: on line 9018-4 : Rate B, Rate C , 0.0, 0.0 -> 3374
% INFO    : Updated Thermal Rating: on line 9018-4829 : Rate B, Rate C , 0.0, 0.0 -> 2406
% INFO    : Updated Thermal Rating: on line 6253-5383 : Rate B, Rate C , 0.0, 0.0 -> 2604
% INFO    : Updated Thermal Rating: on line 6253-7507 : Rate B, Rate C , 0.0, 0.0 -> 2881
% INFO    : Updated Thermal Rating: on line 8887-1644 : Rate B, Rate C , 0.0, 0.0 -> 3037
% INFO    : Updated Thermal Rating: on line 8887-3483 : Rate B, Rate C , 0.0, 0.0 -> 2684
% INFO    : Updated Thermal Rating: on line 6639-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3311
% INFO    : Updated Thermal Rating: on line 6639-7840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3250
% INFO    : Updated Thermal Rating: on line 5461-8109 : Rate B, Rate C , 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 6291-4189 : Rate B, Rate C , 0.0, 0.0 -> 1258
% INFO    : Updated Thermal Rating: on line 8405-4747 : Rate B, Rate C , 0.0, 0.0 -> 7369
% INFO    : Updated Thermal Rating: on line 8405-4580 : Rate B, Rate C , 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 338-7824 : Rate B, Rate C , 0.0, 0.0 -> 11239
% INFO    : Updated Thermal Rating: on line 2468-7824 : Rate B, Rate C , 0.0, 0.0 -> 11053
% INFO    : Updated Thermal Rating: on line 5257-7824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13399
% INFO    : Updated Thermal Rating: on line 2189-7824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13134
% INFO    : Updated Thermal Rating: on line 8458-8267 : Rate B, Rate C , 0.0, 0.0 -> 16324
% INFO    : Updated Thermal Rating: on line 2676-5987 : Rate B, Rate C , 0.0, 0.0 -> 2085
% INFO    : Updated Thermal Rating: on line 1187-5712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2558
% INFO    : Updated Thermal Rating: on line 1187-6521 : Rate B, Rate C , 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 2360-8636 : Rate B, Rate C , 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 2360-8829 : Rate B, Rate C , 0.0, 0.0 -> 25455
% INFO    : Updated Thermal Rating: on line 2360-4235 : Rate B, Rate C , 0.0, 0.0 -> 1801
% INFO    : Updated Thermal Rating: on line 2360-4235 : Rate B, Rate C , 0.0, 0.0 -> 1773
% INFO    : Updated Thermal Rating: on line 2360-4235 : Rate B, Rate C , 0.0, 0.0 -> 1833
% INFO    : Updated Thermal Rating: on line 8818-5099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 5781-4734 : Rate B, Rate C , 0.0, 0.0 -> 2600
% INFO    : Updated Thermal Rating: on line 5781-905 : Rate B, Rate C , 0.0, 0.0 -> 3928
% INFO    : Updated Thermal Rating: on line 5781-8334 : Rate B, Rate C , 0.0, 0.0 -> 4709
% INFO    : Updated Thermal Rating: on line 5781-2093 : Rate A, Rate B, Rate C , 1315.0, 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on line 6772-6989 : Rate B, Rate C , 0.0, 0.0 -> 10553
% INFO    : Updated Thermal Rating: on line 7885-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 6730-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67388
% INFO    : Updated Thermal Rating: on line 4301-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64510
% INFO    : Updated Thermal Rating: on line 5362-5610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5841
% INFO    : Updated Thermal Rating: on line 5362-350 : Rate B, Rate C , 0.0, 0.0 -> 28553
% INFO    : Updated Thermal Rating: on line 5362-6763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28222
% INFO    : Updated Thermal Rating: on line 3855-1973 : Rate B, Rate C , 0.0, 0.0 -> 37967
% INFO    : Updated Thermal Rating: on line 3855-1973 : Rate B, Rate C , 0.0, 0.0 -> 22051
% INFO    : Updated Thermal Rating: on line 3481-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1342
% INFO    : Updated Thermal Rating: on line 5460-8222 : Rate B, Rate C , 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 5460-8222 : Rate B, Rate C , 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 5460-2721 : Rate B, Rate C , 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 5460-2721 : Rate B, Rate C , 0.0, 0.0 -> 2858
% INFO    : Updated Thermal Rating: on line 3786-8578 : Rate B, Rate C , 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 490-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46468
% INFO    : Updated Thermal Rating: on line 148-7069 : Rate B, Rate C , 0.0, 0.0 -> 25372
% INFO    : Updated Thermal Rating: on line 7256-8743 : Rate B, Rate C , 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 7256-1742 : Rate B, Rate C , 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 8930-314 : Rate B, Rate C , 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 6954-7974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93784
% INFO    : Updated Thermal Rating: on line 3325-7974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99888
% INFO    : Updated Thermal Rating: on line 5627-1742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16564
% INFO    : Updated Thermal Rating: on line 5610-6989 : Rate B, Rate C , 0.0, 0.0 -> 4733
% INFO    : Updated Thermal Rating: on line 21-6163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55892
% INFO    : Updated Thermal Rating: on line 3749-5365 : Rate B, Rate C , 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 3749-6982 : Rate B, Rate C , 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 2291-3133 : Rate B, Rate C , 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 2291-4738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 2291-3656 : Rate B, Rate C , 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 314-4300 : Rate B, Rate C , 0.0, 0.0 -> 7799
% INFO    : Updated Thermal Rating: on line 314-5789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7797
% INFO    : Updated Thermal Rating: on line 314-2467 : Rate B, Rate C , 0.0, 0.0 -> 1749
% INFO    : Updated Thermal Rating: on line 314-2467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1709
% INFO    : Updated Thermal Rating: on line 314-5256 : Rate B, Rate C , 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 3200-2653 : Rate B, Rate C , 0.0, 0.0 -> 29775
% INFO    : Updated Thermal Rating: on line 4679-4852 : Rate B, Rate C , 0.0, 0.0 -> 2496
% INFO    : Updated Thermal Rating: on line 4679-4852 : Rate B, Rate C , 0.0, 0.0 -> 3923
% INFO    : Updated Thermal Rating: on line 4679-1151 : Rate B, Rate C , 0.0, 0.0 -> 9867
% INFO    : Updated Thermal Rating: on line 8568-5215 : Rate B, Rate C , 0.0, 0.0 -> 13881
% INFO    : Updated Thermal Rating: on line 58-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8180
% INFO    : Updated Thermal Rating: on line 6807-851 : Rate B, Rate C , 0.0, 0.0 -> 3799
% INFO    : Updated Thermal Rating: on line 150-5099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 150-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6482
% INFO    : Updated Thermal Rating: on line 7209-2934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9308
% INFO    : Updated Thermal Rating: on line 1465-4787 : Rate B, Rate C , 0.0, 0.0 -> 4611
% INFO    : Updated Thermal Rating: on line 1465-3830 : Rate B, Rate C , 0.0, 0.0 -> 6274
% INFO    : Updated Thermal Rating: on line 1465-5648 : Rate B, Rate C , 0.0, 0.0 -> 6400
% INFO    : Updated Thermal Rating: on line 1465-4000 : Rate B, Rate C , 0.0, 0.0 -> 5103
% INFO    : Updated Thermal Rating: on line 7537-3485 : Rate B, Rate C , 0.0, 0.0 -> 10015
% INFO    : Updated Thermal Rating: on line 7537-3830 : Rate B, Rate C , 0.0, 0.0 -> 4715
% INFO    : Updated Thermal Rating: on line 7537-5648 : Rate B, Rate C , 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 1262-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1832
% INFO    : Updated Thermal Rating: on line 1262-1156 : Rate B, Rate C , 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 1262-4914 : Rate B, Rate C , 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 1262-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2821
% INFO    : Updated Thermal Rating: on line 1262-3834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11729
% INFO    : Updated Thermal Rating: on line 1262-556 : Rate B, Rate C , 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 1262-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4048
% INFO    : Updated Thermal Rating: on line 1262-7923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12172
% INFO    : Updated Thermal Rating: on line 1551-4103 : Rate B, Rate C , 0.0, 0.0 -> 2607
% INFO    : Updated Thermal Rating: on line 1551-7862 : Rate B, Rate C , 0.0, 0.0 -> 4274
% INFO    : Updated Thermal Rating: on line 1551-5458 : Rate B, Rate C , 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 1551-1838 : Rate B, Rate C , 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 3070-2888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10884
% INFO    : Updated Thermal Rating: on line 4874-4504 : Rate B, Rate C , 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 4874-3579 : Rate B, Rate C , 0.0, 0.0 -> 2469
% INFO    : Updated Thermal Rating: on line 4874-3579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 4874-7903 : Rate B, Rate C , 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on line 6368-1102 : Rate B, Rate C , 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 6368-9217 : Rate B, Rate C , 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 6368-5653 : Rate B, Rate C , 0.0, 0.0 -> 1841
% INFO    : Updated Thermal Rating: on line 8478-5907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 5241-6921 : Rate B, Rate C , 0.0, 0.0 -> 3877
% INFO    : Updated Thermal Rating: on line 4-1813 : Rate B, Rate C , 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 8950-7049 : Rate B, Rate C , 0.0, 0.0 -> 9413
% INFO    : Updated Thermal Rating: on line 6846-8788 : Rate B, Rate C , 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 6846-6734 : Rate B, Rate C , 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 4426-5616 : Rate A, Rate B, Rate C , 453.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 4426-1965 : Rate B, Rate C , 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 4426-1767 : Rate B, Rate C , 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 3037-1102 : Rate B, Rate C , 0.0, 0.0 -> 7428
% INFO    : Updated Thermal Rating: on line 3037-8485 : Rate B, Rate C , 0.0, 0.0 -> 4197
% INFO    : Updated Thermal Rating: on line 3037-5653 : Rate B, Rate C , 0.0, 0.0 -> 2553
% INFO    : Updated Thermal Rating: on line 5395-4661 : Rate B, Rate C , 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 5395-520 : Rate B, Rate C , 0.0, 0.0 -> 3383
% INFO    : Updated Thermal Rating: on line 5395-6816 : Rate B, Rate C , 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 5395-5918 : Rate B, Rate C , 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on line 5395-5918 : Rate B, Rate C , 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on line 8636-1380 : Rate B, Rate C , 0.0, 0.0 -> 2291
% INFO    : Updated Thermal Rating: on line 3436-4239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2547
% INFO    : Updated Thermal Rating: on line 3436-4239 : Rate B, Rate C , 0.0, 0.0 -> 2529
% INFO    : Updated Thermal Rating: on line 3436-3656 : Rate B, Rate C , 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on line 6203-7124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on line 9059-7124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 5994-96 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 5049-306 : Rate B, Rate C , 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 718-8397 : Rate B, Rate C , 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 718-6982 : Rate B, Rate C , 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 7202-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 7202-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 8592-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5816
% INFO    : Updated Thermal Rating: on line 6581-823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95544
% INFO    : Updated Thermal Rating: on line 6581-1680 : Rate B, Rate C , 0.0, 0.0 -> 92864
% INFO    : Updated Thermal Rating: on line 6199-953 : Rate B, Rate C , 0.0, 0.0 -> 12195
% INFO    : Updated Thermal Rating: on line 6199-1817 : Rate B, Rate C , 0.0, 0.0 -> 12483
% INFO    : Updated Thermal Rating: on line 3231-1504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3602
% INFO    : Updated Thermal Rating: on line 3231-7226 : Rate B, Rate C , 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 2928-7865 : Rate B, Rate C , 0.0, 0.0 -> 37425
% INFO    : Updated Thermal Rating: on line 3916-6891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2768
% INFO    : Updated Thermal Rating: on line 6053-171 : Rate B, Rate C , 0.0, 0.0 -> 1839
% INFO    : Updated Thermal Rating: on line 6053-171 : Rate B, Rate C , 0.0, 0.0 -> 1876
% INFO    : Updated Thermal Rating: on line 8829-3044 : Rate B, Rate C , 0.0, 0.0 -> 26188
% INFO    : Updated Thermal Rating: on line 1552-1194 : Rate B, Rate C , 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 3912-3740 : Rate B, Rate C , 0.0, 0.0 -> 6862
% INFO    : Updated Thermal Rating: on line 3912-2695 : Rate B, Rate C , 0.0, 0.0 -> 18126
% INFO    : Updated Thermal Rating: on line 3912-2695 : Rate B, Rate C , 0.0, 0.0 -> 40050
% INFO    : Updated Thermal Rating: on line 3912-8877 : Rate B, Rate C , 0.0, 0.0 -> 4693
% INFO    : Updated Thermal Rating: on line 7520-8222 : Rate B, Rate C , 0.0, 0.0 -> 3758
% INFO    : Updated Thermal Rating: on line 7520-8222 : Rate B, Rate C , 0.0, 0.0 -> 3689
% INFO    : Updated Thermal Rating: on line 2421-3610 : Rate B, Rate C , 0.0, 0.0 -> 1819
% INFO    : Updated Thermal Rating: on line 2421-1414 : Rate B, Rate C , 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 8879-3610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1615
% INFO    : Updated Thermal Rating: on line 8397-5918 : Rate B, Rate C , 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 1914-6982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11266
% INFO    : Updated Thermal Rating: on line 7873-6638 : Rate B, Rate C , 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 4562-7702 : Rate B, Rate C , 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 4562-7702 : Rate B, Rate C , 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 8835-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5127
% INFO    : Updated Thermal Rating: on line 8835-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5224
% INFO    : Updated Thermal Rating: on line 3390-408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39117
% INFO    : Updated Thermal Rating: on line 3390-7231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45856
% INFO    : Updated Thermal Rating: on line 3390-5993 : Rate B, Rate C , 0.0, 0.0 -> 3676
% INFO    : Updated Thermal Rating: on line 1910-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30131
% INFO    : Updated Thermal Rating: on line 3975-7353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 3126-7495 : Rate B, Rate C , 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 2689-5753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8836
% INFO    : Updated Thermal Rating: on line 1201-4235 : Rate B, Rate C , 0.0, 0.0 -> 3507
% INFO    : Updated Thermal Rating: on line 7626-7076 : Rate B, Rate C , 0.0, 0.0 -> 74627
% INFO    : Updated Thermal Rating: on line 4823-4060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5902
% INFO    : Updated Thermal Rating: on line 4141-1311 : Rate B, Rate C , 0.0, 0.0 -> 3816
% INFO    : Updated Thermal Rating: on line 7124-4566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 7124-8873 : Rate B, Rate C , 0.0, 0.0 -> 32351
% INFO    : Updated Thermal Rating: on line 6684-5383 : Rate B, Rate C , 0.0, 0.0 -> 3092
% INFO    : Updated Thermal Rating: on line 8151-5383 : Rate B, Rate C , 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 4357-6619 : Rate B, Rate C , 0.0, 0.0 -> 4605
% INFO    : Updated Thermal Rating: on line 8191-8765 : Rate B, Rate C , 0.0, 0.0 -> 5309
% INFO    : Updated Thermal Rating: on line 7466-5469 : Rate B, Rate C , 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 3401-5351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87580
% INFO    : Updated Thermal Rating: on line 3760-225 : Rate B, Rate C , 0.0, 0.0 -> 4182
% INFO    : Updated Thermal Rating: on line 53-4031 : Rate B, Rate C , 0.0, 0.0 -> 1290
% INFO    : Updated Thermal Rating: on line 8222-6921 : Rate A, Rate B, Rate C , 1578.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 8222-6921 : Rate A, Rate B, Rate C , 1677.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 6556-4239 : Rate B, Rate C , 0.0, 0.0 -> 5553
% INFO    : Updated Thermal Rating: on line 6556-4239 : Rate B, Rate C , 0.0, 0.0 -> 5069
% INFO    : Updated Thermal Rating: on line 2940-7178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3077
% INFO    : Updated Thermal Rating: on line 3928-2563 : Rate B, Rate C , 0.0, 0.0 -> 15364
% INFO    : Updated Thermal Rating: on line 3928-6521 : Rate B, Rate C , 0.0, 0.0 -> 47279
% INFO    : Updated Thermal Rating: on line 1923-3830 : Rate B, Rate C , 0.0, 0.0 -> 6234
% INFO    : Updated Thermal Rating: on line 1923-5648 : Rate B, Rate C , 0.0, 0.0 -> 6371
% INFO    : Updated Thermal Rating: on line 2815-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39182
% INFO    : Updated Thermal Rating: on line 2815-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41796
% INFO    : Updated Thermal Rating: on line 4125-1644 : Rate A, Rate B, Rate C , 1743.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 163-3498 : Rate B, Rate C , 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 163-2430 : Rate B, Rate C , 0.0, 0.0 -> 1528
% INFO    : Updated Thermal Rating: on line 7943-9108 : Rate B, Rate C , 0.0, 0.0 -> 8334
% INFO    : Updated Thermal Rating: on line 7943-1478 : Rate B, Rate C , 0.0, 0.0 -> 8174
% INFO    : Updated Thermal Rating: on line 2308-3541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5453
% INFO    : Updated Thermal Rating: on line 3535-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5552
% INFO    : Updated Thermal Rating: on line 2019-8542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21943
% INFO    : Updated Thermal Rating: on line 5174-8542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22129
% INFO    : Updated Thermal Rating: on line 7945-5215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9325
% INFO    : Updated Thermal Rating: on line 2057-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18132
% INFO    : Updated Thermal Rating: on line 2057-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18519
% INFO    : Updated Thermal Rating: on line 4661-6816 : Rate B, Rate C , 0.0, 0.0 -> 996
% INFO    : Updated Thermal Rating: on line 7519-776 : Rate B, Rate C , 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 8989-3435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65948
% INFO    : Updated Thermal Rating: on line 7797-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65948
% INFO    : Updated Thermal Rating: on line 871-4031 : Rate B, Rate C , 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 871-2878 : Rate B, Rate C , 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 7353-9164 : Rate B, Rate C , 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 7974-2012 : Rate B, Rate C , 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 7974-2012 : Rate B, Rate C , 0.0, 0.0 -> 2132
% INFO    : Updated Thermal Rating: on line 7974-1750 : Rate B, Rate C , 0.0, 0.0 -> 3105
% INFO    : Updated Thermal Rating: on line 1401-2303 : Rate B, Rate C , 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 4504-7903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 5837-449 : Rate B, Rate C , 0.0, 0.0 -> 3535
% INFO    : Updated Thermal Rating: on line 5837-449 : Rate B, Rate C , 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 5837-1817 : Rate A, Rate B, Rate C , 1578.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 5837-2458 : Rate B, Rate C , 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 5837-6427 : Rate B, Rate C , 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 5837-1730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 9217-594 : Rate B, Rate C , 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on line 6351-5393 : Rate B, Rate C , 0.0, 0.0 -> 7699
% INFO    : Updated Thermal Rating: on line 6194-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 2503-7491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 4031-2872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7474
% INFO    : Updated Thermal Rating: on line 4031-8043 : Rate B, Rate C , 0.0, 0.0 -> 1667
% INFO    : Updated Thermal Rating: on line 1813-2866 : Rate B, Rate C , 0.0, 0.0 -> 1824
% INFO    : Updated Thermal Rating: on line 5365-5417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 5365-4100 : Rate B, Rate C , 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 5365-1556 : Rate B, Rate C , 0.0, 0.0 -> 55676
% INFO    : Updated Thermal Rating: on line 3894-3865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on line 128-1554 : Rate B, Rate C , 0.0, 0.0 -> 19092
% INFO    : Updated Thermal Rating: on line 198-7994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2671
% INFO    : Updated Thermal Rating: on line 198-1554 : Rate B, Rate C , 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 2985-3133 : Rate B, Rate C , 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 7316-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23827
% INFO    : Updated Thermal Rating: on line 6486-8992 : Rate B, Rate C , 0.0, 0.0 -> 2371
% INFO    : Updated Thermal Rating: on line 8485-594 : Rate B, Rate C , 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 682-8477 : Rate B, Rate C , 0.0, 0.0 -> 7532
% INFO    : Updated Thermal Rating: on line 5146-5488 : Rate B, Rate C , 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 6638-776 : Rate B, Rate C , 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 8788-789 : Rate B, Rate C , 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 6332-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5705
% INFO    : Updated Thermal Rating: on line 6332-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5809
% INFO    : Updated Thermal Rating: on line 1883-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 1883-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 171-2341 : Rate B, Rate C , 0.0, 0.0 -> 2364
% INFO    : Updated Thermal Rating: on line 6630-10 : Rate B, Rate C , 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 4484-4239 : Rate B, Rate C , 0.0, 0.0 -> 19365
% INFO    : Updated Thermal Rating: on line 3044-4235 : Rate B, Rate C , 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 851-4454 : Rate B, Rate C , 0.0, 0.0 -> 3535
% INFO    : Updated Thermal Rating: on line 3485-2183 : Rate B, Rate C , 0.0, 0.0 -> 11041
% INFO    : Updated Thermal Rating: on line 1156-7923 : Rate B, Rate C , 0.0, 0.0 -> 3479
% INFO    : Updated Thermal Rating: on line 1156-1233 : Rate B, Rate C , 0.0, 0.0 -> 80052
% INFO    : Updated Thermal Rating: on line 8913-4852 : Rate B, Rate C , 0.0, 0.0 -> 3446
% INFO    : Updated Thermal Rating: on line 4039-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70621
% INFO    : Updated Thermal Rating: on line 4914-2653 : Rate B, Rate C , 0.0, 0.0 -> 59321
% INFO    : Updated Thermal Rating: on line 4914-2653 : Rate B, Rate C , 0.0, 0.0 -> 62899
% INFO    : Updated Thermal Rating: on line 4914-556 : Rate B, Rate C , 0.0, 0.0 -> 8170
% INFO    : Updated Thermal Rating: on line 4914-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11052
% INFO    : Updated Thermal Rating: on line 7994-5256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 1709-3346 : Rate B, Rate C , 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 1709-8468 : Rate B, Rate C , 0.0, 0.0 -> 3639
% INFO    : Updated Thermal Rating: on line 7702-1234 : Rate B, Rate C , 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 7702-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 8677-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 8189-3643 : Rate B, Rate C , 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 3133-8477 : Rate B, Rate C , 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 6744-6101 : Rate B, Rate C , 0.0, 0.0 -> 2551
% INFO    : Updated Thermal Rating: on line 8542-4313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17353
% INFO    : Updated Thermal Rating: on line 769-5233 : Rate B, Rate C , 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 1965-5926 : Rate B, Rate C , 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 9014-3999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21842
% INFO    : Updated Thermal Rating: on line 1917-8406 : Rate B, Rate C , 0.0, 0.0 -> 11385
% INFO    : Updated Thermal Rating: on line 1917-2021 : Rate B, Rate C , 0.0, 0.0 -> 11989
% INFO    : Updated Thermal Rating: on line 1917-8293 : Rate B, Rate C , 0.0, 0.0 -> 2601
% INFO    : Updated Thermal Rating: on line 4738-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 867
% INFO    : Updated Thermal Rating: on line 4738-8477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3636
% INFO    : Updated Thermal Rating: on line 7998-1644 : Rate B, Rate C , 0.0, 0.0 -> 4432
% INFO    : Updated Thermal Rating: on line 6734-1015 : Rate B, Rate C , 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 6734-8992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 6734-789 : Rate B, Rate C , 0.0, 0.0 -> 2512
% INFO    : Updated Thermal Rating: on line 5004-5393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17113
% INFO    : Updated Thermal Rating: on line 1708-3906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73380
% INFO    : Updated Thermal Rating: on line 9150-3906 : Rate B, Rate C , 0.0, 0.0 -> 78748
% INFO    : Updated Thermal Rating: on line 280-9158 : Rate B, Rate C , 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 8043-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 5712-8992 : Rate B, Rate C , 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 5712-8466 : Rate B, Rate C , 0.0, 0.0 -> 9920
% INFO    : Updated Thermal Rating: on line 5712-6880 : Rate B, Rate C , 0.0, 0.0 -> 10368
% INFO    : Updated Thermal Rating: on line 5215-7266 : Rate B, Rate C , 0.0, 0.0 -> 5338
% INFO    : Updated Thermal Rating: on line 8807-8992 : Rate B, Rate C , 0.0, 0.0 -> 4978
% INFO    : Updated Thermal Rating: on line 8807-8992 : Rate B, Rate C , 0.0, 0.0 -> 4887
% INFO    : Updated Thermal Rating: on line 8807-8992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6219
% INFO    : Updated Thermal Rating: on line 218-2088 : Rate B, Rate C , 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on line 520-5918 : Rate B, Rate C , 0.0, 0.0 -> 1999
% INFO    : Updated Thermal Rating: on line 2653-2128 : Rate B, Rate C , 0.0, 0.0 -> 36817
% INFO    : Updated Thermal Rating: on line 1216-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55045
% INFO    : Updated Thermal Rating: on line 8980-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13915
% INFO    : Updated Thermal Rating: on line 5212-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14137
% INFO    : Updated Thermal Rating: on line 3656-4060 : Rate B, Rate C , 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 883-3331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 5144-3346 : Rate A, Rate B, Rate C , 1447.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 3498-2563 : Rate B, Rate C , 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 1896-8200 : Rate B, Rate C , 0.0, 0.0 -> 29948
% INFO    : Updated Thermal Rating: on line 9130-8864 : Rate B, Rate C , 0.0, 0.0 -> 1805
% INFO    : Updated Thermal Rating: on line 3503-2510 : Rate B, Rate C , 0.0, 0.0 -> 2962
% INFO    : Updated Thermal Rating: on line 3503-6146 : Rate B, Rate C , 0.0, 0.0 -> 4121
% INFO    : Updated Thermal Rating: on line 401-1584 : Rate B, Rate C , 0.0, 0.0 -> 102150
% INFO    : Updated Thermal Rating: on line 7328-6921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 7328-6921 : Rate A, Rate B, Rate C , 1644.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 6816-5573 : Rate B, Rate C , 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 7396-8564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62614
% INFO    : Updated Thermal Rating: on line 7396-8564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63968
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 3095
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 4173
% INFO    : Updated Thermal Rating: on line 6921-432 : Rate B, Rate C , 0.0, 0.0 -> 4092
% INFO    : Updated Thermal Rating: on line 6921-8200 : Rate A, Rate B, Rate C , 1545.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 2949-3121 : Rate B, Rate C , 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 2949-3121 : Rate B, Rate C , 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 953-1730 : Rate B, Rate C , 0.0, 0.0 -> 2312
% INFO    : Updated Thermal Rating: on line 1767-892 : Rate B, Rate C , 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 4674-4889 : Rate B, Rate C , 0.0, 0.0 -> 6553
% INFO    : Updated Thermal Rating: on line 4674-7076 : Rate B, Rate C , 0.0, 0.0 -> 28567
% INFO    : Updated Thermal Rating: on line 1234-8035 : Rate B, Rate C , 0.0, 0.0 -> 5032
% INFO    : Updated Thermal Rating: on line 115-225 : Rate B, Rate C , 0.0, 0.0 -> 8039
% INFO    : Updated Thermal Rating: on line 5720-8578 : Rate B, Rate C , 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 3579-5469 : Rate B, Rate C , 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 3246-124 : Rate B, Rate C , 0.0, 0.0 -> 28416
% INFO    : Updated Thermal Rating: on line 8846-4783 : Rate B, Rate C , 0.0, 0.0 -> 28923
% INFO    : Updated Thermal Rating: on line 2393-3306 : Rate B, Rate C , 0.0, 0.0 -> 35458
% INFO    : Updated Thermal Rating: on line 1895-4480 : Rate B, Rate C , 0.0, 0.0 -> 35026
% INFO    : Updated Thermal Rating: on line 678-4454 : Rate B, Rate C , 0.0, 0.0 -> 28133
% INFO    : Updated Thermal Rating: on line 1002-4852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11613
% INFO    : Updated Thermal Rating: on line 6429-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8540
% INFO    : Updated Thermal Rating: on line 4889-7076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11440
% INFO    : Updated Thermal Rating: on line 5341-7491 : Rate B, Rate C , 0.0, 0.0 -> 6226
% INFO    : Updated Thermal Rating: on line 2563-6521 : Rate B, Rate C , 0.0, 0.0 -> 37622
% INFO    : Updated Thermal Rating: on line 1111-594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2494
% INFO    : Updated Thermal Rating: on line 4747-7791 : Rate B, Rate C , 0.0, 0.0 -> 4005
% INFO    : Updated Thermal Rating: on line 3906-3022 : Rate B, Rate C , 0.0, 0.0 -> 5690
% INFO    : Updated Thermal Rating: on line 3906-1194 : Rate B, Rate C , 0.0, 0.0 -> 5036
% INFO    : Updated Thermal Rating: on line 5993-8804 : Rate B, Rate C , 0.0, 0.0 -> 2911
% INFO    : Updated Thermal Rating: on line 1798-8487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5304
% INFO    : Updated Thermal Rating: on line 2467-7178 : Rate B, Rate C , 0.0, 0.0 -> 2142
% INFO    : Updated Thermal Rating: on line 2132-2303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 8992-8466 : Rate B, Rate C , 0.0, 0.0 -> 2819
% INFO    : Updated Thermal Rating: on line 8992-6880 : Rate B, Rate C , 0.0, 0.0 -> 3102
% INFO    : Updated Thermal Rating: on line 8992-2995 : Rate B, Rate C , 0.0, 0.0 -> 2211
% INFO    : Updated Thermal Rating: on line 805-3221 : Rate B, Rate C , 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 805-3327 : Rate B, Rate C , 0.0, 0.0 -> 2203
% INFO    : Updated Thermal Rating: on line 805-8310 : Rate B, Rate C , 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 805-2088 : Rate B, Rate C , 0.0, 0.0 -> 4025
% INFO    : Updated Thermal Rating: on line 5383-2021 : Rate B, Rate C , 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 5383-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9353
% INFO    : Updated Thermal Rating: on line 5383-5519 : Rate B, Rate C , 0.0, 0.0 -> 8632
% INFO    : Updated Thermal Rating: on line 5383-8293 : Rate B, Rate C , 0.0, 0.0 -> 7757
% INFO    : Updated Thermal Rating: on line 5383-3435 : Rate B, Rate C , 0.0, 0.0 -> 3571
% INFO    : Updated Thermal Rating: on line 7507-6990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10003
% INFO    : Updated Thermal Rating: on line 7507-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7874
% INFO    : Updated Thermal Rating: on line 7507-2020 : Rate B, Rate C , 0.0, 0.0 -> 3199
% INFO    : Updated Thermal Rating: on line 6478-6146 : Rate B, Rate C , 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 4852-2695 : Rate B, Rate C , 0.0, 0.0 -> 3390
% INFO    : Updated Thermal Rating: on line 4852-2695 : Rate B, Rate C , 0.0, 0.0 -> 3259
% INFO    : Updated Thermal Rating: on line 4852-5502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3517
% INFO    : Updated Thermal Rating: on line 4852-8877 : Rate B, Rate C , 0.0, 0.0 -> 6356
% INFO    : Updated Thermal Rating: on line 4852-9119 : Rate B, Rate C , 0.0, 0.0 -> 5658
% INFO    : Updated Thermal Rating: on line 4852-1151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5280
% INFO    : Updated Thermal Rating: on line 2012-1750 : Rate B, Rate C , 0.0, 0.0 -> 7030
% INFO    : Updated Thermal Rating: on line 1478-6616 : Rate B, Rate C , 0.0, 0.0 -> 2394
% INFO    : Updated Thermal Rating: on line 809-4594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2190
% INFO    : Updated Thermal Rating: on line 8656-4729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30397
% INFO    : Updated Thermal Rating: on line 4100-615 : Rate B, Rate C , 0.0, 0.0 -> 11773
% INFO    : Updated Thermal Rating: on line 4060-5393 : Rate B, Rate C , 0.0, 0.0 -> 6861
% INFO    : Updated Thermal Rating: on transformer 9203-2426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on transformer 9203-2426 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 118-2426 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 3145-7770 : Rate B, Rate C , 0.0, 0.0 -> 1336
% INFO    : Updated Thermal Rating: on transformer 7267-4918 : Rate B, Rate C , 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 7267-4918 : Rate B, Rate C , 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on transformer 839-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on transformer 839-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on transformer 3445-6114 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3445-6114 : Rate B, Rate C , 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on transformer 3445-7264 : Rate B, Rate C , 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 891-6306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on transformer 720-1711 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 720-1711 : Rate B, Rate C , 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on transformer 6206-3240 : Rate B, Rate C , 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on transformer 6206-3240 : Rate B, Rate C , 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on transformer 9174-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 9174-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 1355-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on transformer 1355-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 1355-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on transformer 3205-4683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on transformer 3205-4683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on transformer 5350-2361 : Rate B, Rate C , 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on transformer 5350-2361 : Rate B, Rate C , 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on transformer 5016-6112 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 5016-8860 : Rate B, Rate C , 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 7471-549 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 7471-549 : Rate B, Rate C , 0.0, 0.0 -> 1122
% INFO    : Updated Thermal Rating: on transformer 549-5002 : Rate B, Rate C , 0.0, 0.0 -> 3435
% INFO    : Updated Thermal Rating: on transformer 5490-3817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on transformer 2854-9112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on transformer 2918-6532 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 2918-6532 : Rate B, Rate C , 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 4494-7284 : Rate B, Rate C , 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 2656-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on transformer 3519-5641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on transformer 3543-367 : Rate B, Rate C , 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 3543-1833 : Rate B, Rate C , 0.0, 0.0 -> 1410
% INFO    : Updated Thermal Rating: on transformer 2372-367 : Rate B, Rate C , 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on transformer 2372-367 : Rate B, Rate C , 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 1876-7752 : Rate B, Rate C , 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on transformer 113-7752 : Rate B, Rate C , 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on transformer 3499-7289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on transformer 3499-7289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on transformer 3082-2083 : Rate B, Rate C , 0.0, 0.0 -> 1099
% INFO    : Updated Thermal Rating: on transformer 6224-2083 : Rate B, Rate C , 0.0, 0.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 2174-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 4623-1609 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4623-1609 : Rate B, Rate C , 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on transformer 4623-1609 : Rate B, Rate C , 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate B, Rate C , 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on transformer 5589-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on transformer 1198-7473 : Rate B, Rate C , 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on transformer 1198-7473 : Rate B, Rate C , 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on transformer 2479-5482 : Rate B, Rate C , 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 2479-5482 : Rate B, Rate C , 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 7831-5525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on transformer 7831-5525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on transformer 7831-5525 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 4970-7955 : Rate B, Rate C , 0.0, 0.0 -> 1308
% INFO    : Updated Thermal Rating: on transformer 4970-7955 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 5007-7367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on transformer 757-3758 : Rate B, Rate C , 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate B, Rate C , 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on transformer 3697-6952 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 6738-8180 : Rate B, Rate C , 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 6738-8180 : Rate B, Rate C , 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on transformer 9222-5935 : Rate B, Rate C , 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on transformer 7988-804 : Rate B, Rate C , 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on transformer 7988-804 : Rate B, Rate C , 0.0, 0.0 -> 1234
% INFO    : Updated Thermal Rating: on transformer 3239-1539 : Rate B, Rate C , 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on transformer 3239-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on transformer 2056-4084 : Rate B, Rate C , 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on transformer 2056-4084 : Rate B, Rate C , 0.0, 0.0 -> 1154
% INFO    : Updated Thermal Rating: on transformer 4598-5110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on transformer 2129-5110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on transformer 5658-5550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on transformer 5658-5550 : Rate B, Rate C , 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 2848-1526 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 4541-7464 : Rate B, Rate C , 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on transformer 4541-7464 : Rate B, Rate C , 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on transformer 1754-3857 : Rate B, Rate C , 0.0, 0.0 -> 1080
% INFO    : Updated Thermal Rating: on transformer 1754-3857 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 1754-3857 : Rate B, Rate C , 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on transformer 2518-4544 : Rate B, Rate C , 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 2518-4544 : Rate B, Rate C , 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on transformer 3069-6115 : Rate B, Rate C , 0.0, 0.0 -> 3546
% INFO    : Updated Thermal Rating: on transformer 5067-7641 : Rate B, Rate C , 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on transformer 6036-8670 : Rate B, Rate C , 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on transformer 6036-5522 : Rate B, Rate C , 0.0, 0.0 -> 1179
% INFO    : Updated Thermal Rating: on transformer 8486-8791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on transformer 7530-8791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on transformer 7522-7571 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 7522-7571 : Rate B, Rate C , 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on transformer 7522-7571 : Rate B, Rate C , 0.0, 0.0 -> 1124
% INFO    : Updated Thermal Rating: on transformer 2526-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on transformer 2365-8316 : Rate B, Rate C , 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 8672-1860 : Rate B, Rate C , 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 8672-1860 : Rate B, Rate C , 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on transformer 1494-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on transformer 1494-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on transformer 1502-2795 : Rate B, Rate C , 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 8195-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on transformer 8195-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on transformer 8195-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 3918-6802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 3918-4025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 721
% INFO    : Updated Thermal Rating: on transformer 4435-2079 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 4435-2079 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 4435-2079 : Rate B, Rate C , 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on transformer 1081-7361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on transformer 9101-2177 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 6555-8475 : Rate B, Rate C , 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on transformer 6555-8475 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 7056-7577 : Rate B, Rate C , 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on transformer 7056-7577 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 7056-9051 : Rate B, Rate C , 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on transformer 6889-6785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on transformer 6889-6785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on transformer 6889-6785 : Rate B, Rate C , 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on transformer 1027-7148 : Rate B, Rate C , 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 1027-44 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 5308-7148 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 5308-44 : Rate B, Rate C , 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on transformer 9213-6231 : Rate B, Rate C , 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on transformer 9213-8291 : Rate B, Rate C , 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on transformer 9213-6842 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 3608-6664 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 4339-6570 : Rate B, Rate C , 0.0, 0.0 -> 1339
% INFO    : Updated Thermal Rating: on transformer 4339-6570 : Rate B, Rate C , 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on transformer 7513-6570 : Rate B, Rate C , 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 7513-6570 : Rate B, Rate C , 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on transformer 8887-6639 : Rate B, Rate C , 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 8887-6639 : Rate B, Rate C , 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on transformer 5461-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 5461-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on transformer 5461-4816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on transformer 5460-3786 : Rate B, Rate C , 0.0, 0.0 -> 1214
% INFO    : Updated Thermal Rating: on transformer 5460-3786 : Rate B, Rate C , 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 7256-4491 : Rate B, Rate C , 0.0, 0.0 -> 2824
% INFO    : Updated Thermal Rating: on transformer 6153-58 : Rate B, Rate C , 0.0, 0.0 -> 4652
% INFO    : Updated Thermal Rating: on transformer 6153-6807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on transformer 1465-1262 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1465-1262 : Rate B, Rate C , 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 1465-1551 : Rate B, Rate C , 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 7537-1551 : Rate B, Rate C , 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 7537-1551 : Rate B, Rate C , 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on transformer 6901-4874 : Rate B, Rate C , 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on transformer 5241-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on transformer 7520-561 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on transformer 749-4324 : Rate B, Rate C , 0.0, 0.0 -> 1382
% INFO    : Updated Thermal Rating: on transformer 4141-7124 : Rate B, Rate C , 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on transformer 4141-7124 : Rate B, Rate C , 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on transformer 7466-3649 : Rate B, Rate C , 0.0, 0.0 -> 3016
% INFO    : Updated Thermal Rating: on transformer 8222-6556 : Rate B, Rate C , 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on transformer 8222-6556 : Rate B, Rate C , 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on transformer 8222-6556 : Rate B, Rate C , 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on transformer 4125-163 : Rate B, Rate C , 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 4125-163 : Rate B, Rate C , 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on transformer 4125-163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on transformer 5837-9217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 5837-1448 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 5837-1448 : Rate B, Rate C , 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on transformer 8267-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 8267-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 2359-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on transformer 2359-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on transformer 8109-171 : Rate B, Rate C , 0.0, 0.0 -> 1204
% INFO    : Updated Thermal Rating: on transformer 8109-171 : Rate B, Rate C , 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on transformer 3485-1156 : Rate B, Rate C , 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on transformer 4734-2229 : Rate B, Rate C , 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 1709-7702 : Rate B, Rate C , 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on transformer 1709-7702 : Rate B, Rate C , 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 905-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 8334-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on transformer 8334-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 7998-6734 : Rate B, Rate C , 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 4196-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on transformer 4196-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on transformer 6475-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 6475-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 7328-4235 : Rate B, Rate C , 0.0, 0.0 -> 1137
% INFO    : Updated Thermal Rating: on transformer 7328-4235 : Rate B, Rate C , 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on transformer 7328-4235 : Rate B, Rate C , 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 6921-2949 : Rate B, Rate C , 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on transformer 6921-2949 : Rate B, Rate C , 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on transformer 3830-306 : Rate B, Rate C , 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on transformer 5648-306 : Rate B, Rate C , 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on transformer 1730-115 : Rate B, Rate C , 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 1730-115 : Rate B, Rate C , 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on transformer 2721-5720 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 2721-5720 : Rate B, Rate C , 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 432-3246 : Rate B, Rate C , 0.0, 0.0 -> 2432
% INFO    : Updated Thermal Rating: on transformer 432-8846 : Rate B, Rate C , 0.0, 0.0 -> 2483
% INFO    : Updated Thermal Rating: on transformer 432-2393 : Rate B, Rate C , 0.0, 0.0 -> 2533
% INFO    : Updated Thermal Rating: on transformer 432-1895 : Rate B, Rate C , 0.0, 0.0 -> 2588
% INFO    : Updated Thermal Rating: on transformer 432-3412 : Rate B, Rate C , 0.0, 0.0 -> 2447
% INFO    : Updated Thermal Rating: on transformer 432-5586 : Rate B, Rate C , 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on transformer 432-3112 : Rate B, Rate C , 0.0, 0.0 -> 2207
% INFO    : Updated Thermal Rating: on transformer 432-3112 : Rate B, Rate C , 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on transformer 432-7857 : Rate B, Rate C , 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 960-8497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 960-8497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 3577-5907 : Rate B, Rate C , 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 3577-5907 : Rate B, Rate C , 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 3577-5907 : Rate B, Rate C , 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 7164-5918 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 7164-5918 : Rate B, Rate C , 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on transformer 1798-2467 : Rate B, Rate C , 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 1798-2467 : Rate B, Rate C , 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on transformer 3346-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 3346-2132 : Rate B, Rate C , 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on transformer 3346-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 792
% INFO    : Updated Thermal Rating: on transformer 3483-8992 : Rate B, Rate C , 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on transformer 8886-8992 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 2093-805 : Rate B, Rate C , 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 2093-805 : Rate B, Rate C , 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on transformer 221-1541 : Rate B, Rate C , 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 8347-5383 : Rate B, Rate C , 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on transformer 8347-5383 : Rate B, Rate C , 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 8347-5383 : Rate B, Rate C , 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8347-7507 : Rate B, Rate C , 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on transformer 8347-7507 : Rate B, Rate C , 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on transformer 8347-7507 : Rate B, Rate C , 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on transformer 4000-4852 : Rate B, Rate C , 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 4000-2012 : Rate B, Rate C , 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 2183-4852 : Rate B, Rate C , 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 2183-2012 : Rate B, Rate C , 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on transformer 1642-7098 : Rate B, Rate C , 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 1642-687 : Rate B, Rate C , 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on transformer 809-7098 : Rate B, Rate C , 0.0, 0.0 -> 1144
% INFO    : Updated Thermal Rating: on transformer 809-687 : Rate B, Rate C , 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on transformer 4594-8804 : Rate B, Rate C , 0.0, 0.0 -> 1220
% INFO    : Updated Thermal Rating: on transformer 4594-8804 : Rate B, Rate C , 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on transformer 2919-4215 : Rate B, Rate C , 0.0, 0.0 -> 1178
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 3	: V=1.016674, theta=-21.761632 -> V=1.0, theta=0.0
% INFO    : Bus 4	: V=1.026472, theta=-7.007354 -> V=1.0, theta=0.0
% INFO    : Bus 10	: V=1.038534, theta=-24.281644 -> V=1.0, theta=0.0
% INFO    : Bus 21	: V=1.036195, theta=-21.958828 -> V=1.0, theta=0.0
% INFO    : Bus 22	: V=1.035058, theta=-18.483339 -> V=1.0, theta=0.0
% INFO    : Bus 26	: V=1.032267, theta=-3.318448 -> V=1.0, theta=0.0
% INFO    : Bus 29	: V=0.994409, theta=-13.816418 -> V=1.0, theta=0.0
% INFO    : Bus 44	: V=1.045829, theta=-22.181066 -> V=1.0, theta=0.0
% INFO    : Bus 53	: V=1.063422, theta=-9.070013 -> V=1.0, theta=0.0
% INFO    : Bus 58	: V=0.983702, theta=-21.159412 -> V=1.0, theta=0.0
% INFO    : Bus 59	: V=1.036808, theta=-23.631999 -> V=1.0, theta=0.0
% INFO    : Bus 90	: V=1.042187, theta=-27.546292 -> V=1.0, theta=0.0
% INFO    : Bus 96	: V=1.030441, theta=-15.689479 -> V=1.0, theta=0.0
% INFO    : Bus 113	: V=1.030718, theta=-14.242909 -> V=1.0, theta=0.0
% INFO    : Bus 115	: V=1.066797, theta=-19.783678 -> V=1.0, theta=0.0
% INFO    : Bus 118	: V=1.020256, theta=-11.430028 -> V=1.0, theta=0.0
% INFO    : Bus 124	: V=1.081537, theta=8.330657 -> V=1.0, theta=0.0
% INFO    : Bus 128	: V=1.020482, theta=-16.063366 -> V=1.0, theta=0.0
% INFO    : Bus 145	: V=1.039096, theta=-8.903623 -> V=1.0, theta=0.0
% INFO    : Bus 148	: V=1.041568, theta=-7.991267 -> V=1.0, theta=0.0
% INFO    : Bus 150	: V=1.062805, theta=2.531831 -> V=1.0, theta=0.0
% INFO    : Bus 163	: V=1.047047, theta=-10.672351 -> V=1.0, theta=0.0
% INFO    : Bus 171	: V=1.069649, theta=-25.153324 -> V=1.0, theta=0.0
% INFO    : Bus 174	: V=1.074846, theta=-27.942789 -> V=1.0, theta=0.0
% INFO    : Bus 184	: V=1.042771, theta=-11.94851 -> V=1.0, theta=0.0
% INFO    : Bus 188	: V=1.018752, theta=-19.550413 -> V=1.0, theta=0.0
% INFO    : Bus 195	: V=1.056337, theta=-8.791116 -> V=1.0, theta=0.0
% INFO    : Bus 196	: V=1.074825, theta=-26.319857 -> V=1.0, theta=0.0
% INFO    : Bus 198	: V=1.01673, theta=-16.306681 -> V=1.0, theta=0.0
% INFO    : Bus 207	: V=1.026604, theta=-13.457588 -> V=1.0, theta=0.0
% INFO    : Bus 216	: V=1.039362, theta=-24.590496 -> V=1.0, theta=0.0
% INFO    : Bus 217	: V=1.042762, theta=-2.603638 -> V=1.0, theta=0.0
% INFO    : Bus 218	: V=1.045923, theta=-13.114892 -> V=1.0, theta=0.0
% INFO    : Bus 221	: V=0.984682, theta=-21.807603 -> V=1.0, theta=0.0
% INFO    : Bus 225	: V=1.063761, theta=-20.174043 -> V=1.0, theta=0.0
% INFO    : Bus 280	: V=1.035725, theta=-11.193679 -> V=1.0, theta=0.0
% INFO    : Bus 283	: V=1.035204, theta=-12.094637 -> V=1.0, theta=0.0
% INFO    : Bus 292	: V=1.047544, theta=-14.765137 -> V=1.0, theta=0.0
% INFO    : Bus 305	: V=1.067188, theta=-32.434719 -> V=1.0, theta=0.0
% INFO    : Bus 306	: V=1.030032, theta=-18.823594 -> V=1.0, theta=0.0
% INFO    : Bus 314	: V=1.005548, theta=-16.020947 -> V=1.0, theta=0.0
% INFO    : Bus 333	: V=1.014579, theta=-42.137692 -> V=1.0, theta=0.0
% INFO    : Bus 338	: V=1.048249, theta=-6.162533 -> V=1.0, theta=0.0
% INFO    : Bus 346	: V=1.040694, theta=-21.298393 -> V=1.0, theta=0.0
% INFO    : Bus 350	: V=1.043185, theta=-24.295117 -> V=1.0, theta=0.0
% INFO    : Bus 352	: V=1.055378, theta=0.262953 -> V=1.0, theta=0.0
% INFO    : Bus 367	: V=1.07164, theta=-23.599251 -> V=1.0, theta=0.0
% INFO    : Bus 401	: V=1.026548, theta=-14.262083 -> V=1.0, theta=0.0
% INFO    : Bus 408	: V=1.039791, theta=-11.549917 -> V=1.0, theta=0.0
% INFO    : Bus 410	: V=1.041564, theta=-26.439994 -> V=1.0, theta=0.0
% INFO    : Bus 413	: V=1.05013, theta=-6.606455 -> V=1.0, theta=0.0
% INFO    : Bus 416	: V=1.0458, theta=-6.728632 -> V=1.0, theta=0.0
% INFO    : Bus 426	: V=1.040489, theta=-18.395441 -> V=1.0, theta=0.0
% INFO    : Bus 432	: V=1.047774, theta=2.403578 -> V=1.0, theta=0.0
% INFO    : Bus 444	: V=1.036267, theta=-12.201434 -> V=1.0, theta=0.0
% INFO    : Bus 449	: V=1.021739, theta=-8.489958 -> V=1.0, theta=0.0
% INFO    : Bus 453	: V=1.018914, theta=-7.857046 -> V=1.0, theta=0.0
% INFO    : Bus 455	: V=1.045882, theta=-30.596498 -> V=1.0, theta=0.0
% INFO    : Bus 490	: V=1.036451, theta=-23.014287 -> V=1.0, theta=0.0
% INFO    : Bus 500	: V=1.040423, theta=-15.042452 -> V=1.0, theta=0.0
% INFO    : Bus 502	: V=1.043564, theta=-6.675538 -> V=1.0, theta=0.0
% INFO    : Bus 506	: V=1.063297, theta=-9.078728 -> V=1.0, theta=0.0
% INFO    : Bus 513	: V=1.038461, theta=-7.443414 -> V=1.0, theta=0.0
% INFO    : Bus 516	: V=1.075592, theta=-33.453515 -> V=1.0, theta=0.0
% INFO    : Bus 520	: V=1.048239, theta=-27.108761 -> V=1.0, theta=0.0
% INFO    : Bus 549	: V=1.074517, theta=-10.959606 -> V=1.0, theta=0.0
% INFO    : Bus 554	: V=1.024071, theta=-20.793083 -> V=1.0, theta=0.0
% INFO    : Bus 556	: V=1.03694, theta=-22.762979 -> V=1.0, theta=0.0
% INFO    : Bus 561	: V=1.055451, theta=-11.021763 -> V=1.0, theta=0.0
% INFO    : Bus 564	: V=1.069817, theta=-47.078276 -> V=1.0, theta=0.0
% INFO    : Bus 575	: V=1.04436, theta=-11.163788 -> V=1.0, theta=0.0
% INFO    : Bus 583	: V=1.045397, theta=-15.568574 -> V=1.0, theta=0.0
% INFO    : Bus 594	: V=1.036683, theta=-8.869667 -> V=1.0, theta=0.0
% INFO    : Bus 601	: V=1.040685, theta=-14.418335 -> V=1.0, theta=0.0
% INFO    : Bus 604	: V=0.996939, theta=-12.93567 -> V=1.0, theta=0.0
% INFO    : Bus 608	: V=1.071753, theta=-32.66829 -> V=1.0, theta=0.0
% INFO    : Bus 609	: V=1.025344, theta=-14.779536 -> V=1.0, theta=0.0
% INFO    : Bus 615	: V=1.063876, theta=-10.607341 -> V=1.0, theta=0.0
% INFO    : Bus 616	: V=1.048713, theta=-12.997468 -> V=1.0, theta=0.0
% INFO    : Bus 619	: V=1.046742, theta=-25.252227 -> V=1.0, theta=0.0
% INFO    : Bus 639	: V=1.051376, theta=-29.999643 -> V=1.0, theta=0.0
% INFO    : Bus 641	: V=1.03515, theta=-13.956622 -> V=1.0, theta=0.0
% INFO    : Bus 658	: V=1.033849, theta=-17.442414 -> V=1.0, theta=0.0
% INFO    : Bus 661	: V=1.040021, theta=2.414523 -> V=1.0, theta=0.0
% INFO    : Bus 666	: V=1.03076, theta=-5.413919 -> V=1.0, theta=0.0
% INFO    : Bus 678	: V=0.986375, theta=-18.62447 -> V=1.0, theta=0.0
% INFO    : Bus 682	: V=1.0691, theta=-10.045044 -> V=1.0, theta=0.0
% INFO    : Bus 687	: V=1.05742, theta=-4.068613 -> V=1.0, theta=0.0
% INFO    : Bus 707	: V=1.054495, theta=-25.620212 -> V=1.0, theta=0.0
% INFO    : Bus 718	: V=1.031148, theta=-24.884639 -> V=1.0, theta=0.0
% INFO    : Bus 720	: V=0.981824, theta=-26.763103 -> V=1.0, theta=0.0
% INFO    : Bus 726	: V=1.048069, theta=-4.933448 -> V=1.0, theta=0.0
% INFO    : Bus 742	: V=1.05759, theta=-4.070122 -> V=1.0, theta=0.0
% INFO    : Bus 747	: V=1.073922, theta=-26.380554 -> V=1.0, theta=0.0
% INFO    : Bus 749	: V=1.057884, theta=-28.950791 -> V=1.0, theta=0.0
% INFO    : Bus 750	: V=1.041141, theta=-24.444747 -> V=1.0, theta=0.0
% INFO    : Bus 757	: V=1.017567, theta=-13.765564 -> V=1.0, theta=0.0
% INFO    : Bus 766	: V=1.047952, theta=-19.8489 -> V=1.0, theta=0.0
% INFO    : Bus 769	: V=1.024104, theta=-10.886119 -> V=1.0, theta=0.0
% INFO    : Bus 772	: V=1.034361, theta=-14.167643 -> V=1.0, theta=0.0
% INFO    : Bus 776	: V=1.026368, theta=-13.331099 -> V=1.0, theta=0.0
% INFO    : Bus 778	: V=1.049411, theta=-6.680953 -> V=1.0, theta=0.0
% INFO    : Bus 789	: V=1.051689, theta=-5.954643 -> V=1.0, theta=0.0
% INFO    : Bus 795	: V=1.035522, theta=-15.484388 -> V=1.0, theta=0.0
% INFO    : Bus 800	: V=1.034778, theta=-12.128589 -> V=1.0, theta=0.0
% INFO    : Bus 803	: V=1.041369, theta=-24.768342 -> V=1.0, theta=0.0
% INFO    : Bus 804	: V=1.05585, theta=-7.563603 -> V=1.0, theta=0.0
% INFO    : Bus 805	: V=1.05673, theta=-11.12828 -> V=1.0, theta=0.0
% INFO    : Bus 809	: V=1.027525, theta=-0.064839 -> V=1.0, theta=0.0
% INFO    : Bus 819	: V=1.052169, theta=-0.720463 -> V=1.0, theta=0.0
% INFO    : Bus 823	: V=1.044097, theta=-2.229251 -> V=1.0, theta=0.0
% INFO    : Bus 839	: V=1.024385, theta=-1.386321 -> V=1.0, theta=0.0
% INFO    : Bus 851	: V=1.00025, theta=-17.401395 -> V=1.0, theta=0.0
% INFO    : Bus 858	: V=1.031745, theta=1.110134 -> V=1.0, theta=0.0
% INFO    : Bus 870	: V=1.040762, theta=-24.602002 -> V=1.0, theta=0.0
% INFO    : Bus 871	: V=1.056945, theta=-11.955754 -> V=1.0, theta=0.0
% INFO    : Bus 883	: V=1.017176, theta=-10.133417 -> V=1.0, theta=0.0
% INFO    : Bus 891	: V=1.064525, theta=-18.97841 -> V=1.0, theta=0.0
% INFO    : Bus 892	: V=1.069234, theta=-34.99461 -> V=1.0, theta=0.0
% INFO    : Bus 900	: V=1.050278, theta=-15.385577 -> V=1.0, theta=0.0
% INFO    : Bus 903	: V=1.073885, theta=-26.405705 -> V=1.0, theta=0.0
% INFO    : Bus 905	: V=1.035643, theta=-15.075813 -> V=1.0, theta=0.0
% INFO    : Bus 907	: V=1.038555, theta=-9.767436 -> V=1.0, theta=0.0
% INFO    : Bus 908	: V=1.065214, theta=-7.929625 -> V=1.0, theta=0.0
% INFO    : Bus 920	: V=1.045537, theta=-20.769903 -> V=1.0, theta=0.0
% INFO    : Bus 923	: V=1.035596, theta=-23.090183 -> V=1.0, theta=0.0
% INFO    : Bus 933	: V=1.019946, theta=-21.525393 -> V=1.0, theta=0.0
% INFO    : Bus 935	: V=1.049182, theta=-24.470238 -> V=1.0, theta=0.0
% INFO    : Bus 953	: V=1.065973, theta=-13.014498 -> V=1.0, theta=0.0
% INFO    : Bus 954	: V=1.044324, theta=-21.525875 -> V=1.0, theta=0.0
% INFO    : Bus 960	: V=1.063295, theta=-9.078724 -> V=1.0, theta=0.0
% INFO    : Bus 964	: V=1.015553, theta=-11.659761 -> V=1.0, theta=0.0
% INFO    : Bus 972	: V=1.072621, theta=5.35893 -> V=1.0, theta=0.0
% INFO    : Bus 980	: V=1.047164, theta=-25.138433 -> V=1.0, theta=0.0
% INFO    : Bus 1001	: V=1.074143, theta=-33.62199 -> V=1.0, theta=0.0
% INFO    : Bus 1002	: V=1.041506, theta=-20.086455 -> V=1.0, theta=0.0
% INFO    : Bus 1005	: V=1.053955, theta=-12.379476 -> V=1.0, theta=0.0
% INFO    : Bus 1015	: V=1.056277, theta=-5.398682 -> V=1.0, theta=0.0
% INFO    : Bus 1026	: V=1.028182, theta=-29.352232 -> V=1.0, theta=0.0
% INFO    : Bus 1027	: V=0.990542, theta=-18.181223 -> V=1.0, theta=0.0
% INFO    : Bus 1033	: V=1.040934, theta=-24.521854 -> V=1.0, theta=0.0
% INFO    : Bus 1035	: V=1.067815, theta=-32.322562 -> V=1.0, theta=0.0
% INFO    : Bus 1039	: V=1.034441, theta=-19.543294 -> V=1.0, theta=0.0
% INFO    : Bus 1040	: V=1.038913, theta=-9.027471 -> V=1.0, theta=0.0
% INFO    : Bus 1043	: V=1.028946, theta=-3.693426 -> V=1.0, theta=0.0
% INFO    : Bus 1051	: V=1.041627, theta=-12.829065 -> V=1.0, theta=0.0
% INFO    : Bus 1077	: V=1.035206, theta=-12.094658 -> V=1.0, theta=0.0
% INFO    : Bus 1078	: V=1.061509, theta=-3.472987 -> V=1.0, theta=0.0
% INFO    : Bus 1081	: V=1.038644, theta=-10.509999 -> V=1.0, theta=0.0
% INFO    : Bus 1083	: V=1.049472, theta=-8.613737 -> V=1.0, theta=0.0
% INFO    : Bus 1090	: V=1.0101, theta=-21.692579 -> V=1.0, theta=0.0
% INFO    : Bus 1093	: V=1.027056, theta=-8.507308 -> V=1.0, theta=0.0
% INFO    : Bus 1096	: V=1.050189, theta=-1.116839 -> V=1.0, theta=0.0
% INFO    : Bus 1100	: V=1.042801, theta=-4.348181 -> V=1.0, theta=0.0
% INFO    : Bus 1101	: V=1.033508, theta=-14.209132 -> V=1.0, theta=0.0
% INFO    : Bus 1102	: V=1.049879, theta=-6.64195 -> V=1.0, theta=0.0
% INFO    : Bus 1105	: V=1.074759, theta=-26.325932 -> V=1.0, theta=0.0
% INFO    : Bus 1111	: V=1.036823, theta=-8.871578 -> V=1.0, theta=0.0
% INFO    : Bus 1129	: V=1.003325, theta=-22.532961 -> V=1.0, theta=0.0
% INFO    : Bus 1136	: V=1.034786, theta=-18.539009 -> V=1.0, theta=0.0
% INFO    : Bus 1137	: V=1.048666, theta=-24.42816 -> V=1.0, theta=0.0
% INFO    : Bus 1146	: V=1.032638, theta=-5.627486 -> V=1.0, theta=0.0
% INFO    : Bus 1151	: V=1.043354, theta=-20.606997 -> V=1.0, theta=0.0
% INFO    : Bus 1153	: V=1.034654, theta=-6.058841 -> V=1.0, theta=0.0
% INFO    : Bus 1156	: V=1.038055, theta=-22.501868 -> V=1.0, theta=0.0
% INFO    : Bus 1159	: V=1.052615, theta=-36.244174 -> V=1.0, theta=0.0
% INFO    : Bus 1172	: V=1.074468, theta=-25.55724 -> V=1.0, theta=0.0
% INFO    : Bus 1179	: V=1.040896, theta=-2.802576 -> V=1.0, theta=0.0
% INFO    : Bus 1183	: V=1.066643, theta=-33.081849 -> V=1.0, theta=0.0
% INFO    : Bus 1187	: V=1.039857, theta=-4.955282 -> V=1.0, theta=0.0
% INFO    : Bus 1188	: V=1.054495, theta=-14.222981 -> V=1.0, theta=0.0
% INFO    : Bus 1194	: V=1.03896, theta=-15.127161 -> V=1.0, theta=0.0
% INFO    : Bus 1198	: V=0.987964, theta=-14.637206 -> V=1.0, theta=0.0
% INFO    : Bus 1201	: V=1.050304, theta=-19.627666 -> V=1.0, theta=0.0
% INFO    : Bus 1216	: V=1.040626, theta=-10.966354 -> V=1.0, theta=0.0
% INFO    : Bus 1233	: V=1.037981, theta=-22.526704 -> V=1.0, theta=0.0
% INFO    : Bus 1234	: V=1.022628, theta=-16.524518 -> V=1.0, theta=0.0
% INFO    : Bus 1237	: V=1.108028, theta=-6.285992 -> V=1.0, theta=0.0
% INFO    : Bus 1248	: V=1.047205, theta=-10.673893 -> V=1.0, theta=0.0
% INFO    : Bus 1249	: V=1.019402, theta=-11.26449 -> V=1.0, theta=0.0
% INFO    : Bus 1251	: V=1.027102, theta=-8.516785 -> V=1.0, theta=0.0
% INFO    : Bus 1262	: V=1.038607, theta=-22.034538 -> V=1.0, theta=0.0
% INFO    : Bus 1265	: V=1.066705, theta=-50.057306 -> V=1.0, theta=0.0
% INFO    : Bus 1275	: V=1.032647, theta=-18.856368 -> V=1.0, theta=0.0
% INFO    : Bus 1295	: V=1.03682, theta=-8.643487 -> V=1.0, theta=0.0
% INFO    : Bus 1301	: V=1.05167, theta=-28.720012 -> V=1.0, theta=0.0
% INFO    : Bus 1305	: V=1.038253, theta=-22.269637 -> V=1.0, theta=0.0
% INFO    : Bus 1311	: V=1.033986, theta=-21.654604 -> V=1.0, theta=0.0
% INFO    : Bus 1326	: V=1.069384, theta=-34.995605 -> V=1.0, theta=0.0
% INFO    : Bus 1334	: V=1.025188, theta=-16.314102 -> V=1.0, theta=0.0
% INFO    : Bus 1341	: V=1.032899, theta=-14.204982 -> V=1.0, theta=0.0
% INFO    : Bus 1343	: V=0.996377, theta=-14.200565 -> V=1.0, theta=0.0
% INFO    : Bus 1354	: V=1.041045, theta=-7.375163 -> V=1.0, theta=0.0
% INFO    : Bus 1355	: V=1.0328, theta=-8.554156 -> V=1.0, theta=0.0
% INFO    : Bus 1364	: V=1.039851, theta=-12.092524 -> V=1.0, theta=0.0
% INFO    : Bus 1380	: V=1.033661, theta=-22.574327 -> V=1.0, theta=0.0
% INFO    : Bus 1394	: V=1.074659, theta=-26.314245 -> V=1.0, theta=0.0
% INFO    : Bus 1397	: V=1.037924, theta=-12.820941 -> V=1.0, theta=0.0
% INFO    : Bus 1398	: V=1.017322, theta=-19.003234 -> V=1.0, theta=0.0
% INFO    : Bus 1401	: V=1.038647, theta=-14.758146 -> V=1.0, theta=0.0
% INFO    : Bus 1414	: V=1.022683, theta=-27.895964 -> V=1.0, theta=0.0
% INFO    : Bus 1415	: V=1.032141, theta=-11.506028 -> V=1.0, theta=0.0
% INFO    : Bus 1422	: V=1.04353, theta=-20.966559 -> V=1.0, theta=0.0
% INFO    : Bus 1435	: V=1.044674, theta=-24.345986 -> V=1.0, theta=0.0
% INFO    : Bus 1436	: V=1.047684, theta=-12.917585 -> V=1.0, theta=0.0
% INFO    : Bus 1448	: V=1.075069, theta=-15.319825 -> V=1.0, theta=0.0
% INFO    : Bus 1459	: V=1.042934, theta=-21.817757 -> V=1.0, theta=0.0
% INFO    : Bus 1462	: V=1.043552, theta=-20.967069 -> V=1.0, theta=0.0
% INFO    : Bus 1465	: V=0.988454, theta=-15.339654 -> V=1.0, theta=0.0
% INFO    : Bus 1478	: V=1.048068, theta=-15.82908 -> V=1.0, theta=0.0
% INFO    : Bus 1483	: V=1.064156, theta=-26.867437 -> V=1.0, theta=0.0
% INFO    : Bus 1486	: V=1.034956, theta=-23.34269 -> V=1.0, theta=0.0
% INFO    : Bus 1494	: V=1.034255, theta=-11.521816 -> V=1.0, theta=0.0
% INFO    : Bus 1502	: V=1.027764, theta=-26.693479 -> V=1.0, theta=0.0
% INFO    : Bus 1504	: V=1.025322, theta=-14.28951 -> V=1.0, theta=0.0
% INFO    : Bus 1526	: V=1.042753, theta=-11.9479 -> V=1.0, theta=0.0
% INFO    : Bus 1538	: V=1.033256, theta=-8.75699 -> V=1.0, theta=0.0
% INFO    : Bus 1539	: V=1.059384, theta=-15.296455 -> V=1.0, theta=0.0
% INFO    : Bus 1541	: V=1.039282, theta=-23.538177 -> V=1.0, theta=0.0
% INFO    : Bus 1545	: V=1.042222, theta=-23.472695 -> V=1.0, theta=0.0
% INFO    : Bus 1547	: V=1.040481, theta=-15.042995 -> V=1.0, theta=0.0
% INFO    : Bus 1551	: V=1.043158, theta=-20.41875 -> V=1.0, theta=0.0
% INFO    : Bus 1552	: V=1.042604, theta=-16.620759 -> V=1.0, theta=0.0
% INFO    : Bus 1554	: V=1.020729, theta=-16.043428 -> V=1.0, theta=0.0
% INFO    : Bus 1556	: V=1.061796, theta=-11.391738 -> V=1.0, theta=0.0
% INFO    : Bus 1562	: V=1.042236, theta=-25.854486 -> V=1.0, theta=0.0
% INFO    : Bus 1566	: V=1.036219, theta=-24.756749 -> V=1.0, theta=0.0
% INFO    : Bus 1568	: V=1.046858, theta=-25.154702 -> V=1.0, theta=0.0
% INFO    : Bus 1578	: V=1.040417, theta=-12.029853 -> V=1.0, theta=0.0
% INFO    : Bus 1584	: V=1.026871, theta=-14.239921 -> V=1.0, theta=0.0
% INFO    : Bus 1592	: V=1.037512, theta=-2.335282 -> V=1.0, theta=0.0
% INFO    : Bus 1595	: V=1.01584, theta=-29.283839 -> V=1.0, theta=0.0
% INFO    : Bus 1604	: V=1.043862, theta=-6.640235 -> V=1.0, theta=0.0
% INFO    : Bus 1605	: V=1.076968, theta=-24.357645 -> V=1.0, theta=0.0
% INFO    : Bus 1607	: V=1.030671, theta=-5.514136 -> V=1.0, theta=0.0
% INFO    : Bus 1609	: V=1.05016, theta=-20.676376 -> V=1.0, theta=0.0
% INFO    : Bus 1625	: V=1.047827, theta=-19.847235 -> V=1.0, theta=0.0
% INFO    : Bus 1629	: V=1.043667, theta=-11.062381 -> V=1.0, theta=0.0
% INFO    : Bus 1642	: V=1.028554, theta=0.427747 -> V=1.0, theta=0.0
% INFO    : Bus 1643	: V=1.042277, theta=-25.887944 -> V=1.0, theta=0.0
% INFO    : Bus 1644	: V=1.054472, theta=3.4279 -> V=1.0, theta=0.0
% INFO    : Bus 1662	: V=1.046228, theta=-20.80193 -> V=1.0, theta=0.0
% INFO    : Bus 1672	: V=1.061821, theta=-11.405066 -> V=1.0, theta=0.0
% INFO    : Bus 1680	: V=1.04395, theta=-2.225166 -> V=1.0, theta=0.0
% INFO    : Bus 1692	: V=1.047275, theta=-10.47462 -> V=1.0, theta=0.0
% INFO    : Bus 1704	: V=1.038923, theta=-13.052366 -> V=1.0, theta=0.0
% INFO    : Bus 1708	: V=1.037938, theta=-13.186223 -> V=1.0, theta=0.0
% INFO    : Bus 1709	: V=1.007462, theta=-14.734072 -> V=1.0, theta=0.0
% INFO    : Bus 1711	: V=1.052686, theta=-29.767092 -> V=1.0, theta=0.0
% INFO    : Bus 1721	: V=1.062238, theta=2.466713 -> V=1.0, theta=0.0
% INFO    : Bus 1730	: V=1.025799, theta=-14.51076 -> V=1.0, theta=0.0
% INFO    : Bus 1742	: V=1.030326, theta=-32.491405 -> V=1.0, theta=0.0
% INFO    : Bus 1746	: V=1.049354, theta=-24.089302 -> V=1.0, theta=0.0
% INFO    : Bus 1750	: V=1.036578, theta=-19.191311 -> V=1.0, theta=0.0
% INFO    : Bus 1754	: V=1.04286, theta=-17.149587 -> V=1.0, theta=0.0
% INFO    : Bus 1758	: V=1.03465, theta=-4.424306 -> V=1.0, theta=0.0
% INFO    : Bus 1763	: V=1.034875, theta=-30.808254 -> V=1.0, theta=0.0
% INFO    : Bus 1767	: V=1.049612, theta=-45.569227 -> V=1.0, theta=0.0
% INFO    : Bus 1768	: V=1.042927, theta=-11.13756 -> V=1.0, theta=0.0
% INFO    : Bus 1775	: V=1.05106, theta=-25.97492 -> V=1.0, theta=0.0
% INFO    : Bus 1794	: V=1.05295, theta=-0.236871 -> V=1.0, theta=0.0
% INFO    : Bus 1798	: V=0.987325, theta=-7.424983 -> V=1.0, theta=0.0
% INFO    : Bus 1803	: V=1.038883, theta=-22.036572 -> V=1.0, theta=0.0
% INFO    : Bus 1808	: V=1.046224, theta=-0.834506 -> V=1.0, theta=0.0
% INFO    : Bus 1813	: V=1.029057, theta=-7.519944 -> V=1.0, theta=0.0
% INFO    : Bus 1817	: V=1.069539, theta=-12.567622 -> V=1.0, theta=0.0
% INFO    : Bus 1833	: V=1.036371, theta=-22.480232 -> V=1.0, theta=0.0
% INFO    : Bus 1838	: V=1.037419, theta=-22.162507 -> V=1.0, theta=0.0
% INFO    : Bus 1844	: V=1.061839, theta=-11.404513 -> V=1.0, theta=0.0
% INFO    : Bus 1851	: V=1.04762, theta=-12.927099 -> V=1.0, theta=0.0
% INFO    : Bus 1852	: V=1.054325, theta=-25.744509 -> V=1.0, theta=0.0
% INFO    : Bus 1857	: V=1.028608, theta=-11.055937 -> V=1.0, theta=0.0
% INFO    : Bus 1860	: V=1.060858, theta=-25.532569 -> V=1.0, theta=0.0
% INFO    : Bus 1866	: V=1.04474, theta=-28.285319 -> V=1.0, theta=0.0
% INFO    : Bus 1868	: V=1.035258, theta=-15.877966 -> V=1.0, theta=0.0
% INFO    : Bus 1876	: V=1.030797, theta=-14.242223 -> V=1.0, theta=0.0
% INFO    : Bus 1883	: V=1.029787, theta=-16.425673 -> V=1.0, theta=0.0
% INFO    : Bus 1888	: V=1.039377, theta=-2.376673 -> V=1.0, theta=0.0
% INFO    : Bus 1895	: V=1.070353, theta=7.588403 -> V=1.0, theta=0.0
% INFO    : Bus 1896	: V=1.021131, theta=-6.153674 -> V=1.0, theta=0.0
% INFO    : Bus 1910	: V=1.049243, theta=-6.695385 -> V=1.0, theta=0.0
% INFO    : Bus 1914	: V=1.035636, theta=-20.619184 -> V=1.0, theta=0.0
% INFO    : Bus 1917	: V=1.050486, theta=-25.132946 -> V=1.0, theta=0.0
% INFO    : Bus 1923	: V=1.002407, theta=-11.646061 -> V=1.0, theta=0.0
% INFO    : Bus 1940	: V=1.03614, theta=-18.037347 -> V=1.0, theta=0.0
% INFO    : Bus 1959	: V=1.064692, theta=-10.511132 -> V=1.0, theta=0.0
% INFO    : Bus 1965	: V=1.066548, theta=-49.702693 -> V=1.0, theta=0.0
% INFO    : Bus 1973	: V=1.074741, theta=-26.300211 -> V=1.0, theta=0.0
% INFO    : Bus 1979	: V=1.074144, theta=-33.621995 -> V=1.0, theta=0.0
% INFO    : Bus 1980	: V=1.040983, theta=-21.42173 -> V=1.0, theta=0.0
% INFO    : Bus 1998	: V=1.033294, theta=-20.141362 -> V=1.0, theta=0.0
% INFO    : Bus 2012	: V=1.038506, theta=-18.675791 -> V=1.0, theta=0.0
% INFO    : Bus 2019	: V=1.044528, theta=-21.078894 -> V=1.0, theta=0.0
% INFO    : Bus 2020	: V=1.051074, theta=-24.096673 -> V=1.0, theta=0.0
% INFO    : Bus 2021	: V=1.050096, theta=-24.96566 -> V=1.0, theta=0.0
% INFO    : Bus 2035	: V=1.03088, theta=0.693557 -> V=1.0, theta=0.0
% INFO    : Bus 2042	: V=1.037536, theta=-5.903671 -> V=1.0, theta=0.0
% INFO    : Bus 2043	: V=1.043517, theta=-20.967534 -> V=1.0, theta=0.0
% INFO    : Bus 2044	: V=1.032138, theta=-12.426968 -> V=1.0, theta=0.0
% INFO    : Bus 2050	: V=1.009914, theta=-1.144693 -> V=1.0, theta=0.0
% INFO    : Bus 2056	: V=1.038215, theta=-9.076082 -> V=1.0, theta=0.0
% INFO    : Bus 2057	: V=1.04971, theta=-30.773674 -> V=1.0, theta=0.0
% INFO    : Bus 2072	: V=1.065746, theta=-17.405584 -> V=1.0, theta=0.0
% INFO    : Bus 2078	: V=1.020675, theta=-14.721188 -> V=1.0, theta=0.0
% INFO    : Bus 2079	: V=1.050272, theta=-12.128304 -> V=1.0, theta=0.0
% INFO    : Bus 2083	: V=1.035, theta=-18.482915 -> V=1.0, theta=0.0
% INFO    : Bus 2085	: V=1.040351, theta=2.467063 -> V=1.0, theta=0.0
% INFO    : Bus 2088	: V=1.052176, theta=-12.052739 -> V=1.0, theta=0.0
% INFO    : Bus 2089	: V=1.04312, theta=-25.770522 -> V=1.0, theta=0.0
% INFO    : Bus 2093	: V=1.016671, theta=-8.086067 -> V=1.0, theta=0.0
% INFO    : Bus 2101	: V=1.02998, theta=-5.549174 -> V=1.0, theta=0.0
% INFO    : Bus 2128	: V=1.035961, theta=-23.062582 -> V=1.0, theta=0.0
% INFO    : Bus 2129	: V=1.016495, theta=-8.242431 -> V=1.0, theta=0.0
% INFO    : Bus 2132	: V=1.039669, theta=-15.783021 -> V=1.0, theta=0.0
% INFO    : Bus 2142	: V=1.050391, theta=-7.902365 -> V=1.0, theta=0.0
% INFO    : Bus 2155	: V=1.037645, theta=-5.893797 -> V=1.0, theta=0.0
% INFO    : Bus 2161	: V=1.048364, theta=-28.662661 -> V=1.0, theta=0.0
% INFO    : Bus 2166	: V=1.052887, theta=-14.673236 -> V=1.0, theta=0.0
% INFO    : Bus 2174	: V=1.011944, theta=-13.202451 -> V=1.0, theta=0.0
% INFO    : Bus 2177	: V=1.07333, theta=-28.416356 -> V=1.0, theta=0.0
% INFO    : Bus 2183	: V=0.995876, theta=-16.181883 -> V=1.0, theta=0.0
% INFO    : Bus 2189	: V=1.047761, theta=-6.28234 -> V=1.0, theta=0.0
% INFO    : Bus 2197	: V=1.035528, theta=-6.012095 -> V=1.0, theta=0.0
% INFO    : Bus 2208	: V=1.051126, theta=-13.420372 -> V=1.0, theta=0.0
% INFO    : Bus 2229	: V=1.062959, theta=-13.080678 -> V=1.0, theta=0.0
% INFO    : Bus 2230	: V=1.036513, theta=-22.481463 -> V=1.0, theta=0.0
% INFO    : Bus 2231	: V=1.049391, theta=1.166976 -> V=1.0, theta=0.0
% INFO    : Bus 2242	: V=1.02489, theta=-19.020985 -> V=1.0, theta=0.0
% INFO    : Bus 2252	: V=1.068023, theta=-47.917821 -> V=1.0, theta=0.0
% INFO    : Bus 2273	: V=1.074359, theta=-26.339387 -> V=1.0, theta=0.0
% INFO    : Bus 2276	: V=1.05324, theta=-23.758819 -> V=1.0, theta=0.0
% INFO    : Bus 2286	: V=1.023269, theta=-8.717089 -> V=1.0, theta=0.0
% INFO    : Bus 2288	: V=1.034468, theta=-8.57662 -> V=1.0, theta=0.0
% INFO    : Bus 2291	: V=1.072528, theta=-10.610728 -> V=1.0, theta=0.0
% INFO    : Bus 2303	: V=1.03744, theta=-15.856049 -> V=1.0, theta=0.0
% INFO    : Bus 2304	: V=1.058495, theta=-25.832763 -> V=1.0, theta=0.0
% INFO    : Bus 2308	: V=1.038612, theta=-24.078628 -> V=1.0, theta=0.0
% INFO    : Bus 2313	: V=1.046654, theta=-21.265608 -> V=1.0, theta=0.0
% INFO    : Bus 2319	: V=1.061069, theta=-8.962289 -> V=1.0, theta=0.0
% INFO    : Bus 2327	: V=1.047194, theta=-25.133812 -> V=1.0, theta=0.0
% INFO    : Bus 2328	: V=1.017489, theta=-14.250876 -> V=1.0, theta=0.0
% INFO    : Bus 2337	: V=1.045493, theta=-29.7818 -> V=1.0, theta=0.0
% INFO    : Bus 2340	: V=1.03958, theta=-12.236094 -> V=1.0, theta=0.0
% INFO    : Bus 2341	: V=1.065118, theta=-26.070582 -> V=1.0, theta=0.0
% INFO    : Bus 2359	: V=1.024884, theta=-9.921886 -> V=1.0, theta=0.0
% INFO    : Bus 2360	: V=1.044563, theta=-21.085033 -> V=1.0, theta=0.0
% INFO    : Bus 2361	: V=1.052288, theta=-29.004707 -> V=1.0, theta=0.0
% INFO    : Bus 2365	: V=1.033702, theta=-22.17424 -> V=1.0, theta=0.0
% INFO    : Bus 2372	: V=0.991274, theta=-17.482034 -> V=1.0, theta=0.0
% INFO    : Bus 2377	: V=1.036655, theta=-14.897845 -> V=1.0, theta=0.0
% INFO    : Bus 2393	: V=1.070495, theta=7.700354 -> V=1.0, theta=0.0
% INFO    : Bus 2406	: V=1.048666, theta=-24.428158 -> V=1.0, theta=0.0
% INFO    : Bus 2421	: V=1.047766, theta=-23.702161 -> V=1.0, theta=0.0
% INFO    : Bus 2424	: V=1.034979, theta=-22.416002 -> V=1.0, theta=0.0
% INFO    : Bus 2425	: V=1.041186, theta=-9.882232 -> V=1.0, theta=0.0
% INFO    : Bus 2426	: V=1.037687, theta=-13.762974 -> V=1.0, theta=0.0
% INFO    : Bus 2430	: V=1.041369, theta=-11.921713 -> V=1.0, theta=0.0
% INFO    : Bus 2432	: V=1.030479, theta=-32.300033 -> V=1.0, theta=0.0
% INFO    : Bus 2438	: V=1.046626, theta=-21.265307 -> V=1.0, theta=0.0
% INFO    : Bus 2446	: V=1.06157, theta=7.557722 -> V=1.0, theta=0.0
% INFO    : Bus 2457	: V=1.040059, theta=-24.619174 -> V=1.0, theta=0.0
% INFO    : Bus 2458	: V=1.006537, theta=-13.460583 -> V=1.0, theta=0.0
% INFO    : Bus 2467	: V=1.018095, theta=-14.100158 -> V=1.0, theta=0.0
% INFO    : Bus 2468	: V=1.048132, theta=-6.215141 -> V=1.0, theta=0.0
% INFO    : Bus 2475	: V=1.065573, theta=-7.808732 -> V=1.0, theta=0.0
% INFO    : Bus 2479	: V=1.008158, theta=-2.627166 -> V=1.0, theta=0.0
% INFO    : Bus 2481	: V=1.042777, theta=-18.185589 -> V=1.0, theta=0.0
% INFO    : Bus 2489	: V=1.049366, theta=1.167288 -> V=1.0, theta=0.0
% INFO    : Bus 2503	: V=1.012856, theta=-21.48175 -> V=1.0, theta=0.0
% INFO    : Bus 2510	: V=1.028486, theta=-12.08393 -> V=1.0, theta=0.0
% INFO    : Bus 2518	: V=0.999088, theta=-11.536983 -> V=1.0, theta=0.0
% INFO    : Bus 2526	: V=1.044376, theta=-19.855823 -> V=1.0, theta=0.0
% INFO    : Bus 2527	: V=1.043988, theta=-4.63491 -> V=1.0, theta=0.0
% INFO    : Bus 2535	: V=1.037544, theta=-2.896669 -> V=1.0, theta=0.0
% INFO    : Bus 2550	: V=1.049384, theta=-6.666685 -> V=1.0, theta=0.0
% INFO    : Bus 2558	: V=1.023305, theta=-16.640241 -> V=1.0, theta=0.0
% INFO    : Bus 2563	: V=1.046977, theta=-4.707678 -> V=1.0, theta=0.0
% INFO    : Bus 2575	: V=1.04159, theta=-2.724929 -> V=1.0, theta=0.0
% INFO    : Bus 2591	: V=1.030923, theta=-15.233022 -> V=1.0, theta=0.0
% INFO    : Bus 2597	: V=1.033106, theta=-10.863404 -> V=1.0, theta=0.0
% INFO    : Bus 2598	: V=1.040506, theta=-15.286014 -> V=1.0, theta=0.0
% INFO    : Bus 2600	: V=1.038821, theta=-13.64341 -> V=1.0, theta=0.0
% INFO    : Bus 2627	: V=1.061488, theta=7.521439 -> V=1.0, theta=0.0
% INFO    : Bus 2629	: V=1.045498, theta=-24.492103 -> V=1.0, theta=0.0
% INFO    : Bus 2641	: V=1.042124, theta=-11.251293 -> V=1.0, theta=0.0
% INFO    : Bus 2644	: V=1.07369, theta=-24.808555 -> V=1.0, theta=0.0
% INFO    : Bus 2653	: V=1.036517, theta=-23.007774 -> V=1.0, theta=0.0
% INFO    : Bus 2654	: V=1.019228, theta=-18.770253 -> V=1.0, theta=0.0
% INFO    : Bus 2656	: V=1.034308, theta=-22.749906 -> V=1.0, theta=0.0
% INFO    : Bus 2676	: V=1.035697, theta=-14.93988 -> V=1.0, theta=0.0
% INFO    : Bus 2689	: V=1.034001, theta=-3.213772 -> V=1.0, theta=0.0
% INFO    : Bus 2695	: V=1.038344, theta=-21.004788 -> V=1.0, theta=0.0
% INFO    : Bus 2702	: V=1.043222, theta=-25.609448 -> V=1.0, theta=0.0
% INFO    : Bus 2719	: V=1.035384, theta=-15.495326 -> V=1.0, theta=0.0
% INFO    : Bus 2721	: V=0.983623, theta=-22.371652 -> V=1.0, theta=0.0
% INFO    : Bus 2732	: V=1.013054, theta=-10.064991 -> V=1.0, theta=0.0
% INFO    : Bus 2749	: V=1.049925, theta=-30.124895 -> V=1.0, theta=0.0
% INFO    : Bus 2751	: V=1.042162, theta=-21.896741 -> V=1.0, theta=0.0
% INFO    : Bus 2754	: V=1.051994, theta=-13.365671 -> V=1.0, theta=0.0
% INFO    : Bus 2770	: V=1.047946, theta=-9.667144 -> V=1.0, theta=0.0
% INFO    : Bus 2782	: V=1.06184, theta=-11.404239 -> V=1.0, theta=0.0
% INFO    : Bus 2786	: V=1.073795, theta=6.427789 -> V=1.0, theta=0.0
% INFO    : Bus 2794	: V=1.035004, theta=-18.482955 -> V=1.0, theta=0.0
% INFO    : Bus 2795	: V=1.070164, theta=-32.44656 -> V=1.0, theta=0.0
% INFO    : Bus 2797	: V=1.042226, theta=-4.483231 -> V=1.0, theta=0.0
% INFO    : Bus 2799	: V=1.05396, theta=-12.355638 -> V=1.0, theta=0.0
% INFO    : Bus 2801	: V=1.041023, theta=-24.502823 -> V=1.0, theta=0.0
% INFO    : Bus 2806	: V=1.050477, theta=0.170291 -> V=1.0, theta=0.0
% INFO    : Bus 2815	: V=1.03655, theta=-22.984441 -> V=1.0, theta=0.0
% INFO    : Bus 2816	: V=1.053944, theta=-0.390904 -> V=1.0, theta=0.0
% INFO    : Bus 2841	: V=1.08248, theta=-26.223645 -> V=1.0, theta=0.0
% INFO    : Bus 2842	: V=1.043712, theta=-6.650222 -> V=1.0, theta=0.0
% INFO    : Bus 2847	: V=1.050663, theta=-3.956106 -> V=1.0, theta=0.0
% INFO    : Bus 2848	: V=0.998047, theta=-7.830482 -> V=1.0, theta=0.0
% INFO    : Bus 2850	: V=1.03307, theta=-18.741426 -> V=1.0, theta=0.0
% INFO    : Bus 2854	: V=1.044838, theta=-10.677353 -> V=1.0, theta=0.0
% INFO    : Bus 2863	: V=1.028402, theta=-11.074681 -> V=1.0, theta=0.0
% INFO    : Bus 2866	: V=1.03784, theta=-7.272198 -> V=1.0, theta=0.0
% INFO    : Bus 2872	: V=1.063841, theta=-10.631082 -> V=1.0, theta=0.0
% INFO    : Bus 2877	: V=1.041807, theta=-14.920901 -> V=1.0, theta=0.0
% INFO    : Bus 2878	: V=1.057626, theta=-10.952158 -> V=1.0, theta=0.0
% INFO    : Bus 2886	: V=1.055151, theta=-14.128145 -> V=1.0, theta=0.0
% INFO    : Bus 2888	: V=1.013722, theta=-21.258074 -> V=1.0, theta=0.0
% INFO    : Bus 2889	: V=1.050185, theta=-1.116811 -> V=1.0, theta=0.0
% INFO    : Bus 2898	: V=1.035844, theta=-23.070363 -> V=1.0, theta=0.0
% INFO    : Bus 2902	: V=1.059072, theta=-23.273273 -> V=1.0, theta=0.0
% INFO    : Bus 2910	: V=1.040554, theta=-2.262281 -> V=1.0, theta=0.0
% INFO    : Bus 2918	: V=1.02385, theta=-28.205516 -> V=1.0, theta=0.0
% INFO    : Bus 2919	: V=0.991588, theta=-18.308905 -> V=1.0, theta=0.0
% INFO    : Bus 2924	: V=1.057573, theta=-33.080856 -> V=1.0, theta=0.0
% INFO    : Bus 2928	: V=1.074568, theta=-26.335879 -> V=1.0, theta=0.0
% INFO    : Bus 2930	: V=1.047695, theta=-12.912307 -> V=1.0, theta=0.0
% INFO    : Bus 2931	: V=1.043622, theta=-32.26389 -> V=1.0, theta=0.0
% INFO    : Bus 2934	: V=1.051149, theta=-6.52803 -> V=1.0, theta=0.0
% INFO    : Bus 2938	: V=1.005521, theta=-7.42176 -> V=1.0, theta=0.0
% INFO    : Bus 2940	: V=1.01671, theta=-14.352513 -> V=1.0, theta=0.0
% INFO    : Bus 2949	: V=1.050433, theta=-4.837602 -> V=1.0, theta=0.0
% INFO    : Bus 2961	: V=1.041215, theta=-24.387727 -> V=1.0, theta=0.0
% INFO    : Bus 2967	: V=1.046973, theta=-17.07434 -> V=1.0, theta=0.0
% INFO    : Bus 2968	: V=1.044527, theta=-8.952764 -> V=1.0, theta=0.0
% INFO    : Bus 2972	: V=1.038342, theta=-15.064035 -> V=1.0, theta=0.0
% INFO    : Bus 2980	: V=1.063297, theta=-9.078731 -> V=1.0, theta=0.0
% INFO    : Bus 2981	: V=1.075422, theta=-15.322665 -> V=1.0, theta=0.0
% INFO    : Bus 2985	: V=1.053607, theta=-8.47854 -> V=1.0, theta=0.0
% INFO    : Bus 2995	: V=1.051891, theta=-3.763961 -> V=1.0, theta=0.0
% INFO    : Bus 3013	: V=1.049575, theta=-5.241034 -> V=1.0, theta=0.0
% INFO    : Bus 3018	: V=1.041705, theta=-12.798969 -> V=1.0, theta=0.0
% INFO    : Bus 3019	: V=1.036837, theta=-22.763335 -> V=1.0, theta=0.0
% INFO    : Bus 3021	: V=1.042535, theta=-11.458053 -> V=1.0, theta=0.0
% INFO    : Bus 3022	: V=1.038441, theta=-14.928463 -> V=1.0, theta=0.0
% INFO    : Bus 3028	: V=1.030654, theta=0.605264 -> V=1.0, theta=0.0
% INFO    : Bus 3036	: V=1.046808, theta=-25.175878 -> V=1.0, theta=0.0
% INFO    : Bus 3037	: V=1.04857, theta=-6.585978 -> V=1.0, theta=0.0
% INFO    : Bus 3044	: V=1.044991, theta=-21.014316 -> V=1.0, theta=0.0
% INFO    : Bus 3051	: V=1.031148, theta=-24.884639 -> V=1.0, theta=0.0
% INFO    : Bus 3069	: V=1.033466, theta=-8.740353 -> V=1.0, theta=0.0
% INFO    : Bus 3070	: V=1.013716, theta=-21.258029 -> V=1.0, theta=0.0
% INFO    : Bus 3071	: V=1.044715, theta=-7.284056 -> V=1.0, theta=0.0
% INFO    : Bus 3072	: V=1.050676, theta=-30.097241 -> V=1.0, theta=0.0
% INFO    : Bus 3075	: V=1.020662, theta=-16.898848 -> V=1.0, theta=0.0
% INFO    : Bus 3082	: V=0.998938, theta=-15.122127 -> V=1.0, theta=0.0
% INFO    : Bus 3083	: V=1.068389, theta=-27.641331 -> V=1.0, theta=0.0
% INFO    : Bus 3085	: V=1.067218, theta=-27.697899 -> V=1.0, theta=0.0
% INFO    : Bus 3112	: V=1.057299, theta=2.403578 -> V=1.0, theta=0.0
% INFO    : Bus 3114	: V=1.071964, theta=-11.598423 -> V=1.0, theta=0.0
% INFO    : Bus 3121	: V=1.031627, theta=-7.214885 -> V=1.0, theta=0.0
% INFO    : Bus 3126	: V=1.021547, theta=-17.925447 -> V=1.0, theta=0.0
% INFO    : Bus 3133	: V=1.065372, theta=-9.169038 -> V=1.0, theta=0.0
% INFO    : Bus 3134	: V=1.023117, theta=-15.704702 -> V=1.0, theta=0.0
% INFO    : Bus 3137	: V=1.065118, theta=-26.070583 -> V=1.0, theta=0.0
% INFO    : Bus 3145	: V=0.993017, theta=-41.441031 -> V=1.0, theta=0.0
% INFO    : Bus 3166	: V=1.039048, theta=-17.527734 -> V=1.0, theta=0.0
% INFO    : Bus 3183	: V=1.055515, theta=-11.832574 -> V=1.0, theta=0.0
% INFO    : Bus 3184	: V=1.040299, theta=-21.338667 -> V=1.0, theta=0.0
% INFO    : Bus 3187	: V=1.042404, theta=-12.953299 -> V=1.0, theta=0.0
% INFO    : Bus 3191	: V=1.040776, theta=-12.071062 -> V=1.0, theta=0.0
% INFO    : Bus 3200	: V=1.036168, theta=-23.053307 -> V=1.0, theta=0.0
% INFO    : Bus 3204	: V=1.017023, theta=-10.267075 -> V=1.0, theta=0.0
% INFO    : Bus 3205	: V=1.041982, theta=-1.292668 -> V=1.0, theta=0.0
% INFO    : Bus 3218	: V=1.028507, theta=-11.253521 -> V=1.0, theta=0.0
% INFO    : Bus 3221	: V=1.047766, theta=-12.146786 -> V=1.0, theta=0.0
% INFO    : Bus 3231	: V=1.025161, theta=-14.287368 -> V=1.0, theta=0.0
% INFO    : Bus 3239	: V=1.056229, theta=-11.611515 -> V=1.0, theta=0.0
% INFO    : Bus 3240	: V=1.050305, theta=-1.129073 -> V=1.0, theta=0.0
% INFO    : Bus 3241	: V=1.030192, theta=-17.957576 -> V=1.0, theta=0.0
% INFO    : Bus 3243	: V=0.990554, theta=-18.181283 -> V=1.0, theta=0.0
% INFO    : Bus 3246	: V=1.080513, theta=7.863586 -> V=1.0, theta=0.0
% INFO    : Bus 3248	: V=1.05498, theta=-11.325947 -> V=1.0, theta=0.0
% INFO    : Bus 3255	: V=1.038882, theta=-22.03657 -> V=1.0, theta=0.0
% INFO    : Bus 3276	: V=1.050076, theta=-7.893785 -> V=1.0, theta=0.0
% INFO    : Bus 3293	: V=1.038075, theta=-11.39812 -> V=1.0, theta=0.0
% INFO    : Bus 3306	: V=1.071978, theta=8.08029 -> V=1.0, theta=0.0
% INFO    : Bus 3324	: V=1.014126, theta=-16.129669 -> V=1.0, theta=0.0
% INFO    : Bus 3325	: V=1.033998, theta=-20.055869 -> V=1.0, theta=0.0
% INFO    : Bus 3327	: V=1.038066, theta=-12.156606 -> V=1.0, theta=0.0
% INFO    : Bus 3331	: V=1.0175, theta=-10.215862 -> V=1.0, theta=0.0
% INFO    : Bus 3344	: V=1.039524, theta=-16.595479 -> V=1.0, theta=0.0
% INFO    : Bus 3346	: V=1.01594, theta=-12.063974 -> V=1.0, theta=0.0
% INFO    : Bus 3353	: V=1.045739, theta=-3.042188 -> V=1.0, theta=0.0
% INFO    : Bus 3364	: V=1.0538, theta=-12.359552 -> V=1.0, theta=0.0
% INFO    : Bus 3377	: V=1.018192, theta=-10.51029 -> V=1.0, theta=0.0
% INFO    : Bus 3390	: V=1.039984, theta=-11.495624 -> V=1.0, theta=0.0
% INFO    : Bus 3391	: V=1.059691, theta=-20.937372 -> V=1.0, theta=0.0
% INFO    : Bus 3400	: V=1.047571, theta=-25.085016 -> V=1.0, theta=0.0
% INFO    : Bus 3401	: V=1.034711, theta=-14.123031 -> V=1.0, theta=0.0
% INFO    : Bus 3412	: V=1.057299, theta=2.403578 -> V=1.0, theta=0.0
% INFO    : Bus 3422	: V=1.063657, theta=-10.680951 -> V=1.0, theta=0.0
% INFO    : Bus 3430	: V=1.015255, theta=-16.040907 -> V=1.0, theta=0.0
% INFO    : Bus 3435	: V=1.043606, theta=-25.55539 -> V=1.0, theta=0.0
% INFO    : Bus 3436	: V=1.060777, theta=-13.286433 -> V=1.0, theta=0.0
% INFO    : Bus 3445	: V=0.999706, theta=-5.879329 -> V=1.0, theta=0.0
% INFO    : Bus 3450	: V=1.046643, theta=-21.48337 -> V=1.0, theta=0.0
% INFO    : Bus 3481	: V=1.023602, theta=-20.789174 -> V=1.0, theta=0.0
% INFO    : Bus 3483	: V=1.051877, theta=2.264367 -> V=1.0, theta=0.0
% INFO    : Bus 3485	: V=0.991148, theta=-16.268999 -> V=1.0, theta=0.0
% INFO    : Bus 3486	: V=1.037237, theta=-20.871205 -> V=1.0, theta=0.0
% INFO    : Bus 3488	: V=1.038891, theta=-12.374272 -> V=1.0, theta=0.0
% INFO    : Bus 3492	: V=1.04852, theta=-8.570568 -> V=1.0, theta=0.0
% INFO    : Bus 3496	: V=1.03602, theta=-21.337931 -> V=1.0, theta=0.0
% INFO    : Bus 3498	: V=1.04022, theta=-10.181185 -> V=1.0, theta=0.0
% INFO    : Bus 3499	: V=1.035853, theta=-3.63424 -> V=1.0, theta=0.0
% INFO    : Bus 3502	: V=1.020854, theta=-10.552336 -> V=1.0, theta=0.0
% INFO    : Bus 3503	: V=1.032128, theta=-11.505891 -> V=1.0, theta=0.0
% INFO    : Bus 3513	: V=1.028771, theta=-3.782955 -> V=1.0, theta=0.0
% INFO    : Bus 3519	: V=1.033967, theta=-22.784898 -> V=1.0, theta=0.0
% INFO    : Bus 3520	: V=1.037612, theta=-5.896123 -> V=1.0, theta=0.0
% INFO    : Bus 3526	: V=1.056871, theta=-4.128916 -> V=1.0, theta=0.0
% INFO    : Bus 3535	: V=1.035787, theta=-24.451001 -> V=1.0, theta=0.0
% INFO    : Bus 3541	: V=1.039193, theta=-23.983552 -> V=1.0, theta=0.0
% INFO    : Bus 3543	: V=0.991625, theta=-17.553669 -> V=1.0, theta=0.0
% INFO    : Bus 3545	: V=1.049206, theta=-8.009952 -> V=1.0, theta=0.0
% INFO    : Bus 3557	: V=1.048975, theta=-30.444694 -> V=1.0, theta=0.0
% INFO    : Bus 3558	: V=1.062152, theta=2.457422 -> V=1.0, theta=0.0
% INFO    : Bus 3565	: V=1.081614, theta=-26.430835 -> V=1.0, theta=0.0
% INFO    : Bus 3577	: V=1.031951, theta=-5.185856 -> V=1.0, theta=0.0
% INFO    : Bus 3579	: V=1.072032, theta=-39.86741 -> V=1.0, theta=0.0
% INFO    : Bus 3580	: V=1.07602, theta=-33.404876 -> V=1.0, theta=0.0
% INFO    : Bus 3589	: V=1.042938, theta=-6.728326 -> V=1.0, theta=0.0
% INFO    : Bus 3594	: V=1.034276, theta=-19.803995 -> V=1.0, theta=0.0
% INFO    : Bus 3601	: V=1.040409, theta=-21.360272 -> V=1.0, theta=0.0
% INFO    : Bus 3602	: V=1.032076, theta=-18.933744 -> V=1.0, theta=0.0
% INFO    : Bus 3608	: V=1.00943, theta=-41.64982 -> V=1.0, theta=0.0
% INFO    : Bus 3609	: V=1.061834, theta=-11.405533 -> V=1.0, theta=0.0
% INFO    : Bus 3610	: V=1.03662, theta=-22.744804 -> V=1.0, theta=0.0
% INFO    : Bus 3611	: V=1.03905, theta=-18.955066 -> V=1.0, theta=0.0
% INFO    : Bus 3613	: V=1.03039, theta=-28.045674 -> V=1.0, theta=0.0
% INFO    : Bus 3643	: V=1.033238, theta=-19.364356 -> V=1.0, theta=0.0
% INFO    : Bus 3645	: V=1.057259, theta=-33.103595 -> V=1.0, theta=0.0
% INFO    : Bus 3649	: V=1.049277, theta=-36.568687 -> V=1.0, theta=0.0
% INFO    : Bus 3654	: V=1.074155, theta=-26.393413 -> V=1.0, theta=0.0
% INFO    : Bus 3656	: V=1.070983, theta=-11.746409 -> V=1.0, theta=0.0
% INFO    : Bus 3657	: V=1.075593, theta=-26.08278 -> V=1.0, theta=0.0
% INFO    : Bus 3661	: V=1.059676, theta=4.513427 -> V=1.0, theta=0.0
% INFO    : Bus 3670	: V=1.036121, theta=-21.979516 -> V=1.0, theta=0.0
% INFO    : Bus 3672	: V=1.032626, theta=-12.873557 -> V=1.0, theta=0.0
% INFO    : Bus 3674	: V=1.042158, theta=-14.835571 -> V=1.0, theta=0.0
% INFO    : Bus 3680	: V=1.035367, theta=-15.507057 -> V=1.0, theta=0.0
% INFO    : Bus 3697	: V=1.04888, theta=-20.581455 -> V=1.0, theta=0.0
% INFO    : Bus 3698	: V=1.041813, theta=-24.312887 -> V=1.0, theta=0.0
% INFO    : Bus 3701	: V=1.048029, theta=-25.022699 -> V=1.0, theta=0.0
% INFO    : Bus 3707	: V=1.050811, theta=-15.306372 -> V=1.0, theta=0.0
% INFO    : Bus 3718	: V=1.04576, theta=-25.247909 -> V=1.0, theta=0.0
% INFO    : Bus 3737	: V=1.036909, theta=-2.934488 -> V=1.0, theta=0.0
% INFO    : Bus 3740	: V=1.03798, theta=-21.218929 -> V=1.0, theta=0.0
% INFO    : Bus 3741	: V=1.031629, theta=0.717314 -> V=1.0, theta=0.0
% INFO    : Bus 3749	: V=1.041217, theta=-17.23173 -> V=1.0, theta=0.0
% INFO    : Bus 3758	: V=1.023928, theta=-19.012865 -> V=1.0, theta=0.0
% INFO    : Bus 3760	: V=1.058074, theta=-20.932224 -> V=1.0, theta=0.0
% INFO    : Bus 3768	: V=1.042031, theta=-21.905161 -> V=1.0, theta=0.0
% INFO    : Bus 3775	: V=1.001347, theta=-23.504647 -> V=1.0, theta=0.0
% INFO    : Bus 3786	: V=1.052535, theta=-19.650048 -> V=1.0, theta=0.0
% INFO    : Bus 3793	: V=1.034254, theta=-20.635259 -> V=1.0, theta=0.0
% INFO    : Bus 3794	: V=1.030869, theta=-28.137864 -> V=1.0, theta=0.0
% INFO    : Bus 3809	: V=1.084785, theta=-33.980103 -> V=1.0, theta=0.0
% INFO    : Bus 3814	: V=1.041172, theta=-21.968498 -> V=1.0, theta=0.0
% INFO    : Bus 3817	: V=1.089268, theta=-15.202915 -> V=1.0, theta=0.0
% INFO    : Bus 3818	: V=1.042892, theta=-25.785119 -> V=1.0, theta=0.0
% INFO    : Bus 3825	: V=1.026994, theta=-8.529973 -> V=1.0, theta=0.0
% INFO    : Bus 3830	: V=0.99448, theta=-13.765558 -> V=1.0, theta=0.0
% INFO    : Bus 3834	: V=1.036267, theta=-22.248651 -> V=1.0, theta=0.0
% INFO    : Bus 3855	: V=1.07551, theta=-26.170776 -> V=1.0, theta=0.0
% INFO    : Bus 3857	: V=1.081278, theta=-23.127573 -> V=1.0, theta=0.0
% INFO    : Bus 3865	: V=1.027017, theta=-14.866102 -> V=1.0, theta=0.0
% INFO    : Bus 3866	: V=1.048033, theta=-27.549636 -> V=1.0, theta=0.0
% INFO    : Bus 3869	: V=1.031907, theta=1.193974 -> V=1.0, theta=0.0
% INFO    : Bus 3876	: V=1.044501, theta=-9.587109 -> V=1.0, theta=0.0
% INFO    : Bus 3880	: V=1.061821, theta=-11.404764 -> V=1.0, theta=0.0
% INFO    : Bus 3894	: V=1.02402, theta=-15.319245 -> V=1.0, theta=0.0
% INFO    : Bus 3903	: V=1.051358, theta=-24.515174 -> V=1.0, theta=0.0
% INFO    : Bus 3906	: V=1.037271, theta=-13.381903 -> V=1.0, theta=0.0
% INFO    : Bus 3912	: V=1.038244, theta=-21.078792 -> V=1.0, theta=0.0
% INFO    : Bus 3916	: V=1.043758, theta=-14.004059 -> V=1.0, theta=0.0
% INFO    : Bus 3918	: V=1.02393, theta=-1.867594 -> V=1.0, theta=0.0
% INFO    : Bus 3919	: V=1.024896, theta=-6.075842 -> V=1.0, theta=0.0
% INFO    : Bus 3925	: V=1.026482, theta=-13.116396 -> V=1.0, theta=0.0
% INFO    : Bus 3928	: V=1.046535, theta=-4.757211 -> V=1.0, theta=0.0
% INFO    : Bus 3929	: V=1.03267, theta=-20.217595 -> V=1.0, theta=0.0
% INFO    : Bus 3951	: V=1.027439, theta=-12.908691 -> V=1.0, theta=0.0
% INFO    : Bus 3956	: V=1.049338, theta=-24.08911 -> V=1.0, theta=0.0
% INFO    : Bus 3962	: V=1.041036, theta=-23.700249 -> V=1.0, theta=0.0
% INFO    : Bus 3969	: V=1.018397, theta=-10.494183 -> V=1.0, theta=0.0
% INFO    : Bus 3971	: V=1.063145, theta=-8.854993 -> V=1.0, theta=0.0
% INFO    : Bus 3975	: V=0.986357, theta=-24.771259 -> V=1.0, theta=0.0
% INFO    : Bus 3985	: V=1.047148, theta=-0.061532 -> V=1.0, theta=0.0
% INFO    : Bus 3994	: V=1.035393, theta=-2.725702 -> V=1.0, theta=0.0
% INFO    : Bus 3997	: V=1.042584, theta=-11.956467 -> V=1.0, theta=0.0
% INFO    : Bus 3999	: V=1.051666, theta=-6.639084 -> V=1.0, theta=0.0
% INFO    : Bus 4000	: V=0.991622, theta=-15.520854 -> V=1.0, theta=0.0
% INFO    : Bus 4005	: V=1.067869, theta=-31.620043 -> V=1.0, theta=0.0
% INFO    : Bus 4024	: V=1.040328, theta=2.440561 -> V=1.0, theta=0.0
% INFO    : Bus 4025	: V=1.035538, theta=-2.7146 -> V=1.0, theta=0.0
% INFO    : Bus 4031	: V=1.063769, theta=-10.640029 -> V=1.0, theta=0.0
% INFO    : Bus 4032	: V=0.999578, theta=-11.699686 -> V=1.0, theta=0.0
% INFO    : Bus 4039	: V=1.037985, theta=-22.526852 -> V=1.0, theta=0.0
% INFO    : Bus 4049	: V=1.017178, theta=-10.133503 -> V=1.0, theta=0.0
% INFO    : Bus 4054	: V=1.035023, theta=-18.483102 -> V=1.0, theta=0.0
% INFO    : Bus 4056	: V=1.038526, theta=-9.78553 -> V=1.0, theta=0.0
% INFO    : Bus 4060	: V=1.066903, theta=-14.674014 -> V=1.0, theta=0.0
% INFO    : Bus 4084	: V=1.063234, theta=-8.796721 -> V=1.0, theta=0.0
% INFO    : Bus 4100	: V=1.063607, theta=-10.700214 -> V=1.0, theta=0.0
% INFO    : Bus 4103	: V=1.037109, theta=-21.700054 -> V=1.0, theta=0.0
% INFO    : Bus 4110	: V=1.048623, theta=0.630118 -> V=1.0, theta=0.0
% INFO    : Bus 4114	: V=1.048622, theta=-24.482065 -> V=1.0, theta=0.0
% INFO    : Bus 4118	: V=1.027195, theta=-14.802318 -> V=1.0, theta=0.0
% INFO    : Bus 4125	: V=1.003502, theta=-8.417156 -> V=1.0, theta=0.0
% INFO    : Bus 4127	: V=1.033235, theta=-20.156948 -> V=1.0, theta=0.0
% INFO    : Bus 4128	: V=1.019761, theta=-15.71382 -> V=1.0, theta=0.0
% INFO    : Bus 4134	: V=1.074144, theta=-33.622001 -> V=1.0, theta=0.0
% INFO    : Bus 4141	: V=1.032772, theta=-21.096452 -> V=1.0, theta=0.0
% INFO    : Bus 4143	: V=1.05009, theta=-1.152786 -> V=1.0, theta=0.0
% INFO    : Bus 4144	: V=1.048354, theta=-19.735876 -> V=1.0, theta=0.0
% INFO    : Bus 4157	: V=1.074571, theta=-26.335983 -> V=1.0, theta=0.0
% INFO    : Bus 4185	: V=1.042708, theta=-25.806182 -> V=1.0, theta=0.0
% INFO    : Bus 4186	: V=1.036176, theta=-23.132591 -> V=1.0, theta=0.0
% INFO    : Bus 4189	: V=1.037191, theta=-26.003681 -> V=1.0, theta=0.0
% INFO    : Bus 4196	: V=1.029571, theta=-7.552855 -> V=1.0, theta=0.0
% INFO    : Bus 4197	: V=1.06874, theta=0.692131 -> V=1.0, theta=0.0
% INFO    : Bus 4205	: V=1.052019, theta=-12.684377 -> V=1.0, theta=0.0
% INFO    : Bus 4215	: V=1.046292, theta=-23.032269 -> V=1.0, theta=0.0
% INFO    : Bus 4231	: V=1.049182, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 4234	: V=1.046192, theta=-17.159976 -> V=1.0, theta=0.0
% INFO    : Bus 4235	: V=1.053821, theta=-19.119448 -> V=1.0, theta=0.0
% INFO    : Bus 4239	: V=1.052709, theta=-13.186066 -> V=1.0, theta=0.0
% INFO    : Bus 4245	: V=1.041034, theta=-9.897904 -> V=1.0, theta=0.0
% INFO    : Bus 4251	: V=1.026731, theta=-17.726744 -> V=1.0, theta=0.0
% INFO    : Bus 4267	: V=1.038616, theta=-8.918342 -> V=1.0, theta=0.0
% INFO    : Bus 4281	: V=1.05107, theta=-11.692848 -> V=1.0, theta=0.0
% INFO    : Bus 4300	: V=1.00381, theta=-16.189999 -> V=1.0, theta=0.0
% INFO    : Bus 4301	: V=1.038253, theta=-21.079157 -> V=1.0, theta=0.0
% INFO    : Bus 4306	: V=1.034875, theta=-30.808256 -> V=1.0, theta=0.0
% INFO    : Bus 4313	: V=1.043554, theta=-21.132272 -> V=1.0, theta=0.0
% INFO    : Bus 4314	: V=1.044059, theta=-14.213235 -> V=1.0, theta=0.0
% INFO    : Bus 4324	: V=1.06402, theta=-29.724601 -> V=1.0, theta=0.0
% INFO    : Bus 4331	: V=1.028646, theta=-11.048944 -> V=1.0, theta=0.0
% INFO    : Bus 4339	: V=0.994972, theta=-15.805227 -> V=1.0, theta=0.0
% INFO    : Bus 4353	: V=1.055169, theta=-26.615369 -> V=1.0, theta=0.0
% INFO    : Bus 4355	: V=1.07349, theta=-26.435642 -> V=1.0, theta=0.0
% INFO    : Bus 4357	: V=1.046909, theta=-15.944189 -> V=1.0, theta=0.0
% INFO    : Bus 4368	: V=1.060945, theta=-25.082183 -> V=1.0, theta=0.0
% INFO    : Bus 4395	: V=1.039834, theta=-20.6569 -> V=1.0, theta=0.0
% INFO    : Bus 4402	: V=1.089271, theta=-15.202973 -> V=1.0, theta=0.0
% INFO    : Bus 4410	: V=1.046754, theta=-36.877378 -> V=1.0, theta=0.0
% INFO    : Bus 4418	: V=1.076968, theta=-24.357646 -> V=1.0, theta=0.0
% INFO    : Bus 4419	: V=1.059565, theta=4.496453 -> V=1.0, theta=0.0
% INFO    : Bus 4426	: V=1.068079, theta=-46.755413 -> V=1.0, theta=0.0
% INFO    : Bus 4432	: V=1.07457, theta=-26.335948 -> V=1.0, theta=0.0
% INFO    : Bus 4435	: V=1.006778, theta=-8.596561 -> V=1.0, theta=0.0
% INFO    : Bus 4454	: V=0.987785, theta=-18.481884 -> V=1.0, theta=0.0
% INFO    : Bus 4480	: V=1.071852, theta=7.973164 -> V=1.0, theta=0.0
% INFO    : Bus 4482	: V=1.049914, theta=-6.455681 -> V=1.0, theta=0.0
% INFO    : Bus 4484	: V=1.051896, theta=-13.325368 -> V=1.0, theta=0.0
% INFO    : Bus 4491	: V=1.032064, theta=-28.901791 -> V=1.0, theta=0.0
% INFO    : Bus 4494	: V=1.024773, theta=-0.869931 -> V=1.0, theta=0.0
% INFO    : Bus 4504	: V=1.072324, theta=-42.518571 -> V=1.0, theta=0.0
% INFO    : Bus 4505	: V=1.047176, theta=-15.911012 -> V=1.0, theta=0.0
% INFO    : Bus 4506	: V=1.036047, theta=-5.941934 -> V=1.0, theta=0.0
% INFO    : Bus 4511	: V=1.041941, theta=-25.929686 -> V=1.0, theta=0.0
% INFO    : Bus 4513	: V=1.030552, theta=-9.829625 -> V=1.0, theta=0.0
% INFO    : Bus 4520	: V=1.017179, theta=-10.133508 -> V=1.0, theta=0.0
% INFO    : Bus 4525	: V=1.060611, theta=-8.826883 -> V=1.0, theta=0.0
% INFO    : Bus 4529	: V=1.055612, theta=-15.125162 -> V=1.0, theta=0.0
% INFO    : Bus 4541	: V=1.023455, theta=-9.910829 -> V=1.0, theta=0.0
% INFO    : Bus 4544	: V=1.047769, theta=-14.697837 -> V=1.0, theta=0.0
% INFO    : Bus 4549	: V=1.03214, theta=-11.506046 -> V=1.0, theta=0.0
% INFO    : Bus 4550	: V=1.019271, theta=-10.38876 -> V=1.0, theta=0.0
% INFO    : Bus 4554	: V=1.041048, theta=-9.799798 -> V=1.0, theta=0.0
% INFO    : Bus 4562	: V=1.02147, theta=-16.819485 -> V=1.0, theta=0.0
% INFO    : Bus 4566	: V=1.073282, theta=-27.676255 -> V=1.0, theta=0.0
% INFO    : Bus 4580	: V=1.045713, theta=-12.00096 -> V=1.0, theta=0.0
% INFO    : Bus 4594	: V=0.998779, theta=-5.591046 -> V=1.0, theta=0.0
% INFO    : Bus 4598	: V=1.024757, theta=-7.997137 -> V=1.0, theta=0.0
% INFO    : Bus 4615	: V=1.066957, theta=-25.393864 -> V=1.0, theta=0.0
% INFO    : Bus 4623	: V=0.9943, theta=-16.866228 -> V=1.0, theta=0.0
% INFO    : Bus 4624	: V=1.042135, theta=-15.685962 -> V=1.0, theta=0.0
% INFO    : Bus 4656	: V=1.052781, theta=-19.605607 -> V=1.0, theta=0.0
% INFO    : Bus 4661	: V=1.049813, theta=-26.16746 -> V=1.0, theta=0.0
% INFO    : Bus 4674	: V=1.032396, theta=-12.4247 -> V=1.0, theta=0.0
% INFO    : Bus 4679	: V=1.042344, theta=-20.616305 -> V=1.0, theta=0.0
% INFO    : Bus 4683	: V=1.052059, theta=-3.729961 -> V=1.0, theta=0.0
% INFO    : Bus 4685	: V=1.042999, theta=-25.790941 -> V=1.0, theta=0.0
% INFO    : Bus 4689	: V=1.048918, theta=-30.792772 -> V=1.0, theta=0.0
% INFO    : Bus 4701	: V=1.043063, theta=-9.879302 -> V=1.0, theta=0.0
% INFO    : Bus 4710	: V=1.026719, theta=-9.176978 -> V=1.0, theta=0.0
% INFO    : Bus 4711	: V=1.042937, theta=-11.415152 -> V=1.0, theta=0.0
% INFO    : Bus 4725	: V=1.014202, theta=-10.601951 -> V=1.0, theta=0.0
% INFO    : Bus 4728	: V=1.040401, theta=-21.360189 -> V=1.0, theta=0.0
% INFO    : Bus 4729	: V=1.032006, theta=-8.433928 -> V=1.0, theta=0.0
% INFO    : Bus 4734	: V=1.014516, theta=-10.190708 -> V=1.0, theta=0.0
% INFO    : Bus 4738	: V=1.06866, theta=-10.715961 -> V=1.0, theta=0.0
% INFO    : Bus 4747	: V=1.035644, theta=-12.325346 -> V=1.0, theta=0.0
% INFO    : Bus 4748	: V=1.032136, theta=-12.426948 -> V=1.0, theta=0.0
% INFO    : Bus 4765	: V=1.03734, theta=-12.246628 -> V=1.0, theta=0.0
% INFO    : Bus 4783	: V=1.071981, theta=8.277038 -> V=1.0, theta=0.0
% INFO    : Bus 4787	: V=0.99123, theta=-14.709219 -> V=1.0, theta=0.0
% INFO    : Bus 4816	: V=1.067305, theta=-23.812093 -> V=1.0, theta=0.0
% INFO    : Bus 4819	: V=1.031907, theta=1.213157 -> V=1.0, theta=0.0
% INFO    : Bus 4823	: V=1.067114, theta=-14.648331 -> V=1.0, theta=0.0
% INFO    : Bus 4826	: V=1.076968, theta=-24.357644 -> V=1.0, theta=0.0
% INFO    : Bus 4829	: V=1.020877, theta=-5.66958 -> V=1.0, theta=0.0
% INFO    : Bus 4831	: V=1.023656, theta=-15.867691 -> V=1.0, theta=0.0
% INFO    : Bus 4850	: V=1.054975, theta=-13.889155 -> V=1.0, theta=0.0
% INFO    : Bus 4852	: V=1.040672, theta=-20.328499 -> V=1.0, theta=0.0
% INFO    : Bus 4864	: V=1.037977, theta=-12.814047 -> V=1.0, theta=0.0
% INFO    : Bus 4867	: V=1.031537, theta=-3.407292 -> V=1.0, theta=0.0
% INFO    : Bus 4874	: V=1.07611, theta=-39.379591 -> V=1.0, theta=0.0
% INFO    : Bus 4880	: V=1.034991, theta=-15.897969 -> V=1.0, theta=0.0
% INFO    : Bus 4885	: V=1.074189, theta=-26.349591 -> V=1.0, theta=0.0
% INFO    : Bus 4889	: V=1.034333, theta=-12.232863 -> V=1.0, theta=0.0
% INFO    : Bus 4907	: V=1.041821, theta=-13.302552 -> V=1.0, theta=0.0
% INFO    : Bus 4908	: V=1.037684, theta=-21.273347 -> V=1.0, theta=0.0
% INFO    : Bus 4914	: V=1.036628, theta=-22.980806 -> V=1.0, theta=0.0
% INFO    : Bus 4918	: V=1.057325, theta=-11.046567 -> V=1.0, theta=0.0
% INFO    : Bus 4925	: V=1.036525, theta=-22.48156 -> V=1.0, theta=0.0
% INFO    : Bus 4936	: V=1.049019, theta=-30.699604 -> V=1.0, theta=0.0
% INFO    : Bus 4939	: V=1.043989, theta=-4.549265 -> V=1.0, theta=0.0
% INFO    : Bus 4942	: V=1.028311, theta=-12.898354 -> V=1.0, theta=0.0
% INFO    : Bus 4950	: V=1.036717, theta=-40.104666 -> V=1.0, theta=0.0
% INFO    : Bus 4951	: V=1.053531, theta=-1.663312 -> V=1.0, theta=0.0
% INFO    : Bus 4952	: V=1.045386, theta=-17.502534 -> V=1.0, theta=0.0
% INFO    : Bus 4970	: V=1.064315, theta=-17.672609 -> V=1.0, theta=0.0
% INFO    : Bus 4974	: V=1.023886, theta=-13.4778 -> V=1.0, theta=0.0
% INFO    : Bus 5002	: V=1.071581, theta=-8.674239 -> V=1.0, theta=0.0
% INFO    : Bus 5003	: V=1.042135, theta=-9.676575 -> V=1.0, theta=0.0
% INFO    : Bus 5004	: V=1.0663, theta=-15.374553 -> V=1.0, theta=0.0
% INFO    : Bus 5007	: V=1.021829, theta=-15.303707 -> V=1.0, theta=0.0
% INFO    : Bus 5016	: V=1.02139, theta=-5.019103 -> V=1.0, theta=0.0
% INFO    : Bus 5019	: V=1.047693, theta=-12.9179 -> V=1.0, theta=0.0
% INFO    : Bus 5049	: V=1.01997, theta=-20.429759 -> V=1.0, theta=0.0
% INFO    : Bus 5051	: V=1.037373, theta=-16.452704 -> V=1.0, theta=0.0
% INFO    : Bus 5067	: V=1.021924, theta=-7.972254 -> V=1.0, theta=0.0
% INFO    : Bus 5077	: V=1.055018, theta=-26.635396 -> V=1.0, theta=0.0
% INFO    : Bus 5083	: V=1.039314, theta=-12.19306 -> V=1.0, theta=0.0
% INFO    : Bus 5093	: V=1.010775, theta=-14.861295 -> V=1.0, theta=0.0
% INFO    : Bus 5099	: V=1.058325, theta=1.539585 -> V=1.0, theta=0.0
% INFO    : Bus 5106	: V=1.071273, theta=-31.590024 -> V=1.0, theta=0.0
% INFO    : Bus 5110	: V=1.032061, theta=-10.28337 -> V=1.0, theta=0.0
% INFO    : Bus 5120	: V=1.055539, theta=-23.597086 -> V=1.0, theta=0.0
% INFO    : Bus 5131	: V=1.074641, theta=-26.336733 -> V=1.0, theta=0.0
% INFO    : Bus 5137	: V=1.025017, theta=-16.369795 -> V=1.0, theta=0.0
% INFO    : Bus 5144	: V=1.035201, theta=-3.127844 -> V=1.0, theta=0.0
% INFO    : Bus 5146	: V=1.01309, theta=-34.0847 -> V=1.0, theta=0.0
% INFO    : Bus 5174	: V=1.045055, theta=-21.030104 -> V=1.0, theta=0.0
% INFO    : Bus 5179	: V=1.049521, theta=-30.437104 -> V=1.0, theta=0.0
% INFO    : Bus 5182	: V=1.04247, theta=-7.991956 -> V=1.0, theta=0.0
% INFO    : Bus 5212	: V=1.043532, theta=-11.000335 -> V=1.0, theta=0.0
% INFO    : Bus 5213	: V=1.046557, theta=-26.37211 -> V=1.0, theta=0.0
% INFO    : Bus 5215	: V=1.029858, theta=-5.840941 -> V=1.0, theta=0.0
% INFO    : Bus 5233	: V=1.040607, theta=-10.965139 -> V=1.0, theta=0.0
% INFO    : Bus 5237	: V=1.052719, theta=-14.75067 -> V=1.0, theta=0.0
% INFO    : Bus 5241	: V=1.030298, theta=-3.61649 -> V=1.0, theta=0.0
% INFO    : Bus 5256	: V=1.00434, theta=-16.654648 -> V=1.0, theta=0.0
% INFO    : Bus 5257	: V=1.04776, theta=-6.282341 -> V=1.0, theta=0.0
% INFO    : Bus 5270	: V=1.040679, theta=-21.118583 -> V=1.0, theta=0.0
% INFO    : Bus 5278	: V=1.042037, theta=-24.259299 -> V=1.0, theta=0.0
% INFO    : Bus 5286	: V=1.037376, theta=-22.164674 -> V=1.0, theta=0.0
% INFO    : Bus 5288	: V=0.998946, theta=-15.122249 -> V=1.0, theta=0.0
% INFO    : Bus 5297	: V=1.041403, theta=-24.362719 -> V=1.0, theta=0.0
% INFO    : Bus 5300	: V=1.045246, theta=-10.990672 -> V=1.0, theta=0.0
% INFO    : Bus 5308	: V=0.984486, theta=-18.190432 -> V=1.0, theta=0.0
% INFO    : Bus 5317	: V=1.028707, theta=-44.346536 -> V=1.0, theta=0.0
% INFO    : Bus 5334	: V=1.033829, theta=-12.746707 -> V=1.0, theta=0.0
% INFO    : Bus 5340	: V=1.054941, theta=-11.154638 -> V=1.0, theta=0.0
% INFO    : Bus 5341	: V=1.011142, theta=-21.65338 -> V=1.0, theta=0.0
% INFO    : Bus 5350	: V=0.981529, theta=-24.398889 -> V=1.0, theta=0.0
% INFO    : Bus 5351	: V=1.034562, theta=-14.13742 -> V=1.0, theta=0.0
% INFO    : Bus 5354	: V=1.045497, theta=-8.643995 -> V=1.0, theta=0.0
% INFO    : Bus 5362	: V=1.043688, theta=-24.235922 -> V=1.0, theta=0.0
% INFO    : Bus 5365	: V=1.061754, theta=-11.4194 -> V=1.0, theta=0.0
% INFO    : Bus 5379	: V=1.107976, theta=-6.815844 -> V=1.0, theta=0.0
% INFO    : Bus 5383	: V=1.048549, theta=-24.463345 -> V=1.0, theta=0.0
% INFO    : Bus 5388	: V=1.013391, theta=-14.763695 -> V=1.0, theta=0.0
% INFO    : Bus 5393	: V=1.065867, theta=-15.42107 -> V=1.0, theta=0.0
% INFO    : Bus 5395	: V=1.048137, theta=-27.33134 -> V=1.0, theta=0.0
% INFO    : Bus 5400	: V=1.025608, theta=-14.012865 -> V=1.0, theta=0.0
% INFO    : Bus 5410	: V=1.045719, theta=-21.375392 -> V=1.0, theta=0.0
% INFO    : Bus 5413	: V=1.036008, theta=-18.03631 -> V=1.0, theta=0.0
% INFO    : Bus 5417	: V=1.057776, theta=-12.050099 -> V=1.0, theta=0.0
% INFO    : Bus 5418	: V=1.037717, theta=-21.273778 -> V=1.0, theta=0.0
% INFO    : Bus 5419	: V=1.021201, theta=-15.134475 -> V=1.0, theta=0.0
% INFO    : Bus 5420	: V=1.024419, theta=-22.859247 -> V=1.0, theta=0.0
% INFO    : Bus 5421	: V=0.998945, theta=-15.122174 -> V=1.0, theta=0.0
% INFO    : Bus 5441	: V=1.037781, theta=-2.820227 -> V=1.0, theta=0.0
% INFO    : Bus 5455	: V=1.042465, theta=-7.991918 -> V=1.0, theta=0.0
% INFO    : Bus 5458	: V=1.038913, theta=-21.424694 -> V=1.0, theta=0.0
% INFO    : Bus 5460	: V=0.992989, theta=-17.9255 -> V=1.0, theta=0.0
% INFO    : Bus 5461	: V=1.06213, theta=-18.41436 -> V=1.0, theta=0.0
% INFO    : Bus 5469	: V=1.067374, theta=-38.727555 -> V=1.0, theta=0.0
% INFO    : Bus 5477	: V=1.075392, theta=-26.166931 -> V=1.0, theta=0.0
% INFO    : Bus 5481	: V=1.063711, theta=-8.933875 -> V=1.0, theta=0.0
% INFO    : Bus 5482	: V=1.044486, theta=-7.317519 -> V=1.0, theta=0.0
% INFO    : Bus 5486	: V=1.059636, theta=4.495854 -> V=1.0, theta=0.0
% INFO    : Bus 5488	: V=1.041881, theta=-29.8855 -> V=1.0, theta=0.0
% INFO    : Bus 5490	: V=1.068845, theta=-15.202054 -> V=1.0, theta=0.0
% INFO    : Bus 5502	: V=1.038483, theta=-20.512891 -> V=1.0, theta=0.0
% INFO    : Bus 5519	: V=1.048798, theta=-24.5238 -> V=1.0, theta=0.0
% INFO    : Bus 5522	: V=1.068862, theta=0.701223 -> V=1.0, theta=0.0
% INFO    : Bus 5525	: V=1.03913, theta=-14.017648 -> V=1.0, theta=0.0
% INFO    : Bus 5529	: V=1.037801, theta=-2.820407 -> V=1.0, theta=0.0
% INFO    : Bus 5533	: V=1.038212, theta=-13.663692 -> V=1.0, theta=0.0
% INFO    : Bus 5546	: V=1.05378, theta=-23.67431 -> V=1.0, theta=0.0
% INFO    : Bus 5550	: V=1.051152, theta=-25.756092 -> V=1.0, theta=0.0
% INFO    : Bus 5564	: V=1.04123, theta=-12.598948 -> V=1.0, theta=0.0
% INFO    : Bus 5567	: V=1.017813, theta=-18.930548 -> V=1.0, theta=0.0
% INFO    : Bus 5571	: V=1.036516, theta=-22.481578 -> V=1.0, theta=0.0
% INFO    : Bus 5573	: V=1.05903, theta=-23.279891 -> V=1.0, theta=0.0
% INFO    : Bus 5574	: V=1.03922, theta=-11.857544 -> V=1.0, theta=0.0
% INFO    : Bus 5586	: V=1.057299, theta=2.403578 -> V=1.0, theta=0.0
% INFO    : Bus 5589	: V=1.034874, theta=-30.808253 -> V=1.0, theta=0.0
% INFO    : Bus 5610	: V=1.045824, theta=-24.167858 -> V=1.0, theta=0.0
% INFO    : Bus 5616	: V=1.076287, theta=-35.225281 -> V=1.0, theta=0.0
% INFO    : Bus 5627	: V=1.030337, theta=-32.491502 -> V=1.0, theta=0.0
% INFO    : Bus 5630	: V=1.043599, theta=-4.085534 -> V=1.0, theta=0.0
% INFO    : Bus 5641	: V=1.049836, theta=-26.047052 -> V=1.0, theta=0.0
% INFO    : Bus 5648	: V=0.995233, theta=-13.451687 -> V=1.0, theta=0.0
% INFO    : Bus 5653	: V=1.045504, theta=-7.661043 -> V=1.0, theta=0.0
% INFO    : Bus 5658	: V=1.017689, theta=-23.66504 -> V=1.0, theta=0.0
% INFO    : Bus 5664	: V=1.070507, theta=0.956534 -> V=1.0, theta=0.0
% INFO    : Bus 5666	: V=1.046065, theta=-10.74401 -> V=1.0, theta=0.0
% INFO    : Bus 5686	: V=1.030503, theta=-10.223727 -> V=1.0, theta=0.0
% INFO    : Bus 5688	: V=1.033877, theta=-8.079704 -> V=1.0, theta=0.0
% INFO    : Bus 5691	: V=1.061392, theta=-45.226837 -> V=1.0, theta=0.0
% INFO    : Bus 5695	: V=1.047646, theta=-27.137982 -> V=1.0, theta=0.0
% INFO    : Bus 5699	: V=1.049081, theta=-6.522248 -> V=1.0, theta=0.0
% INFO    : Bus 5709	: V=1.027078, theta=-8.525839 -> V=1.0, theta=0.0
% INFO    : Bus 5712	: V=1.0445, theta=-4.578143 -> V=1.0, theta=0.0
% INFO    : Bus 5720	: V=1.045667, theta=-24.989207 -> V=1.0, theta=0.0
% INFO    : Bus 5723	: V=1.045129, theta=-9.640756 -> V=1.0, theta=0.0
% INFO    : Bus 5735	: V=1.060348, theta=-26.902429 -> V=1.0, theta=0.0
% INFO    : Bus 5738	: V=1.013795, theta=-10.544291 -> V=1.0, theta=0.0
% INFO    : Bus 5743	: V=1.052165, theta=-24.123493 -> V=1.0, theta=0.0
% INFO    : Bus 5753	: V=1.033984, theta=-3.213627 -> V=1.0, theta=0.0
% INFO    : Bus 5764	: V=1.034962, theta=-25.335623 -> V=1.0, theta=0.0
% INFO    : Bus 5781	: V=1.0396, theta=-11.754534 -> V=1.0, theta=0.0
% INFO    : Bus 5789	: V=1.005562, theta=-16.021128 -> V=1.0, theta=0.0
% INFO    : Bus 5799	: V=1.043907, theta=-32.265811 -> V=1.0, theta=0.0
% INFO    : Bus 5803	: V=1.043774, theta=-14.004171 -> V=1.0, theta=0.0
% INFO    : Bus 5814	: V=1.044051, theta=-11.822108 -> V=1.0, theta=0.0
% INFO    : Bus 5836	: V=1.040266, theta=-12.0279 -> V=1.0, theta=0.0
% INFO    : Bus 5837	: V=1.019818, theta=-10.148769 -> V=1.0, theta=0.0
% INFO    : Bus 5853	: V=1.042789, theta=-7.464608 -> V=1.0, theta=0.0
% INFO    : Bus 5856	: V=1.038417, theta=-11.615407 -> V=1.0, theta=0.0
% INFO    : Bus 5857	: V=1.057665, theta=-21.071135 -> V=1.0, theta=0.0
% INFO    : Bus 5881	: V=1.065605, theta=-10.395605 -> V=1.0, theta=0.0
% INFO    : Bus 5891	: V=1.036617, theta=-12.108533 -> V=1.0, theta=0.0
% INFO    : Bus 5907	: V=1.046917, theta=-8.47729 -> V=1.0, theta=0.0
% INFO    : Bus 5918	: V=1.053364, theta=-25.787722 -> V=1.0, theta=0.0
% INFO    : Bus 5926	: V=1.072067, theta=-47.920607 -> V=1.0, theta=0.0
% INFO    : Bus 5935	: V=1.065025, theta=-22.144776 -> V=1.0, theta=0.0
% INFO    : Bus 5940	: V=1.030075, theta=-14.582177 -> V=1.0, theta=0.0
% INFO    : Bus 5944	: V=1.059622, theta=-25.872698 -> V=1.0, theta=0.0
% INFO    : Bus 5957	: V=1.025527, theta=-16.209872 -> V=1.0, theta=0.0
% INFO    : Bus 5971	: V=1.070056, theta=4.938459 -> V=1.0, theta=0.0
% INFO    : Bus 5983	: V=1.066029, theta=-14.886912 -> V=1.0, theta=0.0
% INFO    : Bus 5987	: V=1.036825, theta=-13.937479 -> V=1.0, theta=0.0
% INFO    : Bus 5990	: V=1.023107, theta=-10.218557 -> V=1.0, theta=0.0
% INFO    : Bus 5993	: V=1.043528, theta=-11.000279 -> V=1.0, theta=0.0
% INFO    : Bus 5994	: V=1.029184, theta=-15.420668 -> V=1.0, theta=0.0
% INFO    : Bus 6010	: V=1.08135, theta=-23.128077 -> V=1.0, theta=0.0
% INFO    : Bus 6031	: V=1.041572, theta=-15.751421 -> V=1.0, theta=0.0
% INFO    : Bus 6036	: V=1.043738, theta=-0.899698 -> V=1.0, theta=0.0
% INFO    : Bus 6041	: V=1.072109, theta=-47.920883 -> V=1.0, theta=0.0
% INFO    : Bus 6053	: V=1.058134, theta=-26.592239 -> V=1.0, theta=0.0
% INFO    : Bus 6071	: V=1.035726, theta=-16.340255 -> V=1.0, theta=0.0
% INFO    : Bus 6101	: V=1.02679, theta=-10.858615 -> V=1.0, theta=0.0
% INFO    : Bus 6104	: V=1.056405, theta=-12.076426 -> V=1.0, theta=0.0
% INFO    : Bus 6110	: V=1.056871, theta=-35.945281 -> V=1.0, theta=0.0
% INFO    : Bus 6112	: V=1.024189, theta=-9.306431 -> V=1.0, theta=0.0
% INFO    : Bus 6114	: V=1.048769, theta=-10.298802 -> V=1.0, theta=0.0
% INFO    : Bus 6115	: V=1.02848, theta=-11.273668 -> V=1.0, theta=0.0
% INFO    : Bus 6119	: V=1.039102, theta=-15.995867 -> V=1.0, theta=0.0
% INFO    : Bus 6146	: V=1.028373, theta=-12.079992 -> V=1.0, theta=0.0
% INFO    : Bus 6151	: V=1.032517, theta=-24.013495 -> V=1.0, theta=0.0
% INFO    : Bus 6153	: V=0.988112, theta=-14.90068 -> V=1.0, theta=0.0
% INFO    : Bus 6163	: V=1.036223, theta=-21.959198 -> V=1.0, theta=0.0
% INFO    : Bus 6168	: V=1.040343, theta=-13.438292 -> V=1.0, theta=0.0
% INFO    : Bus 6178	: V=1.040244, theta=-24.602196 -> V=1.0, theta=0.0
% INFO    : Bus 6194	: V=1.026211, theta=-16.329018 -> V=1.0, theta=0.0
% INFO    : Bus 6199	: V=1.072632, theta=-12.599054 -> V=1.0, theta=0.0
% INFO    : Bus 6203	: V=1.070264, theta=-27.353716 -> V=1.0, theta=0.0
% INFO    : Bus 6206	: V=1.037591, theta=0.03956 -> V=1.0, theta=0.0
% INFO    : Bus 6219	: V=1.033837, theta=-12.746776 -> V=1.0, theta=0.0
% INFO    : Bus 6220	: V=1.055297, theta=-22.931727 -> V=1.0, theta=0.0
% INFO    : Bus 6224	: V=1.000545, theta=-12.907246 -> V=1.0, theta=0.0
% INFO    : Bus 6231	: V=1.034263, theta=-8.032463 -> V=1.0, theta=0.0
% INFO    : Bus 6232	: V=1.042941, theta=-25.794518 -> V=1.0, theta=0.0
% INFO    : Bus 6240	: V=1.075696, theta=-34.242457 -> V=1.0, theta=0.0
% INFO    : Bus 6246	: V=1.045739, theta=-36.412972 -> V=1.0, theta=0.0
% INFO    : Bus 6252	: V=1.020382, theta=-29.885564 -> V=1.0, theta=0.0
% INFO    : Bus 6253	: V=1.04318, theta=-25.753603 -> V=1.0, theta=0.0
% INFO    : Bus 6267	: V=1.041192, theta=-24.394509 -> V=1.0, theta=0.0
% INFO    : Bus 6271	: V=1.054472, theta=-20.10439 -> V=1.0, theta=0.0
% INFO    : Bus 6290	: V=1.062557, theta=-12.82926 -> V=1.0, theta=0.0
% INFO    : Bus 6291	: V=1.040598, theta=-23.840293 -> V=1.0, theta=0.0
% INFO    : Bus 6306	: V=1.077228, theta=-24.297873 -> V=1.0, theta=0.0
% INFO    : Bus 6308	: V=1.044666, theta=-25.545467 -> V=1.0, theta=0.0
% INFO    : Bus 6313	: V=1.033893, theta=-23.915745 -> V=1.0, theta=0.0
% INFO    : Bus 6331	: V=1.052181, theta=-0.845895 -> V=1.0, theta=0.0
% INFO    : Bus 6332	: V=1.062214, theta=-11.259336 -> V=1.0, theta=0.0
% INFO    : Bus 6337	: V=1.090736, theta=-9.663194 -> V=1.0, theta=0.0
% INFO    : Bus 6351	: V=1.064446, theta=-16.194964 -> V=1.0, theta=0.0
% INFO    : Bus 6357	: V=0.986449, theta=-24.787083 -> V=1.0, theta=0.0
% INFO    : Bus 6368	: V=1.043835, theta=-8.297319 -> V=1.0, theta=0.0
% INFO    : Bus 6371	: V=1.04624, theta=-0.834636 -> V=1.0, theta=0.0
% INFO    : Bus 6376	: V=1.046714, theta=-0.304027 -> V=1.0, theta=0.0
% INFO    : Bus 6382	: V=1.042008, theta=-9.653397 -> V=1.0, theta=0.0
% INFO    : Bus 6384	: V=1.042953, theta=-1.650086 -> V=1.0, theta=0.0
% INFO    : Bus 6405	: V=1.016603, theta=-16.051975 -> V=1.0, theta=0.0
% INFO    : Bus 6416	: V=1.044399, theta=-9.544276 -> V=1.0, theta=0.0
% INFO    : Bus 6426	: V=1.054991, theta=1.525091 -> V=1.0, theta=0.0
% INFO    : Bus 6427	: V=1.00477, theta=-13.123224 -> V=1.0, theta=0.0
% INFO    : Bus 6429	: V=1.039574, theta=-18.343476 -> V=1.0, theta=0.0
% INFO    : Bus 6430	: V=1.052192, theta=-28.928753 -> V=1.0, theta=0.0
% INFO    : Bus 6450	: V=1.010198, theta=-10.933937 -> V=1.0, theta=0.0
% INFO    : Bus 6455	: V=1.038267, theta=-22.056487 -> V=1.0, theta=0.0
% INFO    : Bus 6472	: V=1.042806, theta=-24.004462 -> V=1.0, theta=0.0
% INFO    : Bus 6474	: V=1.06557, theta=-7.808697 -> V=1.0, theta=0.0
% INFO    : Bus 6475	: V=1.026549, theta=-8.701988 -> V=1.0, theta=0.0
% INFO    : Bus 6478	: V=1.012128, theta=-14.390515 -> V=1.0, theta=0.0
% INFO    : Bus 6486	: V=1.048545, theta=-3.989815 -> V=1.0, theta=0.0
% INFO    : Bus 6495	: V=1.043059, theta=-21.768062 -> V=1.0, theta=0.0
% INFO    : Bus 6510	: V=1.050118, theta=-26.338765 -> V=1.0, theta=0.0
% INFO    : Bus 6516	: V=1.052452, theta=-3.60194 -> V=1.0, theta=0.0
% INFO    : Bus 6521	: V=1.046651, theta=-4.738353 -> V=1.0, theta=0.0
% INFO    : Bus 6532	: V=1.075728, theta=-31.435419 -> V=1.0, theta=0.0
% INFO    : Bus 6552	: V=1.048796, theta=-21.140924 -> V=1.0, theta=0.0
% INFO    : Bus 6555	: V=1.008884, theta=-43.693382 -> V=1.0, theta=0.0
% INFO    : Bus 6556	: V=1.052054, theta=-12.679594 -> V=1.0, theta=0.0
% INFO    : Bus 6563	: V=1.040617, theta=-24.64966 -> V=1.0, theta=0.0
% INFO    : Bus 6565	: V=1.033616, theta=-7.247992 -> V=1.0, theta=0.0
% INFO    : Bus 6570	: V=1.045563, theta=-20.766442 -> V=1.0, theta=0.0
% INFO    : Bus 6581	: V=1.042943, theta=-2.447442 -> V=1.0, theta=0.0
% INFO    : Bus 6612	: V=1.047964, theta=-31.701384 -> V=1.0, theta=0.0
% INFO    : Bus 6616	: V=1.044855, theta=-15.904052 -> V=1.0, theta=0.0
% INFO    : Bus 6619	: V=1.050275, theta=-15.385558 -> V=1.0, theta=0.0
% INFO    : Bus 6624	: V=1.058707, theta=4.26077 -> V=1.0, theta=0.0
% INFO    : Bus 6629	: V=1.054419, theta=-11.400101 -> V=1.0, theta=0.0
% INFO    : Bus 6630	: V=1.039511, theta=-24.152951 -> V=1.0, theta=0.0
% INFO    : Bus 6636	: V=1.036596, theta=0.577218 -> V=1.0, theta=0.0
% INFO    : Bus 6638	: V=1.020424, theta=-14.95076 -> V=1.0, theta=0.0
% INFO    : Bus 6639	: V=1.050408, theta=-2.453064 -> V=1.0, theta=0.0
% INFO    : Bus 6648	: V=1.06183, theta=-11.406171 -> V=1.0, theta=0.0
% INFO    : Bus 6664	: V=1.06971, theta=-46.294482 -> V=1.0, theta=0.0
% INFO    : Bus 6675	: V=1.035344, theta=-23.290216 -> V=1.0, theta=0.0
% INFO    : Bus 6684	: V=1.044665, theta=-25.545459 -> V=1.0, theta=0.0
% INFO    : Bus 6691	: V=1.083988, theta=-34.063221 -> V=1.0, theta=0.0
% INFO    : Bus 6692	: V=1.02441, theta=-15.580999 -> V=1.0, theta=0.0
% INFO    : Bus 6697	: V=1.0463, theta=-37.100468 -> V=1.0, theta=0.0
% INFO    : Bus 6714	: V=1.046238, theta=-0.834605 -> V=1.0, theta=0.0
% INFO    : Bus 6723	: V=1.032514, theta=-9.464819 -> V=1.0, theta=0.0
% INFO    : Bus 6730	: V=1.038253, theta=-21.079078 -> V=1.0, theta=0.0
% INFO    : Bus 6734	: V=1.061492, theta=-3.472634 -> V=1.0, theta=0.0
% INFO    : Bus 6735	: V=1.041984, theta=-1.292675 -> V=1.0, theta=0.0
% INFO    : Bus 6737	: V=1.021139, theta=-10.532887 -> V=1.0, theta=0.0
% INFO    : Bus 6738	: V=1.029435, theta=-24.781868 -> V=1.0, theta=0.0
% INFO    : Bus 6742	: V=1.037902, theta=-21.502542 -> V=1.0, theta=0.0
% INFO    : Bus 6744	: V=1.033513, theta=-10.221422 -> V=1.0, theta=0.0
% INFO    : Bus 6757	: V=1.040789, theta=-1.178761 -> V=1.0, theta=0.0
% INFO    : Bus 6763	: V=1.043751, theta=-24.236704 -> V=1.0, theta=0.0
% INFO    : Bus 6772	: V=1.045385, theta=-24.09701 -> V=1.0, theta=0.0
% INFO    : Bus 6773	: V=1.041981, theta=-24.273746 -> V=1.0, theta=0.0
% INFO    : Bus 6785	: V=1.054082, theta=-0.784591 -> V=1.0, theta=0.0
% INFO    : Bus 6791	: V=1.04692, theta=-25.227196 -> V=1.0, theta=0.0
% INFO    : Bus 6802	: V=1.034691, theta=-6.054841 -> V=1.0, theta=0.0
% INFO    : Bus 6806	: V=1.046591, theta=-21.264934 -> V=1.0, theta=0.0
% INFO    : Bus 6807	: V=1.006037, theta=-16.618507 -> V=1.0, theta=0.0
% INFO    : Bus 6816	: V=1.053803, theta=-24.150678 -> V=1.0, theta=0.0
% INFO    : Bus 6820	: V=1.049557, theta=-6.650937 -> V=1.0, theta=0.0
% INFO    : Bus 6828	: V=1.037156, theta=-13.39716 -> V=1.0, theta=0.0
% INFO    : Bus 6831	: V=1.031347, theta=-9.785828 -> V=1.0, theta=0.0
% INFO    : Bus 6837	: V=1.050311, theta=-7.914424 -> V=1.0, theta=0.0
% INFO    : Bus 6842	: V=1.037762, theta=-8.446373 -> V=1.0, theta=0.0
% INFO    : Bus 6844	: V=1.015966, theta=-29.284947 -> V=1.0, theta=0.0
% INFO    : Bus 6845	: V=1.055216, theta=-11.135397 -> V=1.0, theta=0.0
% INFO    : Bus 6846	: V=1.053078, theta=-4.617698 -> V=1.0, theta=0.0
% INFO    : Bus 6852	: V=1.031296, theta=-19.801967 -> V=1.0, theta=0.0
% INFO    : Bus 6854	: V=1.054902, theta=-11.343079 -> V=1.0, theta=0.0
% INFO    : Bus 6857	: V=1.021411, theta=-8.599284 -> V=1.0, theta=0.0
% INFO    : Bus 6880	: V=1.045265, theta=-4.460667 -> V=1.0, theta=0.0
% INFO    : Bus 6887	: V=1.045229, theta=-3.097099 -> V=1.0, theta=0.0
% INFO    : Bus 6888	: V=1.039234, theta=-13.670722 -> V=1.0, theta=0.0
% INFO    : Bus 6889	: V=1.040018, theta=2.414551 -> V=1.0, theta=0.0
% INFO    : Bus 6891	: V=1.042154, theta=-14.327292 -> V=1.0, theta=0.0
% INFO    : Bus 6897	: V=1.05642, theta=-16.592196 -> V=1.0, theta=0.0
% INFO    : Bus 6901	: V=1.010989, theta=-32.14614 -> V=1.0, theta=0.0
% INFO    : Bus 6908	: V=1.037832, theta=-40.113954 -> V=1.0, theta=0.0
% INFO    : Bus 6909	: V=1.036123, theta=-23.128738 -> V=1.0, theta=0.0
% INFO    : Bus 6921	: V=1.036075, theta=-1.608828 -> V=1.0, theta=0.0
% INFO    : Bus 6922	: V=1.036504, theta=-8.622098 -> V=1.0, theta=0.0
% INFO    : Bus 6926	: V=1.033188, theta=-12.416059 -> V=1.0, theta=0.0
% INFO    : Bus 6940	: V=1.057214, theta=-27.586432 -> V=1.0, theta=0.0
% INFO    : Bus 6947	: V=1.051367, theta=-3.749893 -> V=1.0, theta=0.0
% INFO    : Bus 6952	: V=1.074941, theta=-25.158601 -> V=1.0, theta=0.0
% INFO    : Bus 6954	: V=1.033937, theta=-20.057453 -> V=1.0, theta=0.0
% INFO    : Bus 6961	: V=1.046702, theta=-0.041292 -> V=1.0, theta=0.0
% INFO    : Bus 6969	: V=1.059486, theta=-23.158005 -> V=1.0, theta=0.0
% INFO    : Bus 6982	: V=1.036531, theta=-20.798066 -> V=1.0, theta=0.0
% INFO    : Bus 6989	: V=1.046262, theta=-24.006134 -> V=1.0, theta=0.0
% INFO    : Bus 6990	: V=1.049424, theta=-24.091607 -> V=1.0, theta=0.0
% INFO    : Bus 7014	: V=1.042775, theta=-2.603788 -> V=1.0, theta=0.0
% INFO    : Bus 7019	: V=1.042599, theta=-25.81851 -> V=1.0, theta=0.0
% INFO    : Bus 7021	: V=1.00593, theta=-17.187001 -> V=1.0, theta=0.0
% INFO    : Bus 7030	: V=1.065574, theta=-7.808728 -> V=1.0, theta=0.0
% INFO    : Bus 7036	: V=1.041241, theta=-12.591424 -> V=1.0, theta=0.0
% INFO    : Bus 7042	: V=1.05498, theta=-30.089269 -> V=1.0, theta=0.0
% INFO    : Bus 7047	: V=1.036489, theta=-21.901119 -> V=1.0, theta=0.0
% INFO    : Bus 7049	: V=1.049669, theta=-14.344403 -> V=1.0, theta=0.0
% INFO    : Bus 7050	: V=1.037777, theta=-21.239311 -> V=1.0, theta=0.0
% INFO    : Bus 7052	: V=1.047794, theta=-12.393218 -> V=1.0, theta=0.0
% INFO    : Bus 7056	: V=1.006597, theta=-4.279873 -> V=1.0, theta=0.0
% INFO    : Bus 7069	: V=1.041721, theta=-7.971411 -> V=1.0, theta=0.0
% INFO    : Bus 7070	: V=1.051529, theta=-13.392684 -> V=1.0, theta=0.0
% INFO    : Bus 7076	: V=1.032543, theta=-12.400826 -> V=1.0, theta=0.0
% INFO    : Bus 7092	: V=1.048118, theta=-25.098572 -> V=1.0, theta=0.0
% INFO    : Bus 7098	: V=1.040402, theta=-2.260554 -> V=1.0, theta=0.0
% INFO    : Bus 7115	: V=1.008722, theta=-16.289324 -> V=1.0, theta=0.0
% INFO    : Bus 7119	: V=1.011547, theta=-16.3375 -> V=1.0, theta=0.0
% INFO    : Bus 7124	: V=1.071843, theta=-27.185513 -> V=1.0, theta=0.0
% INFO    : Bus 7129	: V=1.03765, theta=-2.840915 -> V=1.0, theta=0.0
% INFO    : Bus 7132	: V=1.017449, theta=-15.909765 -> V=1.0, theta=0.0
% INFO    : Bus 7133	: V=1.034901, theta=-14.267058 -> V=1.0, theta=0.0
% INFO    : Bus 7144	: V=1.03015, theta=-13.008541 -> V=1.0, theta=0.0
% INFO    : Bus 7148	: V=1.050811, theta=-23.312468 -> V=1.0, theta=0.0
% INFO    : Bus 7159	: V=1.059575, theta=4.500856 -> V=1.0, theta=0.0
% INFO    : Bus 7162	: V=1.051693, theta=-13.395189 -> V=1.0, theta=0.0
% INFO    : Bus 7163	: V=1.04999, theta=-24.866445 -> V=1.0, theta=0.0
% INFO    : Bus 7164	: V=1.027379, theta=-22.063848 -> V=1.0, theta=0.0
% INFO    : Bus 7165	: V=1.071048, theta=-34.202221 -> V=1.0, theta=0.0
% INFO    : Bus 7178	: V=1.017469, theta=-14.250696 -> V=1.0, theta=0.0
% INFO    : Bus 7183	: V=1.107733, theta=-6.868685 -> V=1.0, theta=0.0
% INFO    : Bus 7202	: V=1.050711, theta=-3.937783 -> V=1.0, theta=0.0
% INFO    : Bus 7209	: V=1.051113, theta=-6.533675 -> V=1.0, theta=0.0
% INFO    : Bus 7222	: V=1.068964, theta=-23.827934 -> V=1.0, theta=0.0
% INFO    : Bus 7226	: V=1.022196, theta=-15.530828 -> V=1.0, theta=0.0
% INFO    : Bus 7231	: V=1.039985, theta=-11.495627 -> V=1.0, theta=0.0
% INFO    : Bus 7253	: V=1.048698, theta=-2.446191 -> V=1.0, theta=0.0
% INFO    : Bus 7256	: V=1.022568, theta=-35.394958 -> V=1.0, theta=0.0
% INFO    : Bus 7259	: V=1.06537, theta=-7.876917 -> V=1.0, theta=0.0
% INFO    : Bus 7264	: V=1.042846, theta=-10.973594 -> V=1.0, theta=0.0
% INFO    : Bus 7266	: V=1.032954, theta=-5.485507 -> V=1.0, theta=0.0
% INFO    : Bus 7267	: V=1.010817, theta=-7.692119 -> V=1.0, theta=0.0
% INFO    : Bus 7273	: V=1.042886, theta=-24.322652 -> V=1.0, theta=0.0
% INFO    : Bus 7274	: V=1.040156, theta=-3.899721 -> V=1.0, theta=0.0
% INFO    : Bus 7282	: V=1.034538, theta=-4.68119 -> V=1.0, theta=0.0
% INFO    : Bus 7284	: V=1.094644, theta=-0.869931 -> V=1.0, theta=0.0
% INFO    : Bus 7289	: V=1.054049, theta=-6.174395 -> V=1.0, theta=0.0
% INFO    : Bus 7309	: V=1.054902, theta=-11.343079 -> V=1.0, theta=0.0
% INFO    : Bus 7316	: V=1.044717, theta=-7.284069 -> V=1.0, theta=0.0
% INFO    : Bus 7325	: V=1.052061, theta=-12.679657 -> V=1.0, theta=0.0
% INFO    : Bus 7327	: V=1.043172, theta=-18.073929 -> V=1.0, theta=0.0
% INFO    : Bus 7328	: V=0.999675, theta=-14.476061 -> V=1.0, theta=0.0
% INFO    : Bus 7338	: V=1.045891, theta=-14.743514 -> V=1.0, theta=0.0
% INFO    : Bus 7341	: V=1.040136, theta=-2.402429 -> V=1.0, theta=0.0
% INFO    : Bus 7342	: V=1.018398, theta=-16.108009 -> V=1.0, theta=0.0
% INFO    : Bus 7351	: V=1.037551, theta=-2.8443 -> V=1.0, theta=0.0
% INFO    : Bus 7353	: V=0.985936, theta=-22.42059 -> V=1.0, theta=0.0
% INFO    : Bus 7361	: V=1.053815, theta=-15.271705 -> V=1.0, theta=0.0
% INFO    : Bus 7367	: V=1.028631, theta=-18.905659 -> V=1.0, theta=0.0
% INFO    : Bus 7373	: V=1.071954, theta=-23.60091 -> V=1.0, theta=0.0
% INFO    : Bus 7377	: V=1.014168, theta=-16.130077 -> V=1.0, theta=0.0
% INFO    : Bus 7380	: V=0.992016, theta=-14.57117 -> V=1.0, theta=0.0
% INFO    : Bus 7396	: V=1.019741, theta=-19.557023 -> V=1.0, theta=0.0
% INFO    : Bus 7422	: V=1.033674, theta=-10.805957 -> V=1.0, theta=0.0
% INFO    : Bus 7437	: V=1.04383, theta=-25.64578 -> V=1.0, theta=0.0
% INFO    : Bus 7438	: V=1.035924, theta=-12.727575 -> V=1.0, theta=0.0
% INFO    : Bus 7464	: V=1.041056, theta=-12.617278 -> V=1.0, theta=0.0
% INFO    : Bus 7466	: V=1.057257, theta=-34.871885 -> V=1.0, theta=0.0
% INFO    : Bus 7471	: V=1.020554, theta=-6.279485 -> V=1.0, theta=0.0
% INFO    : Bus 7473	: V=1.035336, theta=-16.025005 -> V=1.0, theta=0.0
% INFO    : Bus 7474	: V=1.027108, theta=-14.200631 -> V=1.0, theta=0.0
% INFO    : Bus 7485	: V=1.042606, theta=-25.826706 -> V=1.0, theta=0.0
% INFO    : Bus 7491	: V=1.012242, theta=-21.474958 -> V=1.0, theta=0.0
% INFO    : Bus 7495	: V=1.035256, theta=-15.196734 -> V=1.0, theta=0.0
% INFO    : Bus 7507	: V=1.04914, theta=-24.08765 -> V=1.0, theta=0.0
% INFO    : Bus 7513	: V=0.993009, theta=-15.030612 -> V=1.0, theta=0.0
% INFO    : Bus 7519	: V=1.036786, theta=-10.798224 -> V=1.0, theta=0.0
% INFO    : Bus 7520	: V=1.037447, theta=-9.123264 -> V=1.0, theta=0.0
% INFO    : Bus 7522	: V=0.99994, theta=-10.953994 -> V=1.0, theta=0.0
% INFO    : Bus 7523	: V=1.052161, theta=-0.72038 -> V=1.0, theta=0.0
% INFO    : Bus 7530	: V=1.046869, theta=-19.820201 -> V=1.0, theta=0.0
% INFO    : Bus 7537	: V=0.989983, theta=-15.6248 -> V=1.0, theta=0.0
% INFO    : Bus 7539	: V=1.053724, theta=-12.373239 -> V=1.0, theta=0.0
% INFO    : Bus 7541	: V=1.054084, theta=-16.465783 -> V=1.0, theta=0.0
% INFO    : Bus 7571	: V=1.044943, theta=-13.985525 -> V=1.0, theta=0.0
% INFO    : Bus 7576	: V=1.04028, theta=-12.028046 -> V=1.0, theta=0.0
% INFO    : Bus 7577	: V=1.0481, theta=-10.467484 -> V=1.0, theta=0.0
% INFO    : Bus 7579	: V=1.048022, theta=-26.50227 -> V=1.0, theta=0.0
% INFO    : Bus 7580	: V=1.05695, theta=-11.9558 -> V=1.0, theta=0.0
% INFO    : Bus 7582	: V=1.035758, theta=-24.450751 -> V=1.0, theta=0.0
% INFO    : Bus 7583	: V=1.04744, theta=-0.936009 -> V=1.0, theta=0.0
% INFO    : Bus 7599	: V=1.034704, theta=-6.055108 -> V=1.0, theta=0.0
% INFO    : Bus 7624	: V=1.01592, theta=-20.903943 -> V=1.0, theta=0.0
% INFO    : Bus 7626	: V=1.032312, theta=-12.417124 -> V=1.0, theta=0.0
% INFO    : Bus 7635	: V=1.050003, theta=-7.891572 -> V=1.0, theta=0.0
% INFO    : Bus 7640	: V=1.033083, theta=-6.005598 -> V=1.0, theta=0.0
% INFO    : Bus 7641	: V=1.051427, theta=-6.243524 -> V=1.0, theta=0.0
% INFO    : Bus 7647	: V=1.063763, theta=-20.174055 -> V=1.0, theta=0.0
% INFO    : Bus 7653	: V=1.0368, theta=-22.767059 -> V=1.0, theta=0.0
% INFO    : Bus 7663	: V=1.042204, theta=-11.956017 -> V=1.0, theta=0.0
% INFO    : Bus 7691	: V=1.026843, theta=-3.944271 -> V=1.0, theta=0.0
% INFO    : Bus 7694	: V=1.027078, theta=-14.861465 -> V=1.0, theta=0.0
% INFO    : Bus 7697	: V=1.052424, theta=-3.583012 -> V=1.0, theta=0.0
% INFO    : Bus 7700	: V=1.018432, theta=-10.528155 -> V=1.0, theta=0.0
% INFO    : Bus 7702	: V=1.025153, theta=-16.313747 -> V=1.0, theta=0.0
% INFO    : Bus 7726	: V=1.018323, theta=-10.493485 -> V=1.0, theta=0.0
% INFO    : Bus 7738	: V=1.027755, theta=-21.847912 -> V=1.0, theta=0.0
% INFO    : Bus 7752	: V=1.03043, theta=-18.412915 -> V=1.0, theta=0.0
% INFO    : Bus 7766	: V=1.033279, theta=-12.689648 -> V=1.0, theta=0.0
% INFO    : Bus 7770	: V=1.031073, theta=-44.333742 -> V=1.0, theta=0.0
% INFO    : Bus 7772	: V=1.053846, theta=-25.615931 -> V=1.0, theta=0.0
% INFO    : Bus 7775	: V=1.054984, theta=-28.678026 -> V=1.0, theta=0.0
% INFO    : Bus 7776	: V=1.072261, theta=6.181044 -> V=1.0, theta=0.0
% INFO    : Bus 7778	: V=1.057591, theta=-16.510132 -> V=1.0, theta=0.0
% INFO    : Bus 7791	: V=1.03015, theta=-12.988362 -> V=1.0, theta=0.0
% INFO    : Bus 7797	: V=1.051084, theta=-24.096828 -> V=1.0, theta=0.0
% INFO    : Bus 7808	: V=1.054562, theta=-0.188042 -> V=1.0, theta=0.0
% INFO    : Bus 7809	: V=1.024952, theta=-11.538551 -> V=1.0, theta=0.0
% INFO    : Bus 7824	: V=1.047756, theta=-6.282298 -> V=1.0, theta=0.0
% INFO    : Bus 7831	: V=1.011199, theta=-11.417611 -> V=1.0, theta=0.0
% INFO    : Bus 7840	: V=1.049049, theta=-2.414341 -> V=1.0, theta=0.0
% INFO    : Bus 7842	: V=1.001912, theta=-12.534976 -> V=1.0, theta=0.0
% INFO    : Bus 7847	: V=1.040499, theta=-8.878125 -> V=1.0, theta=0.0
% INFO    : Bus 7857	: V=1.050458, theta=0.170436 -> V=1.0, theta=0.0
% INFO    : Bus 7862	: V=1.040593, theta=-21.115869 -> V=1.0, theta=0.0
% INFO    : Bus 7865	: V=1.074298, theta=-26.36902 -> V=1.0, theta=0.0
% INFO    : Bus 7873	: V=1.021235, theta=-15.229234 -> V=1.0, theta=0.0
% INFO    : Bus 7881	: V=1.055617, theta=-14.956341 -> V=1.0, theta=0.0
% INFO    : Bus 7883	: V=1.050929, theta=-28.78941 -> V=1.0, theta=0.0
% INFO    : Bus 7885	: V=1.037839, theta=-21.110646 -> V=1.0, theta=0.0
% INFO    : Bus 7886	: V=1.018149, theta=-19.303853 -> V=1.0, theta=0.0
% INFO    : Bus 7892	: V=1.053815, theta=-11.294264 -> V=1.0, theta=0.0
% INFO    : Bus 7895	: V=1.059845, theta=-19.561088 -> V=1.0, theta=0.0
% INFO    : Bus 7903	: V=1.072768, theta=-41.998744 -> V=1.0, theta=0.0
% INFO    : Bus 7905	: V=1.046655, theta=-17.893306 -> V=1.0, theta=0.0
% INFO    : Bus 7913	: V=1.063764, theta=-8.906151 -> V=1.0, theta=0.0
% INFO    : Bus 7923	: V=1.038632, theta=-22.138858 -> V=1.0, theta=0.0
% INFO    : Bus 7937	: V=1.040168, theta=-7.402075 -> V=1.0, theta=0.0
% INFO    : Bus 7943	: V=1.047179, theta=-16.175311 -> V=1.0, theta=0.0
% INFO    : Bus 7945	: V=1.031087, theta=-5.74962 -> V=1.0, theta=0.0
% INFO    : Bus 7955	: V=1.068312, theta=-23.349161 -> V=1.0, theta=0.0
% INFO    : Bus 7961	: V=1.034289, theta=-8.616758 -> V=1.0, theta=0.0
% INFO    : Bus 7967	: V=1.043007, theta=-11.416934 -> V=1.0, theta=0.0
% INFO    : Bus 7972	: V=1.035175, theta=-19.298443 -> V=1.0, theta=0.0
% INFO    : Bus 7974	: V=1.033995, theta=-20.055775 -> V=1.0, theta=0.0
% INFO    : Bus 7982	: V=1.036111, theta=-23.13213 -> V=1.0, theta=0.0
% INFO    : Bus 7988	: V=1.0339, theta=-2.136803 -> V=1.0, theta=0.0
% INFO    : Bus 7989	: V=1.052062, theta=-3.729978 -> V=1.0, theta=0.0
% INFO    : Bus 7994	: V=1.015764, theta=-16.263273 -> V=1.0, theta=0.0
% INFO    : Bus 7998	: V=1.048854, theta=4.223749 -> V=1.0, theta=0.0
% INFO    : Bus 8005	: V=1.027697, theta=-13.719399 -> V=1.0, theta=0.0
% INFO    : Bus 8030	: V=1.034376, theta=-4.451962 -> V=1.0, theta=0.0
% INFO    : Bus 8035	: V=1.023645, theta=-16.359288 -> V=1.0, theta=0.0
% INFO    : Bus 8043	: V=1.066913, theta=-11.239517 -> V=1.0, theta=0.0
% INFO    : Bus 8057	: V=1.045952, theta=-8.643584 -> V=1.0, theta=0.0
% INFO    : Bus 8060	: V=1.05168, theta=-13.395033 -> V=1.0, theta=0.0
% INFO    : Bus 8104	: V=1.070946, theta=-25.178857 -> V=1.0, theta=0.0
% INFO    : Bus 8107	: V=1.034732, theta=-23.363006 -> V=1.0, theta=0.0
% INFO    : Bus 8109	: V=1.067387, theta=-21.117921 -> V=1.0, theta=0.0
% INFO    : Bus 8112	: V=1.031544, theta=-3.541639 -> V=1.0, theta=0.0
% INFO    : Bus 8128	: V=1.090736, theta=-9.663123 -> V=1.0, theta=0.0
% INFO    : Bus 8151	: V=1.044491, theta=-25.577335 -> V=1.0, theta=0.0
% INFO    : Bus 8158	: V=1.052602, theta=-0.559615 -> V=1.0, theta=0.0
% INFO    : Bus 8165	: V=1.061504, theta=-3.473077 -> V=1.0, theta=0.0
% INFO    : Bus 8180	: V=1.075394, theta=-30.774767 -> V=1.0, theta=0.0
% INFO    : Bus 8189	: V=1.042203, theta=-18.144075 -> V=1.0, theta=0.0
% INFO    : Bus 8190	: V=1.048784, theta=-10.298904 -> V=1.0, theta=0.0
% INFO    : Bus 8191	: V=1.051859, theta=-15.264149 -> V=1.0, theta=0.0
% INFO    : Bus 8195	: V=1.02377, theta=-17.045599 -> V=1.0, theta=0.0
% INFO    : Bus 8200	: V=1.021119, theta=-6.153606 -> V=1.0, theta=0.0
% INFO    : Bus 8209	: V=1.033486, theta=-20.136338 -> V=1.0, theta=0.0
% INFO    : Bus 8214	: V=1.04259, theta=-11.470366 -> V=1.0, theta=0.0
% INFO    : Bus 8222	: V=1.02335, theta=-10.438616 -> V=1.0, theta=0.0
% INFO    : Bus 8225	: V=1.071504, theta=-11.705551 -> V=1.0, theta=0.0
% INFO    : Bus 8250	: V=1.04037, theta=-25.998622 -> V=1.0, theta=0.0
% INFO    : Bus 8255	: V=1.021879, theta=-13.796655 -> V=1.0, theta=0.0
% INFO    : Bus 8265	: V=1.066641, theta=-23.859918 -> V=1.0, theta=0.0
% INFO    : Bus 8267	: V=1.043326, theta=-9.93055 -> V=1.0, theta=0.0
% INFO    : Bus 8291	: V=1.043396, theta=-7.697439 -> V=1.0, theta=0.0
% INFO    : Bus 8293	: V=1.048233, theta=-24.806368 -> V=1.0, theta=0.0
% INFO    : Bus 8294	: V=1.043617, theta=-11.857424 -> V=1.0, theta=0.0
% INFO    : Bus 8307	: V=1.051092, theta=-3.882875 -> V=1.0, theta=0.0
% INFO    : Bus 8310	: V=1.049352, theta=-8.638203 -> V=1.0, theta=0.0
% INFO    : Bus 8311	: V=1.035451, theta=-15.519296 -> V=1.0, theta=0.0
% INFO    : Bus 8312	: V=1.07814, theta=-12.220054 -> V=1.0, theta=0.0
% INFO    : Bus 8316	: V=1.084023, theta=-26.486866 -> V=1.0, theta=0.0
% INFO    : Bus 8328	: V=1.041343, theta=-24.415623 -> V=1.0, theta=0.0
% INFO    : Bus 8331	: V=1.047611, theta=-12.932386 -> V=1.0, theta=0.0
% INFO    : Bus 8334	: V=1.034142, theta=-14.749149 -> V=1.0, theta=0.0
% INFO    : Bus 8347	: V=0.988493, theta=-18.64268 -> V=1.0, theta=0.0
% INFO    : Bus 8361	: V=1.073653, theta=-26.422933 -> V=1.0, theta=0.0
% INFO    : Bus 8367	: V=1.034784, theta=-6.699666 -> V=1.0, theta=0.0
% INFO    : Bus 8369	: V=1.02695, theta=-9.179276 -> V=1.0, theta=0.0
% INFO    : Bus 8373	: V=1.071546, theta=-48.132392 -> V=1.0, theta=0.0
% INFO    : Bus 8397	: V=1.042817, theta=-25.347834 -> V=1.0, theta=0.0
% INFO    : Bus 8405	: V=1.036479, theta=-12.357404 -> V=1.0, theta=0.0
% INFO    : Bus 8406	: V=1.050892, theta=-25.13855 -> V=1.0, theta=0.0
% INFO    : Bus 8411	: V=1.042819, theta=-25.804727 -> V=1.0, theta=0.0
% INFO    : Bus 8439	: V=0.998187, theta=-23.461096 -> V=1.0, theta=0.0
% INFO    : Bus 8448	: V=1.018069, theta=-20.595036 -> V=1.0, theta=0.0
% INFO    : Bus 8458	: V=1.042925, theta=-9.400848 -> V=1.0, theta=0.0
% INFO    : Bus 8466	: V=1.045302, theta=-4.473537 -> V=1.0, theta=0.0
% INFO    : Bus 8467	: V=0.98622, theta=-22.981008 -> V=1.0, theta=0.0
% INFO    : Bus 8468	: V=1.005238, theta=-14.948026 -> V=1.0, theta=0.0
% INFO    : Bus 8473	: V=1.039202, theta=-8.879096 -> V=1.0, theta=0.0
% INFO    : Bus 8475	: V=1.072229, theta=-47.841521 -> V=1.0, theta=0.0
% INFO    : Bus 8477	: V=1.068335, theta=-10.11476 -> V=1.0, theta=0.0
% INFO    : Bus 8478	: V=1.04799, theta=-8.490097 -> V=1.0, theta=0.0
% INFO    : Bus 8485	: V=1.039726, theta=-7.369105 -> V=1.0, theta=0.0
% INFO    : Bus 8486	: V=1.04752, theta=-19.530978 -> V=1.0, theta=0.0
% INFO    : Bus 8487	: V=1.003338, theta=-3.846694 -> V=1.0, theta=0.0
% INFO    : Bus 8494	: V=1.08964, theta=-9.846898 -> V=1.0, theta=0.0
% INFO    : Bus 8497	: V=1.046629, theta=-14.553599 -> V=1.0, theta=0.0
% INFO    : Bus 8507	: V=1.074417, theta=-26.347125 -> V=1.0, theta=0.0
% INFO    : Bus 8511	: V=1.04106, theta=-24.505876 -> V=1.0, theta=0.0
% INFO    : Bus 8515	: V=1.053872, theta=-12.378436 -> V=1.0, theta=0.0
% INFO    : Bus 8522	: V=1.019671, theta=-15.723378 -> V=1.0, theta=0.0
% INFO    : Bus 8535	: V=1.036308, theta=-21.925576 -> V=1.0, theta=0.0
% INFO    : Bus 8542	: V=1.044937, theta=-21.028222 -> V=1.0, theta=0.0
% INFO    : Bus 8546	: V=1.038205, theta=-11.643532 -> V=1.0, theta=0.0
% INFO    : Bus 8560	: V=0.984498, theta=-18.190495 -> V=1.0, theta=0.0
% INFO    : Bus 8564	: V=1.019727, theta=-19.556828 -> V=1.0, theta=0.0
% INFO    : Bus 8568	: V=1.027945, theta=-6.041782 -> V=1.0, theta=0.0
% INFO    : Bus 8578	: V=1.049043, theta=-21.931929 -> V=1.0, theta=0.0
% INFO    : Bus 8592	: V=1.051916, theta=-3.764146 -> V=1.0, theta=0.0
% INFO    : Bus 8626	: V=0.99463, theta=-17.562106 -> V=1.0, theta=0.0
% INFO    : Bus 8627	: V=1.048517, theta=-26.395781 -> V=1.0, theta=0.0
% INFO    : Bus 8628	: V=1.042001, theta=-23.598682 -> V=1.0, theta=0.0
% INFO    : Bus 8636	: V=1.041292, theta=-21.579777 -> V=1.0, theta=0.0
% INFO    : Bus 8651	: V=1.024808, theta=-17.313776 -> V=1.0, theta=0.0
% INFO    : Bus 8653	: V=1.036488, theta=-16.021006 -> V=1.0, theta=0.0
% INFO    : Bus 8656	: V=1.031987, theta=-8.436898 -> V=1.0, theta=0.0
% INFO    : Bus 8669	: V=1.050943, theta=-15.2714 -> V=1.0, theta=0.0
% INFO    : Bus 8670	: V=1.049066, theta=-6.522112 -> V=1.0, theta=0.0
% INFO    : Bus 8672	: V=1.023418, theta=-20.934804 -> V=1.0, theta=0.0
% INFO    : Bus 8676	: V=1.018762, theta=-21.841814 -> V=1.0, theta=0.0
% INFO    : Bus 8677	: V=1.018085, theta=-10.22697 -> V=1.0, theta=0.0
% INFO    : Bus 8683	: V=1.041975, theta=-24.273671 -> V=1.0, theta=0.0
% INFO    : Bus 8689	: V=1.036224, theta=-20.697926 -> V=1.0, theta=0.0
% INFO    : Bus 8691	: V=1.047013, theta=-33.585967 -> V=1.0, theta=0.0
% INFO    : Bus 8704	: V=1.039389, theta=-7.999499 -> V=1.0, theta=0.0
% INFO    : Bus 8707	: V=1.032359, theta=-11.707737 -> V=1.0, theta=0.0
% INFO    : Bus 8711	: V=1.040912, theta=-12.07314 -> V=1.0, theta=0.0
% INFO    : Bus 8721	: V=1.054052, theta=-15.864679 -> V=1.0, theta=0.0
% INFO    : Bus 8722	: V=1.072192, theta=-25.045427 -> V=1.0, theta=0.0
% INFO    : Bus 8732	: V=1.038041, theta=-21.15003 -> V=1.0, theta=0.0
% INFO    : Bus 8743	: V=1.035613, theta=-34.477305 -> V=1.0, theta=0.0
% INFO    : Bus 8748	: V=1.067084, theta=-49.622846 -> V=1.0, theta=0.0
% INFO    : Bus 8763	: V=1.04005, theta=2.599263 -> V=1.0, theta=0.0
% INFO    : Bus 8765	: V=1.051157, theta=-15.257422 -> V=1.0, theta=0.0
% INFO    : Bus 8787	: V=1.066984, theta=-16.98525 -> V=1.0, theta=0.0
% INFO    : Bus 8788	: V=1.046176, theta=-5.977711 -> V=1.0, theta=0.0
% INFO    : Bus 8791	: V=1.057978, theta=-22.356166 -> V=1.0, theta=0.0
% INFO    : Bus 8795	: V=1.054157, theta=-0.136311 -> V=1.0, theta=0.0
% INFO    : Bus 8804	: V=1.049065, theta=-9.481469 -> V=1.0, theta=0.0
% INFO    : Bus 8807	: V=1.05109, theta=-3.882868 -> V=1.0, theta=0.0
% INFO    : Bus 8808	: V=1.060353, theta=-25.817931 -> V=1.0, theta=0.0
% INFO    : Bus 8809	: V=1.029974, theta=-32.515321 -> V=1.0, theta=0.0
% INFO    : Bus 8818	: V=1.050791, theta=0.636035 -> V=1.0, theta=0.0
% INFO    : Bus 8825	: V=1.014963, theta=-2.776003 -> V=1.0, theta=0.0
% INFO    : Bus 8829	: V=1.044583, theta=-21.076938 -> V=1.0, theta=0.0
% INFO    : Bus 8834	: V=1.003582, theta=-22.536497 -> V=1.0, theta=0.0
% INFO    : Bus 8835	: V=1.036698, theta=-22.906459 -> V=1.0, theta=0.0
% INFO    : Bus 8843	: V=1.054844, theta=-11.164607 -> V=1.0, theta=0.0
% INFO    : Bus 8846	: V=1.070172, theta=7.811263 -> V=1.0, theta=0.0
% INFO    : Bus 8853	: V=1.052314, theta=-36.519464 -> V=1.0, theta=0.0
% INFO    : Bus 8854	: V=1.027794, theta=-44.429467 -> V=1.0, theta=0.0
% INFO    : Bus 8860	: V=1.020431, theta=-10.190501 -> V=1.0, theta=0.0
% INFO    : Bus 8864	: V=1.048228, theta=-31.670524 -> V=1.0, theta=0.0
% INFO    : Bus 8872	: V=1.053844, theta=-15.88923 -> V=1.0, theta=0.0
% INFO    : Bus 8873	: V=1.071142, theta=-27.284425 -> V=1.0, theta=0.0
% INFO    : Bus 8874	: V=1.046146, theta=-20.00976 -> V=1.0, theta=0.0
% INFO    : Bus 8877	: V=1.039567, theta=-20.646198 -> V=1.0, theta=0.0
% INFO    : Bus 8879	: V=1.036915, theta=-22.747121 -> V=1.0, theta=0.0
% INFO    : Bus 8886	: V=0.983701, theta=-3.785162 -> V=1.0, theta=0.0
% INFO    : Bus 8887	: V=1.045962, theta=1.729833 -> V=1.0, theta=0.0
% INFO    : Bus 8893	: V=1.05128, theta=-15.163258 -> V=1.0, theta=0.0
% INFO    : Bus 8900	: V=1.047741, theta=-23.703947 -> V=1.0, theta=0.0
% INFO    : Bus 8903	: V=1.020268, theta=-11.421507 -> V=1.0, theta=0.0
% INFO    : Bus 8906	: V=1.036, theta=-23.062052 -> V=1.0, theta=0.0
% INFO    : Bus 8913	: V=1.040075, theta=-20.555337 -> V=1.0, theta=0.0
% INFO    : Bus 8930	: V=0.991658, theta=-18.577239 -> V=1.0, theta=0.0
% INFO    : Bus 8931	: V=1.090352, theta=-9.661963 -> V=1.0, theta=0.0
% INFO    : Bus 8947	: V=1.03998, theta=-11.496674 -> V=1.0, theta=0.0
% INFO    : Bus 8950	: V=1.047268, theta=-14.839334 -> V=1.0, theta=0.0
% INFO    : Bus 8961	: V=1.035459, theta=-14.187287 -> V=1.0, theta=0.0
% INFO    : Bus 8975	: V=1.04225, theta=-24.276259 -> V=1.0, theta=0.0
% INFO    : Bus 8976	: V=1.046972, theta=-17.074322 -> V=1.0, theta=0.0
% INFO    : Bus 8980	: V=1.042994, theta=-11.072487 -> V=1.0, theta=0.0
% INFO    : Bus 8989	: V=1.043398, theta=-25.575347 -> V=1.0, theta=0.0
% INFO    : Bus 8992	: V=1.051114, theta=-3.785395 -> V=1.0, theta=0.0
% INFO    : Bus 8997	: V=0.997131, theta=-13.27089 -> V=1.0, theta=0.0
% INFO    : Bus 8999	: V=1.044391, theta=-21.558302 -> V=1.0, theta=0.0
% INFO    : Bus 9002	: V=1.021009, theta=-10.528192 -> V=1.0, theta=0.0
% INFO    : Bus 9011	: V=1.036275, theta=-23.026084 -> V=1.0, theta=0.0
% INFO    : Bus 9012	: V=1.048758, theta=1.093286 -> V=1.0, theta=0.0
% INFO    : Bus 9014	: V=1.051072, theta=-6.681904 -> V=1.0, theta=0.0
% INFO    : Bus 9018	: V=1.022715, theta=-6.602667 -> V=1.0, theta=0.0
% INFO    : Bus 9019	: V=1.040421, theta=-24.677298 -> V=1.0, theta=0.0
% INFO    : Bus 9021	: V=1.035437, theta=-6.308005 -> V=1.0, theta=0.0
% INFO    : Bus 9033	: V=1.049786, theta=-26.382004 -> V=1.0, theta=0.0
% INFO    : Bus 9045	: V=1.039905, theta=-24.629587 -> V=1.0, theta=0.0
% INFO    : Bus 9051	: V=1.036594, theta=0.577238 -> V=1.0, theta=0.0
% INFO    : Bus 9059	: V=1.072487, theta=-27.192131 -> V=1.0, theta=0.0
% INFO    : Bus 9065	: V=1.040021, theta=2.414524 -> V=1.0, theta=0.0
% INFO    : Bus 9066	: V=1.019989, theta=-20.806005 -> V=1.0, theta=0.0
% INFO    : Bus 9067	: V=1.040924, theta=1.549232 -> V=1.0, theta=0.0
% INFO    : Bus 9091	: V=1.038554, theta=-9.767436 -> V=1.0, theta=0.0
% INFO    : Bus 9101	: V=1.02885, theta=-21.628013 -> V=1.0, theta=0.0
% INFO    : Bus 9108	: V=1.046626, theta=-16.441009 -> V=1.0, theta=0.0
% INFO    : Bus 9109	: V=1.036596, theta=0.577218 -> V=1.0, theta=0.0
% INFO    : Bus 9112	: V=1.047611, theta=-12.93238 -> V=1.0, theta=0.0
% INFO    : Bus 9119	: V=1.04289, theta=-20.527494 -> V=1.0, theta=0.0
% INFO    : Bus 9128	: V=1.042244, theta=-2.676445 -> V=1.0, theta=0.0
% INFO    : Bus 9130	: V=1.049965, theta=-30.721639 -> V=1.0, theta=0.0
% INFO    : Bus 9131	: V=1.051124, theta=-24.097314 -> V=1.0, theta=0.0
% INFO    : Bus 9137	: V=1.049768, theta=-26.378636 -> V=1.0, theta=0.0
% INFO    : Bus 9140	: V=1.049624, theta=-5.232971 -> V=1.0, theta=0.0
% INFO    : Bus 9150	: V=1.037969, theta=-13.200551 -> V=1.0, theta=0.0
% INFO    : Bus 9155	: V=1.02382, theta=-20.860292 -> V=1.0, theta=0.0
% INFO    : Bus 9158	: V=1.025798, theta=-14.56483 -> V=1.0, theta=0.0
% INFO    : Bus 9164	: V=1.001887, theta=-19.403088 -> V=1.0, theta=0.0
% INFO    : Bus 9173	: V=1.032906, theta=-20.202148 -> V=1.0, theta=0.0
% INFO    : Bus 9174	: V=1.03623, theta=-32.377948 -> V=1.0, theta=0.0
% INFO    : Bus 9176	: V=1.047842, theta=-12.93497 -> V=1.0, theta=0.0
% INFO    : Bus 9180	: V=1.061189, theta=-8.603491 -> V=1.0, theta=0.0
% INFO    : Bus 9181	: V=1.032498, theta=-9.466095 -> V=1.0, theta=0.0
% INFO    : Bus 9185	: V=1.051815, theta=-6.62338 -> V=1.0, theta=0.0
% INFO    : Bus 9189	: V=1.048019, theta=-25.022568 -> V=1.0, theta=0.0
% INFO    : Bus 9191	: V=1.073685, theta=-24.80852 -> V=1.0, theta=0.0
% INFO    : Bus 9203	: V=1.001613, theta=-12.605605 -> V=1.0, theta=0.0
% INFO    : Bus 9213	: V=1.023742, theta=-4.653017 -> V=1.0, theta=0.0
% INFO    : Bus 9217	: V=1.040155, theta=-8.875709 -> V=1.0, theta=0.0
% INFO    : Bus 9222	: V=1.053345, theta=-16.073005 -> V=1.0, theta=0.0
% INFO    : Bus 9231	: V=1.029833, theta=-19.150137 -> V=1.0, theta=0.0
% INFO    : Bus 9241	: V=1.049081, theta=-9.481609 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 124	: Pg=861.3, Qg=56.53 -> Pg=666.665, Qg=133.865
% INFO    : Gen at bus 124	: Vg=1.081537 -> Vg=1.0
% INFO    : Gen at bus 150	: Pg=67.29, Qg=-7.99 -> Pg=80.0, Qg=27.275
% INFO    : Gen at bus 150	: Vg=1.062805 -> Vg=1.0
% INFO    : Gen at bus 221	: Pg=-155.39, Qg=97.68 -> Pg=-53.59, Qg=59.31
% INFO    : Gen at bus 221	: Vg=0.984682 -> Vg=1.0
% INFO    : Gen at bus 338	: Pg=83.7, Qg=2.5 -> Pg=60.0, Qg=18.19
% INFO    : Gen at bus 338	: Vg=1.048249 -> Vg=1.0
% INFO    : Gen at bus 352	: Pg=1250.4, Qg=278.94 -> Pg=1333.335, Qg=314.335
% INFO    : Gen at bus 352	: Vg=1.055378 -> Vg=1.0
% INFO    : Gen at bus 413	: Pg=231.0, Qg=19.11 -> Pg=140.0, Qg=37.14
% INFO    : Gen at bus 413	: Vg=1.05013 -> Vg=1.0
% INFO    : Gen at bus 453	: Pg=260.1, Qg=57.98 -> Pg=270.0, Qg=91.415
% INFO    : Gen at bus 453	: Vg=1.018914 -> Vg=1.0
% INFO    : Gen at bus 516	: Pg=539.4, Qg=190.43 -> Pg=400.0, Qg=77.56
% INFO    : Gen at bus 516	: Vg=1.075592 -> Vg=1.0
% INFO    : Gen at bus 564	: Pg=-51.67, Qg=-3.31 -> Pg=15.555, Qg=-0.44
% INFO    : Gen at bus 564	: Vg=1.069817 -> Vg=1.0
% INFO    : Gen at bus 583	: Pg=-270.0, Qg=3.65 -> Pg=-130.0, Qg=5.425
% INFO    : Gen at bus 583	: Vg=1.045397 -> Vg=1.0
% INFO    : Gen at bus 615	: Pg=38.2, Qg=-0.39 -> Pg=20.0, Qg=4.65
% INFO    : Gen at bus 615	: Vg=1.063876 -> Vg=1.0
% INFO    : Gen at bus 616	: Pg=379.2, Qg=37.76 -> Pg=320.0, Qg=68.37
% INFO    : Gen at bus 616	: Vg=1.048713 -> Vg=1.0
% INFO    : Gen at bus 639	: Pg=-46.2, Qg=112.55 -> Pg=19.2, Qg=48.31
% INFO    : Gen at bus 639	: Vg=1.051376 -> Vg=1.0
% INFO    : Gen at bus 682	: Pg=37.4, Qg=8.53 -> Pg=40.0, Qg=13.855
% INFO    : Gen at bus 682	: Vg=1.0691 -> Vg=1.0
% INFO    : Gen at bus 749	: Pg=198.88, Qg=-11.17 -> Pg=120.0, Qg=30.925
% INFO    : Gen at bus 749	: Vg=1.057884 -> Vg=1.0
% INFO    : Gen at bus 757	: Pg=116.7, Qg=13.66 -> Pg=60.0, Qg=13.945
% INFO    : Gen at bus 757	: Vg=1.017567 -> Vg=1.0
% INFO    : Gen at bus 776	: Pg=-111.4, Qg=3.36 -> Pg=-24.265, Qg=5.715
% INFO    : Gen at bus 776	: Vg=1.026368 -> Vg=1.0
% INFO    : Gen at bus 778	: Pg=16.5, Qg=-0.67 -> Pg=16.79, Qg=1.505
% INFO    : Gen at bus 778	: Vg=1.049411 -> Vg=1.0
% INFO    : Gen at bus 795	: Pg=58.4, Qg=7.75 -> Pg=40.0, Qg=11.855
% INFO    : Gen at bus 795	: Vg=1.035522 -> Vg=1.0
% INFO    : Gen at bus 803	: Pg=-89.2, Qg=-1.52 -> Pg=-9.465, Qg=24.245
% INFO    : Gen at bus 803	: Vg=1.041369 -> Vg=1.0
% INFO    : Gen at bus 823	: Pg=1274.2, Qg=289.74 -> Pg=1333.335, Qg=314.185
% INFO    : Gen at bus 823	: Vg=1.044097 -> Vg=1.0
% INFO    : Gen at bus 851	: Pg=59.56, Qg=50.82 -> Pg=100.0, Qg=34.415
% INFO    : Gen at bus 851	: Vg=1.00025 -> Vg=1.0
% INFO    : Gen at bus 858	: Pg=855.6, Qg=147.86 -> Pg=666.665, Qg=134.26
% INFO    : Gen at bus 858	: Vg=1.031745 -> Vg=1.0
% INFO    : Gen at bus 891	: Pg=1702.8, Qg=651.53 -> Pg=1600.0, Qg=361.75
% INFO    : Gen at bus 891	: Vg=1.064525 -> Vg=1.0
% INFO    : Gen at bus 972	: Pg=1221.2, Qg=393.14 -> Pg=1333.335, Qg=321.605
% INFO    : Gen at bus 972	: Vg=1.072621 -> Vg=1.0
% INFO    : Gen at bus 1001	: Pg=92.1, Qg=25.97 -> Pg=60.0, Qg=17.605
% INFO    : Gen at bus 1001	: Vg=1.074143 -> Vg=1.0
% INFO    : Gen at bus 1002	: Pg=171.0, Qg=10.89 -> Pg=100.0, Qg=27.2
% INFO    : Gen at bus 1002	: Vg=1.041506 -> Vg=1.0
% INFO    : Gen at bus 1043	: Pg=829.5, Qg=49.0 -> Pg=600.0, Qg=112.24
% INFO    : Gen at bus 1043	: Vg=1.028946 -> Vg=1.0
% INFO    : Gen at bus 1083	: Pg=91.8, Qg=9.85 -> Pg=60.0, Qg=17.515
% INFO    : Gen at bus 1083	: Vg=1.049472 -> Vg=1.0
% INFO    : Gen at bus 1093	: Pg=837.0, Qg=83.03 -> Pg=800.0, Qg=182.77
% INFO    : Gen at bus 1093	: Vg=1.027056 -> Vg=1.0
% INFO    : Gen at bus 1100	: Pg=58.2, Qg=5.6 -> Pg=40.0, Qg=11.895
% INFO    : Gen at bus 1100	: Vg=1.042801 -> Vg=1.0
% INFO    : Gen at bus 1102	: Pg=-124.15, Qg=7.32 -> Pg=-32.77, Qg=13.23
% INFO    : Gen at bus 1102	: Vg=1.049879 -> Vg=1.0
% INFO    : Gen at bus 1237	: Pg=1504.8, Qg=364.78 -> Pg=1333.335, Qg=293.585
% INFO    : Gen at bus 1237	: Vg=1.108028 -> Vg=1.0
% INFO    : Gen at bus 1251	: Pg=837.0, Qg=77.94 -> Pg=800.0, Qg=182.77
% INFO    : Gen at bus 1251	: Vg=1.027102 -> Vg=1.0
% INFO    : Gen at bus 1295	: Pg=-124.1, Qg=4.52 -> Pg=-32.735, Qg=12.02
% INFO    : Gen at bus 1295	: Vg=1.03682 -> Vg=1.0
% INFO    : Gen at bus 1341	: Pg=67.2, Qg=29.74 -> Pg=60.0, Qg=19.705
% INFO    : Gen at bus 1341	: Vg=1.032899 -> Vg=1.0
% INFO    : Gen at bus 1354	: Pg=-246.5, Qg=13.72 -> Pg=-114.335, Qg=13.175
% INFO    : Gen at bus 1354	: Vg=1.041045 -> Vg=1.0
% INFO    : Gen at bus 1422	: Pg=-101.0, Qg=2.33 -> Pg=-17.335, Qg=5.65
% INFO    : Gen at bus 1422	: Vg=1.04353 -> Vg=1.0
% INFO    : Gen at bus 1436	: Pg=49.4, Qg=2.95 -> Pg=40.0, Qg=12.815
% INFO    : Gen at bus 1436	: Vg=1.047684 -> Vg=1.0
% INFO    : Gen at bus 1478	: Pg=62.6, Qg=7.49 -> Pg=40.0, Qg=11.48
% INFO    : Gen at bus 1478	: Vg=1.048068 -> Vg=1.0
% INFO    : Gen at bus 1604	: Pg=50.6, Qg=13.86 -> Pg=40.0, Qg=12.745
% INFO    : Gen at bus 1604	: Vg=1.043862 -> Vg=1.0
% INFO    : Gen at bus 1642	: Pg=50.4, Qg=11.76 -> Pg=40.0, Qg=12.815
% INFO    : Gen at bus 1642	: Vg=1.028554 -> Vg=1.0
% INFO    : Gen at bus 1680	: Pg=1250.4, Qg=274.36 -> Pg=1333.335, Qg=316.395
% INFO    : Gen at bus 1680	: Vg=1.04395 -> Vg=1.0
% INFO    : Gen at bus 1708	: Pg=860.8, Qg=121.94 -> Pg=666.665, Qg=133.035
% INFO    : Gen at bus 1708	: Vg=1.037938 -> Vg=1.0
% INFO    : Gen at bus 1721	: Pg=28.1, Qg=1.73 -> Pg=20.0, Qg=6.065
% INFO    : Gen at bus 1721	: Vg=1.062238 -> Vg=1.0
% INFO    : Gen at bus 1754	: Pg=40.0, Qg=3.62 -> Pg=20.53, Qg=4.535
% INFO    : Gen at bus 1754	: Vg=1.04286 -> Vg=1.0
% INFO    : Gen at bus 1794	: Pg=1250.4, Qg=253.94 -> Pg=1333.335, Qg=314.335
% INFO    : Gen at bus 1794	: Vg=1.05295 -> Vg=1.0
% INFO    : Gen at bus 1808	: Pg=-0.6, Qg=-13.17 -> Pg=49.6, Qg=36.535
% INFO    : Gen at bus 1808	: Vg=1.046224 -> Vg=1.0
% INFO    : Gen at bus 1851	: Pg=15.6, Qg=-1.26 -> Pg=15.96, Qg=1.435
% INFO    : Gen at bus 1851	: Vg=1.04762 -> Vg=1.0
% INFO    : Gen at bus 1852	: Pg=-241.8, Qg=10.63 -> Pg=-111.2, Qg=20.82
% INFO    : Gen at bus 1852	: Vg=1.054325 -> Vg=1.0
% INFO    : Gen at bus 1888	: Pg=573.68, Qg=42.43 -> Pg=612.78, Qg=120.095
% INFO    : Gen at bus 1888	: Vg=1.039377 -> Vg=1.0
% INFO    : Gen at bus 1914	: Pg=115.5, Qg=-45.22 -> Pg=255.755, Qg=4.705
% INFO    : Gen at bus 1914	: Vg=1.035636 -> Vg=1.0
% INFO    : Gen at bus 1959	: Pg=31.0, Qg=0.56 -> Pg=20.0, Qg=5.695
% INFO    : Gen at bus 1959	: Vg=1.064692 -> Vg=1.0
% INFO    : Gen at bus 2035	: Pg=855.6, Qg=149.85 -> Pg=666.665, Qg=135.29
% INFO    : Gen at bus 2035	: Vg=1.03088 -> Vg=1.0
% INFO    : Gen at bus 2050	: Pg=836.2, Qg=-16.43 -> Pg=1333.335, Qg=349.275
% INFO    : Gen at bus 2050	: Vg=1.009914 -> Vg=1.0
% INFO    : Gen at bus 2085	: Pg=176.0, Qg=31.77 -> Pg=100.0, Qg=26.1
% INFO    : Gen at bus 2085	: Vg=1.040351 -> Vg=1.0
% INFO    : Gen at bus 2177	: Pg=-121.3, Qg=13.33 -> Pg=-30.865, Qg=21.045
% INFO    : Gen at bus 2177	: Vg=1.07333 -> Vg=1.0
% INFO    : Gen at bus 2197	: Pg=-53.29, Qg=-1.42 -> Pg=14.475, Qg=2.385
% INFO    : Gen at bus 2197	: Vg=1.035528 -> Vg=1.0
% INFO    : Gen at bus 2276	: Pg=38.9, Qg=-22.64 -> Pg=59.65, Qg=2.585
% INFO    : Gen at bus 2276	: Vg=1.05324 -> Vg=1.0
% INFO    : Gen at bus 2291	: Pg=110.5, Qg=13.69 -> Pg=100.0, Qg=33.38
% INFO    : Gen at bus 2291	: Vg=1.072528 -> Vg=1.0
% INFO    : Gen at bus 2359	: Pg=78.2, Qg=7.2 -> Pg=40.0, Qg=9.425
% INFO    : Gen at bus 2359	: Vg=1.024884 -> Vg=1.0
% INFO    : Gen at bus 2421	: Pg=-320.4, Qg=4.66 -> Pg=-163.6, Qg=12.47
% INFO    : Gen at bus 2421	: Vg=1.047766 -> Vg=1.0
% INFO    : Gen at bus 2425	: Pg=-100.5, Qg=5.31 -> Pg=-17.0, Qg=16.905
% INFO    : Gen at bus 2425	: Vg=1.041186 -> Vg=1.0
% INFO    : Gen at bus 2426	: Pg=-43.2, Qg=-30.65 -> Pg=21.2, Qg=3.16
% INFO    : Gen at bus 2426	: Vg=1.037687 -> Vg=1.0
% INFO    : Gen at bus 2446	: Pg=1367.0, Qg=286.48 -> Pg=1333.335, Qg=308.445
% INFO    : Gen at bus 2446	: Vg=1.06157 -> Vg=1.0
% INFO    : Gen at bus 2468	: Pg=46.8, Qg=5.15 -> Pg=40.0, Qg=13.105
% INFO    : Gen at bus 2468	: Vg=1.048132 -> Vg=1.0
% INFO    : Gen at bus 2481	: Pg=31.8, Qg=11.5 -> Pg=40.0, Qg=14.205
% INFO    : Gen at bus 2481	: Vg=1.042777 -> Vg=1.0
% INFO    : Gen at bus 2489	: Pg=286.5, Qg=-15.8 -> Pg=180.0, Qg=50.305
% INFO    : Gen at bus 2489	: Vg=1.049366 -> Vg=1.0
% INFO    : Gen at bus 2550	: Pg=54.3, Qg=4.31 -> Pg=60.0, Qg=20.87
% INFO    : Gen at bus 2550	: Vg=1.049384 -> Vg=1.0
% INFO    : Gen at bus 2600	: Pg=76.48, Qg=16.9 -> Pg=80.0, Qg=26.245
% INFO    : Gen at bus 2600	: Vg=1.038821 -> Vg=1.0
% INFO    : Gen at bus 2627	: Pg=1367.0, Qg=302.84 -> Pg=1333.335, Qg=308.365
% INFO    : Gen at bus 2627	: Vg=1.061488 -> Vg=1.0
% INFO    : Gen at bus 2653	: Pg=41.92, Qg=3.94 -> Pg=60.0, Qg=14.57
% INFO    : Gen at bus 2653	: Vg=1.036517 -> Vg=1.0
% INFO    : Gen at bus 2719	: Pg=77.6, Qg=-15.35 -> Pg=98.36, Qg=6.025
% INFO    : Gen at bus 2719	: Vg=1.035384 -> Vg=1.0
% INFO    : Gen at bus 2786	: Pg=1221.2, Qg=372.42 -> Pg=1333.335, Qg=321.67
% INFO    : Gen at bus 2786	: Vg=1.073795 -> Vg=1.0
% INFO    : Gen at bus 2797	: Pg=-95.1, Qg=-11.62 -> Pg=-13.4, Qg=26.0
% INFO    : Gen at bus 2797	: Vg=1.042226 -> Vg=1.0
% INFO    : Gen at bus 2799	: Pg=66.8, Qg=-1.21 -> Pg=80.0, Qg=28.125
% INFO    : Gen at bus 2799	: Vg=1.05396 -> Vg=1.0
% INFO    : Gen at bus 2816	: Pg=1250.4, Qg=270.9 -> Pg=1333.335, Qg=314.26
% INFO    : Gen at bus 2816	: Vg=1.053944 -> Vg=1.0
% INFO    : Gen at bus 2841	: Pg=80.7, Qg=-3.29 -> Pg=60.0, Qg=18.61
% INFO    : Gen at bus 2841	: Vg=1.08248 -> Vg=1.0
% INFO    : Gen at bus 2842	: Pg=31.6, Qg=5.75 -> Pg=20.0, Qg=5.725
% INFO    : Gen at bus 2842	: Vg=1.043712 -> Vg=1.0
% INFO    : Gen at bus 2872	: Pg=4.5, Qg=0.33 -> Pg=4.525, Qg=0.385
% INFO    : Gen at bus 2872	: Vg=1.063841 -> Vg=1.0
% INFO    : Gen at bus 2878	: Pg=8.95, Qg=-11.72 -> Pg=107.43, Qg=2.12
% INFO    : Gen at bus 2878	: Vg=1.057626 -> Vg=1.0
% INFO    : Gen at bus 2886	: Pg=60.9, Qg=10.71 -> Pg=60.0, Qg=20.335
% INFO    : Gen at bus 2886	: Vg=1.055151 -> Vg=1.0
% INFO    : Gen at bus 2902	: Pg=20.9, Qg=1.11 -> Pg=20.0, Qg=6.735
% INFO    : Gen at bus 2902	: Vg=1.059072 -> Vg=1.0
% INFO    : Gen at bus 2930	: Pg=53.2, Qg=2.49 -> Pg=40.0, Qg=12.35
% INFO    : Gen at bus 2930	: Vg=1.047695 -> Vg=1.0
% INFO    : Gen at bus 2934	: Pg=3.4, Qg=-0.16 -> Pg=3.415, Qg=0.3
% INFO    : Gen at bus 2934	: Vg=1.051149 -> Vg=1.0
% INFO    : Gen at bus 2985	: Pg=46.6, Qg=-69.84 -> Pg=246.675, Qg=25.895
% INFO    : Gen at bus 2985	: Vg=1.053607 -> Vg=1.0
% INFO    : Gen at bus 3018	: Pg=162.5, Qg=-4.77 -> Pg=100.0, Qg=27.395
% INFO    : Gen at bus 3018	: Vg=1.041705 -> Vg=1.0
% INFO    : Gen at bus 3028	: Pg=855.7, Qg=146.13 -> Pg=666.665, Qg=135.29
% INFO    : Gen at bus 3028	: Vg=1.030654 -> Vg=1.0
% INFO    : Gen at bus 3114	: Pg=38.6, Qg=4.12 -> Pg=20.0, Qg=4.86
% INFO    : Gen at bus 3114	: Vg=1.071964 -> Vg=1.0
% INFO    : Gen at bus 3133	: Pg=85.54, Qg=0.39 -> Pg=120.0, Qg=39.205
% INFO    : Gen at bus 3133	: Vg=1.065372 -> Vg=1.0
% INFO    : Gen at bus 3134	: Pg=-136.3, Qg=-11.71 -> Pg=-40.865, Qg=20.46
% INFO    : Gen at bus 3134	: Vg=1.023117 -> Vg=1.0
% INFO    : Gen at bus 3183	: Pg=98.7, Qg=-3.57 -> Pg=60.0, Qg=16.36
% INFO    : Gen at bus 3183	: Vg=1.055515 -> Vg=1.0
% INFO    : Gen at bus 3205	: Pg=416.7, Qg=119.72 -> Pg=270.0, Qg=77.575
% INFO    : Gen at bus 3205	: Vg=1.041982 -> Vg=1.0
% INFO    : Gen at bus 3218	: Pg=-107.4, Qg=4.44 -> Pg=-21.6, Qg=11.895
% INFO    : Gen at bus 3218	: Vg=1.028507 -> Vg=1.0
% INFO    : Gen at bus 3240	: Pg=-42.3, Qg=-25.61 -> Pg=21.8, Qg=5.43
% INFO    : Gen at bus 3240	: Vg=1.050305 -> Vg=1.0
% INFO    : Gen at bus 3306	: Pg=861.3, Qg=143.67 -> Pg=666.665, Qg=132.885
% INFO    : Gen at bus 3306	: Vg=1.071978 -> Vg=1.0
% INFO    : Gen at bus 3324	: Pg=-26.48, Qg=12.72 -> Pg=32.35, Qg=13.245
% INFO    : Gen at bus 3324	: Vg=1.014126 -> Vg=1.0
% INFO    : Gen at bus 3346	: Pg=56.8, Qg=11.49 -> Pg=40.0, Qg=12.17
% INFO    : Gen at bus 3346	: Vg=1.01594 -> Vg=1.0
% INFO    : Gen at bus 3353	: Pg=19.07, Qg=5.42 -> Pg=40.0, Qg=13.295
% INFO    : Gen at bus 3353	: Vg=1.045739 -> Vg=1.0
% INFO    : Gen at bus 3364	: Pg=44.5, Qg=-21.96 -> Pg=67.635, Qg=2.875
% INFO    : Gen at bus 3364	: Vg=1.0538 -> Vg=1.0
% INFO    : Gen at bus 3390	: Pg=2.4, Qg=12.68 -> Pg=60.0, Qg=17.2
% INFO    : Gen at bus 3390	: Vg=1.039984 -> Vg=1.0
% INFO    : Gen at bus 3422	: Pg=53.7, Qg=-3.24 -> Pg=60.0, Qg=20.845
% INFO    : Gen at bus 3422	: Vg=1.063657 -> Vg=1.0
% INFO    : Gen at bus 3436	: Pg=521.0, Qg=217.43 -> Pg=800.0, Qg=183.04
% INFO    : Gen at bus 3436	: Vg=1.060777 -> Vg=1.0
% INFO    : Gen at bus 3492	: Pg=-370.8, Qg=2.02 -> Pg=-197.2, Qg=16.335
% INFO    : Gen at bus 3492	: Vg=1.04852 -> Vg=1.0
% INFO    : Gen at bus 3513	: Pg=829.8, Qg=51.0 -> Pg=600.0, Qg=112.24
% INFO    : Gen at bus 3513	: Vg=1.028771 -> Vg=1.0
% INFO    : Gen at bus 3565	: Pg=15.88, Qg=2.27 -> Pg=40.0, Qg=13.93
% INFO    : Gen at bus 3565	: Vg=1.081614 -> Vg=1.0
% INFO    : Gen at bus 3580	: Pg=539.0, Qg=189.12 -> Pg=300.0, Qg=77.17
% INFO    : Gen at bus 3580	: Vg=1.07602 -> Vg=1.0
% INFO    : Gen at bus 3611	: Pg=-125.4, Qg=3.51 -> Pg=-33.6, Qg=17.235
% INFO    : Gen at bus 3611	: Vg=1.03905 -> Vg=1.0
% INFO    : Gen at bus 3656	: Pg=-26.2, Qg=12.26 -> Pg=32.535, Qg=41.375
% INFO    : Gen at bus 3656	: Vg=1.070983 -> Vg=1.0
% INFO    : Gen at bus 3661	: Pg=861.2, Qg=118.75 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 3661	: Vg=1.059676 -> Vg=1.0
% INFO    : Gen at bus 3698	: Pg=-12.58, Qg=3.09 -> Pg=41.61, Qg=11.435
% INFO    : Gen at bus 3698	: Vg=1.041813 -> Vg=1.0
% INFO    : Gen at bus 3741	: Pg=854.7, Qg=190.06 -> Pg=800.0, Qg=180.705
% INFO    : Gen at bus 3741	: Vg=1.031629 -> Vg=1.0
% INFO    : Gen at bus 3809	: Pg=257.0, Qg=122.15 -> Pg=466.665, Qg=98.14
% INFO    : Gen at bus 3809	: Vg=1.084785 -> Vg=1.0
% INFO    : Gen at bus 3825	: Pg=837.3, Qg=54.8 -> Pg=600.0, Qg=112.385
% INFO    : Gen at bus 3825	: Vg=1.026994 -> Vg=1.0
% INFO    : Gen at bus 3869	: Pg=855.6, Qg=148.23 -> Pg=666.665, Qg=134.275
% INFO    : Gen at bus 3869	: Vg=1.031907 -> Vg=1.0
% INFO    : Gen at bus 3876	: Pg=-25.1, Qg=6.45 -> Pg=33.265, Qg=9.375
% INFO    : Gen at bus 3876	: Vg=1.044501 -> Vg=1.0
% INFO    : Gen at bus 3916	: Pg=-21.27, Qg=11.22 -> Pg=35.815, Qg=13.125
% INFO    : Gen at bus 3916	: Vg=1.043758 -> Vg=1.0
% INFO    : Gen at bus 3951	: Pg=-27.1, Qg=-74.05 -> Pg=31.935, Qg=-0.7
% INFO    : Gen at bus 3951	: Vg=1.027439 -> Vg=1.0
% INFO    : Gen at bus 3971	: Pg=-134.5, Qg=9.64 -> Pg=-39.665, Qg=18.29
% INFO    : Gen at bus 3971	: Vg=1.063145 -> Vg=1.0
% INFO    : Gen at bus 4024	: Pg=89.5, Qg=40.38 -> Pg=100.0, Qg=34.815
% INFO    : Gen at bus 4024	: Vg=1.040328 -> Vg=1.0
% INFO    : Gen at bus 4056	: Pg=-76.9, Qg=3.73 -> Pg=-1.265, Qg=13.14
% INFO    : Gen at bus 4056	: Vg=1.038526 -> Vg=1.0
% INFO    : Gen at bus 4084	: Pg=366.1, Qg=46.44 -> Pg=300.0, Qg=80.6
% INFO    : Gen at bus 4084	: Vg=1.063234 -> Vg=1.0
% INFO    : Gen at bus 4118	: Pg=41.0, Qg=5.09 -> Pg=40.0, Qg=13.485
% INFO    : Gen at bus 4118	: Vg=1.027195 -> Vg=1.0
% INFO    : Gen at bus 4125	: Pg=59.6, Qg=16.3 -> Pg=40.0, Qg=11.945
% INFO    : Gen at bus 4125	: Vg=1.003502 -> Vg=1.0
% INFO    : Gen at bus 4128	: Pg=67.5, Qg=24.27 -> Pg=60.0, Qg=19.7
% INFO    : Gen at bus 4128	: Vg=1.019761 -> Vg=1.0
% INFO    : Gen at bus 4231	: Pg=2641.24, Qg=771.6 -> Pg=2761.14, Qg=0.0
% INFO    : Gen at bus 4231	: Vg=1.049182 -> Vg=1.0
% INFO    : Gen at bus 4331	: Pg=60.2, Qg=6.92 -> Pg=40.0, Qg=11.805
% INFO    : Gen at bus 4331	: Vg=1.028646 -> Vg=1.0
% INFO    : Gen at bus 4395	: Pg=-129.1, Qg=6.73 -> Pg=-36.065, Qg=13.575
% INFO    : Gen at bus 4395	: Vg=1.039834 -> Vg=1.0
% INFO    : Gen at bus 4419	: Pg=861.3, Qg=121.55 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 4419	: Vg=1.059565 -> Vg=1.0
% INFO    : Gen at bus 4480	: Pg=861.3, Qg=143.79 -> Pg=666.665, Qg=132.885
% INFO    : Gen at bus 4480	: Vg=1.071852 -> Vg=1.0
% INFO    : Gen at bus 4482	: Pg=35.2, Qg=13.53 -> Pg=40.0, Qg=13.95
% INFO    : Gen at bus 4482	: Vg=1.049914 -> Vg=1.0
% INFO    : Gen at bus 4506	: Pg=-171.8, Qg=12.84 -> Pg=-64.535, Qg=12.955
% INFO    : Gen at bus 4506	: Vg=1.036047 -> Vg=1.0
% INFO    : Gen at bus 4566	: Pg=-30.39, Qg=6.81 -> Pg=29.745, Qg=13.035
% INFO    : Gen at bus 4566	: Vg=1.073282 -> Vg=1.0
% INFO    : Gen at bus 4624	: Pg=68.0, Qg=8.25 -> Pg=40.0, Qg=10.715
% INFO    : Gen at bus 4624	: Vg=1.042135 -> Vg=1.0
% INFO    : Gen at bus 4661	: Pg=-78.9, Qg=2.19 -> Pg=-2.6, Qg=6.685
% INFO    : Gen at bus 4661	: Vg=1.049813 -> Vg=1.0
% INFO    : Gen at bus 4701	: Pg=93.2, Qg=-41.31 -> Pg=140.925, Qg=6.055
% INFO    : Gen at bus 4701	: Vg=1.043063 -> Vg=1.0
% INFO    : Gen at bus 4783	: Pg=861.3, Qg=141.62 -> Pg=666.665, Qg=132.885
% INFO    : Gen at bus 4783	: Vg=1.071981 -> Vg=1.0
% INFO    : Gen at bus 4816	: Pg=-26.08, Qg=10.07 -> Pg=32.615, Qg=13.465
% INFO    : Gen at bus 4816	: Vg=1.067305 -> Vg=1.0
% INFO    : Gen at bus 4819	: Pg=855.6, Qg=150.1 -> Pg=666.665, Qg=134.275
% INFO    : Gen at bus 4819	: Vg=1.031907 -> Vg=1.0
% INFO    : Gen at bus 4823	: Pg=10.3, Qg=1.59 -> Pg=5.23, Qg=1.185
% INFO    : Gen at bus 4823	: Vg=1.067114 -> Vg=1.0
% INFO    : Gen at bus 4850	: Pg=88.8, Qg=11.86 -> Pg=80.0, Qg=26.665
% INFO    : Gen at bus 4850	: Vg=1.054975 -> Vg=1.0
% INFO    : Gen at bus 4880	: Pg=-40.3, Qg=5.06 -> Pg=23.135, Qg=25.83
% INFO    : Gen at bus 4880	: Vg=1.034991 -> Vg=1.0
% INFO    : Gen at bus 4918	: Pg=41.69, Qg=8.64 -> Pg=40.0, Qg=12.35
% INFO    : Gen at bus 4918	: Vg=1.057325 -> Vg=1.0
% INFO    : Gen at bus 4952	: Pg=-12.57, Qg=4.47 -> Pg=41.615, Qg=12.31
% INFO    : Gen at bus 4952	: Vg=1.045386 -> Vg=1.0
% INFO    : Gen at bus 5004	: Pg=54.3, Qg=4.85 -> Pg=110.06, Qg=2.16
% INFO    : Gen at bus 5004	: Vg=1.0663 -> Vg=1.0
% INFO    : Gen at bus 5019	: Pg=49.4, Qg=2.95 -> Pg=40.0, Qg=12.815
% INFO    : Gen at bus 5019	: Vg=1.047693 -> Vg=1.0
% INFO    : Gen at bus 5051	: Pg=83.48, Qg=-1.38 -> Pg=80.0, Qg=24.79
% INFO    : Gen at bus 5051	: Vg=1.037373 -> Vg=1.0
% INFO    : Gen at bus 5067	: Pg=542.0, Qg=142.39 -> Pg=300.0, Qg=74.665
% INFO    : Gen at bus 5067	: Vg=1.021924 -> Vg=1.0
% INFO    : Gen at bus 5110	: Pg=-52.51, Qg=8.27 -> Pg=14.995, Qg=13.39
% INFO    : Gen at bus 5110	: Vg=1.032061 -> Vg=1.0
% INFO    : Gen at bus 5120	: Pg=75.6, Qg=-5.04 -> Pg=60.0, Qg=18.965
% INFO    : Gen at bus 5120	: Vg=1.055539 -> Vg=1.0
% INFO    : Gen at bus 5144	: Pg=1713.6, Qg=139.22 -> Pg=1333.335, Qg=269.81
% INFO    : Gen at bus 5144	: Vg=1.035201 -> Vg=1.0
% INFO    : Gen at bus 5237	: Pg=106.8, Qg=10.9 -> Pg=80.0, Qg=25.14
% INFO    : Gen at bus 5237	: Vg=1.052719 -> Vg=1.0
% INFO    : Gen at bus 5278	: Pg=119.4, Qg=-0.06 -> Pg=60.0, Qg=13.905
% INFO    : Gen at bus 5278	: Vg=1.042037 -> Vg=1.0
% INFO    : Gen at bus 5340	: Pg=-159.0, Qg=11.05 -> Pg=-56.0, Qg=11.47
% INFO    : Gen at bus 5340	: Vg=1.054941 -> Vg=1.0
% INFO    : Gen at bus 5365	: Pg=19.59, Qg=1.13 -> Pg=20.0, Qg=5.695
% INFO    : Gen at bus 5365	: Vg=1.061754 -> Vg=1.0
% INFO    : Gen at bus 5379	: Pg=1250.6, Qg=358.22 -> Pg=1333.335, Qg=314.42
% INFO    : Gen at bus 5379	: Vg=1.107976 -> Vg=1.0
% INFO    : Gen at bus 5395	: Pg=-395.8, Qg=3.01 -> Pg=-213.865, Qg=20.7
% INFO    : Gen at bus 5395	: Vg=1.048137 -> Vg=1.0
% INFO    : Gen at bus 5461	: Pg=43.4, Qg=10.92 -> Pg=40.0, Qg=13.355
% INFO    : Gen at bus 5461	: Vg=1.06213 -> Vg=1.0
% INFO    : Gen at bus 5481	: Pg=1368.6, Qg=146.68 -> Pg=1333.335, Qg=307.335
% INFO    : Gen at bus 5481	: Vg=1.063711 -> Vg=1.0
% INFO    : Gen at bus 5482	: Pg=56.8, Qg=-22.21 -> Pg=124.53, Qg=26.6
% INFO    : Gen at bus 5482	: Vg=1.044486 -> Vg=1.0
% INFO    : Gen at bus 5486	: Pg=861.3, Qg=119.59 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 5486	: Vg=1.059636 -> Vg=1.0
% INFO    : Gen at bus 5488	: Pg=-96.4, Qg=14.63 -> Pg=-14.265, Qg=12.58
% INFO    : Gen at bus 5488	: Vg=1.041881 -> Vg=1.0
% INFO    : Gen at bus 5490	: Pg=3424.8, Qg=295.7 -> Pg=2666.665, Qg=539.345
% INFO    : Gen at bus 5490	: Vg=1.068845 -> Vg=1.0
% INFO    : Gen at bus 5533	: Pg=173.0, Qg=14.6 -> Pg=100.0, Qg=26.58
% INFO    : Gen at bus 5533	: Vg=1.038212 -> Vg=1.0
% INFO    : Gen at bus 5546	: Pg=21.5, Qg=1.97 -> Pg=20.0, Qg=6.705
% INFO    : Gen at bus 5546	: Vg=1.05378 -> Vg=1.0
% INFO    : Gen at bus 5564	: Pg=57.6, Qg=11.81 -> Pg=40.0, Qg=11.905
% INFO    : Gen at bus 5564	: Vg=1.04123 -> Vg=1.0
% INFO    : Gen at bus 5658	: Pg=229.8, Qg=77.84 -> Pg=120.0, Qg=28.465
% INFO    : Gen at bus 5658	: Vg=1.017689 -> Vg=1.0
% INFO    : Gen at bus 5664	: Pg=128.0, Qg=14.87 -> Pg=80.0, Qg=22.83
% INFO    : Gen at bus 5664	: Vg=1.070507 -> Vg=1.0
% INFO    : Gen at bus 5709	: Pg=837.0, Qg=75.6 -> Pg=800.0, Qg=182.77
% INFO    : Gen at bus 5709	: Vg=1.027078 -> Vg=1.0
% INFO    : Gen at bus 5781	: Pg=1102.83, Qg=396.26 -> Pg=1200.0, Qg=227.25
% INFO    : Gen at bus 5781	: Vg=1.0396 -> Vg=1.0
% INFO    : Gen at bus 5814	: Pg=181.2, Qg=41.72 -> Pg=293.335, Qg=59.905
% INFO    : Gen at bus 5814	: Vg=1.044051 -> Vg=1.0
% INFO    : Gen at bus 5856	: Pg=305.7, Qg=19.99 -> Pg=320.0, Qg=64.565
% INFO    : Gen at bus 5856	: Vg=1.038417 -> Vg=1.0
% INFO    : Gen at bus 5881	: Pg=60.0, Qg=7.13 -> Pg=40.0, Qg=11.795
% INFO    : Gen at bus 5881	: Vg=1.065605 -> Vg=1.0
% INFO    : Gen at bus 5940	: Pg=-74.9, Qg=4.51 -> Pg=0.065, Qg=4.74
% INFO    : Gen at bus 5940	: Vg=1.030075 -> Vg=1.0
% INFO    : Gen at bus 5971	: Pg=1221.2, Qg=370.23 -> Pg=1333.335, Qg=321.45
% INFO    : Gen at bus 5971	: Vg=1.070056 -> Vg=1.0
% INFO    : Gen at bus 5983	: Pg=-102.5, Qg=3.55 -> Pg=-18.335, Qg=12.34
% INFO    : Gen at bus 5983	: Vg=1.066029 -> Vg=1.0
% INFO    : Gen at bus 5994	: Pg=-87.3, Qg=-16.58 -> Pg=-8.2, Qg=-0.285
% INFO    : Gen at bus 5994	: Vg=1.029184 -> Vg=1.0
% INFO    : Gen at bus 6036	: Pg=820.2, Qg=300.86 -> Pg=600.0, Qg=114.62
% INFO    : Gen at bus 6036	: Vg=1.043738 -> Vg=1.0
% INFO    : Gen at bus 6153	: Pg=94.3, Qg=-78.07 -> Pg=401.01, Qg=-6.085
% INFO    : Gen at bus 6153	: Vg=0.988112 -> Vg=1.0
% INFO    : Gen at bus 6168	: Pg=26.3, Qg=0.4 -> Pg=26.88, Qg=2.465
% INFO    : Gen at bus 6168	: Vg=1.040343 -> Vg=1.0
% INFO    : Gen at bus 6291	: Pg=55.5, Qg=24.55 -> Pg=60.0, Qg=20.76
% INFO    : Gen at bus 6291	: Vg=1.040598 -> Vg=1.0
% INFO    : Gen at bus 6331	: Pg=48.8, Qg=5.01 -> Pg=40.0, Qg=12.855
% INFO    : Gen at bus 6331	: Vg=1.052181 -> Vg=1.0
% INFO    : Gen at bus 6332	: Pg=96.0, Qg=-9.58 -> Pg=100.0, Qg=34.305
% INFO    : Gen at bus 6332	: Vg=1.062214 -> Vg=1.0
% INFO    : Gen at bus 6351	: Pg=22.08, Qg=14.99 -> Pg=40.0, Qg=13.365
% INFO    : Gen at bus 6351	: Vg=1.064446 -> Vg=1.0
% INFO    : Gen at bus 6368	: Pg=-145.3, Qg=3.0 -> Pg=-46.865, Qg=13.825
% INFO    : Gen at bus 6368	: Vg=1.043835 -> Vg=1.0
% INFO    : Gen at bus 6376	: Pg=-27.8, Qg=-23.17 -> Pg=31.465, Qg=48.96
% INFO    : Gen at bus 6376	: Vg=1.046714 -> Vg=1.0
% INFO    : Gen at bus 6429	: Pg=171.0, Qg=18.2 -> Pg=100.0, Qg=26.57
% INFO    : Gen at bus 6429	: Vg=1.039574 -> Vg=1.0
% INFO    : Gen at bus 6474	: Pg=718.5, Qg=-12.86 -> Pg=666.665, Qg=132.285
% INFO    : Gen at bus 6474	: Vg=1.06557 -> Vg=1.0
% INFO    : Gen at bus 6516	: Pg=228.2, Qg=12.73 -> Pg=140.0, Qg=39.45
% INFO    : Gen at bus 6516	: Vg=1.052452 -> Vg=1.0
% INFO    : Gen at bus 6552	: Pg=-204.2, Qg=5.93 -> Pg=-86.135, Qg=12.71
% INFO    : Gen at bus 6552	: Vg=1.048796 -> Vg=1.0
% INFO    : Gen at bus 6734	: Pg=382.7, Qg=-77.78 -> Pg=360.0, Qg=89.715
% INFO    : Gen at bus 6734	: Vg=1.061492 -> Vg=1.0
% INFO    : Gen at bus 6807	: Pg=44.07, Qg=31.99 -> Pg=80.0, Qg=27.34
% INFO    : Gen at bus 6807	: Vg=1.006037 -> Vg=1.0
% INFO    : Gen at bus 6816	: Pg=16.53, Qg=-8.62 -> Pg=80.0, Qg=27.545
% INFO    : Gen at bus 6816	: Vg=1.053803 -> Vg=1.0
% INFO    : Gen at bus 6820	: Pg=15.9, Qg=-0.62 -> Pg=16.265, Qg=1.465
% INFO    : Gen at bus 6820	: Vg=1.049557 -> Vg=1.0
% INFO    : Gen at bus 6831	: Pg=-57.5, Qg=4.01 -> Pg=11.665, Qg=10.685
% INFO    : Gen at bus 6831	: Vg=1.031347 -> Vg=1.0
% INFO    : Gen at bus 6845	: Pg=102.9, Qg=17.09 -> Pg=60.0, Qg=15.885
% INFO    : Gen at bus 6845	: Vg=1.055216 -> Vg=1.0
% INFO    : Gen at bus 6852	: Pg=-344.9, Qg=1.84 -> Pg=-179.935, Qg=6.11
% INFO    : Gen at bus 6852	: Vg=1.031296 -> Vg=1.0
% INFO    : Gen at bus 6857	: Pg=2463.6, Qg=391.48 -> Pg=2666.665, Qg=639.94
% INFO    : Gen at bus 6857	: Vg=1.021411 -> Vg=1.0
% INFO    : Gen at bus 6888	: Pg=133.0, Qg=6.97 -> Pg=194.335, Qg=64.72
% INFO    : Gen at bus 6888	: Vg=1.039234 -> Vg=1.0
% INFO    : Gen at bus 6947	: Pg=227.5, Qg=5.93 -> Pg=140.0, Qg=38.9
% INFO    : Gen at bus 6947	: Vg=1.051367 -> Vg=1.0
% INFO    : Gen at bus 6969	: Pg=39.8, Qg=-1.81 -> Pg=40.0, Qg=13.63
% INFO    : Gen at bus 6969	: Vg=1.059486 -> Vg=1.0
% INFO    : Gen at bus 6982	: Pg=-12.6, Qg=9.53 -> Pg=41.6, Qg=18.89
% INFO    : Gen at bus 6982	: Vg=1.036531 -> Vg=1.0
% INFO    : Gen at bus 7036	: Pg=65.8, Qg=11.07 -> Pg=40.0, Qg=11.22
% INFO    : Gen at bus 7036	: Vg=1.041241 -> Vg=1.0
% INFO    : Gen at bus 7049	: Pg=55.5, Qg=16.47 -> Pg=60.0, Qg=20.81
% INFO    : Gen at bus 7049	: Vg=1.049669 -> Vg=1.0
% INFO    : Gen at bus 7056	: Pg=448.85, Qg=137.55 -> Pg=400.0, Qg=83.19
% INFO    : Gen at bus 7056	: Vg=1.006597 -> Vg=1.0
% INFO    : Gen at bus 7115	: Pg=65.87, Qg=13.66 -> Pg=136.14, Qg=5.86
% INFO    : Gen at bus 7115	: Vg=1.008722 -> Vg=1.0
% INFO    : Gen at bus 7159	: Pg=861.3, Qg=121.21 -> Pg=666.665, Qg=134.495
% INFO    : Gen at bus 7159	: Vg=1.059575 -> Vg=1.0
% INFO    : Gen at bus 7183	: Pg=1250.6, Qg=358.08 -> Pg=1333.335, Qg=314.42
% INFO    : Gen at bus 7183	: Vg=1.107733 -> Vg=1.0
% INFO    : Gen at bus 7209	: Pg=7.3, Qg=0.36 -> Pg=3.675, Qg=0.83
% INFO    : Gen at bus 7209	: Vg=1.051113 -> Vg=1.0
% INFO    : Gen at bus 7267	: Pg=-39.7, Qg=22.41 -> Pg=23.535, Qg=27.5
% INFO    : Gen at bus 7267	: Vg=1.010817 -> Vg=1.0
% INFO    : Gen at bus 7282	: Pg=2340.4, Qg=94.47 -> Pg=2666.665, Qg=637.065
% INFO    : Gen at bus 7282	: Vg=1.034538 -> Vg=1.0
% INFO    : Gen at bus 7327	: Pg=59.06, Qg=19.56 -> Pg=80.0, Qg=26.245
% INFO    : Gen at bus 7327	: Vg=1.043172 -> Vg=1.0
% INFO    : Gen at bus 7328	: Pg=53.0, Qg=24.18 -> Pg=40.0, Qg=12.53
% INFO    : Gen at bus 7328	: Vg=0.999675 -> Vg=1.0
% INFO    : Gen at bus 7466	: Pg=-202.53, Qg=33.59 -> Pg=-85.02, Qg=-0.605
% INFO    : Gen at bus 7466	: Vg=1.057257 -> Vg=1.0
% INFO    : Gen at bus 7474	: Pg=76.5, Qg=8.44 -> Pg=60.0, Qg=18.93
% INFO    : Gen at bus 7474	: Vg=1.027108 -> Vg=1.0
% INFO    : Gen at bus 7495	: Pg=75.8, Qg=67.52 -> Pg=125.265, Qg=77.23
% INFO    : Gen at bus 7495	: Vg=1.035256 -> Vg=1.0
% INFO    : Gen at bus 7520	: Pg=702.4, Qg=277.3 -> Pg=533.335, Qg=104.815
% INFO    : Gen at bus 7520	: Vg=1.037447 -> Vg=1.0
% INFO    : Gen at bus 7522	: Pg=508.0, Qg=235.59 -> Pg=533.335, Qg=125.72
% INFO    : Gen at bus 7522	: Vg=0.99994 -> Vg=1.0
% INFO    : Gen at bus 7641	: Pg=769.2, Qg=22.2 -> Pg=540.0, Qg=107.93
% INFO    : Gen at bus 7641	: Vg=1.051427 -> Vg=1.0
% INFO    : Gen at bus 7697	: Pg=228.2, Qg=12.72 -> Pg=140.0, Qg=39.45
% INFO    : Gen at bus 7697	: Vg=1.052424 -> Vg=1.0
% INFO    : Gen at bus 7776	: Pg=1221.2, Qg=354.58 -> Pg=1333.335, Qg=321.605
% INFO    : Gen at bus 7776	: Vg=1.072261 -> Vg=1.0
% INFO    : Gen at bus 7808	: Pg=1250.4, Qg=279.8 -> Pg=1333.335, Qg=314.335
% INFO    : Gen at bus 7808	: Vg=1.054562 -> Vg=1.0
% INFO    : Gen at bus 7842	: Pg=165.0, Qg=23.34 -> Pg=100.0, Qg=27.76
% INFO    : Gen at bus 7842	: Vg=1.001912 -> Vg=1.0
% INFO    : Gen at bus 7913	: Pg=1368.6, Qg=146.28 -> Pg=1333.335, Qg=307.415
% INFO    : Gen at bus 7913	: Vg=1.063764 -> Vg=1.0
% INFO    : Gen at bus 7998	: Pg=811.8, Qg=175.43 -> Pg=600.0, Qg=115.31
% INFO    : Gen at bus 7998	: Vg=1.048854 -> Vg=1.0
% INFO    : Gen at bus 8043	: Pg=-27.0, Qg=4.11 -> Pg=32.0, Qg=25.855
% INFO    : Gen at bus 8043	: Vg=1.066913 -> Vg=1.0
% INFO    : Gen at bus 8109	: Pg=992.0, Qg=864.28 -> Pg=520.8, Qg=0.0
% INFO    : Gen at bus 8109	: Vg=1.067387 -> Vg=1.0
% INFO    : Gen at bus 8158	: Pg=153.0, Qg=-2.71 -> Pg=100.0, Qg=29.33
% INFO    : Gen at bus 8158	: Vg=1.052602 -> Vg=1.0
% INFO    : Gen at bus 8222	: Pg=66.8, Qg=17.58 -> Pg=40.0, Qg=10.855
% INFO    : Gen at bus 8222	: Vg=1.02335 -> Vg=1.0
% INFO    : Gen at bus 8225	: Pg=17.0, Qg=6.35 -> Pg=20.0, Qg=7.035
% INFO    : Gen at bus 8225	: Vg=1.071504 -> Vg=1.0
% INFO    : Gen at bus 8267	: Pg=203.4, Qg=-3.04 -> Pg=120.0, Qg=32.14
% INFO    : Gen at bus 8267	: Vg=1.043326 -> Vg=1.0
% INFO    : Gen at bus 8311	: Pg=-8.75, Qg=3.43 -> Pg=44.17, Qg=5.335
% INFO    : Gen at bus 8311	: Vg=1.035451 -> Vg=1.0
% INFO    : Gen at bus 8312	: Pg=1702.2, Qg=433.08 -> Pg=1600.0, Qg=360.845
% INFO    : Gen at bus 8312	: Vg=1.07814 -> Vg=1.0
% INFO    : Gen at bus 8458	: Pg=517.1, Qg=-58.18 -> Pg=666.665, Qg=167.965
% INFO    : Gen at bus 8458	: Vg=1.042925 -> Vg=1.0
% INFO    : Gen at bus 8473	: Pg=-135.0, Qg=-7.13 -> Pg=-40.0, Qg=27.88
% INFO    : Gen at bus 8473	: Vg=1.039202 -> Vg=1.0
% INFO    : Gen at bus 8486	: Pg=78.8, Qg=9.58 -> Pg=40.0, Qg=9.245
% INFO    : Gen at bus 8486	: Vg=1.04752 -> Vg=1.0
% INFO    : Gen at bus 8515	: Pg=32.3, Qg=-18.17 -> Pg=100.0, Qg=30.8
% INFO    : Gen at bus 8515	: Vg=1.053872 -> Vg=1.0
% INFO    : Gen at bus 8522	: Pg=-75.69, Qg=1.02 -> Pg=-0.46, Qg=0.96
% INFO    : Gen at bus 8522	: Vg=1.019671 -> Vg=1.0
% INFO    : Gen at bus 8564	: Pg=-65.0, Qg=20.7 -> Pg=6.665, Qg=14.525
% INFO    : Gen at bus 8564	: Vg=1.019727 -> Vg=1.0
% INFO    : Gen at bus 8670	: Pg=-138.3, Qg=10.82 -> Pg=-42.2, Qg=12.47
% INFO    : Gen at bus 8670	: Vg=1.049066 -> Vg=1.0
% INFO    : Gen at bus 8676	: Pg=-259.1, Qg=12.69 -> Pg=-122.735, Qg=9.98
% INFO    : Gen at bus 8676	: Vg=1.018762 -> Vg=1.0
% INFO    : Gen at bus 8683	: Pg=-37.28, Qg=0.32 -> Pg=25.15, Qg=16.965
% INFO    : Gen at bus 8683	: Vg=1.041975 -> Vg=1.0
% INFO    : Gen at bus 8721	: Pg=1232.6, Qg=152.55 -> Pg=1333.335, Qg=319.77
% INFO    : Gen at bus 8721	: Vg=1.054052 -> Vg=1.0
% INFO    : Gen at bus 8795	: Pg=166.2, Qg=-6.14 -> Pg=120.0, Qg=36.925
% INFO    : Gen at bus 8795	: Vg=1.054157 -> Vg=1.0
% INFO    : Gen at bus 8807	: Pg=-304.0, Qg=3.53 -> Pg=-152.665, Qg=10.885
% INFO    : Gen at bus 8807	: Vg=1.05109 -> Vg=1.0
% INFO    : Gen at bus 8818	: Pg=44.66, Qg=-2.57 -> Pg=80.0, Qg=27.06
% INFO    : Gen at bus 8818	: Vg=1.050791 -> Vg=1.0
% INFO    : Gen at bus 8872	: Pg=1232.6, Qg=140.05 -> Pg=1333.335, Qg=319.77
% INFO    : Gen at bus 8872	: Vg=1.053844 -> Vg=1.0
% INFO    : Gen at bus 8903	: Pg=17.0, Qg=-1.08 -> Pg=43.365, Qg=0.29
% INFO    : Gen at bus 8903	: Vg=1.020268 -> Vg=1.0
% INFO    : Gen at bus 8950	: Pg=-255.7, Qg=7.67 -> Pg=-120.47, Qg=13.31
% INFO    : Gen at bus 8950	: Vg=1.047268 -> Vg=1.0
% INFO    : Gen at bus 8961	: Pg=-61.8, Qg=-11.18 -> Pg=8.8, Qg=1.57
% INFO    : Gen at bus 8961	: Vg=1.035459 -> Vg=1.0
% INFO    : Gen at bus 8976	: Pg=110.0, Qg=15.22 -> Pg=100.0, Qg=33.35
% INFO    : Gen at bus 8976	: Vg=1.046972 -> Vg=1.0
% INFO    : Gen at bus 8997	: Pg=78.2, Qg=-5.23 -> Pg=158.545, Qg=3.055
% INFO    : Gen at bus 8997	: Vg=0.997131 -> Vg=1.0
% INFO    : Gen at bus 9067	: Pg=369.6, Qg=48.34 -> Pg=293.335, Qg=60.865
% INFO    : Gen at bus 9067	: Vg=1.040924 -> Vg=1.0
% INFO    : Gen at bus 9101	: Pg=698.8, Qg=0.54 -> Pg=666.665, Qg=136.535
% INFO    : Gen at bus 9101	: Vg=1.02885 -> Vg=1.0
% INFO    : Gen at bus 9108	: Pg=-239.23, Qg=-1.6 -> Pg=-109.485, Qg=2.245
% INFO    : Gen at bus 9108	: Vg=1.046626 -> Vg=1.0
% INFO    : Gen at bus 9137	: Pg=42.7, Qg=18.81 -> Pg=64.235, Qg=121.365
% INFO    : Gen at bus 9137	: Vg=1.049768 -> Vg=1.0
% INFO    : Gen at bus 9140	: Pg=-37.2, Qg=28.17 -> Pg=25.2, Qg=23.355
% INFO    : Gen at bus 9140	: Vg=1.049624 -> Vg=1.0
% INFO    : Gen at bus 9150	: Pg=860.8, Qg=117.32 -> Pg=666.665, Qg=133.05
% INFO    : Gen at bus 9150	: Vg=1.037969 -> Vg=1.0
% INFO    : Gen at bus 9174	: Pg=-331.4, Qg=142.7 -> Pg=-170.935, Qg=62.92
% INFO    : Gen at bus 9174	: Vg=1.03623 -> Vg=1.0
% INFO    : Gen at bus 9180	: Pg=72.0, Qg=7.71 -> Pg=80.0, Qg=27.86
% INFO    : Gen at bus 9180	: Vg=1.061189 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
